(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5982,        212]*)
(*NotebookOutlinePosition[      7125,        250]*)
(*  CellTagsIndexPosition[      7021,        243]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Ancestors and Descendants", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"Ancestors", "[", 
              RowBox[{"g", ",", 
                StyleBox["node",
                  FontSlant->"Italic"]}], 
              "]"}], \(\(lists\)\(\ \)\(all\)\(\ \)\(the\)\(\ \)\(ancestors\)\
\(\ \)\(of\)\(\ \)\(the\)\(\ \)\(\(node\)\(.\)\)\(\ \ \)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"Ancestors"],

Cell["These are the ancestors of node {a}:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ancestors[tr, {a}]\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \({{a, b, c, d, e, f, g, h}, {a, b}}\)], "Output",
  CellLabel->"Out[63]="]
}, Closed]],

Cell["The root node has no ancestors:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ancestors[tr, {a, b, c, d, e, f, gg, h}]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[64]="]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"Descendants", "[", 
              RowBox[{"g", ",", 
                StyleBox["node",
                  FontSlant->"Italic"]}], 
              "]"}], \(lists\ the\ immediate\ descendants\ of\ the\ \
\(\(node\)\(.\)\)\)},
          {
            RowBox[{"Descendants", "[", 
              RowBox[{"g", ",", 
                StyleBox["node",
                  FontSlant->"Italic"], ",", \(DescendantList \[Rule] All\)}],
               "]"}], \(lists\ all\ the\ descendants\ of\ the\ \
\(\(node\)\(.\)\)\)},
          {
            RowBox[{"Descendants", "[", 
              RowBox[{"g", ",", 
                StyleBox["node",
                  FontSlant->"Italic"], 
                ",", \(DescendantList \[Rule] Leaves\)}], 
              "]"}], \(lists\ the\ descendant\ leaves\ of\ the\ \(\(node\)\(.\
\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"Descendants"],

Cell[TextData[{
  "These are the ",
  StyleBox["immediate",
    FontSlant->"Italic"],
  " descendants of the root node {a,b,c,d,e,f,g,h}."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Descendants[tr, {a, b, c, d, e, f, gg, h}]\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \({{a, b}, {c, d, e, f, g, h}}\)], "Output",
  CellLabel->"Out[70]="]
}, Closed]],

Cell[TextData[{
  "The ",
  StyleBox["ultimate",
    FontSlant->"Italic"],
  " descendants can be found by setting ",
  "DescendantList\[Rule]All",
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Descendants[tr, {a, b, c, d, e, f, gg, h}, DescendantList \[Rule] All]
      \)], "Input",
  CellLabel->"In[594]:="],

Cell[BoxData[
    \({{a, b}, {c, d, e, f, gg, h}, {a}, {b}, {c, d}, {e, f, gg, h}, {c}, {
        d}, {e, f, gg}, {h}, {e}, {f}, {gg}}\)], "Output",
  CellLabel->"Out[594]="]
}, Closed]],

Cell["This lists just the descendant leaves:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Descendants[tr, {a, b, c, d, e, f, gg, h}, 
      DescendantList \[Rule] Leaves]\)], "Input",
  CellLabel->"In[595]:="],

Cell[BoxData[
    \({{a}, {b}, {c}, {d}, {e}, {f}, {gg}, {h}}\)], "Output",
  CellLabel->"Out[595]="]
}, Closed]],

Cell["This could also be done using ExtractGenealogy[]:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CollapseGenealogy[ExtractGenealogy[tr, {a, b, c, d, e, f, gg, h}], 
      Node \[Rule] False, Nested \[Rule] False]\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \({{a}, {b}, {c}, {d}, {e}, {f}, {g}, {h}}\)], "Output",
  CellLabel->"Out[69]="]
}, Closed]],

Cell[TextData[{
  "Descendants[] can also be applied to an unrooted genealogy.  This gives \
the relatives of node ",
  Cell[BoxData[
      \(TraditionalForm\`{c, d}\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Descendants[utr, {c, d}]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \({{c}, {d}, {c, d, e, f, g, h}}\)], "Output",
  CellLabel->"Out[10]="]
}, Closed]],

Cell["\<\
This list contains the ancestor as well as the descendants; these \
cannot be distinguished with an unrooted genealogy.  No options can be used \
with unrooted trees.\
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{509, 693},
WindowMargins->{{Automatic, -3}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Ancestors"->{
    Cell[1793, 53, 425, 10, 37, "DefinitionBox",
      CellTags->"Ancestors"]},
  "Descendants"->{
    Cell[2748, 91, 973, 25, 100, "DefinitionBox",
      CellTags->"Descendants"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Ancestors", 6814, 233},
  {"Descendants", 6913, 236}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 51, 0, 36, "SubsectionIcon"],
Cell[1793, 53, 425, 10, 37, "DefinitionBox",
  CellTags->"Ancestors"],
Cell[2221, 65, 59, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2305, 69, 76, 2, 27, "Input"],
Cell[2384, 73, 93, 2, 20, "Output"]
}, Closed]],
Cell[2492, 78, 54, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[2571, 82, 98, 2, 27, "Input"],
Cell[2672, 86, 61, 2, 20, "Output"]
}, Closed]],
Cell[2748, 91, 973, 25, 100, "DefinitionBox",
  CellTags->"Descendants"],
Cell[3724, 118, 157, 5, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[3906, 127, 100, 2, 27, "Input"],
Cell[4009, 131, 87, 2, 20, "Output"]
}, Closed]],
Cell[4111, 136, 172, 7, 20, "MathCaption"],

Cell[CellGroupData[{
Cell[4308, 147, 136, 3, 27, "Input"],
Cell[4447, 152, 174, 3, 20, "Output"]
}, Closed]],
Cell[4636, 158, 61, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[4722, 162, 139, 3, 27, "Input"],
Cell[4864, 167, 101, 2, 20, "Output"]
}, Closed]],
Cell[4980, 172, 72, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[5077, 176, 173, 3, 42, "Input"],
Cell[5253, 181, 99, 2, 20, "Output"]
}, Closed]],
Cell[5367, 186, 195, 6, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[5587, 196, 82, 2, 27, "Input"],
Cell[5672, 200, 89, 2, 20, "Output"]
}, Closed]],
Cell[5776, 205, 190, 4, 32, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

