(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4191,        106]*)
(*NotebookOutlinePosition[      5072,        134]*)
(*  CellTagsIndexPosition[      5028,        130]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Introduction", "SubsubsectionIcon"],

Cell[TextData[{
  "The ancestry of a section of genome can be represented by an ",
  StyleBox["ancestral graph",
    FontSlant->"Italic"],
  ".  As one traces back in time, lineages may coalesce (reflecting the \
action of random drift) or split (reflecting recombination).  If the genetic \
map is taken to be a continuous, then each recombination occurs at a unique \
point.  One can regard the complete graph as a set of genealogies, each \
applying to some short segment of genome, and each obeying the coalescent \
process.  Adjacent genealogies differ by a single recombination event, which \
changes the ancestry of part of the genealogy."
}], "Text"],

Cell[TextData[{
  "Scaling time relative to 2N generations, the rate of coalescence between \
any pair of lineages is 1, and the net rate among ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " lineages is ",
  Cell[BoxData[
      \(TraditionalForm\`\(k \((k - 1)\)\)\/2\)]],
  ".  The rate of recombination in a section of genome of map length ",
  Cell[BoxData[
      \(TraditionalForm\`2  N\[VeryThinSpace]r = R\)]],
  " is just ",
  Cell[BoxData[
      \(TraditionalForm\`k\[VeryThinSpace]R\)]],
  ".  The number of lineages therefore follows a simple branching process.   \
It will eventually reach 1; that is, eventually a single genome will be the \
ancestor of the entire sample, at all loci.  However, tracing further back, \
this single lineage will descend from many ancestors: the 'typical' ancestry \
of a sample will be to descend from a fluctuating # of ancestral genomic \
segments, each being the single common ancestor of some part of the genome of \
the sample."
}], "Text"],

Cell[TextData[{
  "The ancestral graph can be constructed by tracing the whole genome back in \
time, and allowing both coalescence and recombination.   This was the \
algorithm given by Hudson (",
  ButtonBox["1990",
    ButtonData:>{"Ancestral graph references", "Hudson 1990"},
    ButtonStyle->"AddOnsLink"],
  ").  Alternatively, one can start at an arbitrary point in the genome, and \
then work along, until the first recombination event occurs; this determines \
a new genealogy, differing by a single event.  Wiuf and Hein (",
  ButtonBox["1999",
    ButtonData:>{"Ancestral graph references", "Wiuf & Hein 1999"},
    ButtonStyle->"AddOnsLink"],
  ") describe this method, which is somewhat more cumbersome."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{775, 654},
WindowMargins->{{Automatic, 6}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 41, 0, 24, "SubsubsectionIcon"],
Cell[1783, 53, 658, 11, 66, "Text"],
Cell[2444, 66, 998, 21, 92, "Text"],
Cell[3445, 89, 730, 14, 52, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

