(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8753,        259]*)
(*NotebookOutlinePosition[     10068,        301]*)
(*  CellTagsIndexPosition[      9934,        293]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Constructing genealogies", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"ListToGenealogy", "[", 
              FormBox[
                StyleBox["list",
                  FontSlant->"Italic"],
                "TraditionalForm"], "]"}], 
            RowBox[{
            "constructs", " ", "a", " ", "genealogy", " ", "from", " ", "a", 
              " ", "nested", " ", "list", " ", "of", " ", "the", " ", "form", 
              " ", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["label",
                    FontSlant->"Italic"], ",", 
                  RowBox[{"{", 
                    RowBox[{
                      SubscriptBox[
                        StyleBox["node",
                          FontSlant->"Italic"], "1"], ",", 
                      SubscriptBox[
                        StyleBox["node",
                          FontSlant->"Italic"], "2"], ",", "\[Ellipsis]"}], 
                    "}"}]}], "}"}]}]},
          {
            RowBox[{"ListToGenealogy", "[", 
              RowBox[{
                FormBox[
                  StyleBox["list",
                    FontSlant->"Italic"],
                  "TraditionalForm"], ",", \(NodeFunction \[Rule] f\)}], 
              "]"}], 
            RowBox[{
              RowBox[{
                RowBox[{\(includes\ information\ on\ each\ node\), ",", " ", 
                  RowBox[{"where", " ", 
                    FormBox[
                      RowBox[{"f", "[", 
                        StyleBox["label",
                          FontSlant->"Italic"]}],
                      "TraditionalForm"]}]}], "]"}], " ", "gives", " ", "the",
               " ", \(\(information\)\(.\)\)}]}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"ListToGenealogy", "NodeFunction"}],

Cell[TextData[{
  "In order to construct a genealogy with labelled nodes, a list must be \
supplied in the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            StyleBox["label",
              FontSlant->"Italic"], ",", 
            RowBox[{"{", 
              RowBox[{
                SubscriptBox[
                  StyleBox["node",
                    FontSlant->"Italic"], "1"], ",", 
                SubscriptBox[
                  StyleBox["node",
                    FontSlant->"Italic"], "2"], ",", "\[Ellipsis]"}], 
              "}"}]}], "}"}], TraditionalForm]]],
  ".   This is the form returned by CollapseGenealogy[].  ListToGenealogy[",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            StyleBox["label",
              FontSlant->"Italic"], ",", 
            RowBox[{"{", 
              RowBox[{
                SubscriptBox[
                  StyleBox["node",
                    FontSlant->"Italic"], "1"], ",", 
                SubscriptBox[
                  StyleBox["node",
                    FontSlant->"Italic"], "2"], ",", "\[Ellipsis]"}], 
              "}"}]}], "}"}], TraditionalForm]]],
  "] constructs the genealogy.  Information can be supplied by setting ",
  Cell[BoxData[
      \(TraditionalForm\`NodeFunction \[Rule] f\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"f", "[", 
          StyleBox["label",
            FontSlant->"Italic"]}], TraditionalForm]]],
  "] gives the information."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CollapseGenealogy[tr]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \({{a, b, c, d, e, f, g, 
        h}, {{{a, b}, {{a}, {b}}}, {{c, d, e, f, g, 
            h}, {{{c, d}, {{c}, {d}}}, {{e, f, g, 
                h}, {{{e, f, g}, {{e}, {f}, {g}}}, {h}}}}}}}\)], "Output",
  CellLabel->"Out[9]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListToGenealogy[CollapseGenealogy[tr]]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(Node[{a, b, c, d, e, f, g, h}, {}, {
        Node[{a, b}, {}, {Node[{a}, {}, {}], Node[{b}, {}, {}]}], 
        Node[{c, d, e, f, g, h}, {}, {
            Node[{c, d}, {}, {Node[{c}, {}, {}], Node[{d}, {}, {}]}], 
            Node[{e, f, g, h}, {}, {
                Node[{e, f, g}, {}, {Node[{e}, {}, {}], Node[{f}, {}, {}], 
                    Node[{g}, {}, {}]}], Node[{h}, {}, {}]}]}]}]\)], "Output",\

  CellLabel->"Out[10]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListToGenealogy[CollapseGenealogy[tr], NodeFunction -> \((info[#]&)\)]
      \)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(Node[{a, b, c, d, e, f, g, h}, 
      info[{a, b, c, d, e, f, g, h}], {
        Node[{a, b}, info[{a, b}], {{a}, {b}}], 
        Node[{c, d, e, f, g, h}, 
          info[{c, d, e, f, g, h}], {Node[{c, d}, info[{c, d}], {{c}, {d}}], 
            Node[{e, f, g, h}, 
              info[{e, f, g, h}], {
                Node[{e, f, g}, info[{e, f, g}], {{e}, {f}, {g}}], {h}}]}]}]
      \)], "Output",
  CellLabel->"Out[11]="]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"ListToGenealogy", "[", 
              RowBox[{
                FormBox[
                  StyleBox[\({a, b, \[Ellipsis]}\),
                    FontSlant->"Italic"],
                  "TraditionalForm"], ",", " ", \(Node \[Rule] False\)}], 
              "]"}], \(gives\ a\ genealogy\ relating\ objects\ {a, 
                  b, \[Ellipsis]} . \ \ Internal\ nodes\ are\ \
\(\(unlabelled\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"Node"],

Cell[TextData[
"This gives a genealogy which relates objects {{a,b},{{c,d},e}}.  The leaves \
are labelled by {a, b, \[Ellipsis]}, whilst internal nodes are unlabelled.  \
This form is not very useful, because most of the functions defined here \
require that nodes be identified by unique labels."], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListToGenealogy[{{a, b}, {{c, d}, e}}, Node \[Rule] False]\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \(Node[{}, {}, {Node[{}, {}, {Node[a, {}, {}], Node[b, {}, {}]}], 
        Node[{}, {}, {Node[{}, {}, {Node[c, {}, {}], Node[d, {}, {}]}], 
            Node[e, {}, {}]}]}]\)], "Output",
  CellLabel->"Out[16]="]
}, Closed]],

Cell[TextData[{
  " Information can be provided about the leaves using ",
  Cell[BoxData[
      \(TraditionalForm\`NodeFunction \[Rule] f\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListToGenealogy[{{a, b}, {{c, d}, e}}, Node \[Rule] False, 
      NodeFunction \[Rule] f]\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \(Node[{}, {}, {Node[{}, {}, {Node[a, f[a], {}], Node[b, f[b], {}]}], 
        Node[{}, {}, {Node[{}, {}, {Node[c, f[c], {}], Node[d, f[d], {}]}], 
            Node[e, f[e], {}]}]}]\)], "Output",
  CellLabel->"Out[17]="]
}, Closed]],

Cell["\<\
Note that the labelling of nodes by the set of objects they contain \
(as in the example above) is not possible here: information on relationships \
is then confounded.\
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{509, 693},
WindowMargins->{{Automatic, -3}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "ListToGenealogy"->{
    Cell[1792, 53, 1803, 44, 84, "DefinitionBox",
      CellTags->{"ListToGenealogy", "NodeFunction"}]},
  "NodeFunction"->{
    Cell[1792, 53, 1803, 44, 84, "DefinitionBox",
      CellTags->{"ListToGenealogy", "NodeFunction"}]},
  "Node"->{
    Cell[6698, 197, 554, 13, 46, "DefinitionBox",
      CellTags->"Node"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"ListToGenealogy", 9591, 280},
  {"NodeFunction", 9716, 283},
  {"Node", 9833, 286}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 50, 0, 36, "SubsectionIcon"],
Cell[1792, 53, 1803, 44, 84, "DefinitionBox",
  CellTags->{"ListToGenealogy", "NodeFunction"}],
Cell[3598, 99, 1527, 44, 64, "Text"],

Cell[CellGroupData[{
Cell[5150, 147, 78, 2, 27, "Input"],
Cell[5231, 151, 246, 5, 35, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[5514, 161, 96, 2, 23, "Input"],
Cell[5613, 165, 452, 9, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[6102, 179, 135, 3, 23, "Input"],
Cell[6240, 184, 443, 10, 50, "Output"]
}, Closed]],
Cell[6698, 197, 554, 13, 46, "DefinitionBox",
  CellTags->"Node"],
Cell[7255, 212, 308, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[7588, 220, 116, 2, 27, "Input"],
Cell[7707, 224, 228, 4, 35, "Output"]
}, Closed]],
Cell[7950, 231, 167, 5, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[8142, 240, 147, 3, 27, "Input"],
Cell[8292, 245, 238, 4, 35, "Output"]
}, Closed]],
Cell[8545, 252, 192, 4, 32, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

