(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8948,        265]*)
(*NotebookOutlinePosition[     10385,        307]*)
(*  CellTagsIndexPosition[     10237,        299]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Determining ancestry", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"MostRecentCommonAncestor", "[", 
              RowBox[{
                StyleBox["popln",
                  FontSlant->"Italic"], ",", "i", ",", "j"}], 
              "]"}], \(\(\ \)\(gives\ the\ most\ recent\ common\ ancestor\ of\
\ individuals\ i, \ \(\(j\)\(.\)\)\)\)},
          {
            RowBox[{"Ancestors", "[", 
              RowBox[{
                StyleBox["popln",
                  FontSlant->"Italic"], ",", "i"}], 
              "]"}], \(gives\ the\ ultimate\ ancestor\ of\ individual\ \
\(\(i\)\(.\)\)\)},
          {
            RowBox[{"Ancestors", "[", 
              RowBox[{
                StyleBox["popln",
                  FontSlant->"Italic"], ",", \({i\_1, i\_2, \[Ellipsis]}\)}], 
              "]"}], \(lists\ the\ ancestors\ of\ individuals\ \(\({i\_1, 
                  i\_2, \[Ellipsis]}\)\(.\)\)\)},
          {\(Descendants[p, i, 
              s]\), \(\(\ \)\(gives\ the\ descendants\ of\ individual\ i\ who\
\ are\ members\ of\ the\ set\ \(\(s\)\(.\)\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"MostRecentCommonAncestor", "Ancestors", "Descendants"}],

Cell[TextData[{
  "Infomation about the ancestry of individual ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " is contained in the list of ancestors ",
  Cell[BoxData[
      FormBox[
        RowBox[{"Ancestry", "[", 
          RowBox[{
            StyleBox["popln",
              FontSlant->"Italic"], ",", "i"}], "]"}], TraditionalForm]]],
  ".   "
}], "Text"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Genealogies`Continua`;\)\)], "Input",
  CellLabel->"In[259]:="],

Cell["\<\
These are the ancestors of the most recent living individual. \
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ancestry[p1, ExtantIndividuals[p1] // Last]\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \({30035, 29641, 29617, 29479, 29471, 29422, 29288, 29277, 29259, 28475, 
      28442, 27921, 27891, 27570, 27237, 26917, 26906, 26456, 26454, 26343, 
      26279, 26226, 26214, 26080, 26030, 26000, 25821, 25806, 25225, 25133, 
      24854, 24837, 24796, 24357, 24240, 24076, 24027, 23856, 23754, 23610, 
      23504, 23469, 23464, 23277, 23177, 23104, 23046, 22935, 22888, 22792, 
      22699, 22654, 22476, 22361, 22242, 22185, 21997, 21960, 21805, 21670, 
      20912, 19914, 19821, 19782, 19669, 19460, 19429, 19150, 19062, 18953, 
      18766, 18667, 18617, 18487, 18432, 17794, 17772, 17746, 17665, 16955, 
      16626, 16561, 16197, 16128, 15922, 15741, 15719, 15650, 15528, 15505, 
      15502, 15473, 15438, 15429, 15280, 15082, 15019, 15007, 14556, 14437, 
      14092, 14081, 13873, 13739, 13713, 13531, 13355, 13230, 13142, 13136, 
      13106, 13084, 12745, 12718, 12352, 12303, 12218, 12182, 12095, 11950, 
      11704, 11582, 11561, 11303, 11007, 10881, 10782, 10627, 10326, 10244, 
      10148, 10113, 10096, 9938, 9804, 9586, 9408, 9294, 9166, 9153, 8901, 
      8394, 7529, 7478, 7313, 7296, 7142, 6806, 6537, 6294, 5943, 5771, 5685, 
      5636, 5497, 5236, 5195, 5053, 4995, 4885, 4842, 4117, 3512, 3422, 3345, 
      2953, 2940, 2720, 2313, 2235, 2089, 2086, 2065, 1910, 1556, 1255, 1185, 
      1176, 930, 678, 659, 371, 303, 191, 158, 8}\)], "Output",
  CellLabel->"Out[35]="]
}, Closed]],

Cell[TextData[{
  "Ancestors[",
  StyleBox["popln",
    FontSlant->"Italic"],
  ",i] just finds the ultimate ancestor of individual ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ". ",
  Cell[BoxData[
      FormBox[
        RowBox[{"Ancestors", "[", 
          RowBox[{
            StyleBox["popln",
              FontSlant->"Italic"], ",", \({i\_1, i\_2, \[Ellipsis]}\)}], 
          "]"}], TraditionalForm]]],
  " finds the set of ancestors of the set of individuals ",
  Cell[BoxData[
      \(TraditionalForm\`\(\({i\_1, i\_2, \[Ellipsis]}\)\(.\)\)\)]],
  "  "
}], "Text"],

Cell["This is the set of ancestors of the living individuals:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(aa = Ancestors[p1, ExtantIndividuals[p1]]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \({8, 10, 88}\)], "Output",
  CellLabel->"Out[36]="]
}, Closed]],

Cell["\<\
Eventually, this would reduce to a single individual.  However, in \
this example not all lineages have coalesced: the current population has 3 \
distinct ancestors.\
\>", "Text"],

Cell["These are the descendants of individual 10:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{
        FormBox["Descendants",
          "TraditionalForm"], "[", \(p1, 10, ExtantIndividuals[p1]\), 
        "]"}]}]], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \({28770, 29107, 29115, 29209, 29244, 29387, 29407, 29426, 29462, 29587, 
      29626, 29676, 29691, 29743, 29755, 29757, 29762, 29788, 29798, 29799, 
      29836, 29845, 29855, 29858, 29870, 29872, 29885, 29886, 29901, 29905, 
      29906, 29907, 29909, 29911, 29915, 29916, 29921, 29922, 29926, 29933, 
      29943, 29948, 29949, 29953, 29958, 29962, 29964, 29966, 29979, 29982, 
      29987, 29988, 29992, 29993, 30000, 30003, 30010, 30011, 30014, 30015, 
      30020, 30021, 30024, 30028, 30037, 30038, 30039, 30042, 30043, 30045, 
      30049, 30052, 30053, 30054, 30056, 30057, 30067, 30072, 30074, 30078, 
      30089, 30090, 30091, 30095, 30099, 30102, 30104, 30107, 30109, 30114, 
      30116, 30118, 30119, 30120, 30121, 30123, 30124, 30127, 30129, 30130, 
      30131, 30132, 30136, 30137, 30139}\)], "Output",
  CellLabel->"Out[38]="]
}, Closed]],

Cell["\<\
This gives the number of descendants of each of the three ancestors \
:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"Length", "[", " ", 
          RowBox[{
            FormBox["Descendants",
              "TraditionalForm"], "[", \(p1, #, ExtantIndividuals[p1]\), 
            "]"}], "]"}], "&"}], "/@", "aa"}]], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \({68, 105, 9}\)], "Output",
  CellLabel->"Out[39]="]
}, Closed]],

Cell["\<\
This gives the most recent common ancestor of the first and second \
youngest living individuals:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MostRecentCommonAncestor[p1, 
      \(ExtantIndividuals[p1]\)\[LeftDoubleBracket]\(-1
          \)\[RightDoubleBracket], 
      \(ExtantIndividuals[p1]\)\[LeftDoubleBracket]\(-2
          \)\[RightDoubleBracket]]\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(29422\)], "Output",
  CellLabel->"Out[46]="]
}, Closed]],

Cell["\<\
If the individuals have different ultimate ancestors (because not \
all lineages have coalesced), then MostRecentCommonAncestor[] is set to zero:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MostRecentCommonAncestor[p1, 
      \(ExtantIndividuals[p1]\)\[LeftDoubleBracket]1\[RightDoubleBracket], 
      \(ExtantIndividuals[p1]\)\[LeftDoubleBracket]2\[RightDoubleBracket]]
      \)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[47]="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{513, 690},
WindowMargins->{{Automatic, 8}, {Automatic, -5}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "MostRecentCommonAncestor"->{
    Cell[1788, 53, 1203, 27, 124, "DefinitionBox",
      CellTags->{"MostRecentCommonAncestor", "Ancestors", "Descendants"}]},
  "Ancestors"->{
    Cell[1788, 53, 1203, 27, 124, "DefinitionBox",
      CellTags->{"MostRecentCommonAncestor", "Ancestors", "Descendants"}]},
  "Descendants"->{
    Cell[1788, 53, 1203, 27, 124, "DefinitionBox",
      CellTags->{"MostRecentCommonAncestor", "Ancestors", "Descendants"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"MostRecentCommonAncestor", 9795, 286},
  {"Ancestors", 9939, 289},
  {"Descendants", 10085, 292}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 46, 0, 36, "SubsectionIcon"],
Cell[1788, 53, 1203, 27, 124, "DefinitionBox",
  CellTags->{"MostRecentCommonAncestor", "Ancestors", "Descendants"}],
Cell[2994, 82, 368, 12, 22, "Text"],
Cell[3365, 96, 46, 0, 28, "MathCaption"],
Cell[3414, 98, 88, 2, 27, "Input"],
Cell[3505, 102, 95, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3625, 109, 101, 2, 27, "Input"],
Cell[3729, 113, 1417, 19, 305, "Output"]
}, Closed]],
Cell[5161, 135, 581, 19, 34, "Text"],
Cell[5745, 156, 78, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5848, 160, 99, 2, 27, "Input"],
Cell[5950, 164, 70, 2, 20, "Output"]
}, Closed]],
Cell[6035, 169, 189, 4, 32, "Text"],
Cell[6227, 175, 66, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6318, 179, 200, 6, 27, "Input"],
Cell[6521, 187, 864, 12, 185, "Output"]
}, Closed]],
Cell[7400, 202, 102, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[7527, 209, 288, 8, 27, "Input"],
Cell[7818, 219, 71, 2, 20, "Output"]
}, Closed]],
Cell[7904, 224, 128, 3, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[8057, 231, 270, 6, 42, "Input"],
Cell[8330, 239, 64, 2, 20, "Output"]
}, Closed]],
Cell[8409, 244, 178, 4, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[8612, 252, 245, 5, 42, "Input"],
Cell[8860, 259, 60, 2, 20, "Output"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

