(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     23511,        452]*)
(*NotebookOutlinePosition[     25820,        520]*)
(*  CellTagsIndexPosition[     25552,        508]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Boxing the individuals", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{"Individuals", "[", 
                RowBox[{
                  StyleBox["popln",
                    FontSlant->"Italic"], ",", "X"}], "]"}], 
              " "}], \(lists\ the\ codes\ of\ the\ individuals\ in\ box\ \
X\)},
          {\(\(Box[
              x, \[CapitalDelta]]\)\(\ \)\), \(\(gives\)\(\ \)\(the\)\(\ \
\)\(box\)\(\ \)\(in\)\(\ \)\(which\)\(\ \)\(x\)\(\ \)\(is\)\(\ \
\)\(\(found\)\(.\)\)\(\ \ \)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"Individuals", "Box"}],

Cell[TextData[{
  " To speed calculations, density-dependent interactions (determined by a \
function U ",
  Cell[BoxData[
      \(TraditionalForm\`U[]\)]],
  ") are counted only up to a distance \[CapitalDelta].    Individuals are \
assigned to notional boxes of size \[CapitalDelta], so that only individuals \
in adjacent boxes interact."
}], "Text"],

Cell[TextData[{
  "Boxes are of size \[CapitalDelta], and are numbered from {0,0} to {",
  StyleBox["nboxes",
    FontSlant->"Italic"],
  "-1,",
  StyleBox["nboxes",
    FontSlant->"Italic"],
  "-1} in two dimensions; similarly in other dimensions. "
}], "Text"],

Cell["These are the individuals in box {1,1}:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Individuals[p1, {1, 1}]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \({73}\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell["This is the box in which individual 73 is found:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Box[Location[p1, 73], 3]\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \({1, 1}\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(DistanceSquared[x, y, 
              R]\), \(gives\ the\ square\ of\ the\ distance\ between\ x\ and\ \
y, \ on\ a\ torus\ of\ size\ \(\(R\)\(.\)\)\)},
          {\(\(MakeDistances[y, {x\_1, \[Ellipsis]}, 
              R, \[CapitalDelta]\^2]\)\(\ \)\), \(lists\ the\ squared\ \
distances\ from\ y\ to\ each\ of\ the\ neighbours\ at\ \(\({x\_1, \
\[Ellipsis]}\)\(.\)\)\)},
          {
            RowBox[{
              RowBox[{"MakeDistanceList", "[", 
                RowBox[{
                  StyleBox["popln",
                    FontSlant->"Italic"], ",", "R", ",", "\[CapitalDelta]"}], 
                "]"}], " "}], \(generates\ a\ list\ of\ all\ the\ distances\ \
between\ pairs\ of\ neighbouring\ extant\ individuals . \ 
                Each\ distance\ appears\ only\ \(\(once\)\(.\)\)\)},
          {
            RowBox[{
              RowBox[{"Neighbours", "[", 
                RowBox[{
                  StyleBox["popln",
                    FontSlant->"Italic"], ",", \(Box[]\), ",", 
                  StyleBox["nboxes",
                    FontSlant->"Italic"]}], "]"}], 
              " "}], \(lists\ those\ extant\ individuals\ in\ boxes\ of\ size\
\ \[CapitalDelta]\ which\ neighbour\ the\ given\ box . \ 
                These\ neighbours\ can\ be\ no\ more\ than\ 2 \(\@ 
                  d\) \[CapitalDelta]\ away . \ \ Includes\ the\ target\ \
individual\ at\ \(\(x\)\(.\)\)\)},
          {\(NeighbourArray[
              2]\), \(\(\ \)\(gives\ the\ array\ of\ displacements\ in\ two\ \
dimensions, \ {{\(-1\), \(-1\)}, {\(-1\), 0}, {\(-1\), 1}, {0, \(-1\)}, {0, 
                0}, {0, 1}, {1, \(-1\)}, {1, 0}, {1, 1}}; \ 
            similarly\ in\ other\ \(\(dimensions\)\(.\)\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{
  "DistanceSquared", "MakeDistances", "MakeDistanceList", "Neighbours", 
    "NeighbourArray"}],

Cell["This is the squared distance between individuals 73, 74:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DistanceSquared[Location[p1, 73], Location[p1, 74], 30]\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \(331.005300338872965`\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell[TextData[{
  "This lists the neighbours of individual 73; there are 10\[Times]10 boxes \
with ",
  Cell[BoxData[
      \(TraditionalForm\`R = 30\)]],
  ", \[CapitalDelta]=3."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nb = Neighbours[p1, {1, 1}, 10]\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \({71, 73, 24, 9, 43, 91, 38}\)], "Output",
  CellLabel->"Out[17]="]
}, Open  ]],

Cell["\<\
This lists the distances from individual 73 to each of these \
neighbours:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{" ", 
      FormBox[
        \(MakeDistances[Location[p1, 73], \(Location[p1, #]&\)/@nb, 30, 3\^2]
          \),
        "TraditionalForm"]}]], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \({0.`, 8.58771733359344402`, 7.16121125541301228`}\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell["\<\
This generates a list of all distances between pairs of extant \
individuals, counting up to distance \[CapitalDelta]=6.  (This need not be \
the same as is used in the simulation).  It can be very slow for large \
\[CapitalDelta] and high densities, since so many pairs of individuals need \
to be tracked.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{" ", 
      FormBox[\(MakeDistanceList[p1, 30, 6]\),
        "TraditionalForm"]}]], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \({{0.720418793783394662`, 3.89533874731278153`, 4.27839759539825603`, 
        5.32976457479929077`, 1.45192990517002744`, 4.66646734517302608`, 
        4.07680261352145123`, 1.78279289833272969`, 2.78370431533794127`}, {
        5.73049480990133197`, 2.09006997399679361`, 5.05459304495954153`, 
        5.2008751112552698`, 5.64291462184815006`, 5.01492678752993725`, 
        5.22657003928342156`, 5.82898199934370531`, 5.80215370745421221`, 
        5.71093906558557407`}, {2.67104166260475617`, 3.21619768523747762`, 
        4.83212627201495692`, 1.28741301061108813`, 3.82904293316523336`, 
        2.85744787068011127`, 1.72324279706773042`, 5.51204811284551432`, 
        2.90270343849165257`, 3.65437171100999691`, 2.867114773066017`, 
        3.37890249778754636`, 3.4778099442485244`, 2.39806369608590985`, 
        3.98196866522689596`, 5.17177232958561905`}, {4.95357785407660955`, 
        5.46619046585645129`, 4.56248778806093735`, 2.90669628808322233`, 
        2.04325731988163195`, 5.75497287887401398`, 5.73400806225585668`, 
        3.12531644143113718`, 1.53373972758258592`, 3.09118130115549361`, 
        4.037180556964989`, 3.58414882803608936`, 2.93856606438519705`, 
        5.76570157596142607`, 1.17362043779689662`}, {4.31495947876025098`, 
        4.5373199414555696`, 5.89682422247315507`, 1.04436340035314589`, 
        4.78018776949374846`, 4.16505572616878083`, 1.08127649312019681`, 
        5.74886531497471597`, 2.22210191064893791`}, {4.41457725753502039`, 
        3.82578991819030189`, 5.36468192389954978`, 5.45419935493750074`, 
        1.26314939387483082`, 1.95567257352322769`, 4.20810904188701062`, 
        1.60795739621305173`, 4.97866200824323179`, 5.1367061500521105`}, {
        5.41932650826865458`, 4.75275575472134637`, 4.10194050028709256`, 
        5.44074195709830998`, 3.95467708781225582`, 3.76194364618863108`, 
        5.17181074243014471`, 4.964927792755498`, 3.3296608482579928`, 
        4.94995999563459587`, 4.97734601484487448`, 2.74178186971512793`, 
        4.49007917149125113`, 1.91053941880953246`, 3.31833498508260182`}, {
        3.16551616773397226`, 4.85406541277131786`, 3.65646643590046638`, 
        3.81006304671695872`, 3.74324811897679454`, 4.78977314273349197`, 
        2.46383250072813275`, 3.22036585997021163`, 1.3728157113852808`, 
        3.09182173166495477`, 5.40655715732536368`, 4.44183331102052569`, 
        0.71926597791546909`, 1.01101084688466946`, 5.53916119581386734`, 
        4.78119301159759757`, 4.46691412051200664`, 4.3099599315391277`}, {
        5.46861559970462707`, 1.55154666125241451`, 2.46741983327209135`, 
        4.9043863778634531`, 3.91980631488120323`, 4.86879537370676285`, 
        5.78060544144302212`, 2.18373066238637614`, 5.25394580688956658`, 
        4.35449791147374831`}, {5.19941692747580219`, 1.11919387525787916`, 
        4.43958990149068011`, 2.03148145038247429`, 3.88097162076824417`, 
        4.70893514212582431`, 5.33127903172391803`, 2.03000817974529379`, 
        5.25128636398316839`, 4.78082046422386675`, 3.90590854700086289`, 
        5.78949864235193967`}, {5.21817213894532194`, 5.58811003607087553`, 
        5.44342610531763426`, 3.44883631882884378`, 0.751811470216566135`, 
        5.20899191250509385`, 0.314627483802905727`, 4.47710116120533019`, 
        1.34252057555110848`}, {5.69581045026092702`, 5.09576188314117128`, 
        4.52584700654418803`, 4.77994102704202727`, 5.89082723685799614`, 
        4.95417922750923622`, 3.34433009158571836`, 1.70387232615436623`, 
        3.09513384288848047`, 4.15013158491414024`, 4.19043600108597669`, 
        2.13803089340639829`, 5.40200950223885634`, 5.02010642171648679`, 
        5.73193494402488035`, 4.83286721488672821`}, {5.88607678177644721`, 
        5.67444557955427431`, 3.21158734026552838`, 3.88808567998328449`, 
        2.88594323267357353`, 4.54167061693380258`, 5.78723812650059699`, 
        4.71162087095026649`, 4.91934833927576065`, 5.7862847723855566`, 
        4.09945615638431881`}, {3.84373202873531294`, 2.90650668284788871`, 
        3.86569598861594165`, 4.59340057349282737`, 5.47308465187084181`, 
        1.07968106175642275`, 5.32583776729861835`, 3.66843698522557604`, 
        3.22413209411738188`, 5.560196040646046`, 5.84062048538406397`}, {
        4.50439347083467911`, 2.98927770297983173`, 4.54679268128834568`, 
        1.50114273755617722`, 4.73246228381367117`, 2.13080643316433437`, 
        3.288307001122309`, 4.11037514954330607`, 4.11878792908465207`, 
        3.64079172821403096`, 3.40806777798728566`, 2.27625990115780885`, 
        5.26391180531037239`}, {2.97095366995257457`, 0.68178718845920212`, 
        1.15613004223927151`, 4.4923870422132559`, 5.82072850762643057`, 
        4.42164849897242007`, 0.662852578163538819`, 3.62855356292899511`, 
        2.98560540605850377`, 3.54798263672646818`, 5.38473026286661138`, 
        5.28094451420322563`, 4.85085566534336898`}, {4.76529695901671779`, 
        3.95467708781225226`, 3.60231110961772804`, 3.18574640242961848`, 
        1.50243409913568211`, 4.99132414985129191`, 5.00190173081092481`, 
        4.89281071366101283`, 5.91614271194028695`, 2.63439277834030116`, 
        5.87938241635055458`, 3.66565699699500946`, 5.46834848157030695`, 
        3.90998583296928803`, 2.92315209637943382`, 5.67998944856132492`, 
        3.74923780482485691`}, {4.83985999052309878`, 4.9803906041414967`, 
        3.26787814858934577`, 1.85602715081599889`, 3.40501833014180466`, 
        4.80833797629802095`, 3.70917224436328929`, 5.87773567437629829`, 
        3.86918468317796193`, 2.96754895613334124`, 4.90537316876428608`}, {
        5.60235951679869526`, 5.05485984174261027`, 2.23779779085298269`, 
        2.54019806979515427`, 5.65327873148236115`, 5.37702079055662807`, 
        4.89517071456978047`, 3.20689469272984117`, 2.87736755121878537`}, {
        5.74902372622347712`, 5.71748805537996762`, 3.15284706377731582`, 
        4.54774662562519083`, 3.52159010100874958`, 1.61967395078894842`, 
        2.84791501130802782`, 4.96812816571653748`, 5.74915936243484271`, 
        3.78918423373452784`, 5.44221070510023441`}, {3.43197409547675036`, 
        2.18274541376074004`, 2.98288134820405801`, 4.1351989471031505`, 
        3.56370165563046059`, 3.70862319431104436`, 4.37445981233300784`, 
        4.27372534627108535`, 1.14739774114371484`, 2.88508650258072663`, 
        5.73042163362970047`, 4.86716239586762711`, 5.2041009272812122`}, {
        1.33887508848970537`, 5.16326377516556966`, 5.26001128548196472`, 
        5.08951863654759684`, 0.877380417377209553`, 4.23142520311616454`, 
        3.53793799704465206`, 3.83818622121463359`, 5.57841537646325047`, 
        5.47104878311815756`, 4.99437843714048224`}, {3.76655810226313914`, 
        5.12796003715661097`, 0.914888907950657426`, 5.53153849759502413`, 
        2.67035733512876616`, 5.76114093885099709`, 3.64364222802606896`, 
        1.28780937389726979`, 1.34880279178135875`}, {5.60389828687087465`, 
        4.17148044973616904`, 5.55160009722064984`, 4.26771372748084942`, 
        2.93048073421297772`, 5.05239240646403953`}, {4.42623291097749227`, 
        4.81129735393308699`, 1.81393142101173214`, 5.69444923133996994`, 
        4.3326216135916109`, 3.83115853382475322`, 2.49936026955114964`, 
        4.16252531161832006`, 5.99807643696615855`, 5.31440875099434251`}, {
        4.7668540157111261`, 4.84528817441390025`, 5.88468251510196083`, 
        4.89648294361132574`, 4.40168635243492545`, 5.68346023685761281`, 
        5.86705796159372727`, 4.52183805209997924`, 5.29729512610484842`, 
        5.58139629120726876`, 5.30903613923280381`, 4.95151708268585277`}, {
        1.37297959567851379`, 4.4457851238852406`, 2.64966357230788185`, 
        1.50243409913568282`, 5.41758797894427779`, 4.2797980876235977`, 
        5.78514228290679088`, 3.86287880613612788`, 4.97575771893748086`, 
        3.13543169980173619`, 5.23525630454306156`}, {5.08724129364954968`, 
        3.70207346533375236`, 1.81111389006075444`, 5.84254504378373695`, 
        4.99693566525906707`, 5.2240463085032367`, 5.27226123631441279`, 
        2.68675204090066355`, 5.44757955274018268`, 4.26365789668996875`, 
        5.83389396164089735`}, {4.582527954653548`, 3.18431358730589364`, 
        5.05485984174261027`, 4.91583047756765356`, 2.05603950340832408`, 
        3.43426551772802834`, 4.33131090734083468`, 4.41132196882493943`, 
        0.682391816602075262`, 4.91389191852152684`, 2.30303534843934309`}, {
        5.68856198666925028`, 3.92167416669776116`, 4.02801371887743808`, 
        3.96221125709207822`, 4.30095092367639164`, 5.07859681688018405`, 
        5.2133489163227491`, 5.06281069832198138`}, {5.42185415473186527`, 
        5.9367016444898919`, 5.26773162391094107`, 3.73770480466941323`, 
        3.89389352599364979`, 1.28718568642070829`, 4.3893358583000035`, 
        5.70266711496120493`, 5.62715880786181266`, 2.25075567892075412`}, {
        4.27210647947274857`, 5.02829672235509672`, 3.19894417939899611`, 
        3.24825272275189202`, 2.99596359282740429`, 2.52302427247830118`, 
        1.20876871274494357`}, {2.12695594220369876`, 5.65741474980923442`, 
        3.53291458156737547`, 5.44317248755814375`, 5.46884770710508316`, 
        2.9316862796433547`, 4.10794534802634192`, 3.02002393008536795`}, {
        1.65773154974600416`, 3.67484257122469859`, 4.29310086284568726`, 
        3.98714969558924536`, 4.78864268243433954`, 4.13297156735526005`, 
        4.66605017492927665`, 2.81944891256214766`, 4.60016875034845007`, 
        4.44771860621752956`, 5.11654479225106317`}, {4.36611108481606713`, 
        1.81393142101172522`, 4.75554284353997225`, 4.33375329875063552`, 
        1.97846414013935287`, 2.97391991522130858`, 3.47289674136679193`, 
        5.52060611647409249`, 4.02514180232574148`, 5.38643746981963111`, 
        5.5918262254329516`}, {3.23992340340885309`, 1.99127675262567844`, 
        4.26291166909817942`, 5.32767831231212429`, 5.17704500428376235`, 
        4.67158322989452035`, 3.6831558287059436`, 2.01919487637061445`, 
        3.47690818259454648`, 5.5513499571812801`}, {5.81990500726278892`, 
        3.31771256339624587`, 1.47171704654934849`, 5.34359951471454142`, 
        2.82581524009634055`}, {3.2889506248201572`, 4.70260855978474889`, 
        2.67604395618102719`, 5.73232169723642215`, 1.10950259797627648`, 
        4.14925465975282747`}, {5.59933748280675658`, 5.67678601606805255`, 
        4.45431218114637772`, 3.6677736151172704`, 4.4332650212772986`, 
        5.12508485682649705`}, {5.3127228152882866`, 2.63573973144378825`, 
        5.42856937155753094`, 5.98963201697005143`, 4.02801371887744075`, 
        5.93227173127106244`, 2.62248115203095899`, 3.28525860029134442`, 
        2.85742365748229243`, 4.38266624837526297`, 5.50747981655921137`, 
        4.7142683363960165`}, {3.59139776591038772`, 3.90479447989309935`, 
        4.43328715180447918`, 1.94539074493541512`, 5.09862061079185213`, 
        5.29748834031211579`, 5.15271416372397084`, 2.02309691916240019`, 
        4.77196676262821828`}, {5.40654212163447578`, 5.91663098654923302`, 
        4.6020917645443955`, 1.11677400928136294`, 5.83250024005504474`}, {
        5.12020938317526219`, 5.43605863971819225`, 4.17211009265819399`, 
        5.96499245726901694`, 5.94905715205805751`, 4.42052050121970996`, 
        3.7580195285005904`, 2.96571865368703093`, 5.41036290667250163`, 
        2.75069198931994263`}, {1.38919877036503415`, 4.796141251478641`, 
        0.887755846157613603`, 3.75885132044179659`}, {1.64437335866834244`, 
        2.97391991522130858`, 5.53799669943469563`, 4.62980440843922913`, 
        5.06149220696430734`, 4.2468321711630983`}, {4.05795506192535793`, 
        5.11048148207667285`, 2.79182349618074576`, 5.60561396281453294`, 
        3.0517522925629219`, 3.14771070119531115`}, {4.42623291097748872`, 
        4.04152320064753478`, 3.64963648948999086`, 1.47171704654935364`, 
        2.22794443723876645`, 4.40867565656505888`, 5.27771034179302489`, 
        5.29524856193041415`, 5.28413435281064458`}, {2.45095677464729844`, 
        5.70810669702553941`, 5.12692213273983021`, 3.49901568996832601`, 
        5.1965136316360061`, 5.81031172903353887`}, {3.43899174234331672`, 
        2.70440439004888144`, 4.19911472032381194`, 4.77469909431773764`, 
        5.94227810879365136`, 5.81681644300457367`, 4.22062075803929026`}, {
        5.41437965229706463`, 2.78389469970286862`, 5.50191530716268939`, 
        2.4955461727193331`, 4.36049870538109907`, 3.56294289017286613`}, {
        1.37827784701638966`, 5.42440433187237669`, 2.47049329926889882`, 
        1.15735823076192123`}, {4.43492643644207085`, 5.72791496412219114`, 
        5.30215869899863356`, 5.91663098654923125`, 2.375362232014258`, 
        5.20531422879344152`, 5.60162203372165112`, 5.13308184584881033`}, {
        4.93745926512819455`, 5.44975392465266139`, 4.83457076379132288`, 
        4.37971315765703916`, 5.1190950403099773`, 4.10819385508493173`}, {
        3.82065287730287916`, 1.85768495389675063`}, {2.07582722867916791`, 
        2.73142515758582282`, 2.12867029802864227`, 1.01788467294294449`}, {
        0.381330543712877734`, 1.31518324836749811`, 5.03803944375163847`}, {
        5.26681318116774122`, 3.40168413098411992`, 3.83331553592294618`, 
        5.17233162696248083`, 4.11433778489842705`}, {4.78291468020331755`, 
        2.89478773297666904`, 3.6588515422066159`, 4.99191257192536319`}, {
        0.835882699250594818`, 5.13669981416435827`, 5.49600811619159568`, 
        3.91854456470397405`, 3.84482718810449455`}, {5.92243735061599441`, 
        5.3377666618395283`, 3.51548087205368631`, 5.83194341295577789`, 
        3.31420730098769311`}, {5.82972606752006061`, 4.8329714718775758`, 
        5.71130977733349354`, 1.35552102599106971`}, {5.08954700440190954`, 
        0.501470847800132091`, 3.47868436883792631`, 5.43727408102466647`}, {
        1.39065241531405114`, 5.37442794076505059`}, {4.8976310638539946`, 
        2.59232440071145298`, 3.79231902806358167`, 4.30597972626830305`, 
        1.66463704611704361`}, {5.45679910378036048`, 0.440452273058508669`, 
        5.4324761718723824`, 5.17296618357599591`, 2.02394519341827683`}, {
        2.69278361951251588`, 4.23315288492810015`, 1.31518324836749811`, 
        5.99938628475650581`, 2.75256055307205915`}, {3.83331553592294547`, 
        5.0470976295479355`, 2.18761241066436129`}, {3.29243901514445536`, 
        5.97772366233134899`, 5.55684506556245683`}, {1.82629403364610638`, 
        4.60556502961750791`, 4.47687560821628061`, 4.0837845403346904`}, {
        5.4515122171879593`, 2.94631172570098609`, 0.685022664951198478`}, {
        3.43899174234331672`, 5.981152594872575`, 5.12309850582494785`, 
        5.7712344269538871`}, {2.89572864919982908`, 3.52854982331700517`, 
        3.01505301644993028`}, {5.5859782779516145`, 3.32381940112857376`}, {
        2.44889125332679125`}, {5.53574706469278154`, 2.88996502745551921`, 
        4.15702038118541938`, 5.97311568852767837`}, {4.82646589465901065`, 
        2.07767216787938302`}, {5.12565177689520989`, 5.59025718878981336`, 
        5.73384681829487607`, 1.36111375436220893`, 5.99838801918647224`}, {
        4.74982219977443076`, 2.68521072515017245`}, {5.26681318116774122`, 
        2.91540946023515559`, 5.64754206898145927`}, {5.3333256258499242`, 
        5.73298971998148587`, 5.72021634446533155`}, {5.4960081161915939`, 
        5.54792856611886442`}, {3.5154808720536872`, 
        5.9302075880206253`}, {}, {5.86037048460945886`, 
        4.91312881014830971`}, {5.85877063816282284`, 4.75137152900804249`, 
        1.60389696005273707`}, {2.59232440071144987`, 3.94136700641219483`, 
        3.00176134945458761`}, {4.60848322959428902`, 5.62136531062223543`, 
        4.53291414118564617`}, {4.76570994313843687`, 2.85773703529561586`}, {
        2.9531760956331885`}, {4.88171830303471487`}, {
        3.1491926672881072`}, {}, {2.03180644532837861`, 
        5.9653503950134965`}, {}, {}, {}, {}, {}, {}, {}}\)], "Output",
  CellLabel->"Out[19]="]
}, Closed]],

Cell[TextData[{
  StyleBox["Note: ",
    FontWeight->"Bold"],
  "The range R must be divisible by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[CapitalDelta]\)\(\ \ \)\)\)]]
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{457, 639},
WindowMargins->{{Automatic, 20}, {Automatic, -2}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Individuals"->{
    Cell[1790, 53, 609, 15, 56, "DefinitionBox",
      CellTags->{"Individuals", "Box"}]},
  "Box"->{
    Cell[1790, 53, 609, 15, 56, "DefinitionBox",
      CellTags->{"Individuals", "Box"}]},
  "DistanceSquared"->{
    Cell[3533, 116, 1937, 39, 258, "DefinitionBox",
      CellTags->{
      "DistanceSquared", "MakeDistances", "MakeDistanceList", "Neighbours", 
        "NeighbourArray"}]},
  "MakeDistances"->{
    Cell[3533, 116, 1937, 39, 258, "DefinitionBox",
      CellTags->{
      "DistanceSquared", "MakeDistances", "MakeDistanceList", "Neighbours", 
        "NeighbourArray"}]},
  "MakeDistanceList"->{
    Cell[3533, 116, 1937, 39, 258, "DefinitionBox",
      CellTags->{
      "DistanceSquared", "MakeDistances", "MakeDistanceList", "Neighbours", 
        "NeighbourArray"}]},
  "Neighbours"->{
    Cell[3533, 116, 1937, 39, 258, "DefinitionBox",
      CellTags->{
      "DistanceSquared", "MakeDistances", "MakeDistanceList", "Neighbours", 
        "NeighbourArray"}]},
  "NeighbourArray"->{
    Cell[3533, 116, 1937, 39, 258, "DefinitionBox",
      CellTags->{
      "DistanceSquared", "MakeDistances", "MakeDistanceList", "Neighbours", 
        "NeighbourArray"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Individuals", 24346, 473},
  {"Box", 24448, 476},
  {"DistanceSquared", 24562, 479},
  {"MakeDistances", 24759, 484},
  {"MakeDistanceList", 24959, 489},
  {"Neighbours", 25153, 494},
  {"NeighbourArray", 25351, 499}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 48, 0, 36, "SubsectionIcon"],
Cell[1790, 53, 609, 15, 56, "DefinitionBox",
  CellTags->{"Individuals", "Box"}],
Cell[2402, 70, 353, 8, 50, "Text"],
Cell[2758, 80, 262, 8, 38, "Text"],
Cell[3023, 90, 62, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3110, 94, 81, 2, 27, "Input"],
Cell[3194, 98, 63, 2, 20, "Output"]
}, Open  ]],
Cell[3272, 103, 71, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3368, 107, 82, 2, 27, "Input"],
Cell[3453, 111, 65, 2, 20, "Output"]
}, Open  ]],
Cell[3533, 116, 1937, 39, 258, "DefinitionBox",
  CellTags->{
  "DistanceSquared", "MakeDistances", "MakeDistanceList", "Neighbours", 
    "NeighbourArray"}],
Cell[5473, 157, 79, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5577, 161, 113, 2, 27, "Input"],
Cell[5693, 165, 79, 2, 20, "Output"]
}, Open  ]],
Cell[5787, 170, 198, 6, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[6010, 180, 89, 2, 27, "Input"],
Cell[6102, 184, 86, 2, 20, "Output"]
}, Open  ]],
Cell[6203, 189, 105, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6333, 196, 203, 6, 28, "Input"],
Cell[6539, 204, 108, 2, 20, "Output"]
}, Open  ]],
Cell[6662, 209, 331, 6, 50, "Text"],

Cell[CellGroupData[{
Cell[7018, 219, 143, 4, 27, "Input"],
Cell[7164, 225, 16127, 215, 1115, "Output"]
}, Closed]],
Cell[23306, 443, 189, 6, 20, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

