(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     17871,        543]*)
(*NotebookOutlinePosition[     18754,        571]*)
(*  CellTagsIndexPosition[     18710,        567]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Estimating the covariance", "SubsectionIcon"],

Cell[TextData[{
  "The covariance is related to the distribution of distances by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n\^*\) = \)\)]],
  Cell[BoxData[
      \(TraditionalForm\`E[\(n(x)\) \(n(y)\)]/n\&_\)]],
  "= 2\[Pi] r \[Delta]r ",
  Cell[BoxData[
      \(TraditionalForm\`\((n\&_ + C\/n\&_)\)\)]],
  ". Hence, ",
  Cell[BoxData[
      FormBox[
        FractionBox["C", 
          StyleBox[\(n\&_\),
            FontWeight->"Bold"]], TraditionalForm]]],
  " = ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["",
            "TraditionalForm"], 
          \(\((\(n\^*\) - n\&_)\)\/\(2  \[Pi]\ r\ \[Delta]r\)\)}], 
        TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "In this example, the mean census density, averaged over ",
  StyleBox["ns",
    FontSlant->"Italic"],
  "=25 samples, is ",
  Cell[BoxData[
      \(TraditionalForm\`n\&_\)]],
  "=0.0773.  The covariance in density can be calculated from the \
distribution of distances between randomly chosen pairs of individuals using \
SpatialCovariance[].  Distances were counted up to a radius of ",
  Cell[BoxData[
      \(TraditionalForm\`D\_max = 10\)]],
  ", and counted in bins of size \[Delta]D=0.1."
}], "Text"],

Cell["\<\
The covariance is mainly over short scales (~2), but with a long \
tail.  Near to the critical point where the density approaches zero, the \
scale of clustering becomes long.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tbl = 
      Transpose[{\ CovarianceMidPoints[{10, 0.1}], 
          SpatialCovariance[bc\/ns, nbar, R, {10, 0.1}, 2]}]; \n
    ListPlot[tbl, PlotJoined -> True]; \)], "Input",
  CellLabel->"In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0957167 0.0147151 59.6558 [
[.21524 .00222 -3 -9 ]
[.21524 .00222 3 0 ]
[.40668 .00222 -3 -9 ]
[.40668 .00222 3 0 ]
[.59811 .00222 -3 -9 ]
[.59811 .00222 3 0 ]
[.78954 .00222 -3 -9 ]
[.78954 .00222 3 0 ]
[.98098 .00222 -6 -9 ]
[.98098 .00222 6 0 ]
[.01131 .13403 -30 -4.5 ]
[.01131 .13403 0 4.5 ]
[.01131 .25334 -30 -4.5 ]
[.01131 .25334 0 4.5 ]
[.01131 .37265 -30 -4.5 ]
[.01131 .37265 0 4.5 ]
[.01131 .49196 -30 -4.5 ]
[.01131 .49196 0 4.5 ]
[.01131 .61127 -24 -4.5 ]
[.01131 .61127 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21524 .01472 m
.21524 .02097 L
s
[(2)] .21524 .00222 0 1 Mshowa
.40668 .01472 m
.40668 .02097 L
s
[(4)] .40668 .00222 0 1 Mshowa
.59811 .01472 m
.59811 .02097 L
s
[(6)] .59811 .00222 0 1 Mshowa
.78954 .01472 m
.78954 .02097 L
s
[(8)] .78954 .00222 0 1 Mshowa
.98098 .01472 m
.98098 .02097 L
s
[(10)] .98098 .00222 0 1 Mshowa
.125 Mabswid
.07167 .01472 m
.07167 .01847 L
s
.11953 .01472 m
.11953 .01847 L
s
.16738 .01472 m
.16738 .01847 L
s
.2631 .01472 m
.2631 .01847 L
s
.31096 .01472 m
.31096 .01847 L
s
.35882 .01472 m
.35882 .01847 L
s
.45453 .01472 m
.45453 .01847 L
s
.50239 .01472 m
.50239 .01847 L
s
.55025 .01472 m
.55025 .01847 L
s
.64597 .01472 m
.64597 .01847 L
s
.69383 .01472 m
.69383 .01847 L
s
.74168 .01472 m
.74168 .01847 L
s
.8374 .01472 m
.8374 .01847 L
s
.88526 .01472 m
.88526 .01847 L
s
.93312 .01472 m
.93312 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13403 m
.03006 .13403 L
s
[(0.002)] .01131 .13403 1 0 Mshowa
.02381 .25334 m
.03006 .25334 L
s
[(0.004)] .01131 .25334 1 0 Mshowa
.02381 .37265 m
.03006 .37265 L
s
[(0.006)] .01131 .37265 1 0 Mshowa
.02381 .49196 m
.03006 .49196 L
s
[(0.008)] .01131 .49196 1 0 Mshowa
.02381 .61127 m
.03006 .61127 L
s
[(0.01)] .01131 .61127 1 0 Mshowa
.125 Mabswid
.02381 .04454 m
.02756 .04454 L
s
.02381 .07437 m
.02756 .07437 L
s
.02381 .1042 m
.02756 .1042 L
s
.02381 .16385 m
.02756 .16385 L
s
.02381 .19368 m
.02756 .19368 L
s
.02381 .22351 m
.02756 .22351 L
s
.02381 .28317 m
.02756 .28317 L
s
.02381 .31299 m
.02756 .31299 L
s
.02381 .34282 m
.02756 .34282 L
s
.02381 .40248 m
.02756 .40248 L
s
.02381 .43231 m
.02756 .43231 L
s
.02381 .46213 m
.02756 .46213 L
s
.02381 .52179 m
.02756 .52179 L
s
.02381 .55162 m
.02756 .55162 L
s
.02381 .58145 m
.02756 .58145 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.0286 .5649 m
.03817 .44769 L
.04774 .54836 L
.05731 .60332 L
.06688 .59019 L
.07645 .55738 L
.08603 .54104 L
.0956 .52215 L
.10517 .49433 L
.11474 .50394 L
.12431 .46443 L
.13388 .45698 L
.14346 .42093 L
.15303 .43696 L
.1626 .398 L
.17217 .36739 L
.18174 .37498 L
.19131 .33677 L
.20089 .35078 L
.21046 .32623 L
.22003 .30054 L
.2296 .31812 L
.23917 .27071 L
.24874 .26343 L
.25832 .26898 L
.26789 .24854 L
.27746 .22887 L
.28703 .23394 L
.2966 .2245 L
.30617 .20659 L
.31575 .20274 L
.32532 .2034 L
.33489 .20148 L
.34446 .20307 L
.35403 .18537 L
.3636 .16868 L
.37318 .1716 L
.38275 .17519 L
.39232 .16678 L
.40189 .16351 L
.41146 .16014 L
.42103 .15643 L
.43061 .13757 L
.44018 .13527 L
.44975 .14237 L
.45932 .12847 L
.46889 .13474 L
.47846 .13617 L
.48804 .12433 L
.49761 .11275 L
Mistroke
.50718 .11413 L
.51675 .1267 L
.52632 .12953 L
.53589 .10461 L
.54547 .11989 L
.55504 .10666 L
.56461 .09738 L
.57418 .09958 L
.58375 .09957 L
.59332 .08636 L
.6029 .09649 L
.61247 .10361 L
.62204 .08434 L
.63161 .08947 L
.64118 .08337 L
.65075 .07462 L
.66033 .0781 L
.6699 .08393 L
.67947 .08174 L
.68904 .07664 L
.69861 .07609 L
.70818 .07902 L
.71776 .08344 L
.72733 .07563 L
.7369 .07457 L
.74647 .06791 L
.75604 .07022 L
.76561 .07006 L
.77519 .06793 L
.78476 .06807 L
.79433 .06743 L
.8039 .07353 L
.81347 .05793 L
.82304 .06982 L
.83262 .06491 L
.84219 .05745 L
.85176 .05877 L
.86133 .06137 L
.8709 .05969 L
.88047 .05066 L
.89005 .05212 L
.89962 .06021 L
.90919 .05616 L
.91876 .05242 L
.92833 .04832 L
.9379 .04539 L
.94748 .04842 L
.95705 .05191 L
.96662 .04746 L
.97619 .04434 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo001@Ool4000_Ool3000^Ool2000`Ool2000/Ool30004Ool20003Ool0
055oo`03001oogoo031oo`03001oogoo02aoo`04001oogoo000^Ool01000Oomoo`00;7oo00<007oo
Ool00Woo00@007ooOol0009oo`00DWoo00<007ooOol0;Goo1000;Goo00@007ooOol002ioo`04001o
ogoo000/Ool00`00Oomoo`02Ool01000Oomoo`000Woo001COol00`00Oomoo`0/Ool00`00Ool0000^
Ool3000`Ool2000]Ool00`00Oomoo`02Ool01000Oomoo`000Woo001@Ool01000Oomoo`00;Woo00<0
07oo0000;Woo00<007ooOol0;goo00@007ooOol002aoo`03001oogoo009oo`04001oogoo0002Ool0
055oo`80031oo`8002moo`<002moo`8002aoo`8000Eoo`8000=oo`00ogoo8Goo000QOol00`00Oomo
o`3lOol0025oo`03001oogoo0?aoo`008Goo00<007ooOol0o7oo000QOol00`00Oomoo`3lOol001]o
ool000@0009oo`008Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol02Woo00<007ooOol017oo000QOol00`00Oomoo`3lOol0025oo`03001oogoo0?ao
o`008Goo00<007ooOol0o7oo000QOol00`00Oomoo`3lOol0025oo`03001oogoo0?aoo`008Goo0P00
lgoo0P0027oo000QOol00`00Oomoo`3VOol80002Ool2000:Ool0025oo`03001oogoo0=Yoo`@000Eo
o`<000Qoo`8000aoo`008Goo00<007ooOol0fGoo00<007ooOol00Woo00<007ooOol00P006Goo000Q
Ool00`00Oomoo`39Ool00`00Oomoo`04Ool600000goo00000006Ool2000KOol0025oo`03001oogoo
0<Uoo`8000Aoo`03001oogoo00Aoo`03001oogoo02=oo`008Goo00<007ooOol0]goo0`0017oo2000
0Woo00D007ooOol007oo008002eoo`008Goo00<007ooOol0]Woo00@007ooOomoo`@000Qoo`03001o
o`0000=oo`03001oogoo02eoo`008Goo0P00X7oo0`0047oo10004Goo00<007ooOol0<Woo000QOol0
0`00Oomoo`2NOol01@00Oomoogoo00001Goo200000=oo`00Ool0BGoo000QOol00`00Oomoo`2LOol2
0005Ool00`00Ool000020008Ool00`00Oomoo`19Ool0025oo`03001oogoo091oo`03001oogoo00Eo
o`800003Ool007oo00Moo`03001oogoo05Eoo`008Goo00<007ooOol0T7oo0P001Woo00<007oo0000
HGoo000QOol00`00Oomoo`2?Ool01000Oomoo`0017oo00<007ooOol0HWoo000QOol00`00Oomoo`28
Ool30004Ool01@00Oomoogoo00000Woo00<007ooOol0Hgoo000QOol00`00Oomoo`27Ool01000Oomo
ogoo10001Goo00<007oo0000IGoo000QOol20022Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00
Oomoo`1TOol0025oo`03001oogoo085oo`03001oogoo009oo`03001oogoo07=oo`008Goo00<007oo
Ool0Mgoo10001Goo00<007oo00000Woo00<007ooOol0M7oo000QOol00`00Oomoo`1gOol01000Oomo
o`001Goo00H007ooOol007oo001fOol0025oo`03001oogoo07Ioo`03001oogoo009oo`03001oogoo
009oo`05001oogooOol0001gOol0025oo`03001oogoo07Eoo`03001oogoo00=oo`05001oogooOol0
001lOol0009oo`8000Aoo`8000Aoo`8000Aoo`8000=oo`@000Aoo`03001oogoo06eoo`8000Eoo`03
001oogoo00Eoo`@007aoo`0000Eoo`00Oomoo`0000=oo`8000=oo`04001oogoo0002Ool01000Oomo
o`000goo00<007ooOol017oo00<007ooOol0KGoo00<007oo00000goo00<007ooOol0QWoo00001Goo
001oogoo000027oo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`03Ool2001WOol40002
Ool01000Oomoogoo0`00RGoo00001Goo001oogoo000027oo00@007ooOol0009oo`04001oogoo0005
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol01`00Oomoogoo001oo`0008moo`0000Eoo`00Oomoo`00
00Qoo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo06Eoo`03001o
ogoo00=oo`03001oogoo08ioo`000Woo0P002Woo0P0017oo0P0017oo0P001Goo00<007ooOol0IGoo
00<007ooOol0U7oo000QOol00`00Oomoo`1UOol00`00Oomoo`2DOol0025oo`03001oogoo06=oo`80
09Moo`008Goo00<007ooOol0H7oo0`00VGoo000QOol2001OOol2002LOol0025oo`03001oogoo05ao
o`8009ioo`008Goo00<007ooOol0EGoo1@0000=oo`00Ool0Wgoo000QOol00`00Oomoo`1EOol00`00
Oomoo`02Ool00`00Oomoo`2OOol0025oo`03001oogoo05Aoo`03001oogoo0:Eoo`008Goo00<007oo
Ool0Dgoo00<007ooOol0YWoo000QOol00`00Oomoo`1BOol00`00Oomoo`2WOol0025oo`03001oogoo
059oo`03001oogoo0:Moo`008Goo0P00DWoo00<007ooOol0Z7oo000QOol00`00Oomoo`1AOol00`00
Oomoo`2XOol0025oo`03001oogoo04Moo`@00003Ool0000000<00:]oo`008Goo00<007ooOol0AWoo
00<007ooOol00Woo00<007ooOol0[Woo000QOol00`00Oomoo`16Ool00`00Oomoo`2cOol0025oo`03
001oogoo04Eoo`03001oogoo0;Aoo`008Goo00<007ooOol0A7oo00<007ooOol0]Goo000QOol00`00
Oomoo`14Ool00`00Oomoo`2eOol0025oo`8004Aoo`03001oogoo0;Ioo`008Goo00<007ooOol0?Woo
0`0000=oo`00Ool0^7oo000QOol00`00Oomoo`0nOol01000Oomoo`00^Woo000QOol00`00Oomoo`0m
Ool00`00Oomoo`2lOol0025oo`03001oogoo03eoo`03001oogoo0;aoo`000Woo0P0017oo0P0017oo
0P0017oo0P0017oo0`0017oo00<007ooOol0?Goo00<007ooOol0_7oo00001Goo001oogoo00000goo
0P000goo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`0lOol00`00
Oomoo`2mOol00005Ool007ooOol00008Ool01000Oomoo`000Woo00@007ooOol0009oo`@000Aoo`80
03eoo`03001oogoo0;eoo`0000Eoo`00Oomoo`0000Qoo`04001oogoo0002Ool01000Oomoo`000Woo
00<007oo00001Goo00<007ooOol0>goo00<007ooOol0_Woo00001Goo001oogoo000027oo00@007oo
Ool0009oo`04001oogoo0002Ool00`00Ool00005Ool00`00Oomoo`0kOol00`00Oomoo`2nOol0009o
o`8000Yoo`8000Aoo`8000Aoo`8000Eoo`03001oogoo03Ioo`80009oo`03001oogoo0;moo`008Goo
00<007ooOol0=Goo00H007ooOol007oo0031Ool0025oo`03001oogoo03Aoo`03001oogoo009oo`03
001oogoo0<1oo`008Goo00<007ooOol0=7oo00<007ooOol0aGoo000QOol00`00Oomoo`0dOol00`00
Oomoo`35Ool0025oo`8003Eoo`03001oogoo0<Eoo`008Goo00<007ooOol0<goo00<007ooOol0aWoo
000QOol00`00Oomoo`0cOol00`00Oomoo`36Ool0025oo`03001oogoo03=oo`03001oogoo0<Ioo`00
8Goo00<007ooOol0<goo00<007ooOol0aWoo000QOol00`00Oomoo`0`Ool01000Oomoo`00b7oo000Q
Ool00`00Oomoo`0`Ool01000Oomoo`00b7oo000QOol00`00Oomoo`0_Ool01000Ool00000bGoo000Q
Ool2000`Ool01000Ool00000bGoo000QOol00`00Oomoo`0^Ool01@00Oomoogoo0000bGoo000QOol0
0`00Oomoo`0^Ool00`00Oomoo`3;Ool0025oo`03001oogoo02eoo`03001oogoo0<aoo`008Goo00<0
07ooOol0;Goo00<007ooOol0c7oo000QOol00`00Oomoo`0]Ool00`00Oomoo`3<Ool0025oo`03001o
ogoo02Qoo`05001oogooOol0003?Ool0025oo`03001oogoo02Qoo`05001oogooOol0003?Ool0025o
o`8002Uoo`80009oo`03001oogoo0<eoo`008Goo00<007ooOol09goo00<007ooOol00P00d7oo000Q
Ool00`00Oomoo`0WOol01@00Oomoogoo0000d7oo000QOol00`00Oomoo`0WOol00`00Oomoo`3BOol0
025oo`03001oogoo02Moo`03001oogoo0=9oo`000Woo0P0017oo0P0017oo0P0017oo0P0017oo0P00
1Goo00<007ooOol09goo00<007ooOol0dWoo00001Goo001oogoo00000goo0P000goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol08goo0P0000=oo`00Ool0e7oo0000
1Goo001oogoo000027oo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`0017oo0P0097oo
00@007oo00000=Eoo`0000Eoo`00Oomoo`0000Qoo`04001oogoo0002Ool01000Oomoo`000Woo0`00
1Goo00<007ooOol08goo00@007ooOol00=Eoo`0000Eoo`00Oomoo`0000Qoo`04001oogoo0002Ool0
1000Oomoo`000Woo00<007ooOol01Goo00<007ooOol08Woo00<007ooOol0egoo0002Ool2000:Ool2
0004Ool20004Ool30004Ool00`00Oomoo`0ROol00`00Oomoo`3GOol0025oo`03001oogoo029oo`03
001oogoo0=Moo`008Goo00<007ooOol08Woo00<007ooOol0egoo000QOol00`00Oomoo`0QOol00`00
Oomoo`3HOol0025oo`03001oogoo025oo`03001oogoo0=Qoo`008Goo0P008Woo00<007ooOol0f7oo
000QOol00`00Oomoo`0QOol00`00Oomoo`3HOol0025oo`03001oogoo021oo`03001oogoo0=Uoo`00
8Goo00<007ooOol087oo00<007ooOol0fGoo000QOol00`00Oomoo`0POol00`00Oomoo`3IOol0025o
o`03001oogoo01aoo`04001oogoo003LOol0025oo`03001oogoo01aoo`04001oogoo003LOol0025o
o`03001oogoo01]oo`05001oo`00Ool0003LOol0025oo`8001aoo`04001oo`00003MOol0025oo`03
001oogoo01]oo`04001oogoo003MOol0025oo`03001oogoo01Yoo`03001oogoo0=moo`008Goo00<0
07ooOol06Woo00<007ooOol0ggoo000QOol01000Oomoo`006Goo00<007ooOol0ggoo000QOol01000
Oomoo`0067oo00<007ooOol0h7oo000QOol01000Oomoo`0067oo00<007ooOol0h7oo000QOol01000
Oomoo`005goo00<007ooOol0hGoo000QOol200000goo001oo`0EOol00`00Oomoo`3ROol0025oo`03
001oogoo008001Eoo`03001oogoo0>9oo`008Goo00<007ooOol00P005Goo00<007ooOol0hWoo000Q
Ool00`00Oomoo`02000DOol00`00Oomoo`3SOol0025oo`05001oo`00Ool0000DOol00`00Oomoo`3S
Ool0009oo`8000Aoo`8000Aoo`8000Aoo`8000Aoo`8000Eoo`05001oo`00Ool0000DOol00`00Oomo
o`3SOol00005Ool007ooOol00003Ool20003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0004Ool01@00Ool007oo00004goo00<007ooOol0i7oo00001Goo001oogoo000027oo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`0017oo0`0000=oo`00Ool04Woo00<007ooOol0i7oo
00001Goo001oogoo000027oo00@007ooOol0009oo`04001oogoo0003Ool20005Ool01@00Ool007oo
000047oo00@007ooOol00>Ioo`0000Eoo`00Oomoo`0000Qoo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`05001oo`00Ool0000@Ool3003WOol0009oo`8000Yoo`8000Aoo`8000Ao
o`8000Eoo`03001oo`00009oo`03001oogoo00aoo`04001oogoo003WOol0025oo`03001oo`00009o
o`03001oogoo00aoo`03001oogoo0>Qoo`008Goo00<007oo00000Woo00<007ooOol02goo00<007oo
Ool0jGoo000QOol00`00Ool00002Ool00`00Oomoo`0;Ool00`00Oomoo`3YOol0025oo`03001oo`00
009oo`03001oogoo00]oo`03001oogoo0>Uoo`008Goo0`000Woo00<007ooOol02Woo00<007ooOol0
jWoo000QOol00`00Ool00002Ool00`00Oomoo`0:Ool00`00Oomoo`3ZOol0025oo`03001oo`00009o
o`03001oogoo00Uoo`03001oogoo0>]oo`008Goo00<007oo00000Woo00<007ooOol02Goo00<007oo
Ool0jgoo000QOol20004Ool00`00Oomoo`08Ool00`00Oomoo`3[Ool0025oo`8000Aoo`03001oogoo
00Moo`03001oogoo0>aoo`008Goo0P0017oo00<007ooOol01goo00<007ooOol0k7oo000QOol20004
Ool00`00Oomoo`06Ool00`00Oomoo`3]Ool0025oo`8000Aoo`03001oogoo00Eoo`03001oogoo0>io
o`008Goo0P0017oo00<007ooOol017oo00<007ooOol0kgoo000QOol20004Ool00`00Oomoo`04Ool0
0`00Oomoo`3_Ool0025oo`8000Eoo`03001oogoo00=oo`03001oogoo0>moo`008Goo00<007ooOol0
17oo00<007ooOol00Woo00<007ooOol0l7oo000QOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00
Oomoo`3`Ool0025oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo0?1oo`008Goo0P001Goo
00<007ooOol00Woo00<007ooOol0l7oo000QOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomo
o`3`Ool0025oo`03001oogoo00Aoo`05001oogooOol0003cOol0025oo`03001oogoo00Eoo`04001o
ogoo003cOol0025oo`03001oogoo00Eoo`03001oo`000?Aoo`008Goo00<007ooOol01Goo0P00mGoo
0008Ool20004Ool20004Ool20003Ool30005Ool00`00Oomoo`05Ool00`00Oomoo`3dOol000Moo`04
001oogoo0003Ool20003Ool01000Oomoo`000goo00<007ooOol017oo00<007ooOol0o7oo0007Ool0
1000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Aoo`800?eoo`001goo00@007ooOol000Qo
o`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`3lOol000Moo`04001oogoo0008Ool01000
Oomoo`000goo00<007ooOol017oo00<007ooOol0o7oo0008Ool2000:Ool20003Ool2003oOol6Ool0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.34148, -0.000979632, 
  0.0403615, 6.47593*^-5}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{457, 639},
WindowMargins->{{Automatic, 20}, {Automatic, -2}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 51, 0, 36, "SubsectionIcon"],
Cell[1793, 53, 693, 24, 65, "Text"],
Cell[2489, 79, 525, 13, 66, "Text"],
Cell[3017, 94, 199, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[3241, 102, 221, 5, 77, "Input"],
Cell[3465, 109, 14378, 430, 184, 4498, 303, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

