(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     58609,       1491]*)
(*NotebookOutlinePosition[    130220,       4070]*)
(*  CellTagsIndexPosition[    130133,       4064]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Initialising the population", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"InitialiseContinuum", "[", 
              RowBox[{
                StyleBox["popln",
                  FontSlant->"Italic"], ",", "n", ",", "R", ",", 
                "\[CapitalDelta]", ",", "d", ",", "U", ",", "M", ",", "F"}], 
              "]"}], \(sets\ up\ a\ population, \ 
            with\ uniformly\ distributed\ locations\ for\ n\ individuals\ in\ \
d\ dimensions, \ \(\(on\)\(\ \)\(a\)\(\ \)\(range\)\(\ \)\(R . \ \ Box\)\(\ \
\)\(size\)\(\ \)\(is\)\(\ \)\(\(\[CapitalDelta]\)\(.\)\)\(\ \ \ \)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"InitialiseContinuum"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Genealogies`Continua`;\)\)], "Input",
  CellLabel->"In[2]:="],

Cell[TextData[{
  "The simulation can be set up on any number of dimensions ",
  Cell[BoxData[
      \(TraditionalForm\`\((d > 0)\)\)]],
  "; it is arranged on a circle, torus, or higher dimensional analogue, to \
avoid edge effects. Individuals are assigned to notional boxes of size \
\[CapitalDelta]: density dependence, described by ",
  Cell[BoxData[
      \(TraditionalForm\`U[]\)]],
  ", is set to zero beyond this distance, and so only individuals in adjacent \
boxes need be counted."
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`U[x, y, g\_x, g\_y]\)]],
  " is a function  giving the density, \[Rho], percieved at x due to an \
individual at y; this can depend on the genotype of the two individuals \
involved.  This is a fairly general form, the one restriction being that the \
effects of the many individuals sums up to give a net 'density'.  Thisdensity \
could be a number, or a vector, or indeed any structure."
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`M[\[Rho], x, g\_x]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`F[\[Rho], x, g\_x]\)]],
  "  give the mortality and fecundity as a functions of the density, location \
and genotype.  Here, these are defined for a spatially homogeneous habitat, \
and with no genotype-dependence:"
}], "Text"],

Cell[BoxData[{
    \(\(U[\[Gamma]_] := \(1\/\(\(2\)  \(\[Pi]\)\(\[VeryThinSpace]\)\(\[Gamma]\
\)\(\ \)\)\) 
            Exp[\(-\(DistanceSquared[#1, #2, 
                      R]\/\(2  \[Gamma]\)\)\)] &;\)\), "\[IndentingNewLine]", \

    \(\(M[\[Alpha]_] := \((1 + \[Alpha]*#1)\) &\ ;\)\), \
"\[IndentingNewLine]", 
    \(\(F[f_] := f &;\)\)}], "Input",
  CellLabel->"In[3]:="],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`U[]\)]],
  " is a Gaussian with standard deviation ",
  Cell[BoxData[
      \(TraditionalForm\`\@\[Gamma]\)]],
  ".  Fecundity ",
  Cell[BoxData[
      \(TraditionalForm\`F[]\)]],
  " is set at a constant, ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ".  Mortality increases linearly with density, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  ", as ",
  Cell[BoxData[
      \(TraditionalForm\`1 + \[Alpha]\[VeryThinSpace]\[Rho]\)]],
  ".  These are all pure functions, so that they are called using ",
  Cell[BoxData[
      \(TraditionalForm\`\(F[f]\)[\[Rho], x, g\_x]\)]],
  " etc."
}], "Text"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " The function U must allow for the possibility that the two locations are \
over the edge of the torus (e.g. at R-\[Epsilon], R+\[Epsilon]).   Hence, the \
function ",
  ButtonBox["DistanceSquared",
    ButtonData:>{"Boxing the individuals", "DistanceSquared"},
    ButtonStyle->"AddOnsLink"],
  "[] (or equivalent) must be used."
}], "Text"],

Cell[TextData[{
  "The population (labelled as ",
  StyleBox["p1",
    FontSlant->"Italic"],
  ") is set up on a range ",
  Cell[BoxData[
      \(TraditionalForm\`R = 30\)]],
  ":  "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R = 30; \[CapitalDelta] = 3;\), "\n", 
    \(InitialiseContinuum[p1, 100, R, \[CapitalDelta], 2, U[1], M[5], 
      F[2]]\)}], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \({165.85825387391185`, 200}\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell[TextData[{
  "The box size is \[CapitalDelta]=3; since the function ",
  Cell[BoxData[
      \(TraditionalForm\`U[]\)]],
  " is negligible for ",
  Cell[BoxData[
      \(TraditionalForm\`z > 3\)]],
  ", ignoring neighbours beyond \[CapitalDelta]=3 has little effect."
}], "Text"],

Cell[TextData[{
  "Note:  ",
  StyleBox["The list of individuals in each box, Individuals[], ",
    FontWeight->"Plain"],
  "must",
  StyleBox[" be cleared if a simulation with the same name has already been \
run.  Clear[Individuals[]] is not invoked automatically, in order that \
results from simulations with different names can be preserved.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "The net mortality and fecundity are returned.  Other variables can be \
inspected using functions such as ",
  ButtonBox["ExtantIndividuals",
    ButtonData:>{"Global variables", "ExtantIndividuals"},
    ButtonStyle->"AddOnsLink"],
  "[] and ",
  ButtonBox["ExtractExtant",
    ButtonData:>{"Sampling", "ExtractExtant"},
    ButtonStyle->"AddOnsLink"],
  "[]:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtantIndividuals[p1]\)], "Input",
  CellLabel->"In[157]:="],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
      21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 
      39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 
      57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 
      75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 
      93, 94, 95, 96, 97, 98, 99, 100}\)], "Output",
  CellLabel->"Out[157]="]
}, Open  ]],

Cell["\<\
This gives the density perceived at birth by individuals alive now:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtractExtant[Density, p1]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \({0.00906019799940666`, 0.10422400842702369`, 0.14185696587695173`, 
      0.14570255517443564`, 0.015805843977547144`, 0.29338000620798155`, 
      0.01498643159501583`, 0.10222814824952682`, 0.0800649839868948`, 
      0.22517563877142968`, 0.06494748366644765`, 0.02407309410690561`, 
      0.07095143631914752`, 0.03758361899292257`, 0.016621082843136223`, 
      0.17435514526175963`, 0.17994054767588236`, 0.04996529183468514`, 
      0.010218712734815876`, 0.006669697464650461`, 0.015980839471582003`, 
      0.07052432060792244`, 0.14083491846220123`, 0.0941682099312426`, 
      0.17339028207067667`, 0.03531954712251831`, 0.018626836768551674`, 
      0.14806171824913322`, 0.050955264856402685`, 0.017346989489205013`, 
      0.02769778765631143`, 0.03169491004950417`, 0.16443659504533642`, 
      0.12265333640519781`, 0.018677324460578834`, 0.2991736693321545`, 
      0.27087297815265443`, 0.07333322262768485`, 0.003052005524456701`, 
      0.05673401746897538`, 0.06046564756609837`, 0.16316332577472725`, 
      0.15220229442313832`, 0.051390338787085`, 0.21471568263982083`, 
      0.027808243386909934`, 0.12696777846776824`, 0.01520453681738863`, 
      0.07132363265400979`, 0.09836869607161783`, 0.12111651747428705`, 
      0.007742321440081789`, 0.015891975300696068`, 0.11447188448691226`, 
      0.05839808360869079`, 0.12871434147529118`, 0.053457913276587166`, 
      0.06245677808573464`, 0.10914582486533099`, 0.08280360954634952`, 
      0.0032451991864970746`, 0.004693415892145224`, 0.10103515557312391`, 
      0.12175645122637366`, 0.02011118080650759`, 0.2587051844278375`, 
      0.17685181731272265`, 0.0031745712139094437`, 0.1483097957316143`, 
      0.1109853988630439`, 0.15823992136370246`, 0.16582047123600238`, 
      0.23537314142046378`, 0.08046129827131478`, 0.02611341065018324`, 
      0.0696026457071646`, 0.1507902740117298`, 0.10729218756872815`, 
      0.03772630380008019`, 0.22660614247075886`, 0.11247140518383393`, 
      0.00037877517895242474`, 0.18426877785225423`, 0.010562491054323872`, 
      0.16965702268995955`, 0.1732314655637304`, 0.03199347270873865`, 
      0.07050496399028176`, 0.19188209054228197`, 0.00002959465764734501`, 
      0.23920980181828638`, 0.23470621822070148`, 0.015369390129392377`, 
      0.022107330762419747`, 0.10545695774182463`, 0.12268535442334515`, 
      0.07292882076043553`, 0.04652672930290685`, 0.06882682152310574`, 
      0.10186993831777116`}\)], "Output",
  CellLabel->"Out[8]="]
}, Closed]],

Cell["The initial density is close to that expected:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Mean[%], 100. \/R\^2}\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \({0.09518716480223477`, 0.1111111111111111`}\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"InitialiseContinuum", "[", 
              RowBox[{
                StyleBox["popln",
                  FontSlant->"Italic"], ",", "n", ",", "R", ",", 
                "\[CapitalDelta]", ",", "d", ",", "U", ",", "M", ",", "F", 
                ",", \(Genotype \[Rule] f\)}], 
              "]"}], \(sets\ the\ genotype\ to\ f[i, x]\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"InitialiseContinuum"],

Cell["The genotype is set to 0 by default:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtractExtant[Genotype, p1]\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell["\<\
This sets any individuals in a central circle of radius 5 to have \
genotype 1:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InitialiseContinuum[p2, 400, R, \[CapitalDelta], 2, U[1], M[5], F[2], 
      Genotype \[Rule] \((If[DistanceSquared[{R, R}/2, #2, R] < 5\^2, 1, 
              0] &)\)]\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \({1447.1304280839747`, 800}\)], "Output",
  CellLabel->"Out[45]="]
}, Open  ]],

Cell["These are the genotypes:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtractExtant[Genotype, p2]\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 
      0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 
      0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 
      0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 
      0, 0, 0, 0, 1, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 
      0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 
      1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[46]="]
}, Closed]],

Cell["Thisshows the locations of the two different genotypes:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(xl = ExtractExtant[Location, p2];\)\), "\[IndentingNewLine]", 
    \(gl = ExtractExtant[Genotype, p2]; 
    xgl = Transpose[{xl, gl}];\), "\[IndentingNewLine]", 
    \(\(Show[ListPlot[Cases[xgl, {_, 0}] /. {x_List, 0} \[RuleDelayed] x], 
        ListPlot[Cases[xgl, {_, 1}] /. {x_List, 1} \[RuleDelayed] x, 
          PlotStyle \[Rule] RGBColor[1, 0, 0]]];\)\)}], "Input",
  CellLabel->"In[47]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031891 0.0147151 0.0196597 [
[.18326 .00222 -3 -9 ]
[.18326 .00222 3 0 ]
[.34272 .00222 -6 -9 ]
[.34272 .00222 6 0 ]
[.50217 .00222 -6 -9 ]
[.50217 .00222 6 0 ]
[.66163 .00222 -6 -9 ]
[.66163 .00222 6 0 ]
[.82109 .00222 -6 -9 ]
[.82109 .00222 6 0 ]
[.98054 .00222 -6 -9 ]
[.98054 .00222 6 0 ]
[.01131 .11301 -6 -4.5 ]
[.01131 .11301 0 4.5 ]
[.01131 .21131 -12 -4.5 ]
[.01131 .21131 0 4.5 ]
[.01131 .30961 -12 -4.5 ]
[.01131 .30961 0 4.5 ]
[.01131 .40791 -12 -4.5 ]
[.01131 .40791 0 4.5 ]
[.01131 .50621 -12 -4.5 ]
[.01131 .50621 0 4.5 ]
[.01131 .60451 -12 -4.5 ]
[.01131 .60451 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18326 .01472 m
.18326 .02097 L
s
[(5)] .18326 .00222 0 1 Mshowa
.34272 .01472 m
.34272 .02097 L
s
[(10)] .34272 .00222 0 1 Mshowa
.50217 .01472 m
.50217 .02097 L
s
[(15)] .50217 .00222 0 1 Mshowa
.66163 .01472 m
.66163 .02097 L
s
[(20)] .66163 .00222 0 1 Mshowa
.82109 .01472 m
.82109 .02097 L
s
[(25)] .82109 .00222 0 1 Mshowa
.98054 .01472 m
.98054 .02097 L
s
[(30)] .98054 .00222 0 1 Mshowa
.125 Mabswid
.0557 .01472 m
.0557 .01847 L
s
.08759 .01472 m
.08759 .01847 L
s
.11948 .01472 m
.11948 .01847 L
s
.15137 .01472 m
.15137 .01847 L
s
.21516 .01472 m
.21516 .01847 L
s
.24705 .01472 m
.24705 .01847 L
s
.27894 .01472 m
.27894 .01847 L
s
.31083 .01472 m
.31083 .01847 L
s
.37461 .01472 m
.37461 .01847 L
s
.4065 .01472 m
.4065 .01847 L
s
.43839 .01472 m
.43839 .01847 L
s
.47028 .01472 m
.47028 .01847 L
s
.53407 .01472 m
.53407 .01847 L
s
.56596 .01472 m
.56596 .01847 L
s
.59785 .01472 m
.59785 .01847 L
s
.62974 .01472 m
.62974 .01847 L
s
.69352 .01472 m
.69352 .01847 L
s
.72541 .01472 m
.72541 .01847 L
s
.7573 .01472 m
.7573 .01847 L
s
.78919 .01472 m
.78919 .01847 L
s
.85298 .01472 m
.85298 .01847 L
s
.88487 .01472 m
.88487 .01847 L
s
.91676 .01472 m
.91676 .01847 L
s
.94865 .01472 m
.94865 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11301 m
.03006 .11301 L
s
[(5)] .01131 .11301 1 0 Mshowa
.02381 .21131 m
.03006 .21131 L
s
[(10)] .01131 .21131 1 0 Mshowa
.02381 .30961 m
.03006 .30961 L
s
[(15)] .01131 .30961 1 0 Mshowa
.02381 .40791 m
.03006 .40791 L
s
[(20)] .01131 .40791 1 0 Mshowa
.02381 .50621 m
.03006 .50621 L
s
[(25)] .01131 .50621 1 0 Mshowa
.02381 .60451 m
.03006 .60451 L
s
[(30)] .01131 .60451 1 0 Mshowa
.125 Mabswid
.02381 .03437 m
.02756 .03437 L
s
.02381 .05403 m
.02756 .05403 L
s
.02381 .07369 m
.02756 .07369 L
s
.02381 .09335 m
.02756 .09335 L
s
.02381 .13267 m
.02756 .13267 L
s
.02381 .15233 m
.02756 .15233 L
s
.02381 .17199 m
.02756 .17199 L
s
.02381 .19165 m
.02756 .19165 L
s
.02381 .23097 m
.02756 .23097 L
s
.02381 .25063 m
.02756 .25063 L
s
.02381 .27029 m
.02756 .27029 L
s
.02381 .28995 m
.02756 .28995 L
s
.02381 .32927 m
.02756 .32927 L
s
.02381 .34893 m
.02756 .34893 L
s
.02381 .36859 m
.02756 .36859 L
s
.02381 .38825 m
.02756 .38825 L
s
.02381 .42757 m
.02756 .42757 L
s
.02381 .44723 m
.02756 .44723 L
s
.02381 .46689 m
.02756 .46689 L
s
.02381 .48655 m
.02756 .48655 L
s
.02381 .52587 m
.02756 .52587 L
s
.02381 .54553 m
.02756 .54553 L
s
.02381 .56519 m
.02756 .56519 L
s
.02381 .58485 m
.02756 .58485 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.42219 .1656 Mdot
.18509 .18659 Mdot
.57797 .12838 Mdot
.89222 .28714 Mdot
.41507 .54686 Mdot
.30489 .05579 Mdot
.45301 .05167 Mdot
.62867 .59185 Mdot
.30717 .26905 Mdot
.74686 .07186 Mdot
.83108 .58792 Mdot
.34848 .51077 Mdot
.6698 .41604 Mdot
.75105 .3971 Mdot
.75812 .14362 Mdot
.35979 .45475 Mdot
.47704 .10255 Mdot
.89658 .24238 Mdot
.04784 .06559 Mdot
.29172 .25504 Mdot
.72121 .40104 Mdot
.52541 .1979 Mdot
.87067 .41763 Mdot
.20074 .29164 Mdot
.22468 .0163 Mdot
.43023 .49904 Mdot
.4471 .47719 Mdot
.09426 .059 Mdot
.9506 .38936 Mdot
.17821 .42113 Mdot
.92657 .33848 Mdot
.86703 .18081 Mdot
.22917 .54195 Mdot
.36543 .58742 Mdot
.33903 .13903 Mdot
.1885 .31049 Mdot
.13816 .13744 Mdot
.73881 .41596 Mdot
.67161 .26475 Mdot
.66836 .37167 Mdot
.70155 .4799 Mdot
.51395 .55505 Mdot
.75552 .15613 Mdot
.62746 .38896 Mdot
.28584 .40605 Mdot
.23494 .09438 Mdot
.12115 .11027 Mdot
.12059 .56145 Mdot
.67507 .53165 Mdot
.70852 .43601 Mdot
.18493 .5811 Mdot
.93354 .29459 Mdot
.53801 .20686 Mdot
.40718 .09061 Mdot
.27598 .40532 Mdot
.19605 .60074 Mdot
.17864 .30977 Mdot
.09927 .05401 Mdot
.7963 .02567 Mdot
.65029 .34711 Mdot
.14504 .09853 Mdot
.92232 .51561 Mdot
.94065 .12193 Mdot
.96932 .23573 Mdot
.42646 .51958 Mdot
.58595 .15983 Mdot
.17429 .12897 Mdot
.41371 .1636 Mdot
.97619 .42371 Mdot
.33824 .1243 Mdot
.2037 .41276 Mdot
.66849 .3817 Mdot
.08248 .32894 Mdot
.72671 .4706 Mdot
.12237 .22173 Mdot
.73793 .24958 Mdot
.67645 .30666 Mdot
.17579 .10447 Mdot
.52597 .1924 Mdot
.74262 .54538 Mdot
.42819 .43579 Mdot
.35043 .56495 Mdot
.74024 .06881 Mdot
.29176 .25072 Mdot
.03734 .20272 Mdot
.1932 .0437 Mdot
.27995 .55764 Mdot
.12797 .46789 Mdot
.95186 .16386 Mdot
.36589 .52702 Mdot
.91825 .10594 Mdot
.11873 .43473 Mdot
.20182 .05184 Mdot
.80751 .19873 Mdot
.18829 .45363 Mdot
.63812 .16974 Mdot
.88889 .50049 Mdot
.16463 .43269 Mdot
.78473 .04732 Mdot
.19331 .28355 Mdot
.44265 .12481 Mdot
.72851 .49288 Mdot
.50494 .03358 Mdot
.63359 .07286 Mdot
.32693 .58625 Mdot
.80662 .47864 Mdot
.16245 .14733 Mdot
.19232 .32362 Mdot
.2541 .25135 Mdot
.05149 .49543 Mdot
.83872 .2266 Mdot
.03108 .10865 Mdot
.13402 .33822 Mdot
.50668 .08978 Mdot
.20356 .10804 Mdot
.65489 .40594 Mdot
.06492 .56521 Mdot
.48639 .09704 Mdot
.79136 .32858 Mdot
.4587 .20611 Mdot
.36525 .12455 Mdot
.60052 .58402 Mdot
.35798 .03062 Mdot
.83183 .54534 Mdot
.03315 .58495 Mdot
.65208 .45201 Mdot
.3588 .19372 Mdot
.61097 .4913 Mdot
.85295 .1114 Mdot
.80015 .17744 Mdot
.41806 .50979 Mdot
.45872 .0676 Mdot
.79808 .53027 Mdot
.12455 .0517 Mdot
.33158 .28448 Mdot
.27326 .11087 Mdot
.32224 .30403 Mdot
.94398 .12503 Mdot
.97128 .37656 Mdot
.11483 .02834 Mdot
.19494 .21384 Mdot
.67731 .12306 Mdot
.71676 .16095 Mdot
.85977 .19729 Mdot
.61602 .12397 Mdot
.55201 .51732 Mdot
.36658 .02781 Mdot
.25358 .228 Mdot
.7454 .36896 Mdot
.29014 .11769 Mdot
.75466 .5969 Mdot
.19912 .10406 Mdot
.58353 .39778 Mdot
.50235 .58551 Mdot
.84731 .25154 Mdot
.62311 .40293 Mdot
.2551 .14229 Mdot
.09491 .49012 Mdot
.86906 .12919 Mdot
.82187 .27684 Mdot
.14747 .36474 Mdot
.55554 .17387 Mdot
.37334 .37234 Mdot
.38023 .08452 Mdot
.77035 .57906 Mdot
.85842 .10352 Mdot
.90358 .34223 Mdot
.25912 .30509 Mdot
.67229 .21466 Mdot
.18801 .41948 Mdot
.78377 .10018 Mdot
.34668 .15736 Mdot
.66012 .33995 Mdot
.77168 .58799 Mdot
.31058 .57211 Mdot
.41526 .51818 Mdot
.52077 .59755 Mdot
.53738 .42937 Mdot
.30207 .13899 Mdot
.90598 .07009 Mdot
.13787 .32402 Mdot
.14602 .57442 Mdot
.77173 .18138 Mdot
.02386 .19789 Mdot
.17967 .28158 Mdot
.07556 .45935 Mdot
.06551 .03322 Mdot
.75403 .33507 Mdot
.14007 .56763 Mdot
.63996 .02576 Mdot
.97459 .59772 Mdot
.84877 .44889 Mdot
.84873 .26571 Mdot
.3761 .09638 Mdot
.2834 .58599 Mdot
.7172 .41236 Mdot
.23165 .14136 Mdot
.6755 .39386 Mdot
.45817 .4108 Mdot
.55925 .43073 Mdot
.79874 .39975 Mdot
.5652 .43751 Mdot
.93051 .55537 Mdot
.05705 .08898 Mdot
.10559 .30438 Mdot
.6615 .5971 Mdot
.80273 .32289 Mdot
.92483 .19946 Mdot
.59489 .19625 Mdot
.27314 .41011 Mdot
.16053 .38995 Mdot
.69443 .58389 Mdot
.34233 .59471 Mdot
.15304 .16109 Mdot
.39236 .05405 Mdot
.1198 .08682 Mdot
.31058 .35418 Mdot
.43884 .09423 Mdot
.48839 .046 Mdot
.49455 .49927 Mdot
.87404 .45426 Mdot
.24522 .10388 Mdot
.73732 .07902 Mdot
.53133 .1245 Mdot
.41881 .08882 Mdot
.40209 .56792 Mdot
.05026 .04948 Mdot
.30611 .49581 Mdot
.72022 .29981 Mdot
.84781 .4163 Mdot
.25565 .26852 Mdot
.37707 .52153 Mdot
.36214 .41877 Mdot
.15566 .43236 Mdot
.21036 .28035 Mdot
.22659 .35917 Mdot
.18392 .24558 Mdot
.90102 .46786 Mdot
.44423 .55027 Mdot
.07703 .06628 Mdot
.2124 .29647 Mdot
.6805 .14925 Mdot
.83079 .4822 Mdot
.24924 .14246 Mdot
.92432 .60332 Mdot
.06269 .46662 Mdot
.72154 .25887 Mdot
.85931 .23575 Mdot
.80105 .39551 Mdot
.74784 .34395 Mdot
.2503 .59803 Mdot
.09115 .20942 Mdot
.40005 .13054 Mdot
.52304 .49253 Mdot
.17462 .59258 Mdot
.57926 .49372 Mdot
.13574 .14067 Mdot
.83826 .24956 Mdot
.25697 .50943 Mdot
.06102 .45856 Mdot
.79862 .23415 Mdot
.29372 .12932 Mdot
.22639 .5244 Mdot
.19589 .12481 Mdot
.68389 .04659 Mdot
.04508 .13674 Mdot
.12844 .15737 Mdot
.88988 .60057 Mdot
.27072 .51231 Mdot
.65672 .10586 Mdot
.23351 .06847 Mdot
.83864 .47621 Mdot
.92033 .54366 Mdot
.29032 .25029 Mdot
.71775 .03398 Mdot
.11824 .1402 Mdot
.05767 .5919 Mdot
.09697 .01817 Mdot
.90977 .44924 Mdot
.18763 .02211 Mdot
.66286 .54143 Mdot
.51145 .52075 Mdot
.45316 .48767 Mdot
.65335 .05925 Mdot
.51337 .54851 Mdot
.38684 .41347 Mdot
.77615 .52925 Mdot
.29241 .28799 Mdot
.74229 .54186 Mdot
.21925 .28453 Mdot
.81306 .10734 Mdot
.05543 .27714 Mdot
.17401 .17042 Mdot
.70139 .28725 Mdot
.85171 .31636 Mdot
.21184 .34325 Mdot
.48868 .5074 Mdot
.41623 .4185 Mdot
.22008 .23413 Mdot
.65448 .48115 Mdot
.02464 .5541 Mdot
.82196 .38853 Mdot
.94975 .29168 Mdot
.67176 .23283 Mdot
.44904 .53529 Mdot
.95091 .55008 Mdot
.76288 .22155 Mdot
.113 .33076 Mdot
.37046 .40755 Mdot
.87345 .11135 Mdot
.69652 .53091 Mdot
.87262 .16175 Mdot
.8551 .15709 Mdot
.90341 .47458 Mdot
.20715 .52877 Mdot
.47817 .54379 Mdot
.23679 .5832 Mdot
.88085 .32486 Mdot
.79166 .59861 Mdot
.1078 .57332 Mdot
.89875 .50197 Mdot
.39182 .05713 Mdot
.04994 .35494 Mdot
.51725 .50454 Mdot
.12707 .48487 Mdot
.33391 .58028 Mdot
.62944 .54558 Mdot
.12094 .60158 Mdot
.72913 .23543 Mdot
.64703 .23993 Mdot
.91802 .24133 Mdot
.04308 .34386 Mdot
.19503 .2287 Mdot
.97368 .59343 Mdot
.87042 .12328 Mdot
.34821 .35289 Mdot
.26479 .18221 Mdot
.25109 .35581 Mdot
.5162 .55128 Mdot
.5846 .13059 Mdot
.04537 .46398 Mdot
.55945 .58531 Mdot
.83088 .25 Mdot
.56631 .59639 Mdot
.19637 .52585 Mdot
.67643 .48783 Mdot
.8287 .18768 Mdot
.60142 .43637 Mdot
.8998 .37356 Mdot
.04063 .32049 Mdot
.34488 .06361 Mdot
.9758 .46102 Mdot
.76597 .08281 Mdot
.16872 .22573 Mdot
.22347 .09092 Mdot
.95289 .30439 Mdot
.52758 .2076 Mdot
.148 .13143 Mdot
.11593 .49176 Mdot
.19668 .13291 Mdot
.5103 .58358 Mdot
.83233 .08402 Mdot
.51504 .13727 Mdot
.09017 .01592 Mdot
.37013 .51605 Mdot
.84724 .52951 Mdot
.39778 .22637 Mdot
.34347 .33663 Mdot
.27359 .10965 Mdot
.25135 .44937 Mdot
.72701 .41459 Mdot
1 0 0 r
.44374 .22708 Mdot
.55016 .21869 Mdot
.36288 .29881 Mdot
.42952 .31141 Mdot
.53032 .3732 Mdot
.49729 .34155 Mdot
.44535 .39517 Mdot
.44992 .21874 Mdot
.48097 .28007 Mdot
.49031 .26051 Mdot
.60171 .26336 Mdot
.59773 .27003 Mdot
.46644 .24919 Mdot
.58913 .28422 Mdot
.63943 .28853 Mdot
.53196 .36325 Mdot
.60536 .35446 Mdot
.60487 .32258 Mdot
.54865 .32139 Mdot
.43889 .28999 Mdot
.57213 .24063 Mdot
.52452 .36089 Mdot
.57787 .23365 Mdot
.45445 .37637 Mdot
.56304 .27111 Mdot
.65832 .32866 Mdot
.57872 .32467 Mdot
.43545 .32034 Mdot
.52712 .29956 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[47]:=",
  ImageSize->{468, 289.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007D00018B000`400?l00000o`00003oo`3ooooE
0?ooo`00F`3oool300000480oooo0`0000040?ooo`800000?`3oool3000000<0oooo0`00000o0?oo
o`D000000`3oool2000003h0oooo1@0000020?ooo`<00000?`3oool3000000@0oooo0P00000:0?oo
o`00FP3oool01@000000oooo0?ooo`3oool000000480oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`00000o0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`0m0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000?P3oool01P000000
oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0>`3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000002@3oool005h0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000003l0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000?`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03l0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`070?ooo`00GP3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000?`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo03l0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0m0?ooo`8000000`3oool0
10000000oooo0?ooo`0000090?ooo`00FP3oool4000004<0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`00000o0?ooo`040000003oool0oooo0?ooo`@00000?`3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool00000?@3oool01P000000oooo0?ooo`3oool0
00000?ooo`@00000@P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo
001J0?ooo`030000003oool0oooo04<0oooo0P0000040?ooo`040000003oool0oooo000003h0oooo
0P0000030?ooo`030000003oool0oooo0400oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo000003d0oooo00L000000?ooo`3oool0oooo0000003oool000000440oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000T0oooo001J0?ooo`D00000
@P3oool00`000000oooo0?ooo`030?ooo`800000@03oool010000000oooo0?ooo`3oool5000003l0
oooo0`0000040?ooo`800000?`3oool300000080oooo1@00000n0?ooo`<00000103oool2000000X0
oooo000E0?ooo`030000003oool0oooo0?l0oooo_@3oool001D0oooo00<000000?ooo`3oool0o`3o
oonm0?ooo`005@3oool00`000000oooo0?ooo`3o0?oookd0oooo000E0?ooo`030000003oool0oooo
0?l0oooo_@3oool001D0oooo00<000000?ooo`3oool0o`3ooonm0?ooo`005@3oool00`000000oooo
0?ooo`3o0?oookd0oooo000E0?ooo`030000003oool0oooo0?l0oooo_@3oool000X0ooooo`000037
000000@0oooo000E0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool60000
00T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00`0000090?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`005@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo1P0000090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<000002@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool001D0oooo
00<000000?ooo`3oool0703oool3000002H0oooo100000140?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool02`3oool001D0oooo00<000000?ooo`3oool0AP3oool300000<X0oooo0`00
00130?ooo`<00000H03oool001D0oooo00<000000?ooo`3oool0AP3oool3000004h0oooo0`00001i
0?ooo`<00000@`3oool300000600oooo000E0?ooo`030000003oool0oooo02D0oooo0`00001_0?oo
o`<00000N@3oool3000004<0oooo0`00001P0?ooo`005@3oool00`000000oooo0?ooo`0U0?ooo`<0
0000J`3oool3000000040?ooo`000000000000000?l0oooo8`3oool001D0oooo00<000000?ooo`3o
ool03P3oool3000001@0oooo0`00001[0?ooo`<00000?`3oool3000005h0oooo0`0000230?ooo`00
5@3oool2000000l0oooo0`0000220?ooo`<00000?`3oool3000005h0oooo0`0000230?ooo`005@3o
ool00`000000oooo0?ooo`0>0?ooo`<00000a03oool3000005h0oooo0`0000230?ooo`005@3oool0
0`000000oooo0?ooo`3o0?oookd0oooo000E0?ooo`030000003oool0oooo04P0oooo0`00003o0?oo
og80oooo000E0?ooo`030000003oool0oooo04P0oooo0`00003o0?ooog80oooo000E0?ooo`030000
003oool0oooo04P0oooo0`0000230?ooo`<00000E@3oool3000002/0oooo0`00001U0?ooo`005@3o
ool00`000000oooo0?ooo`070?ooo`<00000a03oool3000005D0oooo0`00000[0?ooo`<00000I@3o
ool001D0oooo00<000000?ooo`3oool01`3oool3000001l0oooo0`00000P0?ooo`<00000K`3oool3
000000d0oooo0`00001E0?ooo`<00000:`3oool3000006D0oooo000E0?ooo`030000003oool0oooo
00L0oooo0`00000C0?ooo`<000002@3oool300000200oooo0`00001C0?ooo`<000006@3oool30000
0?/0oooo000E0?ooo`8000007P3oool3000000T0oooo0`00000P0?ooo`<00000;03oool3000002@0
oooo0`00000I0?ooo`<00000n`3oool001D0oooo00<000000?ooo`3oool06`3oool5000005/0oooo
0`00000T0?ooo`<00000o`3ooolH0?ooo`005@3oool00`000000oooo0?ooo`0K0?ooo`<00000G@3o
ool3000002@0oooo0`00001d0?ooo`<00000X03oool001D0oooo00<000000?ooo`3oool06`3oool3
000008@0oooo0`00001d0?ooo`<00000X03oool001D0oooo00<000000?ooo`3oool01P3oool30000
08@0oooo0`0000290?ooo`<00000X03oool001D0oooo00<000000?ooo`3oool01P3oool3000000X0
oooo0`00001g0?ooo`<00000<03oool300000?T0oooo000E0?ooo`030000003oool0oooo00H0oooo
0`00000:0?ooo`<00000A03oool300000300oooo0`00000`0?ooo`<00000O@3oool3000004P0oooo
0`00000^0?ooo`005@3oool00`000000oooo0?ooo`0C0?ooo`<00000A03oool3000006<0oooo0`00
001m0?ooo`H00000A@3oool3000002h0oooo000E0?ooo`030000003oool0oooo05X0oooo0`00002c
0?ooo`<00000;@3oool6000004D0oooo0`00000^0?ooo`005@3oool200000?l0oooo4P3oool30000
0300oooo0`00001f0?ooo`005@3oool00`000000oooo0?ooo`3o0?oooa40oooo0`00000/0?ooo`<0
0000NP3oool001D0oooo00<000000?ooo`3oool0o`3ooom00?ooo`<00000NP3oool001D0oooo00<0
00000?ooo`3oool0o`3ooom00?ooo`<000002P3oool3000006d0oooo000E0?ooo`030000003oool0
oooo09d0oooo0`00002/0?ooo`<000006`3oool3000004l0oooo000E0?ooo`030000003oool0oooo
02L0oooo0`00001c0?ooo`<00000[03oool3000001/0oooo0`00001?0?ooo`005@3oool00`000000
oooo0?ooo`0:0?ooo`<000006P3oool3000007<0oooo0`00000>0?ooo`<000009@3oool300000940
oooo0`00001?0?ooo`005@3oool00`000000oooo0?ooo`0:0?ooo`<000006P3oool3000002`0oooo
0`00001@0?ooo`<000000P3oool3000002D0oooo0`00003S0?ooo`005@3oool00`000000oooo0?oo
o`0:0?ooo`<00000B@3oool300000080oooo0`00001;0?ooo`<000000P3oool3000000H0oooo0`00
000L0?ooo`<00000h`3oool001D0oooo0P00001G0?ooo`<000000P3oool3000003d0oooo0`00000;
0?ooo`<000002`3oool300000?l0oooo0`3oool001D0oooo00<000000?ooo`3oool0<P3oool30000
02H0oooo0`00000m0?ooo`<000006@3oool3000001<0oooo0`00003/0?ooo`005@3oool00`000000
oooo0?ooo`0b0?ooo`<00000IP3oool3000002l0oooo0`0000240?ooo`<00000I@3oool001D0oooo
00<000000?ooo`3oool0<P3oool3000009@0oooo0`000000103oool000000000000000240?ooo`<0
0000I@3oool001D0oooo00<000000?ooo`3oool0@03oool3000000P0oooo0`00000B0?ooo`<00000
IP3oool3000008P0oooo0`00000O0?ooo`<00000@`3oool001D0oooo00<000000?ooo`3oool0@03o
ool3000000P0oooo0`00000B0?ooo`<00000IP3oool3000004h0oooo0`0000140?ooo`<000004P3o
ool3000001P0oooo0`00000X0?ooo`002P3oool3000000P0oooo00<000000?ooo`0000000P00000n
0?ooo`<00000203oool500000100oooo0`00000:0?ooo`<00000ZP3oool3000004@0oooo0`00000B
0?ooo`<00000603oool3000002P0oooo00090?ooo`050000003oool0oooo0?ooo`0000001`3oool0
0`000000oooo00000002000002D0oooo0`00000S0?ooo`<00000703oool400000:X0oooo0`000014
0?ooo`<000003`3oool3000000H0oooo0`00000B0?ooo`<00000:03oool000d0oooo00<000000?oo
o`3oool01@3oool00`000000oooo00000002000002D0oooo0`00000S0?ooo`<00000703oool40000
0?l0oooo103oool3000000H0oooo0`00000m0?ooo`003@3oool00`000000oooo0?ooo`050?ooo`<0
00009`3oool300000480oooo0`00003o0?ooo`D0oooo0`0000060?ooo`<00000?@3oool000T0oooo
100000080?ooo`030000003oool0oooo07@0oooo0`00003o0?ooodH0oooo00090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0M03oool300000?l0ooooAP3oool000T0oooo1@000007
0?ooo`030000003oool0oooo07@0oooo0`00002/0?ooo`<00000M@3oool3000001h0oooo000E0?oo
o`030000003oool0oooo04T0oooo0`00000n0?ooo`<000002@3oool300000200oooo0`00000U0?oo
o`<00000903oool3000001P0oooo0`00001E0?ooo`<000007@3oool4000001d0oooo000E0?ooo`03
0000003oool0oooo04T0oooo0`00000n0?ooo`<000002@3oool300000200oooo0`00000U0?ooo`<0
0000903oool3000001P0oooo0`00001E0?ooo`<000007@3oool4000001d0oooo000E0?ooo`030000
003oool0oooo03l0oooo0`0000070?ooo`<00000:P3oool300000140oooo0`0000090?ooo`<00000
803oool3000002D0oooo0`00000B0?ooo`<000003`3oool3000006l0oooo1000000N0?ooo`<00000
7@3oool001D0oooo00<000000?ooo`3oool0=03oool3000000P0oooo0`00000d0?ooo`<00000;@3o
ool3000004d0oooo1P00001n0?ooo`<00000?`3oool001D0oooo00<000000?ooo`3oool0=03oool3
000000P0oooo0`0000080?ooo`<00000:@3oool3000002d0oooo0`00001=0?ooo`H00000OP3oool3
000003l0oooo000E0?ooo`800000=@3oool3000001<0oooo0`00001I0?ooo`<00000D03oool30000
0<00oooo000E0?ooo`030000003oool0oooo00D0oooo0`00000W0?ooo`<00000603oool3000008d0
oooo0`00003O0?ooo`005@3oool00`000000oooo0?ooo`050?ooo`<000007P3oool3000000D0oooo
100000170?ooo`<000003P3oool3000004d0oooo0`00003O0?ooo`005@3oool00`000000oooo0?oo
o`050?ooo`<000007P3oool3000000D0oooo1000000W0?ooo`<000001@3oool600000180oooo0`00
000>0?ooo`<00000C@3oool300000=l0oooo000E0?ooo`030000003oool0oooo02H0oooo0`000005
0?ooo`<00000:03oool3000000D0oooo1P00000B0?ooo`<000003P3oool300000;/0oooo0`00001a
0?ooo`005@3oool00`000000oooo0?ooo`0j0?ooo`<00000703oool3000000D0oooo1P00003Q0?oo
o`<00000L@3oool001D0oooo00<000000?ooo`3oool0>P3oool300000>P0oooo0`00000P0?ooo`<0
0000L@3oool001D0oooo00<000000?ooo`3oool0>P3oool300000>P0oooo0`00002D0?ooo`005@3o
ool200000?l0oooo9`3oool3000009@0oooo000E0?ooo`030000003oool0oooo0?l0ooooB03oool3
00000780oooo000E0?ooo`030000003oool0oooo02/0oooo0`00001P0?ooo`<00000]P3oool30000
02X0oooo0`0000150?ooo`005@3oool00`000000oooo0?ooo`0[0?ooo`<00000H03oool3000006T0
oooo0`00001:0?ooo`<00000:P3oool3000004D0oooo000E0?ooo`030000003oool0oooo02/0oooo
0`0000080?ooo`<00000E@3oool3000006T0oooo0`00000h0?ooo`<00000?03oool3000000D0oooo
0`00000m0?ooo`005@3oool00`000000oooo0?ooo`0f0?ooo`<00000L`3oool3000004/0oooo0`00
000h0?ooo`<00000A03oool300000240oooo0`00000I0?ooo`005@3oool00`000000oooo0?ooo`0f
0?ooo`<00000L`3oool3000000040?ooo`000000000000000880oooo0`0000140?ooo`<000008@3o
ool3000001T0oooo000E0?ooo`030000003oool0oooo0:`0oooo0`000000103oool0000000000000
003]0?ooo`<000006@3oool001D0oooo00<000000?ooo`3oool0?`3oool3000006h0oooo0`00001O
0?ooo`<00000Y`3oool001D0oooo0P0000100?ooo`<00000ZP3oool3000002<0oooo0`00002W0?oo
o`005@3oool00`000000oooo0?ooo`0o0?ooo`<00000ZP3oool3000002<0oooo0`00002W0?ooo`00
5@3oool00`000000oooo0?ooo`3/0?ooo`<00000K03oool3000005h0oooo000E0?ooo`030000003o
ool0oooo0?l0ooooG03oool3000005h0oooo000E0?ooo`030000003oool0oooo06T0oooo0`00003R
0?ooo`<000002P3oool3000001/0oooo0`0000100?ooo`005@3oool00`000000oooo0?ooo`1Y0?oo
o`<00000hP3oool3000002P0oooo0`0000100?ooo`005@3oool00`000000oooo0?ooo`140?ooo`<0
00008P3oool300000>80oooo0`00000X0?ooo`<00000@03oool001D0oooo00<000000?ooo`3oool0
A03oool300000?l0oooo8P3oool300000540oooo000E0?ooo`030000003oool0oooo04@0oooo0`00
003o0?ooob80oooo0`00001A0?ooo`005@3oool2000009@0oooo0`0000190?ooo`<00000QP3oool3
00000540oooo000E0?ooo`030000003oool0oooo09<0oooo0`0000190?ooo`<00000fP3oool001<0
oooo0`00002E0?ooo`<00000B@3oool3000001`0oooo0`00001e0?ooo`<00000@`3oool001<0oooo
0`00003Q0?ooo`<00000703oool3000005h0oooo0`00000D0?ooo`<000006`3oool3000002D0oooo
000C0?ooo`<00000h@3oool3000001`0oooo0`00001N0?ooo`<00000503oool3000001/0oooo0`00
000U0?ooo`005@3oool010000000oooo0?ooo`3oool300000?l0ooooG03oool300000380oooo0`00
000U0?ooo`005@3oool010000000oooo0?ooo`3oool300000;`0oooo0`00000Q0?ooo`<00000e@3o
ool000@0oooo0`0000040?ooo`800000203oool010000000oooo0?ooo`3oool300000;`0oooo0`00
000M0?ooo`<0000000@0oooo0000000000000000e@3oool000D0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo01X0oooo0`00002S0?ooo`<00000
7@3oool3000000040?ooo`000000000000000=D0oooo00050?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000001`3oool3000001X0oooo0`0000330?ooo`<00000f@3oool000D0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo01X0
oooo0`00000/0?ooo`<00000e@3oool3000009P0oooo00050?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`190?ooo`<00000e@3oool3000009P0
oooo00040?ooo`800000103oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo04T0
oooo0`00001`0?ooo`<0o`00:`3oool30?l003@0oooo0`00002H0?ooo`001@3oool00`000000oooo
0?ooo`030?ooo`800000203oool00`000000oooo0?ooo`0X0?ooo`<00000T@3oool30?l002/0oooo
0`3o001M0?ooo`<00000K`3oool001D0oooo00<000000?ooo`3oool0:03oool300000940oooo0`3o
000[0?ooo`<0o`00G@3oool3000006l0oooo000E0?ooo`030000003oool0oooo02P0oooo0`00000B
0?ooo`<00000I@3oool300000:80oooo0`00000P0?ooo`<00000C03oool001D0oooo00<000000?oo
o`3oool0?@3oool3000000T0oooo0`00000G0?ooo`<00000?`3oool300000180oooo0`3o002`0?oo
o`<00000C03oool001D0oooo00<000000?ooo`3oool0?@3oool3000000T0oooo0`00000G0?ooo`<0
0000?`3oool300000180oooo0`3o002`0?ooo`<00000C03oool001D0oooo0P00001:0?ooo`<00000
5`3oool3000005@0oooo0`3o001T0?ooo`<00000V03oool001D0oooo00<000000?ooo`3oool0E03o
ool3000009l0oooo0`3o000X0?ooo`<000005`3oool3000001`0oooo0`00001O0?ooo`005@3oool0
0`000000oooo0?ooo`1D0?ooo`<00000W`3oool30?l002P0oooo0`00000G0?ooo`<00000703oool3
000001T0oooo0`00000_0?ooo`<000004@3oool001D0oooo00<000000?ooo`3oool0E03oool30000
09l0oooo0`3o000M0?ooo`<000008P3oool3000001`0oooo0`00000I0?ooo`<00000;`3oool30000
0140oooo000E0?ooo`030000003oool0oooo0?@0oooo0`3o000O0?ooo`<00000G@3oool3000001P0
oooo0`00000D0?ooo`<000004@3oool001D0oooo00<000000?ooo`3oool0m03oool30?l001l0oooo
0`00001^0?ooo`<000001`3oool3000002P0oooo000E0?ooo`030000003oool0oooo04@0oooo0`00
002]0?ooo`<0o`00T03oool3000000L0oooo0`00000X0?ooo`005@3oool00`000000oooo0?ooo`14
0?ooo`<00000o`3ooom10?ooo`<00000<P3oool001D0oooo00<000000?ooo`3oool0A03oool30000
02d0oooo1000001<0?ooo`<0o`00N03oool3000002L0oooo1P00001=0?ooo`005@3oool2000006D0
oooo0`00000=0?ooo`@00000C03oool30?l007P0oooo0`00000W0?ooo`H000000P3oool3000004P0
oooo000E0?ooo`030000003oool0oooo06@0oooo0`00000=0?ooo`@00000C03oool30?l007P0oooo
0`00000W0?ooo`H000000P3oool3000004P0oooo000E0?ooo`030000003oool0oooo06@0oooo0`00
000>0?ooo`<00000n@3oool3000004P0oooo000E0?ooo`030000003oool0oooo07D0oooo0`000030
0?ooo`<00000P@3oool001D0oooo00<000000?ooo`3oool0c`3oool30?l006H0oooo0`0000210?oo
o`005@3oool00`000000oooo0?ooo`3?0?ooo`<0o`00;`3oool30?l003@0oooo0`0000210?ooo`00
5@3oool00`000000oooo0?ooo`3?0?ooo`<0o`00;`3oool30?l001d0oooo0`00001=0?ooo`<00000
B03oool001D0oooo00<000000?ooo`3oool0I03oool3000009X0oooo0`3o000M0?ooo`<00000C@3o
ool3000004P0oooo000E0?ooo`030000003oool0oooo06@0oooo0`00000E0?ooo`<00000P03oool3
0?l001l0oooo0`00001=0?ooo`<00000B03oool001D0oooo0P00001U0?ooo`<000005@3oool30000
0740oooo0`3o000<0?ooo`<0o`00^P3oool001D0oooo00<000000?ooo`3oool0O03oool300000740
oooo0`3o000<0?ooo`<0o`00^P3oool001D0oooo00<000000?ooo`3oool02P3oool300000><0oooo
0`3o001b0?ooo`<00000E03oool001D0oooo00<000000?ooo`3oool02P3oool300000?l0ooooF@3o
ool3000005@0oooo000E0?ooo`030000003oool0oooo00X0oooo0`00000e0?ooo`<000002`3oool3
000007P0oooo0`3o002G0?ooo`<00000E03oool001D0oooo00<000000?ooo`3oool0@P3oool30000
00<0oooo0`0000050?ooo`<00000N03oool30?l00>h0oooo000E0?ooo`030000003oool0oooo0480
oooo0`0000030?ooo`<000001@3oool3000000040?ooo`000000000000000300oooo0`0000110?oo
o`<0o`00;P3oool30?l00;d0oooo000E0?ooo`030000003oool0oooo04P0oooo0`0000090?ooo`<0
00007P3oool3000000l0oooo0`00001b0?ooo`<0o`004`3oool30?l001T0oooo0`00001D0?ooo`<0
0000=03oool001D0oooo00<000000?ooo`3oool0E03oool3000001h0oooo0`00000?0?ooo`<00000
;@3oool30?l00480oooo0`3o000C0?ooo`<0o`006@3oool3000005@0oooo0`00000d0?ooo`005@3o
ool2000004`0oooo0`00000W0?ooo`<00000?`3oool30?l005P0oooo0`3o000I0?ooo`<00000E03o
ool3000001L0oooo0`00000J0?ooo`005@3oool00`000000oooo0?ooo`1;0?ooo`<00000J@3oool3
0?l00=h0oooo0`0000040?ooo`<000006P3oool001D0oooo00<000000?ooo`3oool0B`3oool30000
00<0oooo0`00003o0?ooodD0oooo0`0000040?ooo`<000006P3oool001D0oooo00<000000?ooo`3o
ool0D@3oool300000440oooo0`3o00170?ooo`<0o`00]P3oool300000240oooo000E0?ooo`030000
003oool0oooo0540oooo0`0000110?ooo`<0o`00A`3oool30?l005D0oooo0`0000220?ooo`005@3o
ool00`000000oooo0?ooo`230?ooo`<000003`3oool30?l004L0oooo0`3o001E0?ooo`<00000PP3o
ool000@0oooo0`0000030?ooo`<00000203oool00`000000oooo0?ooo`0P0?ooo`<00000@`3oool3
000001X0oooo0`00002a0?ooo`<00000IP3oool3000001T0oooo00050?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0200oooo0`000013
0?ooo`<000006P3oool3000009d0oooo0`00001j0?ooo`<000006@3oool000D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0200oooo0`00000N0?oo
o`<000000P3oool3000001d0oooo0`00002j0?ooo`<00000NP3oool3000001T0oooo00050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool300000440oooo0`0000020?ooo`<0
0000JP3oool30?l006d0oooo0`00002F0?ooo`001@3oool010000000oooo0?ooo`3oool4000000P0
oooo00<000000?ooo`3oool0@@3oool300000080oooo0`00001Z0?ooo`<0o`00o`3oool70?ooo`00
103oool2000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2c0?ooo`<0o`00
_@3oool3000004H0oooo00050?ooo`040000003oool0oooo0?ooo`D000001`3oool00`000000oooo
0?ooo`3o0?ooog@0oooo0`0000160?ooo`005@3oool00`000000oooo0?ooo`030?ooo`<00000/03o
ool30?l00300oooo0`3o00270?ooo`<00000AP3oool001D0oooo00<000000?ooo`3oool00`3oool3
00000480oooo0`00001[0?ooo`<0o`00<03oool30?l001L0oooo0`3o001F0?ooo`<00000G@3oool0
01D0oooo00<000000?ooo`3oool00`3oool3000002T0oooo0`00000F0?ooo`<00000J`3oool30?l0
0300oooo0`3o000;0?ooo`<0o`002@3oool30?l005H0oooo0`00000Q0?ooo`<00000>@3oool001D0
oooo00<000000?ooo`3oool0;`3oool3000001H0oooo0`00002/0?ooo`<0o`002@3oool30?l005H0
oooo0`00000Q0?ooo`<00000>@3oool001D0oooo00<000000?ooo`3oool05P3oool3000001H0oooo
0`0000350?ooo`<0o`008@3oool30?l003T0oooo0`00000V0?ooo`<00000>@3oool001D0oooo0P00
000G0?ooo`<000002`3oool300000?@0oooo0`3o000i0?ooo`<00000HP3oool001D0oooo00<00000
0?ooo`3oool05P3oool3000000/0oooo0`00003d0?ooo`<0o`00>@3oool300000680oooo000E0?oo
o`030000003oool0oooo02@0oooo0`00001U0?ooo`<00000]`3oool3000007<0oooo000E0?ooo`03
0000003oool0oooo02d0oooo0`00001L0?ooo`<00000]`3oool3000004/0oooo0`00000U0?ooo`00
5@3oool00`000000oooo0?ooo`0]0?ooo`<00000G03oool3000004<0oooo0`3o00170?ooo`<00000
9`3oool3000004/0oooo0`00000U0?ooo`005@3oool00`000000oooo0?ooo`0]0?ooo`<000008@3o
ool3000007h0oooo0`3o00170?ooo`<00000J`3oool3000000L0oooo0`00000U0?ooo`005@3oool0
0`000000oooo0?ooo`040?ooo`<00000BP3oool3000007h0oooo0`3o00170?ooo`<00000903oool3
000004@0oooo0`00000_0?ooo`005@3oool00`000000oooo0?ooo`040?ooo`<00000BP3oool30000
0<<0oooo0`00000Y0?ooo`<00000A03oool3000002l0oooo000E0?ooo`030000003oool0oooo00@0
oooo0`00003o0?oooa40oooo0`00000Y0?ooo`<00000MP3oool001D0oooo0P00003o0?oooaT0oooo
0`00002R0?ooo`005@3oool00`000000oooo0?ooo`1m0?ooo`<000003P3oool300000780oooo0`3o
002f0?ooo`005@3oool00`000000oooo0?ooo`070?ooo`<00000F03oool3000001P0oooo0`00000>
0?ooo`<00000LP3oool30?l00;H0oooo000E0?ooo`030000003oool0oooo00L0oooo0`00001=0?oo
o`<00000203oool3000001P0oooo0`00000>0?ooo`<00000LP3oool30?l00;H0oooo000E0?ooo`03
0000003oool0oooo00L0oooo0`00001=0?ooo`<00000203oool3000007T0oooo0`3o003K0?ooo`00
5@3oool00`000000oooo0?ooo`1G0?ooo`<00000Q03oool30?l000040?ooo`3o0000o`000?l00=L0
oooo000E0?ooo`030000003oool0oooo03<0oooo0`00002X0?ooo`<0o`0000@0oooo0?l0003o0000
o`00e`3oool001D0oooo00<000000?ooo`3oool0<`3oool300000:`0oooo0`3o003G0?ooo`005@3o
ool2000003@0oooo0`00003o0?ooo`d0oooo0`00001g0?ooo`005@3oool00`000000oooo0?ooo`2J
0?ooo`<00000PP3oool300000200oooo0`00001g0?ooo`005@3oool00`000000oooo0?ooo`2J0?oo
o`<00000A03oool30?l003/0oooo0`00000P0?ooo`<00000@`3oool300000340oooo000E0?ooo`03
0000003oool0oooo09X0oooo0`00000Q0?ooo`<0o`00803oool30?l003/0oooo0`00001V0?ooo`<0
00007P3oool300000100oooo000E0?ooo`030000003oool0oooo0;h0oooo0`3o000P0?ooo`<0o`00
Y03oool3000001h0oooo0`00000@0?ooo`005@3oool00`000000oooo0?ooo`2n0?ooo`<0o`00j03o
ool300000100oooo000E0?ooo`030000003oool0oooo0?l0oooo803oool3000009X0oooo000E0?oo
o`030000003oool0oooo0?l0oooo803oool3000009X0oooo000E0?ooo`030000003oool0oooo0?l0
oooo803oool3000009X0oooo000E0?ooo`800000>P3oool300000=40oooo0`00001E0?ooo`<00000
=`3oool3000001X0oooo000E0?ooo`030000003oool0oooo03T0oooo0`00003A0?ooo`<00000E@3o
ool3000003L0oooo0`00000J0?ooo`005@3oool00`000000oooo0?ooo`0i0?ooo`<00000d@3oool3
000001<0oooo0`00000o0?ooo`<00000=`3oool3000001X0oooo000E0?ooo`030000003oool0oooo
0;X0oooo0`3o001V0?ooo`<00000=P3oool3000005d0oooo000E0?ooo`030000003oool0oooo0;X0
oooo0`3o000l0?ooo`<000009`3oool3000001l0oooo0`00000D0?ooo`<00000G@3oool001D0oooo
00<000000?ooo`3oool0^P3oool30?l003`0oooo0`00000k0?ooo`<000002`3oool3000001<0oooo
1000001M0?ooo`005@3oool00`000000oooo0?ooo`3i0?ooo`<000003`3oool3000002T0oooo0`00
000;0?ooo`<000004`3oool3000005h0oooo00030?ooo`D000000`3oool2000000P0oooo00<00000
0?ooo`3oool0KP3oool3000009X0oooo0`00000Y0?ooo`<000008@3oool3000005h0oooo00040?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?oo
o`1^0?ooo`<0000000@0oooo00000000000000008`3oool300000700oooo0`00000;0?ooo`<00000
X03oool000D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000070?ooo`<00000
KP3oool3000000040?ooo`0000000000000002<0oooo0`00001n0?ooo`<00000X03oool000H0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0K03oool3000000<0oooo0`00000S0?ooo`<000009@3oool3000005H0oooo0`00002P0?ooo`00
0`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000001`3oool00`00
0000oooo0?ooo`1=0?ooo`<00000703oool300000340oooo0`00000M0?ooo`<00000L`3oool30000
08<0oooo00030?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000007
0?ooo`030000003oool0oooo04d0oooo0`00000L0?ooo`<00000<@3oool3000001d0oooo0`00001M
0?ooo`<000004`3oool3000000040?ooo`000000000000000080oooo0`00000_0?ooo`<00000B03o
ool000@0oooo0`0000040?ooo`800000203oool00`000000oooo0?ooo`1=0?ooo`<00000A@3oool3
000000P0oooo0`00000:0?ooo`<00000L03oool3000001<0oooo0`000000103oool0000000000000
00020?ooo`<00000;`3oool3000000L0oooo0`00000n0?ooo`005@3oool00`000000oooo0?ooo`16
0?ooo`<00000C03oool3000001D0oooo0`00001`0?ooo`<000005`3oool300000080oooo0`00000_
0?ooo`<000001`3oool3000003h0oooo000E0?ooo`030000003oool0oooo0440oooo0`0000020?oo
o`<00000C03oool3000001D0oooo0`00003;0?ooo`<00000?P3oool001D0oooo00<000000?ooo`3o
ool0@@3oool300000080oooo0`00003o0?ooof<0oooo0`00000>0?ooo`005@3oool00`000000oooo
0?ooo`110?ooo`<00000o`3ooomX0?ooo`<000003P3oool001D0oooo0P00003U0?ooo`<00000a03o
ool3000000h0oooo000E0?ooo`030000003oool0oooo0>@0oooo0`0000070?ooo`<00000b`3oool0
01D0oooo00<000000?ooo`3oool0=`3oool3000000040?ooo`000000000000000:H0oooo0`000007
0?ooo`<00000b`3oool001D0oooo00<000000?ooo`3oool09P3oool3000000h0oooo0`000000103o
ool0000000000000001e0?ooo`<00000>03oool300000100oooo0`00000^0?ooo`<00000Q`3oool0
01D0oooo00<000000?ooo`3oool09P3oool3000000h0oooo0`000000103oool0000000000000001e
0?ooo`<00000>`3oool3000000d0oooo0`00000^0?ooo`<00000Q`3oool001D0oooo00<000000?oo
o`3oool09P3oool3000008X0oooo0`00000k0?ooo`<000003@3oool3000002h0oooo0`0000270?oo
o`005@3oool00`000000oooo0?ooo`3a0?ooo`<00000b03oool001D0oooo00<000000?ooo`3oool0
o`3ooonm0?ooo`005@3oool00`000000oooo0?ooo`3o0?oookd0oooo000E0?ooo`800000H`3oool3
00000?l0oooo3@3oool3000001T0oooo0`00000/0?ooo`005@3oool00`000000oooo0?ooo`1R0?oo
o`<00000o`3oool=0?ooo`<000006@3oool3000002`0oooo000E0?ooo`030000003oool0oooo04H0
oooo0`00000I0?ooo`<00000/`3oool3000005H0oooo0`00000I0?ooo`<00000;03oool001D0oooo
00<000000?ooo`3oool0AP3oool3000004/0oooo0`0000210?ooo`<00000HP3oool3000003`0oooo
000E0?ooo`030000003oool0oooo04H0oooo0`00001;0?ooo`<00000P@3oool300000680oooo0`00
000l0?ooo`005@3oool00`000000oooo0?ooo`0<0?ooo`<00000103oool3000007h0oooo0`00003V
0?ooo`<00000?03oool001D0oooo00<000000?ooo`3oool0303oool3000000@0oooo0`00003o0?oo
oiH0oooo0`00000>0?ooo`005@3oool00`000000oooo0?ooo`050?ooo`<00000103oool3000000@0
oooo0`00003o0?oooiH0oooo0`00000>0?ooo`005@3oool00`000000oooo0?ooo`050?ooo`<00000
1@3oool300000?l0ooooW03oool3000000h0oooo000E0?ooo`8000001P3oool3000000D0oooo0`00
000J0?ooo`<00000o`3ooomM0?ooo`<00000<03oool001D0oooo00<000000?ooo`3oool03@3oool3
000001X0oooo0`00003o0?ooo`h0oooo0`00001<0?ooo`<00000<03oool001D0oooo00<000000?oo
o`3oool0:P3oool300000?l0oooo3P3oool3000004`0oooo0`00000`0?ooo`005@3oool00`000000
oooo0?ooo`3o0?oooc/0oooo0`00001=0?ooo`<00000;`3oool001D0oooo00<000000?ooo`3oool0
^`3oool300000:l0oooo0`00000J0?ooo`<00000;`3oool001D0oooo00<000000?ooo`3oool0^`3o
ool300000700oooo0`00000]0?ooo`<00000303oool3000001X0oooo0`00000_0?ooo`005@3oool0
0`000000oooo0?ooo`2k0?ooo`<00000F`3oool300000180oooo0`00000]0?ooo`<00000203oool3
000000040?ooo`0000000000000004`0oooo000E0?ooo`030000003oool0oooo02X0oooo0`00003/
0?ooo`<000004P3oool3000002d0oooo0`0000080?ooo`<00000D03oool001D0oooo00<000000?oo
o`3oool0:P3oool300000>`0oooo0`00001=0?ooo`<00000D03oool001D0oooo0P00000[0?ooo`<0
0000T@3oool300000680oooo0`00002F0?ooo`005@3oool00`000000oooo0?ooo`0L0?ooo`<00000
W`3oool3000004@0oooo0`00000K0?ooo`<00000UP3oool001D0oooo00<000000?ooo`3oool0703o
ool3000000H0oooo0`00002F0?ooo`<000007@3oool3000001H0oooo0`00000;0?ooo`<000006`3o
ool3000001D0oooo0`00001n0?ooo`005@3oool00`000000oooo0?ooo`080?ooo`<000004@3oool3
000000H0oooo0`00001C0?ooo`<00000H03oool3000001H0oooo0`00000;0?ooo`<00000<`3oool3
000007h0oooo000E0?ooo`030000003oool0oooo00P0oooo0`00000J0?ooo`<00000D`3oool30000
0600oooo0`00000F0?ooo`<00000@@3oool3000007h0oooo000E0?ooo`030000003oool0oooo00P0
oooo0`00001`0?ooo`<00000=P3oool3000001X0oooo0`00003X0?ooo`000`3oool500000080oooo
0`0000080?ooo`030000003oool0oooo0;@0oooo0`00000J0?ooo`<00000[`3oool300000080oooo
0`00000a0?ooo`00103oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`2d0?ooo`<000006P3oool3000000L0oooo0`00002U0?ooo`<0
00000P3oool300000340oooo00050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`3K0?ooo`<00000Y@3oool300000080oooo0`00000a0?ooo`001P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo0`00003>0?ooo`<000002P3o
ool300000=h0oooo00030?ooo`060000003oool0oooo0?ooo`000000oooo100000080?ooo`030000
003oool0oooo06D0oooo0`00000V0?ooo`<000007@3oool3000001d0oooo0`00003[0?ooo`000`3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000002`3oool00`000000oooo0?ooo`1U0?ooo`<0
00000`3oool300000200oooo0`00000M0?ooo`<000007@3oool300000>/0oooo00040?ooo`<00000
0P3oool5000000L0oooo00<000000?ooo`3oool0I@3oool3000000<0oooo0`00000P0?ooo`<00000
7@3oool300000>80oooo0`00000V0?ooo`005@3oool00`000000oooo0?ooo`1[0?ooo`<00000:P3o
ool300000500oooo0`00002U0?ooo`<000009P3oool001D0oooo00<000000?ooo`3oool0V03oool3
00000180oooo0`0000020?ooo`<00000=P3oool300000:D0oooo0`00000V0?ooo`005@3oool00`00
0000oooo0?ooo`2H0?ooo`H000003`3oool300000080oooo0`00000S0?ooo`<00000403oool30000
0<h0oooo000E0?ooo`030000003oool0oooo05L0oooo0`0000110?ooo`<000003`3oool300000080
oooo0`00000S0?ooo`<00000h@3oool001D0oooo00<000000?ooo`3oool0BP3oool3000000X0oooo
0`0000110?ooo`<00000>P3oool300000>40oooo000E0?ooo`800000B`3oool3000000040?ooo`00
00000000000000H0oooo0`00000l0?ooo`<00000o`3ooolT0?ooo`005@3oool00`000000oooo0?oo
o`1:0?ooo`<0000000@0oooo0000000000000000A@3oool3000009<0oooo0`00000Q0?ooo`<00000
1`3oool3000001@0oooo0`0000180?ooo`005@3oool00`000000oooo0?ooo`1>0?ooo`<00000A@3o
ool3000008T0oooo0`0000070?ooo`<000008@3oool3000000L0oooo0`00000D0?ooo`<00000B03o
ool001D0oooo00<000000?ooo`3oool0_03oool3000006<0oooo0`0000070?ooo`<000008@3oool3
000000L0oooo0`00000D0?ooo`<00000B03oool001D0oooo00<000000?ooo`3oool0_03oool30000
06<0oooo0`00002G0?ooo`005@3oool00`000000oooo0?ooo`2l0?ooo`<00000o@3oool001D0oooo
00<000000?ooo`3oool0F03oool300000<80oooo0`00000Q0?ooo`<00000N03oool001D0oooo00<0
00000?ooo`3oool0F03oool3000006h0oooo0`00001A0?ooo`<000008@3oool3000004h0oooo0`00
000W0?ooo`005@3oool00`000000oooo0?ooo`1H0?ooo`<00000KP3oool300000480oooo0`00000<
0?ooo`<000008@3oool3000002H0oooo0`00000U0?ooo`<000009`3oool001D0oooo0P00002^0?oo
o`<000006@3oool3000000d0oooo0`00000b0?ooo`<00000<03oool3000002H0oooo0`00000U0?oo
o`<000009`3oool001D0oooo00<000000?ooo`3oool0[@3oool3000000X0oooo0`00000L0?ooo`<0
0000<P3oool300000300oooo0`00000V0?ooo`<00000<`3oool3000001T0oooo000E0?ooo`030000
003oool0oooo0:d0oooo0`00000:0?ooo`<00000703oool400000<<0oooo0`00000I0?ooo`00503o
ool300000;/0oooo0`00000L0?ooo`@00000^@3oool3000000L0oooo0`00000I0?ooo`00503oool3
00000700oooo0`00001W0?ooo`@00000^@3oool3000002<0oooo000D0?ooo`<00000L03oool30000
06L0oooo0`00002j0?ooo`<000008`3oool001D0oooo00<000000?ooo`3oool09`3oool3000004D0
oooo0`00003o0?oood/0oooo000E0?ooo`030000003oool0oooo02L0oooo0`00003o0?oooi<0oooo
000E0?ooo`030000003oool0oooo00h0oooo0`00000F0?ooo`<00000I@3oool300000?l0oooo:`3o
ool001D0oooo0P00000?0?ooo`<000007`3oool3000005`0oooo0`00000E0?ooo`<00000o`3ooolC
0?ooo`005@3oool00`000000oooo0?ooo`0>0?ooo`<000007`3oool3000005`0oooo0`00000E0?oo
o`<00000o`3ooolC0?ooo`005@3oool00`000000oooo0?ooo`0`0?ooo`<00000BP3oool3000002L0
oooo0`00003o0?oooa<0oooo000E0?ooo`030000003oool0oooo0240oooo0`00000?0?ooo`<00000
A`3oool300000?l0oooo?@3oool001D0oooo00<000000?ooo`3oool08@3oool3000000l0oooo0`00
00170?ooo`<00000o`3ooolm0?ooo`005@3oool00`000000oooo0?ooo`0Q0?ooo`<000003`3oool3
00000?l0oooo6@3oool3000006/0oooo000E0?ooo`030000003oool0oooo04@0oooo0`0000110?oo
o`<00000``3oool3000006/0oooo000E0?ooo`030000003oool0oooo04@0oooo0`00000E0?ooo`<0
0000:@3oool3000004d0oooo0`00000V0?ooo`<000009`3oool300000200oooo0`00001[0?ooo`00
5@3oool2000000040?ooo`000000000000000440oooo0`00000E0?ooo`<000004P3oool300000140
oooo1P0000190?ooo`<0000000@0oooo00000000000000004`3oool300000100oooo0`00000W0?oo
o`<00000SP3oool001D0oooo00<000000?ooo`3oool00`00001I0?ooo`<000004P3oool300000140
oooo0`00000>0?ooo`<00000>`3oool3000000040?ooo`0000000000000001<0oooo0`00000@0?oo
o`<000009`3oool300000200oooo0`00000H0?ooo`<00000D03oool001D0oooo00<000000?ooo`3o
ool00`00001^0?ooo`<000004@3oool3000000h0oooo0`00000k0?ooo`<000005`3oool3000005d0
oooo0`00000H0?ooo`<00000D03oool001D0oooo00<000000?ooo`3oool02`3oool300000380oooo
0`00001C0?ooo`<00000M03oool3000003h0oooo0`00000H0?ooo`<00000D03oool001D0oooo00<0
00000?ooo`3oool02`3oool300000380oooo0`0000190?ooo`<00000OP3oool3000009X0oooo0`00
000?0?ooo`005@3oool00`000000oooo0?ooo`0;0?ooo`<00000<P3oool3000004T0oooo0`00001R
0?ooo`<000006@3oool3000000`0oooo0`00000X0?ooo`<00000H03oool3000000l0oooo000E0?oo
o`030000003oool0oooo0680oooo0`00000W0?ooo`<00000CP3oool300000140oooo0`00000X0?oo
o`<00000:03oool3000000d0oooo0`00001@0?ooo`<000003`3oool000@0oooo0`0000040?ooo`80
0000203oool00`000000oooo0?ooo`0W0?ooo`<000007`3oool3000001H0oooo0`00001h0?ooo`<0
00004@3oool3000002P0oooo0`00000X0?ooo`<000003@3oool3000002X0oooo0`00000S0?ooo`<0
00003`3oool000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
00L0oooo00<000000?ooo`3oool09`3oool3000001l0oooo0`00000F0?ooo`<00000N03oool30000
07L0oooo0`00000Z0?ooo`<00000303oool3000001@0oooo0`00000?0?ooo`001`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00D0oooo0`00000W0?ooo`<000007`3oool30000
0?l0oooo>@3oool3000000`0oooo0`00000V0?ooo`001@3oool2000000<0oooo00@000000?ooo`3o
ool000001`3oool00`000000oooo0?ooo`3o0?oooi@0oooo0`00000V0?ooo`001`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooonm0?oo
o`000`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000001`3oool0
0`000000oooo0?ooo`3o0?oookd0oooo00040?ooo`<00000103oool2000000P0oooo00<000000?oo
o`3oool0o`3ooonm0?ooo`005@3oool00`000000oooo0?ooo`3o0?oookd0oooo000E0?ooo`030000
003oool0oooo0?l0oooo_@3oool00001\
\>"],
  ImageRangeCache->{{{0, 467}, {288.125, 0}} -> {-1.45961, -1.64572, \
0.0691806, 0.112221}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["Any",
    FontSlant->"Italic"],
  " value can be given to the genotype:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InitialiseContinuum[p3, 10, R, \[CapitalDelta], 2, U[1], M[5], F[2], 
      Genotype \[Rule] f]\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    \({10.183568386803232`, 20}\)], "Output",
  CellLabel->"Out[50]="]
}, Open  ]],

Cell["These are the genotypes:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtractExtant[Genotype, p3]\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \({f[1, {1.7144904313587828`, 16.096567203926988`}], 
      f[2, {6.795461623316223`, 21.404695955642012`}], 
      f[3, {6.361851051585622`, 12.571580383216302`}], 
      f[4, {21.392042165010803`, 15.17075956434803`}], 
      f[5, {4.281025430825195`, 12.510123705525803`}], 
      f[6, {10.532677784123864`, 19.670348008268643`}], 
      f[7, {8.460875129341646`, 16.32494590374272`}], 
      f[8, {28.806275551871806`, 8.90445583753386`}], 
      f[9, {28.43720747558045`, 29.950823830079845`}], 
      f[10, {20.974036116853885`, 4.075374161861531`}]}\)], "Output",
  CellLabel->"Out[51]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{749, 644},
WindowMargins->{{1, Automatic}, {Automatic, 2}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\[Placeholder]", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->Utilities`Notation`Private`DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "InitialiseContinuum"->{
    Cell[1795, 53, 679, 13, 68, "DefinitionBox",
      CellTags->"InitialiseContinuum"],
    Cell[10650, 291, 503, 11, 52, "DefinitionBox",
      CellTags->"InitialiseContinuum"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"InitialiseContinuum", 129927, 4055}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 53, 0, 36, "SubsectionIcon"],
Cell[1795, 53, 679, 13, 68, "DefinitionBox",
  CellTags->"InitialiseContinuum"],
Cell[2477, 68, 46, 0, 28, "MathCaption"],
Cell[2526, 70, 86, 2, 26, "Input"],
Cell[2615, 74, 505, 11, 50, "Text"],
Cell[3123, 87, 458, 8, 50, "Text"],
Cell[3584, 97, 357, 9, 36, "Text"],
Cell[3944, 108, 378, 9, 77, "Input"],
Cell[4325, 119, 673, 22, 40, "Text"],
Cell[5001, 143, 406, 10, 39, "Text"],
Cell[5410, 155, 201, 8, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[5636, 167, 181, 4, 42, "Input"],
Cell[5820, 173, 85, 2, 20, "Output"]
}, Open  ]],
Cell[5920, 178, 284, 8, 22, "Text"],
Cell[6207, 188, 407, 10, 38, "Text"],
Cell[6617, 200, 399, 11, 44, "MathCaption"],

Cell[CellGroupData[{
Cell[7041, 215, 80, 2, 26, "Input"],
Cell[7124, 219, 487, 7, 65, "Output"]
}, Open  ]],
Cell[7626, 229, 100, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7751, 236, 83, 2, 26, "Input"],
Cell[7837, 240, 2506, 35, 185, "Output"]
}, Closed]],
Cell[10358, 278, 69, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[10452, 282, 79, 2, 41, "Input"],
Cell[10534, 286, 101, 2, 20, "Output"]
}, Open  ]],
Cell[10650, 291, 503, 11, 52, "DefinitionBox",
  CellTags->"InitialiseContinuum"],
Cell[11156, 304, 59, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[11240, 308, 85, 2, 26, "Input"],
Cell[11328, 312, 387, 6, 50, "Output"]
}, Open  ]],
Cell[11730, 321, 110, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[11865, 328, 225, 4, 48, "Input"],
Cell[12093, 334, 85, 2, 20, "Output"]
}, Open  ]],
Cell[12193, 339, 47, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[12265, 343, 85, 2, 26, "Input"],
Cell[12353, 347, 1371, 18, 200, "Output"]
}, Closed]],
Cell[13739, 368, 78, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[13842, 372, 420, 7, 74, "Input"],
Cell[14265, 381, 43136, 1066, 296, 11244, 667, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[57416, 1450, 112, 4, 24, "Text"],

Cell[CellGroupData[{
Cell[57553, 1458, 153, 3, 26, "Input"],
Cell[57709, 1463, 84, 2, 20, "Output"]
}, Open  ]],
Cell[57808, 1468, 47, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[57880, 1472, 85, 2, 26, "Input"],
Cell[57968, 1476, 613, 11, 65, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

