(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4528,        127]*)
(*NotebookOutlinePosition[      5429,        156]*)
(*  CellTagsIndexPosition[      5385,        152]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["The continuum model", "SubsectionIcon"],

Cell[TextData[{
  "\tThe model of reproduction, continuous in space and time, follows Pacala \
and Bolker (",
  StyleBox["Theoretical Population Biology",
    FontSlant->"Italic"],
  ", 1997).  Individuals are scattered over locations ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`d = 1, 2  \[Ellipsis]\)]],
  " or more dimensions.   With probability ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[GothicCapitalD][y, x]\), " ", 
          FormBox[\(F[d[y, t], y]\),
            "TraditionalForm"]}], TraditionalForm]]],
  ", individuals at ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " produce offspring at ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "; the dispersal distribution \[GothicCapitalD] is normalised, so that  \
\[Integral]\[GothicCapitalD](y,x)\[DifferentialD]y=1.  With probability  ",
  Cell[BoxData[
      \(TraditionalForm\`M[d[y, t], y]\)]],
  ", individuals at ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " die.  The  perceived density is an average over the surrounding region: \
",
  Cell[BoxData[
      \(TraditionalForm\`d[y, t]\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]U[y, x] n[x, t] \[DifferentialD]x\)]],
  ";  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]U[y, x]\)]],
  "\[DifferentialD]x=1.  Thus, the model is determined by the dispersal \
distribution, \[GothicCapitalD] (here assumed to be Gaussian), the dependence \
of fecundity and mortality on density and location ",
  Cell[BoxData[
      \(TraditionalForm\`\((F, \ M)\)\)]],
  ", and the area over which density is perceived ",
  Cell[BoxData[
      \(TraditionalForm\`\((U)\)\)]],
  ".\nThere is a slight difference from the Pacala-Bolker simulations: events \
occur at exponentially distributed times, rather than at a predetermined \
time-slice.  This is a more accurate representation of their stochastic \
model.  Note that in these simulations, and in the Bolker-Pacala model, \
individuals stay in the same place throughout their life, and disperse their \
offspring in a single jump, with standard deviation \[Sigma].  They do not \
disperse in a random walk, since that would require a continuous updating of \
percieved densities."
}], "Text"],

Cell[TextData[{
  "The simulation specifies genotype in a general way, using the function \
Genotype[",
  StyleBox["pop,ind",
    FontSlant->"Italic"],
  "], which can take any value.  The interaction U[], the dispersal function \
D[], the mortality M[] and the fecundity F[] can all depend on genotype. "
}], "Text"],

Cell["This loads the package", "MathCaption"],

Cell[BoxData[
    \(\(<< Genealogies`Continua`;\)\)], "Input",
  CellLabel->"In[89]:="]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{982, 629},
WindowMargins->{{Automatic, 67}, {Automatic, 24}},
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 45, 0, 36, "SubsectionIcon"],
Cell[1787, 53, 2267, 56, 117, "Text"],
Cell[4057, 111, 317, 7, 38, "Text"],
Cell[4377, 120, 45, 0, 28, "MathCaption"],
Cell[4425, 122, 87, 2, 26, "Input"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

