(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     19270,        442]*)
(*NotebookOutlinePosition[     21433,        504]*)
(*  CellTagsIndexPosition[     21170,        493]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Sampling", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{"FindPosition", "[", 
                RowBox[{
                  StyleBox["popln",
                    FontSlant->"Italic"], ",", "i"}], "]"}], 
              " "}], \(finds\ the\ position\ of\ individual\ i\ in\ the\ list\
\ of\ extant\ individuals\)},
          {
            RowBox[{"ExtractExtant", "[", 
              RowBox[{"f", ",", 
                StyleBox["popln",
                  FontSlant->"Italic"]}], "]"}], 
            RowBox[{"extracts", " ", "a", " ", "list", " ", "of", " ", 
              RowBox[{"f", "[", 
                RowBox[{
                  StyleBox["popln",
                    FontSlant->"Italic"], ",", "i"}], "]"}], " ", "for", " ", 
              "those", " ", "individuals", " ", "who", " ", "are", " ", 
              "still", " ", "alive"}]},
          {
            RowBox[{"ExtractExtant", "[", 
              RowBox[{"f", ",", 
                StyleBox["popln",
                  FontSlant->"Italic"], 
                StyleBox[",",
                  FontSlant->"Italic"], 
                StyleBox["t",
                  FontSlant->"Italic"]}], "]"}], 
            RowBox[{"extracts", " ", "a", " ", "list", " ", "of", " ", 
              RowBox[{"f", "[", 
                RowBox[{
                  StyleBox["popln",
                    FontSlant->"Italic"], ",", "i"}], "]"}], " ", "for", " ", 
              "those", " ", "individuals", " ", "who", " ", "are", " ", 
              "alive", " ", "at", " ", "time", " ", "t"}]}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"FindPosition", "ExtractExtant"}],

Cell["These are the individuals currently alive:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtantIndividuals[p1]\)], "Input",
  CellLabel->"In[169]:="],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
      21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 34, 35, 36, 37, 38, 39, 
      40, 41, 42, 43, 44, 45, 46, 47, 48, 50, 51, 52, 53, 54, 55, 56, 57, 58, 
      59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 
      77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 
      95, 96, 97, 98, 99, 100, 101, 102}\)], "Output",
  CellLabel->"Out[169]="]
}, Open  ]],

Cell["\<\
This is the position of individual 76 in the list of extant \
individuals:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindPosition[p1, 76]\)], "Input",
  CellLabel->"In[175]:="],

Cell[BoxData[
    \(74\)], "Output",
  CellLabel->"Out[175]="]
}, Open  ]],

Cell["\<\
Individuals 33, 49 have died, and so individual 76 appears earler \
in the list.\
\>", "Text"],

Cell["\<\
This gives the density perceived at birth by individuals alive now:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtractExtant[Density, p1]\)], "Input",
  CellLabel->"In[170]:="],

Cell[BoxData[
    \({0.017057128355168975`, 0.07602460686725027`, 0.5369427515618407`, 
      0.0392430028865691`, 0.011535239697532442`, 0.08806470625891985`, 
      0.1391929847654798`, 0.1423760157453355`, 0.04162095109782166`, 
      0.05579874965156668`, 0.05426233351426912`, 0.023349973761030776`, 
      0.006168945647791696`, 0.2018060787283964`, 0.07543040234008172`, 
      0.1982684940303323`, 0, 0.24887680149234273`, 0.12970733308782628`, 
      0.05426837738405073`, 0.`, 0.08324167597160857`, 0.0698614552298204`, 
      0.008051180797351643`, 0.06350296325957677`, 0.16458011704947562`, 
      0.02187236035452231`, 0.28450540153804493`, 0.08681703160462378`, 
      0.024184692692099514`, 0.006168945647791696`, 0.007006978729421067`, 
      0.05356712902365615`, 0.01919907374753775`, 0.09203944690442788`, 
      0.1811357067154693`, 0.023349973761030818`, 0.09986074539527375`, 
      0.34387341009753447`, 0.017997093108901734`, 0.4633899933072628`, 
      0.005327960388116221`, 0.1318050755362672`, 0.014399705126525258`, 
      0.1860134456888273`, 0.116761001642238`, 0.11395191772769082`, 
      0.18661510000479817`, 0.02053017664126926`, 0.0214815873795103`, 
      0.09356002605877003`, 0.09738249753849938`, 0.10791997185921054`, 
      0.23595480081972733`, 0.14902244338897908`, 0.08296034930546715`, 
      0.06538043423211688`, 0.3014916911235333`, 0.22533052093916597`, 
      0.14526859540701914`, 0.1368730263039999`, 0.262058355678339`, 
      0.16518111492056575`, 0, 0.03406175856710063`, 0.5019379528370385`, 
      0.01169848130596567`, 0.32987780332497296`, 0.03792689162991516`, 0, 
      0.1859840897506797`, 0.0818046740051162`, 0.20244372965208268`, 
      0.03943414404299913`, 0.009555451299150156`, 0.14462145215315383`, 
      0.24021796145363933`, 0.010029766996045518`, 0.0220042342035809`, 
      0.22124995306898282`, 0.17202555956750698`, 0.1842369240340317`, 
      0.09202448062351723`, 0.1353206494900998`, 0.07301082131745043`, 
      0.46419175658760964`, 0.2338818072095016`, 0.1673468434060703`, 
      0.007006978729421036`, 0.12088319575739735`, 0.04292874509399432`, 
      0.14071591917759493`, 0.01905569455009211`, 0.15140555539708522`, 
      0.03792689162991516`, 0.19147684892301062`, 0.1239811853318164`, 
      0.12946718904950327`, 0.08214845266538992`, 
      0.1077024622388823`}\)], "Output",
  CellLabel->"Out[170]="]
}, Open  ]],

Cell["These are the individuals alive at t=0.005:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtantIndividuals[p1, 0.005]\)], "Input",
  CellLabel->"In[173]:="],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
      21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 34, 35, 36, 37, 38, 39, 
      40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 
      58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 
      76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 
      94, 95, 96, 97, 98, 99, 100, 101}\)], "Output",
  CellLabel->"Out[173]="]
}, Open  ]],

Cell[TextData[{
  "Note:  ",
  StyleBox["ExtantIndividuals[pop] is stored by the simulation.  However, \
ExtantIndividuals[p1,t] is calculated as needed, which is much slower for a \
large dataset.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell["This gives the density perceived at time t=0.005:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtractExtant[Density, p1, 0.005]\)], "Input",
  CellLabel->"In[172]:="],

Cell[BoxData[
    \({0.017057128355168975`, 0.07602460686725027`, 0.5369427515618407`, 
      0.0392430028865691`, 0.011535239697532442`, 0.08806470625891985`, 
      0.1391929847654798`, 0.1423760157453355`, 0.04162095109782166`, 
      0.05579874965156668`, 0.05426233351426912`, 0.023349973761030776`, 
      0.006168945647791696`, 0.2018060787283964`, 0.07543040234008172`, 
      0.1982684940303323`, 0, 0.24887680149234273`, 0.12970733308782628`, 
      0.05426837738405073`, 0.`, 0.08324167597160857`, 0.0698614552298204`, 
      0.008051180797351643`, 0.06350296325957677`, 0.16458011704947562`, 
      0.02187236035452231`, 0.28450540153804493`, 0.08681703160462378`, 
      0.024184692692099514`, 0.006168945647791696`, 0.007006978729421067`, 
      0.05356712902365615`, 0.01919907374753775`, 0.09203944690442788`, 
      0.1811357067154693`, 0.023349973761030818`, 0.09986074539527375`, 
      0.34387341009753447`, 0.017997093108901734`, 0.4633899933072628`, 
      0.005327960388116221`, 0.1318050755362672`, 0.014399705126525258`, 
      0.1860134456888273`, 0.116761001642238`, 0.11395191772769082`, 
      0.0573362460769541`, 0.18661510000479817`, 0.02053017664126926`, 
      0.0214815873795103`, 0.09356002605877003`, 0.09738249753849938`, 
      0.10791997185921054`, 0.23595480081972733`, 0.14902244338897908`, 
      0.08296034930546715`, 0.06538043423211688`, 0.3014916911235333`, 
      0.22533052093916597`, 0.14526859540701914`, 0.1368730263039999`, 
      0.262058355678339`, 0.16518111492056575`, 0, 0.03406175856710063`, 
      0.5019379528370385`, 0.01169848130596567`, 0.32987780332497296`, 
      0.03792689162991516`, 0, 0.1859840897506797`, 0.0818046740051162`, 
      0.20244372965208268`, 0.03943414404299913`, 0.009555451299150156`, 
      0.14462145215315383`, 0.24021796145363933`, 0.010029766996045518`, 
      0.0220042342035809`, 0.22124995306898282`, 0.17202555956750698`, 
      0.1842369240340317`, 0.09202448062351723`, 0.1353206494900998`, 
      0.07301082131745043`, 0.46419175658760964`, 0.2338818072095016`, 
      0.1673468434060703`, 0.007006978729421036`, 0.12088319575739735`, 
      0.04292874509399432`, 0.14071591917759493`, 0.01905569455009211`, 
      0.15140555539708522`, 0.03792689162991516`, 0.19147684892301062`, 
      0.1239811853318164`, 0.12946718904950327`, 
      0.08214845266538992`}\)], "Output",
  CellLabel->"Out[172]="]
}, Open  ]],

Cell["These are the locations at time t=0.005:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtractExtant[Location, p1, 0.005]\)], "Input",
  CellLabel->"In[174]:="],

Cell[BoxData[
    \({{9.786107795130578`, 2.364175914688786`}, {3.311773791379446`, 
        16.423626714607227`}, {21.842354453405903`, 
        23.525658326904924`}, {23.235149616827833`, 
        18.140215044332155`}, {14.215119810889053`, 
        17.604180872007863`}, {25.947088818333842`, 
        19.544333873696907`}, {19.11965816108853`, 
        11.350385863310535`}, {17.458796248947394`, 
        7.571660631280316`}, {0.07583821212763345`, 
        9.719487817772528`}, {0.46486611019389507`, 
        7.681999829918056`}, {25.8681347964927`, 
        7.065424410105092`}, {3.7308586714963368`, 
        21.50151882692377`}, {16.08202700136212`, 
        4.701248495416306`}, {0.41908488011689066`, 
        5.077892112316545`}, {24.239672547956218`, 
        11.175590168511382`}, {7.183935263289058`, 
        16.937677067984392`}, {10.024552737067165`, 
        23.57140929650352`}, {11.236846444955217`, 
        27.393343194287482`}, {20.904894575978634`, 
        12.221023433192984`}, {23.778050196007822`, 
        19.821682563007165`}, {20.829056363851`, 
        2.501535615420455`}, {23.313184085813926`, 
        12.139682733089112`}, {24.960921567358298`, 
        25.436111205315363`}, {19.58232541431759`, 
        20.63816390616534`}, {8.878894565996177`, 
        20.73486270989906`}, {19.163240534200703`, 
        15.560271793848795`}, {14.639222018039957`, 
        9.559272541387674`}, {11.979305270911642`, 
        28.622594725864403`}, {4.614669280972794`, 
        15.987863244884153`}, {0.742458825956426`, 
        1.2292515315769217`}, {13.70977470499416`, 
        3.766839811691169`}, {6.964408629948603`, 
        11.407568968569754`}, {13.651224544134674`, 
        29.267886235480642`}, {27.919796773784864`, 
        5.8291929909553515`}, {24.068899129817083`, 
        8.629722329315301`}, {19.04090220778869`, 
        15.094330281056294`}, {4.905658595616384`, 
        23.06945053546651`}, {4.40168018974873`, 
        5.535057739668621`}, {22.926353324704742`, 
        24.446855809602102`}, {29.787010908775937`, 
        19.547194494784467`}, {22.183894498748316`, 
        23.217604278025178`}, {16.077236203781776`, 
        15.7803546830933`}, {15.219485868799712`, 
        11.810035309455426`}, {23.19651786263861`, 
        14.515050486822584`}, {1.568261324665037`, 
        12.542149073974784`}, {25.276721088853748`, 
        8.685857495867234`}, {7.4993621948479525`, 
        3.9124267446594816`}, {6.235818881065061`, 
        23.591527214810938`}, {2.593703599231568`, 
        10.842976209192976`}, {1.8341386913163313`, 
        18.05646947514232`}, {9.667350274526827`, 
        16.396120399590874`}, {2.0471277825403944`, 
        28.50927498035785`}, {17.483455775778513`, 
        23.178516121565693`}, {15.969891578758618`, 
        12.728920297264551`}, {2.263969906978799`, 
        11.368480812110269`}, {22.773373716120005`, 
        28.21386981044197`}, {0.6957085823137618`, 
        28.826331738135483`}, {27.496652627266258`, 
        19.528012314574735`}, {23.19634638746581`, 
        24.913904993476002`}, {21.260833746201197`, 
        25.936485099763797`}, {20.602642788234242`, 
        14.070928784283026`}, {19.426695054884867`, 
        7.88001562462148`}, {10.935292513707415`, 
        27.674808384692152`}, {17.37956727234447`, 
        9.370740644263629`}, {23.451836737928904`, 
        4.49629226312646`}, {1.4096756935858508`, 
        26.64182034699908`}, {21.187866830950103`, 
        23.127811451016193`}, {8.636301977465845`, 
        28.42795053655711`}, {20.492158248636343`, 
        24.301479712880706`}, {11.139649350199589`, 
        8.899938221982373`}, {27.29581186117053`, 
        29.387574719404704`}, {19.87881560399839`, 
        12.963453122218574`}, {6.693169072936292`, 
        15.316645935121679`}, {0.45212054911352745`, 
        5.083437497597096`}, {25.75787655922888`, 
        17.641837550429525`}, {13.072553276769057`, 
        25.712696853333465`}, {2.3060398212999753`, 
        13.145545287303065`}, {11.662877583183208`, 
        29.070876506334393`}, {11.118172990349871`, 
        20.017733836286872`}, {3.026575605717362`, 
        0.6429259697772829`}, {20.62601474171353`, 
        25.716254123406166`}, {21.886926255517775`, 
        21.74298774779491`}, {23.330202880542995`, 
        26.328679404001463`}, {2.0081106515193827`, 
        8.779534625576336`}, {16.637033807606702`, 
        11.012033468879784`}, {1.5559901024058551`, 
        3.696097127979239`}, {20.879157248377822`, 
        23.37019591845026`}, {18.483436825636797`, 
        7.983400274645772`}, {18.57311742707785`, 
        10.224650631147194`}, {6.82055924245359`, 
        8.912523768311381`}, {7.4549444367279785`, 
        20.20691679486032`}, {3.793983636736228`, 
        8.269597798534098`}, {16.82892969501445`, 
        24.490662671454153`}, {11.907057381218454`, 
        16.526610050739187`}, {23.498726814471453`, 
        28.16198326745269`}, {9.898946729699071`, 
        7.747075425162853`}, {6.861693006864751`, 
        17.14994979857291`}, {8.342956627293216`, 
        4.0509782971836135`}, {15.982535758486927`, 
        23.779753880122648`}, {6.299272244859136`, 
        19.669578115129855`}}\)], "Output",
  CellLabel->"Out[174]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(InitialiseCovariance[{D\_max, \[Delta]D}]\), \(returns\ an\ \
empty\ array\ suitable\ for\ accumulating\ covariances\)},
          {
            RowBox[{"SampleCovariance", "[", 
              RowBox[{
                StyleBox["popln",
                  FontSlant->"Italic"], ",", "R", 
                ",", \({D\_max, \[Delta]D}\)}], 
              "]"}], \(uses\ MakeDistanceList[]\ to\ find\ the\ distances\ \
between\ pairs\ of\ individuals; \ 
            returns\ the\ number\ of\ distances\ in\ bins\ of\ size\ \
\[Delta]D\)},
          {\(CovarianceMidPoints[{Dmax, \[Delta]D}]\), \(gives\ a\ list\ of\ \
the\ midpoints\ of\ the\ distance\ \(\(bins\)\(.\)\)\)},
          {
            RowBox[{"SpatialCovariance", "[", 
              RowBox[{
                StyleBox["hist",
                  FontSlant->"Italic"], ",", \(n\&_\), ",", "R", 
                ",", \({D\_max, \[Delta]D}\), ",", 
                StyleBox["dims",
                  FontSlant->"Italic"]}], "]"}], 
            RowBox[{
              RowBox[{
              "gives", " ", "a", " ", "list", " ", "of", " ", "the", " ", 
                "covariance", " ", "in", " ", "density", " ", "as", " ", "a", 
                " ", "function", " ", "of", " ", 
                RowBox[{"distance", ".", "  ", 
                  StyleBox["hist",
                    FontSlant->"Italic"]}], " ", "gives", " ", "the", " ", 
                "distribution", " ", "of", " ", "distances"}], ",", 
              " ", \(in\ bins\ of\ size\ \[Delta]D\), ",", 
              " ", \(and\ n\&_\ the\ mean\ \(\(density\)\(.\)\)\)}]}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{
  "InitialiseCovariance", "SampleCovariance", "CovarianceMidPoints", 
    "SpatialCovariance"}],

Cell[TextData[{
  "Usually, one wishes to sample the distribution of distances over a longer \
distance than the range needed to account for density-dependence, ",
  Cell[BoxData[
      \(TraditionalForm\`U[]\)]],
  ".  MakeDistanceList[] can be called with a larger box size, so as to count \
distances up to a longer  limit, ",
  Cell[BoxData[
      \(TraditionalForm\`\(D\_max . \)\)]],
  "  SampleCovariance[] calls MakeDistanceList[] , and condenses the list of \
distances into a histogram with  bins of width \[Delta]D.  "
}], "Text"],

Cell[TextData[
"InitisaliseCovariance[] returns a list of  {0,0,\[Ellipsis]} which can be \
used to accumulate subsequent sampled histograms.  "], "Text"],

Cell["\<\
SpatialCovariance[] calculates the covariance in density from the \
distribution of distances between randomly chosen pairs of individuals, and \
the mean density.  SpatialCovariance[]  is defined at present only for one or \
two dimensions.  \
\>", "Text"],

Cell["\<\
Note that sampling distances beytween pairs can be extremely slow \
if there are many individuals within the specified distance range.\
\>", 
  "Text"],

Cell[TextData[{
  "*** The range R must be divisible by ",
  Cell[BoxData[
      \(TraditionalForm\`\(D\_max\ \ \)\)]]
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{963, 660},
WindowMargins->{{Automatic, 83}, {Automatic, 13}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "FindPosition"->{
    Cell[1776, 53, 1678, 39, 76, "DefinitionBox",
      CellTags->{"FindPosition", "ExtractExtant"}]},
  "ExtractExtant"->{
    Cell[1776, 53, 1678, 39, 76, "DefinitionBox",
      CellTags->{"FindPosition", "ExtractExtant"}]},
  "InitialiseCovariance"->{
    Cell[16171, 365, 1815, 38, 128, "DefinitionBox",
      CellTags->{
      "InitialiseCovariance", "SampleCovariance", "CovarianceMidPoints", 
        "SpatialCovariance"}]},
  "SampleCovariance"->{
    Cell[16171, 365, 1815, 38, 128, "DefinitionBox",
      CellTags->{
      "InitialiseCovariance", "SampleCovariance", "CovarianceMidPoints", 
        "SpatialCovariance"}]},
  "CovarianceMidPoints"->{
    Cell[16171, 365, 1815, 38, 128, "DefinitionBox",
      CellTags->{
      "InitialiseCovariance", "SampleCovariance", "CovarianceMidPoints", 
        "SpatialCovariance"}]},
  "SpatialCovariance"->{
    Cell[16171, 365, 1815, 38, 128, "DefinitionBox",
      CellTags->{
      "InitialiseCovariance", "SampleCovariance", "CovarianceMidPoints", 
        "SpatialCovariance"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"FindPosition", 20106, 463},
  {"ExtractExtant", 20230, 466},
  {"InitialiseCovariance", 20361, 469},
  {"SampleCovariance", 20562, 474},
  {"CovarianceMidPoints", 20766, 479},
  {"SpatialCovariance", 20968, 484}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 34, 0, 36, "SubsectionIcon"],
Cell[1776, 53, 1678, 39, 76, "DefinitionBox",
  CellTags->{"FindPosition", "ExtractExtant"}],
Cell[3457, 94, 65, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3547, 98, 80, 2, 26, "Input"],
Cell[3630, 102, 489, 7, 50, "Output"]
}, Open  ]],
Cell[4134, 112, 105, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4264, 119, 79, 2, 26, "Input"],
Cell[4346, 123, 62, 2, 20, "Output"]
}, Open  ]],
Cell[4423, 128, 104, 3, 22, "Text"],
Cell[4530, 133, 100, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4655, 140, 85, 2, 26, "Input"],
Cell[4743, 144, 2397, 34, 140, "Output"]
}, Open  ]],
Cell[7155, 181, 66, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7246, 185, 87, 2, 26, "Input"],
Cell[7336, 189, 488, 7, 50, "Output"]
}, Open  ]],
Cell[7839, 199, 258, 7, 24, "Text"],
Cell[8100, 208, 72, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[8197, 212, 92, 2, 26, "Input"],
Cell[8292, 216, 2397, 34, 140, "Output"]
}, Open  ]],
Cell[10704, 253, 63, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[10792, 257, 93, 2, 26, "Input"],
Cell[10888, 261, 5268, 101, 260, "Output"]
}, Open  ]],
Cell[16171, 365, 1815, 38, 128, "DefinitionBox",
  CellTags->{
  "InitialiseCovariance", "SampleCovariance", "CovarianceMidPoints", 
    "SpatialCovariance"}],
Cell[17989, 405, 541, 11, 36, "Text"],
Cell[18533, 418, 154, 2, 22, "Text"],
Cell[18690, 422, 267, 5, 36, "Text"],
Cell[18960, 429, 161, 4, 22, "Text"],
Cell[19124, 435, 130, 4, 22, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

