(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7927,        240]*)
(*NotebookOutlinePosition[      9262,        282]*)
(*  CellTagsIndexPosition[      9121,        274]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Converting between matrix and list representations", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MatrixToList[
              S]\), \(converts\ a\ matrix\ representation\ to\ a\ list\ of\ \
the\ mutations\ held\ by\ each\ leaf . \ \ By\ default, \ 
            mutations\ are\ numbered\ 1, 2 \( \(\[Ellipsis]\)\(.\)\)\)},
          {\(MatrixToList[S, 
              MutationLabels \[Rule] {m\_1, \ 
                  m\_2, \[Ellipsis]}]\), \(labels\ the\ mutations\ as\ \(\({m\
\_1, \ m\_2, \[Ellipsis]}\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"MatrixToList", "MutationLabels"}],

Cell["\<\
Here is a matrix whose elements show whether a particular mutation \
is present in a particular leaf:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(S // MatrixForm\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", "1", "0", "0", "0", "0", "0", "1", "0", "0", "0"},
            {"1", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "1", "1", "1", "1", "1", "0", "1", "0", "0"},
            {"0", "0", "1", "1", "1", "1", "1", "0", "0", "1", "0"},
            {"0", "0", "1", "1", "1", "1", "1", "0", "0", "1", "1"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[18]//MatrixForm="]
}, Open  ]],

Cell["\<\
This lists the mutations which are present at each of the five \
leaves:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(z = MatrixToList[S]; z // TableForm\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"1", "2", "8", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
          {"1", "2", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>"},
          {"3", "4", "5", "6", "7", "9", "\<\"\"\>"},
          {"3", "4", "5", "6", "7", "10", "\<\"\"\>"},
          {"3", "4", "5", "6", "7", "10", "11"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{1, 2, 8}, {1, 2}, {3, 4, 5, 6, 7, 9}, {3, 4, 5, 6, 7, 
        10}, {3, 4, 5, 6, 7, 10, 11}}]]], "Output",
  CellLabel->"Out[21]//TableForm="]
}, Open  ]],

Cell["This labels the mutations:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(z2 = 
      MatrixToList[S, 
        MutationLabels 
          \[Rule] {m\_1, \ m\_2, m\_3, m\_4, m\_5, m\_6, m\_7, m\_8, m\_9, 
            m\_10, m\_11}]; z2 // TableForm\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(m\_1\), \(m\_2\), \(m\_8\), "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>"},
          {\(m\_1\), \(m\_2\), "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>"},
          {\(m\_3\), \(m\_4\), \(m\_5\), \(m\_6\), \(m\_7\), \(m\_9\), 
            "\<\"\"\>"},
          {\(m\_3\), \(m\_4\), \(m\_5\), \(m\_6\), \(m\_7\), \(m\_10\), 
            "\<\"\"\>"},
          {\(m\_3\), \(m\_4\), \(m\_5\), \(m\_6\), \(m\_7\), \(m\_10\), 
            \(m\_11\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{
        Subscript[ m, 1], 
        Subscript[ m, 2], 
        Subscript[ m, 8]}, {
        Subscript[ m, 1], 
        Subscript[ m, 2]}, {
        Subscript[ m, 3], 
        Subscript[ m, 4], 
        Subscript[ m, 5], 
        Subscript[ m, 6], 
        Subscript[ m, 7], 
        Subscript[ m, 9]}, {
        Subscript[ m, 3], 
        Subscript[ m, 4], 
        Subscript[ m, 5], 
        Subscript[ m, 6], 
        Subscript[ m, 7], 
        Subscript[ m, 10]}, {
        Subscript[ m, 3], 
        Subscript[ m, 4], 
        Subscript[ m, 5], 
        Subscript[ m, 6], 
        Subscript[ m, 7], 
        Subscript[ m, 10], 
        Subscript[ m, 11]}}]]], "Output",
  CellLabel->"Out[48]//TableForm="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(ListToMatrix[{{1, 2, 
                  3}, {4}, \[Ellipsis]}]\), \(converts\ a\ list\ of\ \
mutations\ present\ at\ each\ node\ into\ a\ matrix\ \
\(\(representation\)\(.\)\)\)},
          {\(ListToMatrix[{{1, 2, 3}, {4}, \[Ellipsis]}, 
              MutationLabels \[Rule] {m\_1, \[Ellipsis]}]\), \(gives\ the\ \
columns\ in\ the\ specified\ \(\(order\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"ListToMatrix"],

Cell["This converts back to the original matrix representation:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListToMatrix[z] // MatrixForm\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", "1", "0", "0", "0", "0", "0", "1", "0", "0", "0"},
            {"1", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "1", "1", "1", "1", "1", "0", "1", "0", "0"},
            {"0", "0", "1", "1", "1", "1", "1", "0", "0", "1", "0"},
            {"0", "0", "1", "1", "1", "1", "1", "0", "0", "1", "1"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[32]//MatrixForm="]
}, Closed]],

Cell["This lists the mutations in reverse order:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListToMatrix[z2, 
        MutationLabels 
          \[Rule] {m\_11, \ m\_10, m\_9, m\_8, m\_7, m\_6, m\_5, m\_4, m\_3, 
            m\_2, m\_1}] // MatrixForm\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", "1", "0", "0", "0", "0", "0", "1", "1"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "1", "1"},
            {"0", "0", "1", "0", "1", "1", "1", "1", "1", "0", "0"},
            {"0", "1", "0", "0", "1", "1", "1", "1", "1", "0", "0"},
            {"1", "1", "0", "0", "1", "1", "1", "1", "1", "0", "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[50]//MatrixForm="]
}, Closed]],

Cell["\<\
The list of mutations must include all those that are found in the \
list.\
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{520, 653},
WindowMargins->{{Automatic, -2}, {Automatic, 3}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "MatrixToList"->{
    Cell[1818, 53, 580, 11, 104, "DefinitionBox",
      CellTags->{"MatrixToList", "MutationLabels"}]},
  "MutationLabels"->{
    Cell[1818, 53, 580, 11, 104, "DefinitionBox",
      CellTags->{"MatrixToList", "MutationLabels"}]},
  "ListToMatrix"->{
    Cell[5776, 176, 508, 10, 88, "DefinitionBox",
      CellTags->"ListToMatrix"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"MatrixToList", 8762, 261},
  {"MutationLabels", 8888, 264},
  {"ListToMatrix", 9012, 267}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 76, 0, 36, "SubsectionIcon"],
Cell[1818, 53, 580, 11, 104, "DefinitionBox",
  CellTags->{"MatrixToList", "MutationLabels"}],
Cell[2401, 66, 132, 3, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[2558, 73, 73, 2, 26, "Input"],
Cell[2634, 77, 495, 10, 95, "Output"]
}, Open  ]],
Cell[3144, 90, 103, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3272, 97, 93, 2, 26, "Input"],
Cell[3368, 101, 666, 15, 95, "Output"]
}, Open  ]],
Cell[4049, 119, 49, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4123, 123, 230, 6, 58, "Input"],
Cell[4356, 131, 1405, 42, 95, "Output"]
}, Open  ]],
Cell[5776, 176, 508, 10, 88, "DefinitionBox",
  CellTags->"ListToMatrix"],
Cell[6287, 188, 82, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6394, 193, 87, 2, 26, "Input"],
Cell[6484, 197, 495, 10, 94, "Output"]
}, Closed]],
Cell[6994, 210, 65, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[7084, 214, 216, 5, 42, "Input"],
Cell[7303, 221, 495, 10, 94, "Output"]
}, Closed]],
Cell[7813, 234, 98, 3, 18, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

