(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    151162,       4740]*)
(*NotebookOutlinePosition[    152214,       4774]*)
(*  CellTagsIndexPosition[    152125,       4768]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Estimating the probability for ordered genealogies", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"MonteCarloProbability", "[", 
              RowBox[{"g", ",", 
                StyleBox["nodelist",
                  FontSlant->"Italic"], ",", "J", ",", "\[Theta]", 
                ",", \(\[Theta]\^*\), ",", "ns"}], "]"}], 
            
            RowBox[{\(makes\ a\ Monte\ Carlo\ estimate\ of\ the\ probability\ \
of\ the\ genealogy\ g\ and\ the\ mutational\ configuration\ J\), ",", " ", 
              RowBox[{
              "assuming", " ", "that", " ", "the", " ", "coalescences", " ", 
                "are", " ", "in", " ", "the", " ", "order", " ", "specified", 
                " ", "by", " ", 
                RowBox[{
                  StyleBox["nodelist",
                    FontSlant->"Italic"], ".", " ", "A"}], " ", "list", " ", 
                "of", " ", 
                StyleBox["ns",
                  FontSlant->"Italic"], " ", "values", " ", "is", 
                " ", \(returned . \ \ Uses\), " ", "the", " ", "arbitrary", 
                " ", "parameter", " ", \(\[Theta]\^*\), " ", "to", " ", 
                "make", " ", "random", 
                " ", \(partitions . \ \ \(\[Theta]\^*\)\), " ", "must", " ", 
                "be", " ", "a", " ", "number"}], ",", 
              " ", \(but\ \[Theta]\ can\ be\ \(\(symbolic\)\(.\)\)\)}]}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"MonteCarloProbability"],

Cell["\<\
Here is a random genealogy, drawn using the coalescent process with \
\[Theta]=10:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g = RandomGenealogy[{a, b, c, d}, MutationRate \[Rule] 10]\)], "Input",
  CellLabel->"In[160]:="],

Cell[BoxData[
    \(Node[
      4, {0.865546588688212992`, {}}, {
        Node[3, {0.865546588688212992`, {}}, {
            Node[1, {0.120266801174334037`, {1, 2, 3, 4, 5, 6, 7}}, {
                Node[a, {0, {1, 2, 3, 4, 5, 6, 7}}, {}], 
                Node[c, {0, {1, 2, 3, 4, 5, 6, 7}}, {}]}], 
            Node[2, {0.439378490239904717`, {8, 9}}, {
                Node[b, {0, {8, 9, 10, 11, 12}}, {}], 
                Node[d, {0, {8, 9, 13}}, {}]}]}]}]\)], "Output",
  CellLabel->"Out[160]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[PlotGenealogy[g]]; \)\)], "Input",
  CellLabel->"In[161]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.2 0.2 0.123607 0.123607 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.3 .24721 m
.2 .12361 L
s
.3 .24721 m
.4 .12361 L
s
.7 .24721 m
.6 .12361 L
s
.7 .24721 m
.8 .12361 L
s
.5 .37082 m
.3 .24721 L
s
.5 .37082 m
.7 .24721 L
s
.5 .49443 m
.5 .37082 L
s
[(1)] .26 .27193 0 0 Mshowa
[(2)] .66 .27193 0 0 Mshowa
[(3)] .46 .39554 0 0 Mshowa
[(4)] .46 .51915 0 0 Mshowa
gsave
.2 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.4 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.6 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.8 .09889 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[161]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol003Moo`D003Eoo`<003Ioo`@003Ioo`D003Moo`00=goo00@007ooOol003Eo
o`05001oogooOol0000eOol01@00Oomoogoo0000=7oo00D007ooOomoo`0003Qoo`00=goo1000=Goo
00<007ooOol0=goo00D007ooOomoo`0003Aoo`05001oogooOol0000hOol003Yoo`03001oogoo03=o
o`05001oogooOol0000eOol01@00Oomoogoo0000=7oo00D007ooOomoo`0003Qoo`00>7oo0`00=Woo
1000=Goo1000=Woo1000>7oo002ZOol00`00Oomoo`0jOol00`00Oomoo`0fOol00:Uoo`8003]oo`80
03Qoo`00ogoo8Goo003oOolQOol003Uoo`03001oogoo03Ioo`03001oogoo03Moo`03001oogoo03Io
o`03001oogoo03Qoo`00>Goo00<007ooOol0=Woo00<007ooOol0=goo00<007ooOol0=Woo00<007oo
Ool0>7oo000jOol00`00Oomoo`0dOol00`00Oomoo`0iOol00`00Oomoo`0dOol00`00Oomoo`0iOol0
03]oo`03001oogoo039oo`03001oogoo03]oo`03001oogoo039oo`03001oogoo03Yoo`00?7oo00<0
07ooOol0<7oo00<007ooOol0?Goo00<007ooOol0<7oo00<007ooOol0>goo000mOol00`00Oomoo`0^
Ool00`00Oomoo`0oOol00`00Oomoo`0^Ool00`00Oomoo`0lOol003ioo`03001oogoo02eoo`03001o
ogoo03moo`03001oogoo02eoo`03001oogoo03eoo`00?Woo00<007ooOol0;7oo00<007ooOol0@Goo
00<007ooOol0;7oo00<007ooOol0?Goo000oOol00`00Oomoo`0ZOol00`00Oomoo`13Ool00`00Oomo
o`0ZOol00`00Oomoo`0nOol0041oo`03001oogoo02Qoo`03001oogoo04Eoo`03001oogoo02Qoo`03
001oogoo03moo`00@Goo00<007ooOol09Woo00<007ooOol0Agoo00<007ooOol09Woo00<007ooOol0
@7oo0012Ool00`00Oomoo`0UOol00`00Oomoo`17Ool00`00Oomoo`0UOol00`00Oomoo`11Ool004=o
o`03001oogoo02=oo`03001oogoo04Uoo`03001oogoo02=oo`03001oogoo049oo`00@goo00<007oo
Ool08Woo00<007ooOol0Bgoo00<007ooOol08Woo00<007ooOol0@Woo0014Ool00`00Oomoo`0POol0
0`00Oomoo`1=Ool00`00Oomoo`0POol00`00Oomoo`13Ool004Eoo`03001oogoo01ioo`03001oogoo
04moo`03001oogoo01ioo`03001oogoo04Aoo`00AWoo00<007ooOol07Goo00<007ooOol0Cgoo00<0
07ooOol07Goo00<007ooOol0AGoo0017Ool00`00Oomoo`0KOol00`00Oomoo`1AOol00`00Oomoo`0K
Ool00`00Oomoo`16Ool004Qoo`03001oogoo01Uoo`03001oogoo05=oo`03001oogoo01Uoo`03001o
ogoo04Moo`00B7oo00<007ooOol067oo00<007ooOol0EGoo00<007ooOol067oo00<007ooOol0Agoo
0019Ool00`00Oomoo`0FOol00`00Oomoo`1GOol00`00Oomoo`0FOol00`00Oomoo`18Ool004Yoo`03
001oogoo01Eoo`03001oogoo05Moo`03001oogoo01Eoo`03001oogoo04Uoo`00Bgoo00<007ooOol0
4goo00<007ooOol0FGoo00<007ooOol04goo00<007ooOol0BWoo001<Ool00`00Oomoo`0AOol00`00
Oomoo`1KOol00`00Oomoo`0AOol00`00Oomoo`1;Ool004aoo`03001oogoo011oo`03001oogoo05eo
o`03001oogoo011oo`03001oogoo04]oo`00CGoo00<007ooOol03Woo00<007ooOol0Ggoo00<007oo
Ool03Woo00<007ooOol0C7oo001>Ool00`00Oomoo`0=Ool00`00Oomoo`1OOol00`00Oomoo`0=Ool0
0`00Oomoo`1=Ool004moo`03001oogoo00]oo`03001oogoo065oo`03001oogoo00]oo`03001oogoo
04ioo`00D7oo00<007ooOol02Goo00<007ooOol0Hgoo00<007ooOol02Goo00<007ooOol0Cgoo001A
Ool00`00Oomoo`07Ool00`00Oomoo`1UOol00`00Oomoo`07Ool00`00Oomoo`1@Ool0055oo`03001o
ogoo00Ioo`03001oogoo06Moo`03001oogoo00Ioo`03001oogoo051oo`00DWoo00<007ooOol01Goo
00<007ooOol0Igoo00<007ooOol01Goo00<007ooOol0DGoo001COol00`00Oomoo`03Ool00`00Oomo
o`1YOol00`00Oomoo`03Ool00`00Oomoo`1BOol005Aoo`05001oogooOol0001]Ool01@00Oomoogoo
0000EGoo001EOol00`00Ool0001_Ool00`00Ool0001FOol005Ioo`8006moo`8005Moo`00F7oo00<0
07ooOol0Jgoo00<007ooOol0Egoo001IOol2001YOol2001JOol005]oo`8006Eoo`8005aoo`00GGoo
00<007ooOol0HGoo00<007ooOol0G7oo0018Ool3000COol2001KOol6001OOol004Uoo`03001oogoo
01Aoo`03001oogoo05Uoo`03001oo`00065oo`00BGoo00<007ooOol05Goo0P00FGoo0P00HWoo0019
Ool00`00Oomoo`0GOol00`00Oomoo`1EOol01000Oomoo`00HGoo0019Ool00`00Oomoo`0HOol2001C
Ool30002Ool00`00Oomoo`1OOol004Qoo`8001aoo`8004moo`8000=oo`80069oo`00J7oo00<007oo
Ool0Bgoo00<007ooOol0Igoo001YOol20019Ool2001ZOol006]oo`03001oogoo04Eoo`03001oogoo
06Yoo`00K7oo0P00@goo0P00KGoo001^Ool2000oOol2001_Ool0071oo`03001oogoo03]oo`03001o
ogoo06moo`00LGoo0P00>Goo0P00LWoo001cOol00`00Oomoo`0eOol00`00Oomoo`1bOol007Aoo`80
03=oo`8007Eoo`00MWoo00<007ooOol0;goo00<007ooOol0MGoo001gOol2000]Ool2001hOol007Uo
o`8002Uoo`8007Yoo`00Ngoo00<007ooOol09Goo00<007ooOol0NWoo001lOol2000SOol2001mOol0
07ioo`03001oogoo01moo`03001oogoo07eoo`00Ogoo0P007Goo0P00P7oo0021Ool2000IOol20022
Ool008=oo`03001oogoo01Eoo`03001oogoo089oo`00Q7oo0P004goo0P00QGoo0026Ool00`00Oomo
o`0?Ool00`00Oomoo`25Ool008Moo`8000eoo`8008Qoo`00RGoo00<007ooOol02Goo00<007ooOol0
R7oo002:Ool20007Ool2002;Ool008aoo`8000=oo`8008eoo`00SWoo00<007oo0000Sgoo002?Ool0
0`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>
Ool008moo`03001oogoo08ioo`00PWoo0`002Woo00<007ooOol0SWoo0025Ool00`00Oomoo`07Ool0
0`00Oomoo`2>Ool008Eoo`03001oogoo00Moo`03001oogoo08ioo`00Pgoo0P002Woo00<007ooOol0
SWoo0025Ool00`00Oomoo`07Ool00`00Oomoo`2>Ool0089oo`<000Yoo`03001oogoo08ioo`00Sgoo
00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0
SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool0
0`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>
Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03
001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08io
o`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<0
07ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol008=oo`<009Yoo`00Q7oo00<007ooOol0VGoo
0022Ool4002JOol0089oo`03001oo`0009]oo`00PWoo00<007oo0000Vgoo0023Ool2002KOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0062, -1.00003, 
  0.0174648, 0.0282586}}]
}, Closed]],

Cell["\<\
This is a list of the nodes of the above example, in the order in \
which they actually occurred, together with the number of mutations on the \
branch leading down to each node:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nl = 
      OrderedNodes[g, \((#2\[LeftDoubleBracket]1\[RightDoubleBracket]&)\)]; \n
    jl = \(NumberOfMutations[g, #]&\)/@nl; \n{nl, jl} // TableForm\)], "Input",\

  CellLabel->"In[37]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"a", "c", "b", "d", "1", "2", "4", "3"},
          {"0", "0", "3", "1", "7", "2", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[37]//TableForm="]
}, Closed]],

Cell["\<\
This gives an estimate of the probability of this mutational \
configuration and of this ordered genealogy, with \[Theta]=1:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ss = MonteCarloProbability[g, nl, jl, 1. , 1. , 1000]; 
    \n{Mean[ss], StandardErrorOfSampleMean[ss]}\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \({1.30619516323279105`*^-8, 5.45642089951839892`*^-10}\)], "Output",
  CellLabel->"Out[40]="]
}, Closed]],

Cell["This is the alternative ordering:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nl2 = {a, b, c, d, 2, 1, 4, 3}; \njl2 = {0, 3, 0, 1, 2, 7, 0, 0}; 
    \n{nl2, jl2} // TableForm\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"a", "b", "c", "d", "2", "1", "4", "3"},
          {"0", "3", "0", "1", "2", "7", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[41]//TableForm="]
}, Closed]],

Cell[TextData[{
  "This is much less likely, because there are so many fewer mutations along \
branch 2 than branch 1, and more mutations along branches ",
  StyleBox["b, d ",
    FontSlant->"Italic"],
  "than branches ",
  StyleBox["a, c",
    FontSlant->"Italic"],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ss2 = MonteCarloProbability[g, nl2, jl2, 1. , 1. , 1000]; 
    \n{Mean[ss2], StandardErrorOfSampleMean[ss2]}\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    \({1.28401748373573143`*^-10, 3.47794643363902533`*^-12}\)], "Output",
  CellLabel->"Out[42]="]
}, Closed]],

Cell["\<\
The ExactProbability[] is a sum over both orderings; it agrees with \
Mean[ss]+Mean[ss2]\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Mean[ss] + Mean[ss2], ExactProbability[g, 1. ]}\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \({1.31903533807014827`*^-8, 1.33586895949719175`*^-8}\)], "Output",
  CellLabel->"Out[43]="]
}, Closed]],

Cell["The t-statistic for the error is not significant:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((Mean[ss] + Mean[ss2] - ExactProbability[g, 1. ])\)/
      \((\[Sqrt]\((
            StandardErrorOfSampleMean[ss]\^2 + 
              StandardErrorOfSampleMean[ss2]\^2)\))\)\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \(\(-0.308504050285711262`\)\)], "Output",
  CellLabel->"Out[44]="]
}, Closed]],

Cell["\<\
 Because the distribution is skewed (note log scale on the \
histogram), the standard error can be appreciable even with 1000 replicates.  \
Note also that with this small number of mutations, there are only a few \
discrete values which can be realised.\
\>", "Text"],

Cell[BoxData[
    \(\(<< Graphics`Graphics`; \)\)], "Input",
  CellLabel->"In[180]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BarChart[BinCounts[Log[ss2], \ {\(-26\), \(-22\), \ 0.1}], 
      PlotRange \[Rule] {{0, 40}, {0, 500}}]; \)\)], "Input",
  CellLabel->"In[46]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.025 0 0.00123607 [
[.025 -0.0125 -3 -9 ]
[.025 -0.0125 3 0 ]
[.05 -0.0125 -3 -9 ]
[.05 -0.0125 3 0 ]
[.075 -0.0125 -3 -9 ]
[.075 -0.0125 3 0 ]
[.1 -0.0125 -3 -9 ]
[.1 -0.0125 3 0 ]
[.125 -0.0125 -3 -9 ]
[.125 -0.0125 3 0 ]
[.15 -0.0125 -3 -9 ]
[.15 -0.0125 3 0 ]
[.175 -0.0125 -3 -9 ]
[.175 -0.0125 3 0 ]
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.225 -0.0125 -3 -9 ]
[.225 -0.0125 3 0 ]
[.25 -0.0125 -6 -9 ]
[.25 -0.0125 6 0 ]
[.275 -0.0125 -6 -9 ]
[.275 -0.0125 6 0 ]
[.3 -0.0125 -6 -9 ]
[.3 -0.0125 6 0 ]
[.325 -0.0125 -6 -9 ]
[.325 -0.0125 6 0 ]
[.35 -0.0125 -6 -9 ]
[.35 -0.0125 6 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.4 -0.0125 -6 -9 ]
[.4 -0.0125 6 0 ]
[.425 -0.0125 -6 -9 ]
[.425 -0.0125 6 0 ]
[.45 -0.0125 -6 -9 ]
[.45 -0.0125 6 0 ]
[.475 -0.0125 -6 -9 ]
[.475 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.525 -0.0125 -6 -9 ]
[.525 -0.0125 6 0 ]
[.55 -0.0125 -6 -9 ]
[.55 -0.0125 6 0 ]
[.575 -0.0125 -6 -9 ]
[.575 -0.0125 6 0 ]
[.6 -0.0125 -6 -9 ]
[.6 -0.0125 6 0 ]
[.625 -0.0125 -6 -9 ]
[.625 -0.0125 6 0 ]
[.65 -0.0125 -6 -9 ]
[.65 -0.0125 6 0 ]
[.675 -0.0125 -6 -9 ]
[.675 -0.0125 6 0 ]
[.7 -0.0125 -6 -9 ]
[.7 -0.0125 6 0 ]
[.725 -0.0125 -6 -9 ]
[.725 -0.0125 6 0 ]
[.75 -0.0125 -6 -9 ]
[.75 -0.0125 6 0 ]
[.775 -0.0125 -6 -9 ]
[.775 -0.0125 6 0 ]
[.8 -0.0125 -6 -9 ]
[.8 -0.0125 6 0 ]
[.825 -0.0125 -6 -9 ]
[.825 -0.0125 6 0 ]
[.85 -0.0125 -6 -9 ]
[.85 -0.0125 6 0 ]
[.875 -0.0125 -6 -9 ]
[.875 -0.0125 6 0 ]
[.9 -0.0125 -6 -9 ]
[.9 -0.0125 6 0 ]
[.925 -0.0125 -6 -9 ]
[.925 -0.0125 6 0 ]
[.95 -0.0125 -6 -9 ]
[.95 -0.0125 6 0 ]
[.975 -0.0125 -6 -9 ]
[.975 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0025 .12361 -18 -4.5 ]
[-0.0025 .12361 0 4.5 ]
[-0.0025 .24721 -18 -4.5 ]
[-0.0025 .24721 0 4.5 ]
[-0.0025 .37082 -18 -4.5 ]
[-0.0025 .37082 0 4.5 ]
[-0.0025 .49443 -18 -4.5 ]
[-0.0025 .49443 0 4.5 ]
[-0.0025 .61803 -18 -4.5 ]
[-0.0025 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.025 0 m
.025 .00625 L
s
[(1)] .025 -0.0125 0 1 Mshowa
.05 0 m
.05 .00625 L
s
[(2)] .05 -0.0125 0 1 Mshowa
.075 0 m
.075 .00625 L
s
[(3)] .075 -0.0125 0 1 Mshowa
.1 0 m
.1 .00625 L
s
[(4)] .1 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(5)] .125 -0.0125 0 1 Mshowa
.15 0 m
.15 .00625 L
s
[(6)] .15 -0.0125 0 1 Mshowa
.175 0 m
.175 .00625 L
s
[(7)] .175 -0.0125 0 1 Mshowa
.2 0 m
.2 .00625 L
s
[(8)] .2 -0.0125 0 1 Mshowa
.225 0 m
.225 .00625 L
s
[(9)] .225 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(10)] .25 -0.0125 0 1 Mshowa
.275 0 m
.275 .00625 L
s
[(11)] .275 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(12)] .3 -0.0125 0 1 Mshowa
.325 0 m
.325 .00625 L
s
[(13)] .325 -0.0125 0 1 Mshowa
.35 0 m
.35 .00625 L
s
[(14)] .35 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(15)] .375 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(16)] .4 -0.0125 0 1 Mshowa
.425 0 m
.425 .00625 L
s
[(17)] .425 -0.0125 0 1 Mshowa
.45 0 m
.45 .00625 L
s
[(18)] .45 -0.0125 0 1 Mshowa
.475 0 m
.475 .00625 L
s
[(19)] .475 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(20)] .5 -0.0125 0 1 Mshowa
.525 0 m
.525 .00625 L
s
[(21)] .525 -0.0125 0 1 Mshowa
.55 0 m
.55 .00625 L
s
[(22)] .55 -0.0125 0 1 Mshowa
.575 0 m
.575 .00625 L
s
[(23)] .575 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(24)] .6 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(25)] .625 -0.0125 0 1 Mshowa
.65 0 m
.65 .00625 L
s
[(26)] .65 -0.0125 0 1 Mshowa
.675 0 m
.675 .00625 L
s
[(27)] .675 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(28)] .7 -0.0125 0 1 Mshowa
.725 0 m
.725 .00625 L
s
[(29)] .725 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(30)] .75 -0.0125 0 1 Mshowa
.775 0 m
.775 .00625 L
s
[(31)] .775 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(32)] .8 -0.0125 0 1 Mshowa
.825 0 m
.825 .00625 L
s
[(33)] .825 -0.0125 0 1 Mshowa
.85 0 m
.85 .00625 L
s
[(34)] .85 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(35)] .875 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(36)] .9 -0.0125 0 1 Mshowa
.925 0 m
.925 .00625 L
s
[(37)] .925 -0.0125 0 1 Mshowa
.95 0 m
.95 .00625 L
s
[(38)] .95 -0.0125 0 1 Mshowa
.975 0 m
.975 .00625 L
s
[(39)] .975 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(40)] 1 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
.01 .12361 m
.01625 .12361 L
s
[(100)] -0.0025 .12361 1 0 Mshowa
.01 .24721 m
.01625 .24721 L
s
[(200)] -0.0025 .24721 1 0 Mshowa
.01 .37082 m
.01625 .37082 L
s
[(300)] -0.0025 .37082 1 0 Mshowa
.01 .49443 m
.01625 .49443 L
s
[(400)] -0.0025 .49443 1 0 Mshowa
.01 .61803 m
.01625 .61803 L
s
[(500)] -0.0025 .61803 1 0 Mshowa
.125 Mabswid
.01 .02472 m
.01375 .02472 L
s
.01 .04944 m
.01375 .04944 L
s
.01 .07416 m
.01375 .07416 L
s
.01 .09889 m
.01375 .09889 L
s
.01 .14833 m
.01375 .14833 L
s
.01 .17305 m
.01375 .17305 L
s
.01 .19777 m
.01375 .19777 L
s
.01 .22249 m
.01375 .22249 L
s
.01 .27193 m
.01375 .27193 L
s
.01 .29666 m
.01375 .29666 L
s
.01 .32138 m
.01375 .32138 L
s
.01 .3461 m
.01375 .3461 L
s
.01 .39554 m
.01375 .39554 L
s
.01 .42026 m
.01375 .42026 L
s
.01 .44498 m
.01375 .44498 L
s
.01 .46971 m
.01375 .46971 L
s
.01 .51915 m
.01375 .51915 L
s
.01 .54387 m
.01375 .54387 L
s
.01 .56859 m
.01375 .56859 L
s
.01 .59331 m
.01375 .59331 L
s
.25 Mabswid
.01 0 m
.01 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.015 0 m
.015 0 L
.035 0 L
.035 0 L
F
0 g
.5 Mabswid
.015 0 m
.015 0 L
.035 0 L
.035 0 L
.015 0 L
s
1 0 0 r
.04 0 m
.04 0 L
.06 0 L
.06 0 L
F
0 g
.04 0 m
.04 0 L
.06 0 L
.06 0 L
.04 0 L
s
1 0 0 r
.065 0 m
.065 .12237 L
.085 .12237 L
.085 0 L
F
0 g
.065 0 m
.065 .12237 L
.085 .12237 L
.085 0 L
.065 0 L
s
1 0 0 r
.09 0 m
.09 0 L
.11 0 L
.11 0 L
F
0 g
.09 0 m
.09 0 L
.11 0 L
.11 0 L
.09 0 L
s
1 0 0 r
.115 0 m
.115 0 L
.135 0 L
.135 0 L
F
0 g
.115 0 m
.115 0 L
.135 0 L
.135 0 L
.115 0 L
s
1 0 0 r
.14 0 m
.14 0 L
.16 0 L
.16 0 L
F
0 g
.14 0 m
.14 0 L
.16 0 L
.16 0 L
.14 0 L
s
1 0 0 r
.165 0 m
.165 0 L
.185 0 L
.185 0 L
F
0 g
.165 0 m
.165 0 L
.185 0 L
.185 0 L
.165 0 L
s
1 0 0 r
.19 0 m
.19 0 L
.21 0 L
.21 0 L
F
0 g
.19 0 m
.19 0 L
.21 0 L
.21 0 L
.19 0 L
s
1 0 0 r
.215 0 m
.215 0 L
.235 0 L
.235 0 L
F
0 g
.215 0 m
.215 0 L
.235 0 L
.235 0 L
.215 0 L
s
1 0 0 r
.24 0 m
.24 0 L
.26 0 L
.26 0 L
F
0 g
.24 0 m
.24 0 L
.26 0 L
.26 0 L
.24 0 L
s
1 0 0 r
.265 0 m
.265 0 L
.285 0 L
.285 0 L
F
0 g
.265 0 m
.265 0 L
.285 0 L
.285 0 L
.265 0 L
s
1 0 0 r
.29 0 m
.29 0 L
.31 0 L
.31 0 L
F
0 g
.29 0 m
.29 0 L
.31 0 L
.31 0 L
.29 0 L
s
1 0 0 r
.315 0 m
.315 0 L
.335 0 L
.335 0 L
F
0 g
.315 0 m
.315 0 L
.335 0 L
.335 0 L
.315 0 L
s
1 0 0 r
.34 0 m
.34 0 L
.36 0 L
.36 0 L
F
0 g
.34 0 m
.34 0 L
.36 0 L
.36 0 L
.34 0 L
s
1 0 0 r
.365 0 m
.365 0 L
.385 0 L
.385 0 L
F
0 g
.365 0 m
.365 0 L
.385 0 L
.385 0 L
.365 0 L
s
1 0 0 r
.39 0 m
.39 0 L
.41 0 L
.41 0 L
F
0 g
.39 0 m
.39 0 L
.41 0 L
.41 0 L
.39 0 L
s
1 0 0 r
.415 0 m
.415 .52162 L
.435 .52162 L
.435 0 L
F
0 g
.415 0 m
.415 .52162 L
.435 .52162 L
.435 0 L
.415 0 L
s
1 0 0 r
.44 0 m
.44 0 L
.46 0 L
.46 0 L
F
0 g
.44 0 m
.44 0 L
.46 0 L
.46 0 L
.44 0 L
s
1 0 0 r
.465 0 m
.465 0 L
.485 0 L
.485 0 L
F
0 g
.465 0 m
.465 0 L
.485 0 L
.485 0 L
.465 0 L
s
1 0 0 r
.49 0 m
.49 0 L
.51 0 L
.51 0 L
F
0 g
.49 0 m
.49 0 L
.51 0 L
.51 0 L
.49 0 L
s
1 0 0 r
.515 0 m
.515 0 L
.535 0 L
.535 0 L
F
0 g
.515 0 m
.515 0 L
.535 0 L
.535 0 L
.515 0 L
s
1 0 0 r
.54 0 m
.54 0 L
.56 0 L
.56 0 L
F
0 g
.54 0 m
.54 0 L
.56 0 L
.56 0 L
.54 0 L
s
1 0 0 r
.565 0 m
.565 0 L
.585 0 L
.585 0 L
F
0 g
.565 0 m
.565 0 L
.585 0 L
.585 0 L
.565 0 L
s
1 0 0 r
.59 0 m
.59 0 L
.61 0 L
.61 0 L
F
0 g
.59 0 m
.59 0 L
.61 0 L
.61 0 L
.59 0 L
s
1 0 0 r
.615 0 m
.615 0 L
.635 0 L
.635 0 L
F
0 g
.615 0 m
.615 0 L
.635 0 L
.635 0 L
.615 0 L
s
1 0 0 r
.64 0 m
.64 0 L
.66 0 L
.66 0 L
F
0 g
.64 0 m
.64 0 L
.66 0 L
.66 0 L
.64 0 L
s
1 0 0 r
.665 0 m
.665 0 L
.685 0 L
.685 0 L
F
0 g
.665 0 m
.665 0 L
.685 0 L
.685 0 L
.665 0 L
s
1 0 0 r
.69 0 m
.69 0 L
.71 0 L
.71 0 L
F
0 g
.69 0 m
.69 0 L
.71 0 L
.71 0 L
.69 0 L
s
1 0 0 r
.715 0 m
.715 0 L
.735 0 L
.735 0 L
F
0 g
.715 0 m
.715 0 L
.735 0 L
.735 0 L
.715 0 L
s
1 0 0 r
.74 0 m
.74 0 L
.76 0 L
.76 0 L
F
0 g
.74 0 m
.74 0 L
.76 0 L
.76 0 L
.74 0 L
s
1 0 0 r
.765 0 m
.765 0 L
.785 0 L
.785 0 L
F
0 g
.765 0 m
.765 0 L
.785 0 L
.785 0 L
.765 0 L
s
1 0 0 r
.79 0 m
.79 0 L
.81 0 L
.81 0 L
F
0 g
.79 0 m
.79 0 L
.81 0 L
.81 0 L
.79 0 L
s
1 0 0 r
.815 0 m
.815 0 L
.835 0 L
.835 0 L
F
0 g
.815 0 m
.815 0 L
.835 0 L
.835 0 L
.815 0 L
s
1 0 0 r
.84 0 m
.84 0 L
.86 0 L
.86 0 L
F
0 g
.84 0 m
.84 0 L
.86 0 L
.86 0 L
.84 0 L
s
1 0 0 r
.865 0 m
.865 0 L
.885 0 L
.885 0 L
F
0 g
.865 0 m
.865 0 L
.885 0 L
.885 0 L
.865 0 L
s
1 0 0 r
.89 0 m
.89 0 L
.91 0 L
.91 0 L
F
0 g
.89 0 m
.89 0 L
.91 0 L
.91 0 L
.89 0 L
s
1 0 0 r
.915 0 m
.915 0 L
.935 0 L
.935 0 L
F
0 g
.915 0 m
.915 0 L
.935 0 L
.935 0 L
.915 0 L
s
1 0 0 r
.94 0 m
.94 0 L
.96 0 L
.96 0 L
F
0 g
.94 0 m
.94 0 L
.96 0 L
.96 0 L
.94 0 L
s
1 0 0 r
.965 0 m
.965 .59208 L
.985 .59208 L
.985 0 L
F
0 g
.965 0 m
.965 .59208 L
.985 .59208 L
.985 0 L
.965 0 L
s
1 0 0 r
.99 0 m
.99 0 L
1.01 0 L
1.01 0 L
F
0 g
.99 0 m
.99 0 L
s
.99 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[46]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{5, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool001Qoo`<000Aoo`@0009oo`<000Eoo`<0009oo`<000Eoo`8000Aoo`03001oogoo00Aoo`8000=o
o`<00004Ool000000003Ool30003Ool30003Ool40003Ool30004Ool30003Ool30004Ool30003Ool3
0004Ool30003Ool40003Ool40002Ool40002Ool50002Ool40003Ool40002Ool40003Ool40002Ool4
0003Ool40002Ool30004Ool30003Ool30003Ool40003Ool30004Ool30003Ool30003Ool30004Ool3
0003Ool30003Ool50003Ool20005Ool001Uoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00=oo`03001oogoo00Aoo`05001oogooOol00002Ool01@00Oomoogoo00001Goo00@007ooOol000Eo
o`03001oo`0000Aoo`800003Ool007oo009oo`03001oogoo00=oo`8000Eoo`03001oo`0000Aoo`03
001oogoo00=oo`03001oo`00009oo`04001oo`000004Ool00`00Oomoo`02Ool01000Ool0000017oo
00<007oo00000Woo00@007oo000000Aoo`03001oogoo00=oo`8000Eoo`03001oo`0000Aoo`03001o
ogoo00=oo`03001oo`00009oo`04001oo`000004Ool00`00Oomoo`02Ool01000Ool000001Woo00@0
07ooOol0009oo`8000=oo`03001oo`0000=oo`04001oogoo0005Ool00`00Oomoo`02Ool00`00Ool0
0005Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`03Ool0
1@00Oomoogoo00000Woo00<007ooOol00Woo000IOol00`00Oomoo`05Ool00`00Oomoo`04Ool01000
Oomoogoo10001Goo00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo
0003Ool300000goo001oo`03Ool200000goo001oo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Ool00002Ool40004Ool00`00Ool00002Ool01000Ool0000017oo0P000goo00@007oo000000Ao
o`<0009oo`04001oogoo0004Ool20005Ool20005Ool20002Ool40005Ool20002Ool01000Oomoo`00
1Goo00D007ooOomoo`00009oo`03001oogoo009oo`<0009oo`03001oogoo008000=oo`03001oo`00
00Aoo`03001oo`0000Eoo`03001oogoo00D000Eoo`04001oogoo0002Ool00`00Oomoo`02Ool00`00
Ool00002Ool01000Oomoo`000goo10000Woo00@007ooOol000Aoo`006Goo00<007ooOol01Woo00@0
07ooOomoo`8000Aoo`03001oo`0000=oo`<000Aoo`<000Eoo`03001oogoo00=oo`8000=oo`06001o
ogoo001oo`0017oo0P0000=oo`00Ool00Woo00<007ooOol017oo0P0017oo0P000goo00<007oo0000
17oo0`000goo0`001Goo0P0017oo0P0017oo00@007ooOol0009oo`03001oogoo008000=oo`03001o
o`0000Eoo`8000=oo`<0009oo`05001oo`00Ool00002Ool40002Ool300000goo001oo`03Ool20003
Ool2000017oo001oogoo10000Woo00@007oo000000Aoo`8000Eoo`8000Aoo`8000=oo`04001oo`00
0003Ool30003Ool30005Ool20004Ool20003Ool200000goo001oo`02Ool01000Oomoo`0017oo000I
Ool00`00Oomoo`03Ool01000Oomoo`001Goo00L007ooOomoo`00Ool00003Ool00`00Oomoo`04Ool0
0`00Oomoo`06Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oo`0000Aoo`800003Ool0
07oo009oo`03001oogoo009oo`04001oo`000004Ool00`00Ool00002Ool00`00Ool00004Ool20004
Ool00`00Ool00005Ool00`00Ool00002Ool01000Ool000000goo00@007ooOol0009oo`800003Ool0
0000009oo`800004Ool007ooOol200000goo00000002Ool01000Oomoo`000Woo0`0000Eoo`00Oomo
o`00009oo`03001oogoo0080009oo`04001oogoo0002Ool00`00Oomoo`0200000goo00000002Ool0
1000Oomoo`000Woo00<007ooOol00P000goo00<007oo00000Woo00<007ooOol00P001Goo00P007oo
Ool007oo001oo`000Woo00@007ooOol0009oo`04001oogoo0005Ool20002Ool01000Oomoo`000Woo
0P0000=oo`00Ool00Woo00@007ooOol000Aoo`0067oo0P001Woo0P000goo0`001Goo0P000goo1000
17oo0`000Woo100017oo0P0017oo0P0000=oo`00000017oo0`000goo0P001Goo0P0017oo0`0017oo
0P0017oo10000goo0`000goo10000goo0P001Goo0P0017oo0`000goo0`0017oo0`000goo0`0017oo
0`000goo10000goo0`000goo10000goo0`000goo0`0017oo0`000goo0`0017oo0`000goo0`0017oo
0`000goo10000Woo10000Woo10000goo0`0017oo0`0017oo0P001Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol001Aoool000D000Qoo`005Woo00D007ooOomoo`0000Ioo`05001oogooOol0
0004O0001@00Oomoogoo00001Goo00<007ooOol017oo00<007ooOol00goo00<007ooOol017oo00<0
07ooOol00goo00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo00<0
07ooOol00goo00<007ooOol017oo00<007ooOol00goo00D007ooOomoo`0000Al0005001oogooOol0
0006Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomo
o`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomo
o`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomo
o`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01@00Oomo
ogoo000017`000D007ooOomoo`0000Qoo`005Woo00<007ooOol037oo00<007`0O0000W`000<007oo
Ool0DWoo00<007`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo000FOol0
0`00Oomoo`0<Ool00`00O01l0002O0000`00Oomoo`1BOol00`00O01l0002O0000`00Oomoo`27Ool0
0`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001oogoo00aoo`03001l07`0009l0003001oogoo
059oo`03001l07`0009l0003001oogoo08Moo`03001l07`0009l0003001oogoo00Yoo`005Woo00<0
07ooOol037oo00<007`0O0000W`000<007ooOol0DWoo00<007`0O0000W`000<007ooOol0Qgoo00<0
07`0O0000W`000<007ooOol02Woo000FOol2000=Ool00`00O01l0002O0000`00Oomoo`1BOol00`00
O01l0002O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001oogoo00ao
o`03001l07`0009l0003001oogoo059oo`03001l07`0009l0003001oogoo08Moo`03001l07`0009l
0003001oogoo00Yoo`005Woo00<007ooOol037oo00<007`0O0000W`000<007ooOol0DWoo00<007`0
O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo000FOol00`00Oomoo`0<Ool0
0`00O01l0002O0000`00Oomoo`1BOol00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O000
0`00Oomoo`0:Ool001Ioo`03001oogoo00aoo`03001l07`0009l0003001oogoo059oo`03001l07`0
009l0003001oogoo08Moo`03001l07`0009l0003001oogoo00Yoo`005Woo00<007ooOol037oo00<0
07`0O0000W`000<007ooOol0DWoo00<007`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<0
07ooOol02Woo000FOol00`00Oomoo`0<Ool00`00O01l0002O0000`00Oomoo`1BOol00`00O01l0002
O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`8000eoo`03001l07`0009l
0003001oogoo059oo`03001l07`0009l0003001oogoo08Moo`03001l07`0009l0003001oogoo00Yo
o`005Woo00<007ooOol037oo00<007`0O0000W`000<007ooOol0DWoo00<007`0O0000W`000<007oo
Ool0Qgoo00<007`0O0000W`000<007ooOol02Woo000FOol00`00Oomoo`0<Ool00`00O01l0002O000
0`00Oomoo`1BOol00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool0
01Ioo`03001oogoo00aoo`03001l07`0009l0003001oogoo059oo`03001l07`0009l0003001oogoo
08Moo`03001l07`0009l0003001oogoo00Yoo`005Woo00<007ooOol037oo00<007`0O0000W`000<0
07ooOol0DWoo00<007`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo000F
Ool00`00Oomoo`0<Ool00`00O01l0002O0000`00Oomoo`1BOol00`00O01l0002O0000`00Oomoo`27
Ool00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`8000eoo`03001l07`0009l0003001oogoo059o
o`03001l07`0009l0003001oogoo08Moo`03001l07`0009l0003001oogoo00Yoo`005Woo00<007oo
Ool037oo00<007`0O0000W`000<007ooOol0DWoo00<007`0O0000W`000<007ooOol0Qgoo00<007`0
O0000W`000<007ooOol02Woo000FOol00`00Oomoo`0<Ool00`00O01l0002O0000`00Oomoo`1BOol0
0`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001oogoo
00aoo`03001l07`0009l0003001oogoo059oo`03001l07`0009l0003001oogoo08Moo`03001l07`0
009l0003001oogoo00Yoo`005Woo00<007ooOol037oo00<007`0O0000W`000<007ooOol0DWoo00<0
07`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo000FOol00`00Oomoo`0<
Ool00`00O01l0002O0000`00Oomoo`1BOol00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002
O0000`00Oomoo`0:Ool001Ioo`8000eoo`03001l07`0009l0003001oogoo059oo`03001l07`0009l
0003001oogoo08Moo`03001l07`0009l0003001oogoo00Yoo`005Woo00<007ooOol037oo00<007`0
O0000W`000<007ooOol0DWoo00<007`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007oo
Ool02Woo000FOol00`00Oomoo`0<Ool00`00O01l0002O0000`00Oomoo`1BOol00`00O01l0002O000
0`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001oogoo00aoo`03001l07`0
009l0003001oogoo059oo`03001l07`0009l0003001oogoo08Moo`03001l07`0009l0003001oogoo
00Yoo`005Woo00<007ooOol037oo00<007`0O0000W`000<007ooOol0DWoo00<007`0O0000W`000<0
07ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo0002Ool30004Ool20004Ool20005Ool00`00
Oomoo`0<Ool00`00O01l0002O0000`00Oomoo`1BOol00`00O01l0002O0000`00Oomoo`27Ool00`00
O01l0002O0000`00Oomoo`0:Ool000=oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
17oo00<007ooOol037oo00<007`0O0000W`000<007ooOol0DWoo00<007`0O0000W`000<007ooOol0
Qgoo00<007`0O0000W`000<007ooOol02Woo0003Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`<000aoo`H005Aoo`03001l07`0009l0003001oogoo08Moo`03001l07`0009l0003
001oogoo00Yoo`000goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomo
o`1VOol00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool000=oo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0IWoo00<007`0O0000W`0
00<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo0002Ool20005Ool20004Ool20005Ool0
0`00Oomoo`1VOol00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool0
01Ioo`03001oogoo06Ioo`03001l07`0009l0003001oogoo08Moo`03001l07`0009l0003001oogoo
00Yoo`005Woo00<007ooOol0IWoo00<007`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<0
07ooOol02Woo000FOol2001WOol00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O0000`00
Oomoo`0:Ool001Ioo`03001oogoo06Ioo`03001l07`0009l0003001oogoo08Moo`03001l07`0009l
0003001oogoo00Yoo`005Woo00<007ooOol0IWoo00<007`0O0000W`000<007ooOol0Qgoo00<007`0
O0000W`000<007ooOol02Woo000FOol00`00Oomoo`1VOol00`00O01l0002O0000`00Oomoo`27Ool0
0`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001oogoo06Ioo`03001l07`0009l0003001oogoo
08Moo`03001l07`0009l0003001oogoo00Yoo`005Woo00<007ooOol0IWoo00<007`0O0000W`000<0
07ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo000FOol00`00Oomoo`1VOol00`00O01l0002
O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`8006Moo`03001l07`0009l
0003001oogoo08Moo`03001l07`0009l0003001oogoo00Yoo`005Woo00<007ooOol0IWoo00<007`0
O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo000FOol00`00Oomoo`1VOol0
0`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001oogoo
06Ioo`03001l07`0009l0003001oogoo08Moo`03001l07`0009l0003001oogoo00Yoo`005Woo00<0
07ooOol0IWoo00<007`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo000F
Ool00`00Oomoo`1VOol00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:
Ool001Ioo`8006Moo`03001l07`0009l0003001oogoo08Moo`03001l07`0009l0003001oogoo00Yo
o`005Woo00<007ooOol0IWoo00<007`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007oo
Ool02Woo000FOol00`00Oomoo`1VOol00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O000
0`00Oomoo`0:Ool001Ioo`03001oogoo06Ioo`03001l07`0009l0003001oogoo08Moo`03001l07`0
009l0003001oogoo00Yoo`005Woo00<007ooOol0IWoo00<007`0O0000W`000<007ooOol0Qgoo00<0
07`0O0000W`000<007ooOol02Woo000FOol00`00Oomoo`1VOol00`00O01l0002O0000`00Oomoo`27
Ool00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`8006Moo`03001l07`0009l0003001oogoo08Mo
o`03001l07`0009l0003001oogoo00Yoo`005Woo00<007ooOol0IWoo00<007`0O0000W`000<007oo
Ool0Qgoo00<007`0O0000W`000<007ooOol02Woo000FOol00`00Oomoo`1VOol00`00O01l0002O000
0`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001oogoo06Ioo`03001l07`0
009l0003001oogoo08Moo`03001l07`0009l0003001oogoo00Yoo`005Woo00<007ooOol0IWoo00<0
07`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo0002Ool40003Ool20004
Ool20005Ool00`00Oomoo`1VOol00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O0000`00
Oomoo`0:Ool000=oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0
IWoo00<007`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo0004Ool01@00
Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo009oo`<006Ioo`03001l07`0009l0003001o
ogoo08Moo`03001l07`0009l0003001oogoo00Yoo`001Goo00@007ooOol0009oo`04001oogoo0002
Ool00`00Oomoo`02Ool00`00Oomoo`1VOol00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002
O0000`00Oomoo`0:Ool0009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`03
001oogoo06Ioo`03001l07`0009l0003001oogoo08Moo`03001l07`0009l0003001oogoo00Yoo`00
0goo0P0017oo0P0017oo0P001Goo00<007ooOol0IWoo00<007`0O0000W`000<007ooOol0Qgoo00<0
07`0O0000W`000<007ooOol02Woo000FOol00`00Oomoo`1VOol00`00O01l0002O0000`00Oomoo`27
Ool00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001oogoo06Ioo`03001l07`0009l0003001o
ogoo08Moo`03001l07`0009l0003001oogoo00Yoo`005Woo0P00Igoo00<007`0O0000W`000<007oo
Ool0Qgoo00<007`0O0000W`000<007ooOol02Woo000FOol00`00Oomoo`1VOol00`00O01l0002O000
0`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001oogoo06Ioo`03001l07`0
009l0003001oogoo08Moo`03001l07`0009l0003001oogoo00Yoo`005Woo00<007ooOol0IWoo00<0
07`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo000FOol00`00Oomoo`1V
Ool00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001o
ogoo06Ioo`03001l07`0009l0003001oogoo08Moo`03001l07`0009l0003001oogoo00Yoo`005Woo
00<007ooOol0IWoo00<007`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo
000FOol2001WOol00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool0
01Ioo`03001oogoo06Ioo`03001l07`0009l0003001oogoo08Moo`03001l07`0009l0003001oogoo
00Yoo`005Woo00<007ooOol0IWoo00<007`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<0
07ooOol02Woo000FOol00`00Oomoo`1VOol00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002
O0000`00Oomoo`0:Ool001Ioo`03001oogoo06Ioo`03001l07`0009l0003001oogoo08Moo`03001l
07`0009l0003001oogoo00Yoo`005Woo00<007ooOol0IWoo00<007`0O0000W`000<007ooOol0Qgoo
00<007`0O0000W`000<007ooOol02Woo000FOol2001WOol00`00O01l0002O0000`00Oomoo`27Ool0
0`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001oogoo06Ioo`03001l07`0009l0003001oogoo
08Moo`03001l07`0009l0003001oogoo00Yoo`005Woo00<007ooOol0IWoo00<007`0O0000W`000<0
07ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo000FOol00`00Oomoo`1VOol00`00O01l0002
O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001oogoo06Ioo`03001l
07`0009l0003001oogoo08Moo`03001l07`0009l0003001oogoo00Yoo`005Woo00<007ooOol0IWoo
00<007`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo000FOol00`00Oomo
o`1VOol00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`80
06Moo`03001l07`0009l0003001oogoo08Moo`03001l07`0009l0003001oogoo00Yoo`005Woo00<0
07ooOol0IWoo00<007`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo000F
Ool00`00Oomoo`1VOol00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:
Ool001Ioo`03001oogoo06Ioo`03001l07`0009l0003001oogoo08Moo`03001l07`0009l0003001o
ogoo00Yoo`000Woo0`0017oo0P0017oo0P001Goo00<007ooOol0IWoo00<007`0O0000W`000<007oo
Ool0Qgoo00<007`0O0000W`000<007ooOol02Woo0005Ool01000Oomoo`000Woo00@007ooOol0009o
o`03001oogoo009oo`03001oogoo06Ioo`03001l07`0009l0003001oogoo08Moo`03001l07`0009l
0003001oogoo00Yoo`001Goo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02Ool3001V
Ool00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool000=oo`8000=o
o`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0IWoo00<007`0O0000W`000<007ooOol0
Qgoo00<007`0O0000W`000<007ooOol02Woo0005Ool01000Oomoo`000Woo00@007ooOol0009oo`03
001oogoo009oo`03001oogoo06Ioo`03001l07`0009l0003001oogoo08Moo`03001l07`0009l0003
001oogoo00Yoo`000Woo0`0017oo0P0017oo0P001Goo00<007ooOol0IWoo00<007`0O0000W`000<0
07ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo000FOol00`00Oomoo`1VOol00`00O01l0002
O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001oogoo06Ioo`03001l
07`0009l0003001oogoo08Moo`03001l07`0009l0003001oogoo00Yoo`005Woo0P00Igoo00<007`0
O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo000FOol00`00Oomoo`1VOol0
0`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001oogoo
06Ioo`03001l07`0009l0003001oogoo08Moo`03001l07`0009l0003001oogoo00Yoo`005Woo00<0
07ooOol0IWoo00<007`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo000F
Ool00`00Oomoo`1VOol00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:
Ool001Ioo`03001oogoo06Ioo`03001l07`0009l0003001oogoo08Moo`03001l07`0009l0003001o
ogoo00Yoo`005Woo00<007ooOol0IWoo00<007`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`0
00<007ooOol02Woo000FOol2001WOol00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O000
0`00Oomoo`0:Ool001Ioo`03001oogoo06Ioo`03001l07`0009l0003001oogoo08Moo`03001l07`0
009l0003001oogoo00Yoo`005Woo00<007ooOol0IWoo00<007`0O0000W`000<007ooOol0Qgoo00<0
07`0O0000W`000<007ooOol02Woo000FOol00`00Oomoo`1VOol00`00O01l0002O0000`00Oomoo`27
Ool00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001oogoo06Ioo`03001l07`0009l0003001o
ogoo08Moo`03001l07`0009l0003001oogoo00Yoo`005Woo00<007ooOol0IWoo00<007`0O0000W`0
00<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo000FOol2001WOol00`00O01l0002O000
0`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001oogoo06Ioo`03001l07`0
009l0003001oogoo08Moo`03001l07`0009l0003001oogoo00Yoo`005Woo00<007ooOol0IWoo00<0
07`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo000FOol00`00Oomoo`1V
Ool00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001o
ogoo06Ioo`03001l07`0009l0003001oogoo08Moo`03001l07`0009l0003001oogoo00Yoo`005Woo
00<007ooOol0IWoo00<007`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo
000FOol00`00Oomoo`1VOol00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomo
o`0:Ool001Ioo`8006Moo`03001l07`0009l0003001oogoo08Moo`03001l07`0009l0003001oogoo
00Yoo`005Woo00<007ooOol0IWoo00<007`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<0
07ooOol02Woo000FOol00`00Oomoo`1VOol00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002
O0000`00Oomoo`0:Ool001Ioo`03001oogoo06Ioo`03001l07`0009l0003001oogoo08Moo`03001l
07`0009l0003001oogoo00Yoo`000goo0`000goo0P0017oo0P001Goo00<007ooOol0IWoo00<007`0
O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo0004Ool01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo009oo`03001oogoo06Ioo`03001l07`0009l0003001oogoo
08Moo`03001l07`0009l0003001oogoo00Yoo`000Woo10000Woo00@007ooOol0009oo`04001oogoo
0004Ool3001VOol00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool0
009oo`03001oo`0000=oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0IWoo00<007`0
O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo0002Ool00`00Ool00003Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo06Ioo`03001l07`0009l0003001oogoo08Mo
o`03001l07`0009l0003001oogoo00Yoo`000goo0P0017oo0P0017oo0P001Goo00<007ooOol0IWoo
00<007`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo000FOol00`00Oomo
o`1VOol00`00O01l0002O0000`00Oomoo`27Ool00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03
001oogoo06Ioo`03001l07`0009l0003001oogoo08Moo`03001l07`0009l0003001oogoo00Yoo`00
5Woo0P00Igoo00<007`0O0000W`000<007ooOol0Qgoo00<007`0O0000W`000<007ooOol02Woo000F
Ool00`00Oomoo`1VOol60029Ool00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001oogoo0?Eo
o`03001l07`0009l0003001oogoo00Yoo`005Woo00<007ooOol0mGoo00<007`0O0000W`000<007oo
Ool02Woo000FOol00`00Oomoo`3eOol00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001oogoo
0?Eoo`03001l07`0009l0003001oogoo00Yoo`005Woo00<007ooOol0mGoo00<007`0O0000W`000<0
07ooOol02Woo000FOol2003fOol00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001oogoo0?Eo
o`03001l07`0009l0003001oogoo00Yoo`005Woo00<007ooOol0mGoo00<007`0O0000W`000<007oo
Ool02Woo000FOol00`00Oomoo`3eOol00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001oogoo
0?Eoo`03001l07`0009l0003001oogoo00Yoo`005Woo00<007ooOol0mGoo00<007`0O0000W`000<0
07ooOol02Woo000FOol2003fOol00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001oogoo0?Eo
o`03001l07`0009l0003001oogoo00Yoo`005Woo00<007ooOol0mGoo00<007`0O0000W`000<007oo
Ool02Woo000FOol00`00Oomoo`3eOol00`00O01l0002O0000`00Oomoo`0:Ool001Ioo`03001oogoo
0?Eoo`03001l07`0009l0003001oogoo00Yoo`005Woo00<007ooOol0mGoo00<007`0O0000W`000<0
07ooOol02Woo000FOol00`00Oomoo`3eOol6000<Ool001Ioo`800?moo`Uoo`005Woo00<007ooOol0
ogoo27oo000FOol00`00Oomoo`3oOol8Ool001Ioo`03001oogoo0?moo`Qoo`000Woo0`0017oo0P00
17oo0P001Goo00<007ooOol0ogoo27oo0005Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo009oo`03001oogoo0?moo`Qoo`001Goo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomo
o`02Ool3003oOol8Ool0009oo`<000=oo`04001oogoo0002Ool01000Oomoo`00ogoo3goo0002Ool0
0`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol00?moo`moo`000Woo10000goo0P0017oo0P00
ogoo47oo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.12064, -38.2056, 
  0.154319, 3.12116}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Estimating the probability using symbolic expressions", "SubsectionIcon"],

Cell[TextData[{
  "Here, a symbolic expression for the likelihood of \[Theta] is returned, \
for a set of partitions generated using the arbitrary parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Theta]\^*\) = 1\)]],
  ".  The table shows the frequencies of each kind of term; these terms \
correspond to different partitions of mutations across the times when there \
are 4, 3, 2 extant lineages, and hence to different powers of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_4, \ \[Lambda]\_3, \ 
      \[Lambda]\_\(2 : \)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ss4 = MonteCarloProbability[g, nl, jl, \[Theta], 1. , 1000]; \n
    Frequencies[ss4]\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \({{4, 
        \(0.0114926901812913162`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^6\ 
            \((2 + \[Theta])\)\^5\ \((3 + \[Theta])\)\^5\)}, {2, 
        \(0.0114926901812913162`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^7\ 
            \((2 + \[Theta])\)\^4\ \((3 + \[Theta])\)\^5\)}, {2, 
        \(0.0178775180597864924`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^8\ 
            \((2 + \[Theta])\)\^3\ \((3 + \[Theta])\)\^5\)}, {4, 
        \(0.0476733814927639798`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^9\ 
            \((2 + \[Theta])\)\^2\ \((3 + \[Theta])\)\^5\)}, {1, 
        \(0.286040288956583879`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^10\ 
            \((2 + \[Theta])\)\ \((3 + \[Theta])\)\^5\)}, {3, 
        \(0.0193939146809291003`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^5\ 
            \((2 + \[Theta])\)\^7\ \((3 + \[Theta])\)\^4\)}, {9, 
        \(0.0107743970449606107`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^6\ 
            \((2 + \[Theta])\)\^6\ \((3 + \[Theta])\)\^4\)}, {39, 
        \(0.00861951763596848863`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^7\ 
            \((2 + \[Theta])\)\^5\ \((3 + \[Theta])\)\^4\)}, {45, 
        \(0.0100561039086299031`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^8\ 
            \((2 + \[Theta])\)\^4\ \((3 + \[Theta])\)\^4\)}, {27, 
        \(0.0178775180597864924`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^9\ 
            \((2 + \[Theta])\)\^3\ \((3 + \[Theta])\)\^4\)}, {10, 
        \(0.0536325541793594773`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^10\ 
            \((2 + \[Theta])\)\^2\ \((3 + \[Theta])\)\^4\)}, {2, 
        \(0.101818052074877751`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^4\ 
            \((2 + \[Theta])\)\^9\ \((3 + \[Theta])\)\^3\)}, {3, 
        \(0.0339393506916259246`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^5\ 
            \((2 + \[Theta])\)\^8\ \((3 + \[Theta])\)\^3\)}, {26, 
        \(0.0161615955674409139`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^6\ 
            \((2 + \[Theta])\)\^7\ \((3 + \[Theta])\)\^3\)}, {72, 
        \(0.0107743970449606107`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^7\ 
            \((2 + \[Theta])\)\^6\ \((3 + \[Theta])\)\^3\)}, {101, 
        \(0.0100561039086299031`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^8\ 
            \((2 + \[Theta])\)\^5\ \((3 + \[Theta])\)\^3\)}, {83, 
        \(0.0134081385448398693`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^9\ 
            \((2 + \[Theta])\)\^4\ \((3 + \[Theta])\)\^3\)}, {24, 
        \(0.0268162770896797386`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^10\ 
            \((2 + \[Theta])\)\^3\ \((3 + \[Theta])\)\^3\)}, {10, 
        \(0.101818052074877751`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^5\ 
            \((2 + \[Theta])\)\^9\ \((3 + \[Theta])\)\^2\)}, {35, 
        \(0.0424241883645324069`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^6\ 
            \((2 + \[Theta])\)\^8\ \((3 + \[Theta])\)\^2\)}, {102, 
        \(0.0242423933511613753`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^7\ 
            \((2 + \[Theta])\)\^7\ \((3 + \[Theta])\)\^2\)}, {117, 
        \(0.0188551948286810659`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^8\ 
            \((2 + \[Theta])\)\^6\ \((3 + \[Theta])\)\^2\)}, {88, 
        \(0.0201122078172598062`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^9\ 
            \((2 + \[Theta])\)\^5\ \((3 + \[Theta])\)\^2\)}, {30, 
        \(0.0301683117258897048`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^10\ 
            \((2 + \[Theta])\)\^4\ \((3 + \[Theta])\)\^2\)}, {9, 
        \(0.687271851505424891`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^5\ 
            \((2 + \[Theta])\)\^10\ \((3 + \[Theta])\)\)}, {13, 
        \(0.254545130187194423`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^6\ 
            \((2 + \[Theta])\)\^9\ \((3 + \[Theta])\)\)}, {43, 
        \(0.127272565093597211`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^7\ 
            \((2 + \[Theta])\)\^8\ \((3 + \[Theta])\)\)}, {50, 
        \(0.0848483767290648138`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^8\ 
            \((2 + \[Theta])\)\^7\ \((3 + \[Theta])\)\)}, {27, 
        \(0.0754207793147242622`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^9\ 
            \((2 + \[Theta])\)\^6\ \((3 + \[Theta])\)\)}, {19, 
        \(0.0905049351776691146`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^10\ 
            \((2 + \[Theta])\)\^5\ \((3 + \[Theta])\)\)}}\)], "Output",
  CellLabel->"Out[47]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(exgt = ExactProbability[g, \[Theta]]\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(\((\[Theta]\^13\ 
          \((58499235072 + 328633153920\ \[Theta] + 
              837829310976\ \[Theta]\^2 + 1279012849536\ \[Theta]\^3 + 
              1298422333088\ \[Theta]\^4 + 919872926072\ \[Theta]\^5 + 
              463786047696\ \[Theta]\^6 + 166302559252\ \[Theta]\^7 + 
              41533895029\ \[Theta]\^8 + 6876252288\ \[Theta]\^9 + 
              678774692\ \[Theta]\^10 + 30250112\ \[Theta]\^11)\))\)/
      \((725594112\ \((1 + \[Theta])\)\^10\ \((2 + \[Theta])\)\^12\ 
          \((3 + \[Theta])\)\^5)\)\)], "Output",
  CellLabel->"Out[48]="]
}, Closed]],

Cell["The likelihood matches the exact probability closely:", "MathCaption"],

Cell[BoxData[
    \(<< Graphics`Graphics`; << Graphics`Colors`; \)], "Input",
  CellLabel->"In[74]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(mn = Mean[ss4]; se = StandardErrorOfSampleMean[ss4]; \n
    LogLogPlot[{exgt, mn, mn + se, mn - se}, {\[Theta], 0, 50}, 
      PlotStyle 
        \[Rule] {Red, Dashing[{1, 0}], Dashing[{0.01, 0.01}], 
          Dashing[{0.01, 0.01}]}]; \)], "Input",
  CellLabel->"In[49]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.244654 0.430576 1.70904 0.20634 [
[.11504 -0.0125 -11 -12 ]
[.11504 -0.0125 11 0 ]
[.24465 -0.0125 -5 -12 ]
[.24465 -0.0125 5 0 ]
[.54561 -0.0125 -5 -12 ]
[.54561 -0.0125 5 0 ]
[.67523 -0.0125 -8 -12 ]
[.67523 -0.0125 8 0 ]
[.97619 -0.0125 -8 -12 ]
[.97619 -0.0125 8 0 ]
[-0.0125 .05832 -47.0625 -6.40625 ]
[-0.0125 .05832 0 6.40625 ]
[-0.0125 .20255 -47.0625 -6.40625 ]
[-0.0125 .20255 0 6.40625 ]
[-0.0125 .26466 -47.0625 -6.34375 ]
[-0.0125 .26466 0 6.34375 ]
[-0.0125 .40889 -47.0625 -6.34375 ]
[-0.0125 .40889 0 6.34375 ]
[-0.0125 .471 -47.0625 -6.40625 ]
[-0.0125 .471 0 6.40625 ]
[-0.0125 .61523 -47.0625 -6.40625 ]
[-0.0125 .61523 0 6.40625 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11504 0 m
.11504 .00625 L
s
gsave
.11504 -0.0125 -72 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.24465 0 m
.24465 .00625 L
s
gsave
.24465 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.54561 0 m
.54561 .00625 L
s
gsave
.54561 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.67523 0 m
.67523 .00625 L
s
gsave
.67523 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
.01951 0 m
.01951 .00375 L
s
.07331 0 m
.07331 .00375 L
s
.14913 0 m
.14913 .00375 L
s
.17796 0 m
.17796 .00375 L
s
.20293 0 m
.20293 .00375 L
s
.22495 0 m
.22495 .00375 L
s
.37427 0 m
.37427 .00375 L
s
.45009 0 m
.45009 .00375 L
s
.50389 0 m
.50389 .00375 L
s
.57971 0 m
.57971 .00375 L
s
.60853 0 m
.60853 .00375 L
s
.6335 0 m
.6335 .00375 L
s
.65553 0 m
.65553 .00375 L
s
.80485 0 m
.80485 .00375 L
s
.88067 0 m
.88067 .00375 L
s
.93446 0 m
.93446 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .05832 m
.00625 .05832 L
s
gsave
-0.0125 .05832 -108.062 -10.4062 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.812500 moveto
 558.000000 16.812500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.812500 lineto
closepath
clip newpath
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.) show
75.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
76.812500 13.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(\\264) show
84.625000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
96.625000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
96.625000 9.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
100.812500 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
105.000000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
0 .20255 m
.00625 .20255 L
s
gsave
-0.0125 .20255 -108.062 -10.4062 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.812500 moveto
 558.000000 16.812500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.812500 lineto
closepath
clip newpath
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5.) show
75.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
76.812500 13.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(\\264) show
84.625000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
96.625000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
96.625000 9.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
100.812500 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
105.000000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
0 .26466 m
.00625 .26466 L
s
gsave
-0.0125 .26466 -108.062 -10.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.6875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.687500 moveto
 558.000000 16.687500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.687500 lineto
closepath
clip newpath
63.000000 13.687500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.687500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.) show
75.000000 13.687500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
76.812500 13.687500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(\\264) show
84.625000 13.687500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
96.625000 9.312500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
96.625000 9.312500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
100.812500 9.312500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(7) show
105.000000 9.312500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
0 .40889 m
.00625 .40889 L
s
gsave
-0.0125 .40889 -108.062 -10.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.6875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.687500 moveto
 558.000000 16.687500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.687500 lineto
closepath
clip newpath
63.000000 13.687500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.687500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5.) show
75.000000 13.687500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
76.812500 13.687500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(\\264) show
84.625000 13.687500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
96.625000 9.312500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
96.625000 9.312500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
100.812500 9.312500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(7) show
105.000000 9.312500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
0 .471 m
.00625 .471 L
s
gsave
-0.0125 .471 -108.062 -10.4062 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.812500 moveto
 558.000000 16.812500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.812500 lineto
closepath
clip newpath
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.) show
75.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
76.812500 13.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(\\264) show
84.625000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
96.625000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
96.625000 9.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
100.812500 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
105.000000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
0 .61523 m
.00625 .61523 L
s
gsave
-0.0125 .61523 -108.062 -10.4062 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.812500 moveto
 558.000000 16.812500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.812500 lineto
closepath
clip newpath
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5.) show
75.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
76.812500 13.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(\\264) show
84.625000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
96.625000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
96.625000 9.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
100.812500 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
105.000000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
.001 w
0 .12043 m
.00375 .12043 L
s
0 .15677 m
.00375 .15677 L
s
0 .18255 m
.00375 .18255 L
s
0 .21888 m
.00375 .21888 L
s
0 .2327 m
.00375 .2327 L
s
0 .24466 m
.00375 .24466 L
s
0 .25522 m
.00375 .25522 L
s
0 .32677 m
.00375 .32677 L
s
0 .36311 m
.00375 .36311 L
s
0 .38889 m
.00375 .38889 L
s
0 .42522 m
.00375 .42522 L
s
0 .43904 m
.00375 .43904 L
s
0 .451 m
.00375 .451 L
s
0 .46156 m
.00375 .46156 L
s
0 .53311 m
.00375 .53311 L
s
0 .56945 m
.00375 .56945 L
s
0 .59523 m
.00375 .59523 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.22164 0 m
.24228 .07692 L
.31927 .28832 L
.3769 .40921 L
.42503 .48609 L
.46138 .53025 L
.4889 .55615 L
.5148 .57491 L
.53547 .58616 L
.55587 .59419 L
.56535 .59693 L
.57503 .5991 L
.57955 .5999 L
.58374 .60052 L
.58744 .60098 L
.59136 .60136 L
.59343 .60153 L
.5953 .60166 L
.59704 .60175 L
.59894 .60184 L
.60062 .6019 L
.60218 .60194 L
.60382 .60196 L
.60555 .60197 L
.60741 .60196 L
.60846 .60194 L
.60942 .60192 L
.61117 .60187 L
.61302 .6018 L
.61616 .60162 L
.61957 .60137 L
.62551 .60078 L
.63171 .59994 L
.64243 .598 L
.6533 .5954 L
.66452 .59208 L
.68526 .58433 L
.71964 .5672 L
.74766 .5497 L
.77345 .53109 L
.79533 .5136 L
.81421 .49739 L
.8324 .48085 L
.84839 .46563 L
.86257 .45164 L
.87658 .43739 L
.88913 .42428 L
.90162 .41094 L
.9129 .39864 L
.92315 .38728 L
Mistroke
.93347 .37567 L
.9429 .36492 L
.95242 .35393 L
.96116 .34373 L
.9692 .33425 L
.97619 .32594 L
Mfstroke
0 g
[ 1 0 ] 0 setdash
.22199 0 m
.24228 .07553 L
.31927 .28659 L
.3769 .40721 L
.42503 .48386 L
.46138 .52783 L
.4889 .5536 L
.5148 .57221 L
.53547 .58336 L
.55587 .59129 L
.56535 .59398 L
.57503 .5961 L
.57955 .59688 L
.58374 .59748 L
.58744 .59792 L
.59136 .59829 L
.59343 .59844 L
.5953 .59856 L
.59704 .59865 L
.59894 .59873 L
.60062 .59878 L
.60218 .59881 L
.60382 .59882 L
.60555 .59882 L
.60741 .5988 L
.60846 .59878 L
.60942 .59876 L
.61117 .5987 L
.61302 .59861 L
.61616 .59843 L
.61957 .59816 L
.62551 .59754 L
.63171 .59667 L
.64243 .59468 L
.6533 .59204 L
.66452 .58867 L
.68526 .58083 L
.71964 .56357 L
.74766 .54597 L
.77345 .52727 L
.79533 .50972 L
.81421 .49345 L
.8324 .47687 L
.84839 .46161 L
.86257 .44759 L
.87658 .43331 L
.88913 .42017 L
.90162 .40681 L
.9129 .39449 L
.92315 .38311 L
Mistroke
.93347 .37148 L
.9429 .36072 L
.95242 .34971 L
.96116 .3395 L
.9692 .33001 L
.97619 .32169 L
Mfstroke
[ .01 .01 ] 0 setdash
.22091 0 m
.24228 .07949 L
.31927 .2905 L
.3769 .41117 L
.42503 .4879 L
.46138 .53195 L
.4889 .55779 L
.5148 .57647 L
.53547 .58767 L
.55587 .59566 L
.56535 .59837 L
.57503 .60052 L
.57955 .60131 L
.58374 .60192 L
.58744 .60237 L
.59136 .60275 L
.59343 .60291 L
.5953 .60303 L
.59704 .60313 L
.59894 .60321 L
.60062 .60326 L
.60218 .60329 L
.60382 .60332 L
.60555 .60332 L
.60741 .6033 L
.60846 .60328 L
.60942 .60326 L
.61117 .60321 L
.61302 .60313 L
.61616 .60295 L
.61957 .60269 L
.62551 .60208 L
.63171 .60123 L
.64243 .59927 L
.6533 .59665 L
.66452 .5933 L
.68526 .58551 L
.71964 .56831 L
.74766 .55076 L
.77345 .5321 L
.79533 .51458 L
.81421 .49833 L
.8324 .48177 L
.84839 .46653 L
.86257 .45252 L
.87658 .43825 L
.88913 .42513 L
.90162 .41178 L
.9129 .39947 L
.92315 .3881 L
Mistroke
.93347 .37647 L
.9429 .36572 L
.95242 .35472 L
.96116 .34451 L
.9692 .33503 L
.97619 .32671 L
Mfstroke
.22311 0 m
.24228 .07138 L
.31927 .28249 L
.3769 .40307 L
.42503 .47962 L
.46138 .52351 L
.4889 .5492 L
.5148 .56774 L
.53547 .57883 L
.55587 .58669 L
.56535 .58936 L
.57503 .59145 L
.57955 .59222 L
.58374 .59281 L
.58744 .59323 L
.59136 .59359 L
.59343 .59374 L
.5953 .59385 L
.59704 .59394 L
.59894 .59401 L
.60062 .59406 L
.60218 .59408 L
.60382 .59409 L
.60555 .59409 L
.60741 .59406 L
.60846 .59404 L
.60942 .59401 L
.61117 .59395 L
.61302 .59386 L
.61616 .59367 L
.61957 .59339 L
.62551 .59275 L
.63171 .59187 L
.64243 .58985 L
.6533 .58718 L
.66452 .58379 L
.68526 .5759 L
.71964 .55857 L
.74766 .54091 L
.77345 .52217 L
.79533 .50459 L
.81421 .48829 L
.8324 .47168 L
.84839 .45641 L
.86257 .44237 L
.87658 .42807 L
.88913 .41492 L
.90162 .40155 L
.9129 .38922 L
.92315 .37784 L
Mistroke
.93347 .3662 L
.9429 .35543 L
.95242 .34441 L
.96116 .33419 L
.9692 .3247 L
.97619 .31637 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[49]:=",
  ImageSize->{493, 304.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007]0001<1000`40O003h00OogookWoo003oOoo^
Ool00?moonioo`00ogookWoo003oOoo^Ool00?moonioo`00ogookWoo003oOoo^Ool00?moonioo`00
H7oo0P0017oo0P000goo0`00<7oo0`00PGoo0`00<goo0`0017oo0P00Ngoo0`0017oo0P0027oo001O
Ool01000Oomoo`000goo0P001Woo00<007ooOol0;Woo00<007ooOol0Pgoo00<007ooOol0<Goo00<0
07ooOol00Woo00@007ooOol007eoo`04001oogoo0002Ool00`00Oomoo`05Ool005moo`04001oogoo
000;Ool00`00Oomoo`0^Ool00`00Oomoo`23Ool00`00Oomoo`0aOol00`00Oomoo`02Ool01000Oomo
o`00OGoo00@007ooOol0009oo`03001oogoo00Eoo`00Ggoo00@007ooOol000Qoo`<0035oo`03001o
ogoo081oo`<003Aoo`03001oogoo009oo`04001oogoo001jOol30003Ool01000Oomoo`001goo001O
Ool01000Oomoo`0027oo00<007ooOol0<Goo00<007ooOol0P7oo00<007ooOol0=7oo00<007ooOol0
0Woo00@007ooOol007Yoo`03001oogoo00=oo`04001oogoo0007Ool0061oo`8000Uoo`@002moo`80
089oo`@0039oo`8000Eoo`8007]oo`@000=oo`8000Qoo`00ogookWoo003oOoo^Ool00?moonioo`00
ogookWoo003oOoo^Ool00?moonioo`00ogookWoo000dOooo002i0001Ool003Aoo`03001oogoo00Io
o`03001oogoo01Aoo`03001oogoo011oo`03001oogoo00aoo`03001oogoo00Uoo`03001oogoo00Qo
o`03001oogoo00Eoo`<000Qoo`03001oogoo03Ioo`03001oogoo01ioo`03001oogoo01Aoo`03001o
ogoo011oo`03001oogoo00aoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Moo`03001o
ogoo00Ioo`03001oogoo03Ioo`03001oogoo01ioo`03001oogoo01Eoo`03001oogoo00moo`03001o
ogoo00Uoo`00=7oo00<007ooOol01Woo00<007ooOol057oo00<007ooOol047oo00<007ooOol037oo
00<007ooOol02Goo00<007ooOol027oo00<007ooOol01Goo00=l0000000027oo00<007ooOol0=Woo
00<007ooOol07Woo00<007ooOol057oo00<007ooOol047oo00<007ooOol037oo00<007ooOol02Goo
00<007ooOol027oo00<007ooOol01goo00<007ooOol01Woo00<007ooOol0=Woo00<007ooOol07Woo
00<007ooOol05Goo00<007ooOol03goo00<007ooOol02Goo000dOol00`00Oomoo`0`Ool00`00Oomo
o`0/Ool20008Ool00`00Oomoo`21Ool00`00Oomoo`0fOol00`00Oomoo`21Ool00`00Oomoo`09Ool0
03Aoo`03001oogoo05moo`03O00007oo0?mooeEoo`00=7oo00<007ooOol0Ggoo00=l0000Ool0ogoo
EGoo000dOol00`00Oomoo`1POol2003oOomEOol003Aoo`03001oogoo061oo`800?mooeEoo`00=7oo
00<007ooOol0H7oo00=l0000Ool0ogooE7oo000dOol00`00Oomoo`1QOol00`00Oomoo`3oOomCOol0
03Aoo`03001oogoo065oo`800?mooeAoo`00=7oo00<007ooOol0HGoo00=l0000Ool0ogooDgoo000d
Ool00`00Oomoo`1QOol00g`0001oo`3oOomCOol003Aoo`03001oogoo069oo`800?mooe=oo`00=7oo
00<007ooOol0HWoo0P00ogooDgoo000dOol00`00Oomoo`1ROol2003oOomCOol003Aoo`03001oogoo
069oo`800?mooe=oo`00=7oo00<007ooOol0Hgoo0P00ogooDWoo000dOol00`00Oomoo`1SOol2003o
OomBOol003Aoo`03001oogoo06=oo`03O00007oo0?mooe5oo`00=7oo00<007ooOol0I7oo00<007oo
Ool0ogooD7oo000dOol00`00Oomoo`1TOol00g`0001oo`3oOom@Ool003Aoo`03001oogoo06Aoo`80
0?mooe5oo`000goo0`0017oo0P0017oo00D007ooOomoo`0000=oo`<000Aoo`8001=oo`03001oogoo
06Aoo`800?mooe5oo`0017oo00<007ooOol00goo0P001Goo00<007oo00001Goo00<007ooOol00Woo
00@007ooOol0019oo`03001oogoo06Aoo`800?mooe5oo`0017oo00<007ooOol02goo00<007ooOol0
17oo00<007ooOol00Woo00@007ooOol0019oo`03001oogoo06Eoo`800?mooe1oo`0017oo00<007oo
Ool02Woo00<007oo00001Goo00<007ooOol00Woo00@007ooOol0019oo`@006Aoo`800?mooe1oo`00
17oo00<007ooOol02Goo00D007ooOomoo`0000Aoo`03001oogoo009oo`04001oogoo000BOol00`00
Oomoo`1UOol2003oOom@Ool000=oo`8001=oo`8000Eoo`8000Moo`<000Uoo`03001oogoo06Ioo`80
0?moodmoo`0097oo0`0000Aoo`00Ool000Uoo`03001oogoo06Ioo`03O00007oo0?moodioo`00:Goo
00<007ooOol027oo00<007ooOol0Igoo00<007ooOol0ogooCGoo000XOol30009Ool00`00Oomoo`1V
Ool2003oOom?Ool003Aoo`03001oogoo06Ioo`03001l00000?moodioo`00=7oo00<007ooOol0Igoo
0P00ogooCWoo000dOol00`00Oomoo`1WOol3003oOom=Ool003Aoo`03001oogoo06Qoo`800?moodeo
o`00=7oo00<007ooOol0JGoo00<007ooOol0ogooBgoo000dOol00`00Oomoo`1YOol2003oOom<Ool0
03Aoo`03001oogoo06Uoo`03O00007oo0?mood]oo`00=7oo00<007ooOol0JGoo0P00ogooC7oo000d
Ool00`00Oomoo`1YOol2003oOom<Ool003Aoo`03001oogoo06Yoo`800?mood]oo`00=7oo00<007oo
Ool0JWoo0P00ogooBgoo000dOol00`00Oomoo`1[Ool2003oOom:Ool003Aoo`03001oogoo06]oo`03
O00007oo0?moodUoo`00=7oo00<007ooOol0K7oo00<007ooOol0ogooB7oo000dOol00`00Oomoo`1/
Ool2003oOom9Ool003Aoo`03001oogoo06aoo`03O00007oo0?moodQoo`00=7oo00<007ooOol0K7oo
0P00ogooBGoo000dOol00`00Oomoo`1/Ool00`00O000003oOom8Ool003Aoo`03001oogoo06eoo`80
0?moodQoo`00=7oo00<007ooOol0KGoo0`00ogooAgoo000dOol00`00Oomoo`1^Ool2003oOom7Ool0
03Aoo`<006moo`03001oogoo0?moodEoo`00=7oo00<007ooOol0Kgoo0P00ogooAWoo000dOol00`00
Oomoo`1_Ool00g`0001oo`3oOom5Ool003Aoo`03001oogoo06moo`800?moodIoo`00=7oo00<007oo
Ool0Kgoo0P00ogooAWoo000dOol00`00Oomoo`1`Ool2003oOom5Ool003Aoo`03001oogoo071oo`<0
0?moodAoo`00=7oo00<007ooOol0LGoo0P00ogooA7oo000dOol00`00Oomoo`1aOol00g`0001oo`3o
Oom3Ool003Aoo`03001oogoo079oo`800?mood=oo`00=7oo00<007ooOol0LWoo0P00ogoo@goo000d
Ool00`00Oomoo`1bOol2003oOom3Ool003Aoo`03001oogoo079oo`800?mood=oo`00=7oo00<007oo
Ool0Lgoo0P00ogoo@Woo000dOol00`00Oomoo`1cOol3003oOom1Ool003Aoo`03001oogoo07Aoo`80
0?mood5oo`00=7oo0`00M7oo00=l0000Ool0ogoo@7oo000dOol00`00Oomoo`1eOol2003oOom0Ool0
03Aoo`03001oogoo07Eoo`800?mood1oo`00=7oo00<007ooOol0MGoo0P00ogoo@7oo000dOol00`00
Oomoo`1eOol2003oOom0Ool003Aoo`03001oogoo07Ioo`03001oogoo0?moocioo`00=7oo00<007oo
Ool0MWoo0P00ogoo?goo000dOol00`00Oomoo`1gOol2003oOolnOol003Aoo`03001oogoo07Moo`80
0?moocioo`00=7oo00<007ooOol0Mgoo00=l0000Ool0ogoo?Goo000dOol00`00Oomoo`1hOol2003o
OolmOol003Aoo`<007Qoo`03O00007oo0?moocaoo`00=7oo00<007ooOol0N7oo0P00ogoo?Goo000d
Ool00`00Oomoo`1hOol2003oOolmOol003Aoo`03001oogoo07Uoo`800?moocaoo`00=7oo00<007oo
Ool0NGoo0`00ogoo>goo000dOol00`00Oomoo`1jOol2003oOolkOol003Aoo`03001oogoo07Yoo`03
O00007oo0?moocYoo`000goo0`0017oo0P0017oo00D007ooOomoo`0000=oo`<000Aoo`8001=oo`03
001oogoo07]oo`800?moocYoo`001Woo00@007ooOomoo`8000Eoo`03001oo`0000Eoo`03001oogoo
009oo`04001oogoo000BOol00`00Oomoo`1kOol2003oOoljOol000Ioo`03001oogoo00Uoo`03001o
ogoo00Aoo`03001oogoo009oo`04001oogoo000BOol4001jOol2003oOoljOol000=oo`<000]oo`03
001oo`0000Eoo`03001oogoo009oo`04001oogoo000BOol00`00Oomoo`1kOol2003oOoljOol000=o
o`03001oogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`02Ool01000Oomoo`001Woo0`002Goo
00<007ooOol0O7oo00<007ooOol0ogoo>7oo0003Ool4000AOol20005Ool20003Ool3000017oo001o
o`002Goo00<007ooOol0O7oo0`00ogoo>7oo000YOol00`00Oomoo`08Ool00`00Oomoo`1mOol2003o
OolhOol002Qoo`<000Uoo`03001oogoo07eoo`800?moocQoo`00=7oo00<007ooOol0OGoo00=l0000
0000ogoo=goo000dOol3001nOol2003oOolgOol003Aoo`03001oogoo07ioo`800?moocMoo`00=7oo
00<007ooOol0OWoo0P00ogoo=goo000dOol00`00Oomoo`1oOol00`00Oomoo`3oOoleOol003Aoo`03
001oogoo07moo`<00?moocEoo`00=7oo00<007ooOol0P7oo0P00ogoo=Goo000dOol30020Ool2003o
OoleOol003Aoo`03001oogoo081oo`03O00000000?moocAoo`00=7oo00<007ooOol0PGoo0P00ogoo
=7oo000dOol00`00Oomoo`21Ool2003oOoldOol003Aoo`03001oogoo085oo`800?moocAoo`00=7oo
00<007ooOol0PWoo00<007ooOol0ogoo<Woo000dOol30022Ool00`00Oomoo`3oOolbOol003Aoo`03
001oogoo089oo`03O00000000?mooc9oo`00=7oo00<007ooOol0Pgoo0P00ogoo<Woo000dOol00`00
Oomoo`23Ool00g`0001oo`3oOolaOol003Aoo`<008Aoo`800?mooc5oo`00=7oo00<007ooOol0Q7oo
0P00ogoo<Goo0003Ool30004Ool20004Ool01@00Oomoogoo00000goo0`0017oo0P004goo00<007oo
Ool0Q7oo0P00ogoo<Goo0004Ool00`00Oomoo`03Ool20005Ool00`00Ool00005Ool00`00Oomoo`02
Ool01000Oomoo`004Woo00<007ooOol0Q7oo0P00ogoo<Goo0004Ool00`00Oomoo`0;Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool01000Oomoo`004Woo1000Q7oo00<007ooOol0ogoo;goo0004Ool00`00
Oomoo`0:Ool00`00Ool00005Ool00`00Oomoo`02Ool01000Oomoo`004Woo00<007ooOol0QGoo0`00
ogoo;goo0004Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol00Woo00@007ooOol0
00Moo`03001oogoo00Qoo`03001oogoo08Ioo`800?moobmoo`000goo0P004goo0P001Goo0P000goo
0`000Woo00<007ooOol027oo00<007ooOol0QWoo0P00ogoo;goo000ZOol00`00Oomoo`07Ool00`00
Oomoo`26Ool00g`00000003oOol^Ool002Qoo`<000Uoo`03001oogoo08Moo`800?moobioo`00=7oo
00<007ooOol0Qgoo00<007ooOol0ogoo;Goo000dOol00`00Oomoo`27Ool2003oOol^Ool003Aoo`03
001oogoo08Qoo`03001oogoo0?moobaoo`00=7oo00<007ooOol0R7oo00<007oo0000ogoo;7oo000d
Ool00`00Oomoo`28Ool00g`00000003oOol/Ool003Aoo`03001oogoo08Uoo`03001oo`000?moob]o
o`00=7oo00<007ooOol0RGoo00=l00000000ogoo:goo000dOol00`00Oomoo`2:Ool00`00Ool0003o
OolZOol003Aoo`03001oogoo08Yoo`800?moob]oo`00=7oo00<007ooOol0RWoo0P00ogoo:goo000d
Ool00`00Oomoo`2;Ool2003oOolZOol003Aoo`03001oogoo08]oo`800003Ool007oo0?moobMoo`00
=7oo00<007ooOol0S7oo0`00ogoo:7oo000dOol00`00Oomoo`2=Ool2003oOolXOol003Aoo`03001o
ogoo08eoo`03O00000000?moobMoo`00=7oo00<007ooOol0SWoo0P00ogoo9goo000dOol00`00Oomo
o`2>Ool2003oOolWOol003Aoo`03001oogoo08ioo`800?mooa]oo`03001oogoo00Uoo`00=7oo00<0
07ooOol0Sgoo0P00ogoo9Woo000dOol00`00Oomoo`2?Ool3003oOolIOol00`00Oomoo`09Ool003Ao
o`03001oogoo091oo`800?mooaUoo`03001oogoo00Uoo`00=7oo00<007ooOol0TGoo0P00ogoo5Goo
00@007oo001l00]oo`00=7oo0`00TGoo00=l0000Ool0ogoo4goo00D007oo001oo`0000]oo`00=7oo
00<007ooOol0TWoo0P00ogoo4Woo00H007oo001oog`0000;Ool003Aoo`03001oogoo099oo`800?mo
oa5oo`06001oo`00Ooml000037oo000dOol00`00Oomoo`2BOol2003oOolBOol01000Ooml00003Goo
000dOol00`00Oomoo`2COol2003oOol@Ool00`00Ooml000?Ool003Aoo`03001oogoo09=oo`<00?mo
o`aoo`05001oo`00Ooml000@Ool003Aoo`03001oogoo09Aoo`800?moo`aoo`03001oo`000080011o
o`00=7oo00<007ooOol0UGoo0P00ogoo2Woo00@007oo0000019oo`00=7oo00<007ooOol0UGoo00=l
0000Ool0ogoo2Goo0P0000=oo`00Ool04Goo000dOol00`00Oomoo`2FOol2003oOol8Ool01000Ool0
00004goo000dOol00`00Oomoo`2FOol00`00Oomoo`3oOol8Ool00`00O01oo`0COol003Aoo`03001o
ogoo09Ioo`800?moo`Qoo`03001oog`001Aoo`00=7oo00<007ooOol0Ugoo00<007ooOol0ogoo0Woo
0P0000Aoo`00O01l01Eoo`00=7oo00<007ooOol0Ugoo0`00ogoo0Woo00D007oo001l000001Ioo`00
=7oo00<007ooOol0V7oo0P00ogoo0Goo00D007oo001l000001Moo`00=7oo00<007ooOol0V7oo00=l
00000000oWoo00D007oo001l000001Qoo`00=7oo0`00VGoo0P00ogoo00<007`000006Goo000dOol0
0`00Oomoo`2IOol00g`00000003mOol00`00Ooml000JOol003Aoo`03001oogoo09Yoo`03001oogoo
0?]oo`03001oog`001]oo`00=7oo00<007ooOol0VWoo0P00nWoo0P0000=oo`00Ool06goo000dOol0
0`00Oomoo`2JOol2003iOol01@00Ool007`0000077oo000dOol00`00Oomoo`2KOol3003fOol01@00
Ool007`000007Goo000dOol00`00Oomoo`2KOol3003eOol01@00Ool007oo00007Woo000dOol00`00
Oomoo`2LOol00g`00000003eOol00`00Ool0000OOol003Aoo`03001oogoo09eoo`800?Aoo`03001o
og`0021oo`00=7oo00<007ooOol0WGoo00=l00000000l7oo00D007oo001oog`0025oo`00=7oo00<0
07ooOol0WGoo0P00l7oo00D007oo001oo`00029oo`00=7oo0`00WGoo00<007`00000kWoo00H007oo
001oog`0000ROol003Aoo`03001oogoo09ioo`800>eoo`05001oo`00Ool0000TOol003Aoo`03001o
ogoo09ioo`03001l00000>eoo`03001oo`0002Eoo`00=7oo00<007ooOol0Wgoo0P00kGoo0P009Woo
000dOol00`00Oomoo`2POol00g`0001oo`3WOol00`00Oomoo`02000WOol003Aoo`03001oogoo0:5o
o`03001oogoo0>Ioo`05001oo`00Ooml000WOol000=oo`<000Aoo`8000Aoo`05001oogooOol00003
Ool30004Ool2000COol00`00Oomoo`2QOol00g`0001oo`3TOol2000017oo001oog`0:7oo0006Ool0
1000Oomoogoo0P001Goo00<007oo00001Goo00<007ooOol00Woo00@007ooOol0019oo`03001oogoo
0:5oo`800>Aoo`06001oogoo001oog`0:Goo0006Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool01000Oomoo`004Woo00<007ooOol0XGoo00<007`00000iGoo00<007oo0000:Woo0003
Ool3000;Ool00`00Ool00005Ool00`00Oomoo`02Ool01000Oomoo`004Woo1000XGoo0P00iGoo0P00
:goo0003Ool00`00Oomoo`0:Ool01@00Oomoogoo000017oo00<007ooOol00Woo00@007ooOol0019o
o`03001oogoo0:=oo`<00>9oo`8002aoo`000goo10004Goo0P001Goo0P0027oo00<007ooOol027oo
00<007ooOol0Xgoo00<007`00000gWoo00<007ooOol00P0000=l07ooOol0:Woo000TOol30002Ool0
0`00Oomoo`08Ool00`00Oomoo`2UOol2003LOol01P00Oomoo`00Ooml02eoo`00:Woo00<007ooOol0
1goo00<007ooOol0YGoo00=l00000000fWoo00H007ooOol007ooO00^Ool002Qoo`<000Uoo`03001o
ogoo0:Eoo`800=Yoo`03001oo`0000800003O01oogoo02eoo`00=7oo00<007ooOol0YGoo00<007`0
0000fWoo00@007ooOol0031oo`00=7oo0`00YWoo00<007`00000f7oo00@007oo0000035oo`00=7oo
00<007ooOol0Ygoo0`00e7oo00D007oo001oo`0003=oo`00=7oo00<007ooOol0Z7oo0P00dgoo00D0
07oo001oog`003Aoo`00=7oo00<007ooOol0ZGoo0P00dGoo00D007oo001oog`003Eoo`00=7oo00<0
07ooOol0ZGoo00=l00000000cgoo00D007ooOol007`003Ioo`00=7oo00<007ooOol0ZWoo00=l0000
0000d7oo00<007`00000=Woo000dOol3002ZOol2003@Ool00`00Ool0000gOol003Aoo`03001oogoo
0:Yoo`03001l00000<]oo`06001oogoo001oo`00>7oo000dOol00`00Oomoo`2[Ool01000O0000000
b7oo00H007ooOol007oo000iOol003Aoo`03001oogoo0:aoo`<00<Moo`06001oogoo001oog`0>Woo
000dOol00`00Oomoo`2]Ool00g`000000035Ool01P00Oomoo`00Ooml03]oo`00=7oo0`00[Woo0P00
agoo00<007oo0000?7oo000dOol00`00Oomoo`2^Ool00g`000000035Ool00`00Ool0000mOol003Ao
o`03001oogoo0:moo`800<Aoo`03001oo`0003ioo`00=7oo00<007ooOol0[goo0P00`Goo00D007oo
001oo`0003moo`00=7oo00<007ooOol0/7oo0P00_goo00D007oo001oog`0041oo`00=7oo0`00/7oo
00@007`000000;aoo`05001oo`00Ooml0011Ool003Aoo`03001oogoo0;5oo`<00;]oo`05001oo`00
Ool00012Ool000=oo`<000Aoo`8000Aoo`05001oogooOol00003Ool30004Ool2000COol00`00Oomo
o`2bOol00g`00000002kOol00`00O0000013Ool000Aoo`03001oogoo00=oo`8000Eoo`03001oo`00
00Eoo`03001oogoo009oo`04001oogoo000BOol00`00Oomoo`2cOol2002jOol00`00O0000014Ool0
00Aoo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo000BOol4002bOol0
0g`00000002eOol2000017oo001l0000AGoo0004Ool00`00Oomoo`0:Ool00`00Ool00005Ool00`00
Oomoo`02Ool01000Oomoo`004Woo00<007ooOol0/goo00<007`00000]7oo00D007ooOol007`004Mo
o`0017oo00<007ooOol02Goo00D007ooOomoo`0000Aoo`03001oogoo009oo`04001oogoo0006Ool3
0009Ool00`00Oomoo`2dOol2002cOol01@00Oomoo`00O000B7oo0003Ool2000COol20005Ool20003
Ool3000017oo001oo`002Goo00<007ooOol0]Goo0`00/7oo00H007oo000007`00018Ool002Qoo`<0
00Uoo`03001oogoo0;Ioo`03001oo`000;1oo`04001oog`00019Ool002Uoo`8000Uoo`03001oogoo
0;Ioo`03O00000000:moo`04001oo`00001:Ool003Aoo`03001oogoo0;Moo`03O00000000:]oo`05
001oo`00Ool0001<Ool003Aoo`03001oogoo0;Qoo`03001oo`000:Uoo`05001oo`00Ooml001=Ool0
03Aoo`03001oogoo0;Qoo`800:Qoo`800004Ool007ooO01>Ool003Aoo`03001oogoo0;Uoo`800:Uo
o`03001oo`0004moo`00=7oo00<007ooOol0^Woo0P0000=oo`00Ool0Xgoo0P0000=oo`00Ool0Cgoo
000dOol00`00Oomoo`2kOol200000goo001oo`2NOol200001Goo001oogoo0000DGoo000dOol00`00
Oomoo`2lOol017`0001oo`00WGoo00L007ooOol007ooO000001BOol003Aoo`03001oogoo0;eoo`04
001oogoo002KOol01P00Oomoo`00Ooml05Aoo`00=7oo00<007ooOol0_Goo00=l0000Ool0Vgoo00H0
07ooOol007ooO01EOol003Aoo`03001oogoo0;ioo`8009eoo`04001oo`00001EOol003Aoo`03001o
ogoo0;moo`8009]oo`03001oo`0005Moo`00=7oo00<007ooOol0`7oo0P0000=oo`00Ool0TWoo0P00
00Eoo`00001oo`0005Qoo`00=7oo00<007ooOol0`Goo0`00TWoo00@007ooOol0009oo`03001oogoo
05Moo`00=7oo00<007ooOol0`Woo00=l00000000T7oo00D007ooOol007oo009l05Yoo`00=7oo00<0
07ooOol0`goo00<007oo0000SWoo00H007ooOol007ooO01LOol003Aoo`03001oogoo0<=oo`03O000
07oo08moo`800003O000000005aoo`00=7oo00<007ooOol0`goo00<007`00000SWoo00@007oo0000
05ioo`00=7oo00<007ooOol0a7oo00<007`00000RGoo0P0000Aoo`00Ool0061oo`00=7oo00<007oo
Ool0aGoo00@007`0000008Eoo`80009oo`03001l07`0065oo`00=7oo00<007ooOol0aWoo00@007`0
000008=oo`03001oogoo00800003O01oogoo065oo`00=7oo00<007ooOol0b7oo0W`000<007ooOol0
PWoo00@007`0O00006=oo`00=7oo0`00bWoo00=l0000Ool0PGoo00@007`0000006Aoo`00=7oo00<0
07ooOol0bGoo00@007ooO00007aoo`800005Ool00000O000001VOol003Aoo`03001oogoo0<Yoo`04
001oog`0001iOol20002Ool01000Ooml0000Igoo000dOol00`00Oomoo`3;Ool00`00Ooml0002001f
Ool00`00Oomoo`020002O01YOol003Aoo`03001oogoo0<aoo`03001oog`0008007Moo`04001oo`00
001ZOol003Aoo`03001oogoo0<moo`03O000000007Eoo`03001oo`0006aoo`00=7oo00<007ooOol0
d7oo00=l00000000Kgoo0P0000Eoo`00001oo`0006eoo`00=7oo00<007ooOol0d7oo00<007`00000
KGoo0P000Woo00@007ooOol006ioo`00=7oo00<007ooOol0dGoo00@007`0001oo`8006Qoo`03001o
ogoo00800003Ooml07`006moo`00=7oo00<007ooOol0dWoo00H007`0000007oo001XOol200000goo
0000001aOol003Aoo`03001oogoo0==oo`06001l07`0001oo`00HWoo00P007ooOomoo`00Ooml0000
Lgoo000dOol00`00Oomoo`3FOol017`0001oo`00H7oo00<007ooOol00P000W`000<007ooOol0LWoo
000dOol00`00Oomoo`3GOol00g`0001oo`1MOol300001goo000007ooO01oo`0007Eoo`00=7oo00<0
07ooOol0eWoo0P0000=l00000000Ggoo00@007ooO01l07Qoo`00=7oo00<007ooOol0f7oo0P0000Al
0000000005Aoo`8000Aoo`800003O000000007Uoo`00=7oo00<007ooOol0fWoo00D007`0001oo`00
059oo`04001oogooOol30002O0000`00Oomoo`1iOol003Aoo`<00=aoo`03O00007oo008004moo`03
001oogoo00800003Ooml07`0008007aoo`00=7oo00<007ooOol0gGoo00=l0000Ool0DGoo0P0000=o
og`0O000P7oo000dOol00`00Oomoo`3MOol40003Ool20015Ool20002Ool200000gooO01l00020020
Ool003Aoo`03001oogoo0=moo`@000=oo`80045oo`80009oo`80009oo`03O0000000089oo`00=7oo
00<007ooOol0hGoo00<007`000000P000Woo00<007ooOol0?Goo00<007ooOol00P000Woo0W`000<0
07ooOol0PWoo000dOol00`00Oomoo`3SOol2O0000goo00000011Ool20002Ool2O027Ool003Aoo`03
001oogoo0>Eoo`03O01oogoo0080009oo`<003=oo`8000=oo`80009oo`03O000000008Qoo`00=7oo
00<007ooOol0iGoo0`000Woo0P000goo0P00;Woo0`000Woo0`000Woo00=l00000000RWoo000dOol0
0`00Oomoo`3XOol01000O01l07oo0`00:Woo0`001Woo0P000Woo0g`000<007ooOol0RWoo000dOol0
0`00Oomoo`3YOol00`00Ooml0002O0000goo00000003Ool4000OOol20006Ool3000017ooO01l07`0
T7oo000dOol00`00Oomoo`3]Ool20002O0030004Ool00`00Oomoo`0GOol20006Ool5000017ooO01l
07`00`00T7oo000dOol00`00Oomoo`3_Ool20003O0050004Ool50003Ool60003Ool40003Ool50003
Ool3O003002COol003Aoo`<00?5oo`03001oogoo00El00D001Aoo`<000Eoo`<009Uoo`00=7oo00<0
07ooOol0mGoo0`0000Aoog`0O01l009ooa@000=oo`=l008009aoo`00=7oo00<007ooOol0n7oo0P00
0Woo27`01goo1g`00`00XGoo000dOol00`00Oomoo`3nOol50004O0050003Ool3002TOol003Aoo`03
001oogoo0?mookMoo`00=7oo00<007ooOol0ogoo]goo0003Ool30004Ool20004Ool01@00Oomoogoo
00000goo0`0017oo0P004goo00<007ooOol0ogoo]goo0006Ool01000Oomoogoo0P001Goo00<007oo
00001Goo00<007ooOol00Woo00@007ooOol0019oo`03001oogoo0?mookMoo`001Woo00<007ooOol0
2Goo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0019oo`@00?mookIoo`000goo0`002goo
00<007oo00001Goo00<007ooOol00Woo00@007ooOol0019oo`03001oogoo0?mookMoo`000goo00<0
07ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`04001oogoo0006Ool30009Ool00`00
Oomoo`3oOongOol000=oo`@0015oo`8000Eoo`8000=oo`<00004Ool007oo003oOoo3Ool002Qoo`<0
0?mool=oo`00:Goo0P00ogoo`goo003oOoo^Ool00?moonioo`00ogookWoo003oOoo^Ool00?moonio
o`00ogookWoo0000\
\>"],
  ImageRangeCache->{{{0, 492}, {303.562, 0}} -> {-0.845973, -8.52688, 
  0.00528507, 0.0110285}}]
}, Closed]],

Cell["\<\
Note that the less likely order has been neglected here: \
ExactProbability[] sums over all orders, while MonteCarloProbability[] \
requires a specific order.\
\>", "Text"],

Cell[TextData[{
  "Choosing a different parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Theta]\^*\)\(\ \)\)\)]],
  "gives different frequencies and weights to the different terms, but the \
same expectation:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ss5 = MonteCarloProbability[g, nl, jl, \[Theta], 10. , 1000]; \n
    Frequencies[ss5]\)], "Input",
  CellLabel->"In[192]:="],

Cell[BoxData[
    \({{3, 
        \(0.0045175472695780714`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^5\ 
            \((2 + \[Theta])\)\^6\ \((3 + \[Theta])\)\^5\)}, {4, 
        \(0.00414108499711323041`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^6\ 
            \((2 + \[Theta])\)\^5\ \((3 + \[Theta])\)\^5\)}, {5, 
        \(0.00569399187103069159`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^7\ 
            \((2 + \[Theta])\)\^4\ \((3 + \[Theta])\)\^5\)}, {5, 
        \(0.0121788159463711997`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^8\ 
            \((2 + \[Theta])\)\^3\ \((3 + \[Theta])\)\^5\)}, {3, 
        \(0.0446556584700277348`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^9\ 
            \((2 + \[Theta])\)\^2\ \((3 + \[Theta])\)\^5\)}, {1, 
        \(0.368409182377728727`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^10\ 
            \((2 + \[Theta])\)\ \((3 + \[Theta])\)\^5\)}, {1, 
        \(0.0347388758886308712`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^3\ 
            \((2 + \[Theta])\)\^9\ \((3 + \[Theta])\)\^4\)}, {3, 
        \(0.0119414885867168617`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^4\ 
            \((2 + \[Theta])\)\^8\ \((3 + \[Theta])\)\^4\)}, {12, 
        \(0.00625506545018502091`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^5\ 
            \((2 + \[Theta])\)\^7\ \((3 + \[Theta])\)\^4\)}, {26, 
        \(0.00477817499666911249`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^6\ 
            \((2 + \[Theta])\)\^6\ \((3 + \[Theta])\)\^4\)}, {35, 
        \(0.00525599249633602472`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^7\ 
            \((2 + \[Theta])\)\^5\ \((3 + \[Theta])\)\^4\)}, {42, 
        \(0.00843148796287236912`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^8\ 
            \((2 + \[Theta])\)\^4\ \((3 + \[Theta])\)\^4\)}, {25, 
        \(0.0206103039092435702`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^9\ 
            \((2 + \[Theta])\)\^3\ \((3 + \[Theta])\)\^4\)}, {4, 
        \(0.0850175036256297289`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^10\ 
            \((2 + \[Theta])\)\^2\ \((3 + \[Theta])\)\^4\)}, {1, 
        \(0.0961999639992854937`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^3\ 
            \((2 + \[Theta])\)\^10\ \((3 + \[Theta])\)\^3\)}, {5, 
        \(0.0293944334442261165`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^4\ 
            \((2 + \[Theta])\)\^9\ \((3 + \[Theta])\)\^3\)}, {20, 
        \(0.0134724486619369709`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^5\ 
            \((2 + \[Theta])\)\^8\ \((3 + \[Theta])\)\^3\)}, {55, 
        \(0.0088212461476968258`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^6\ 
            \((2 + \[Theta])\)\^7\ \((3 + \[Theta])\)\^3\)}, {104, 
        \(0.00808614230205542128`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^7\ 
            \((2 + \[Theta])\)\^6\ \((3 + \[Theta])\)\^3\)}, {95, 
        \(0.0103772159543044573`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^8\ 
            \((2 + \[Theta])\)\^5\ \((3 + \[Theta])\)\^3\)}, {59, 
        \(0.0190248959162248354`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^9\ 
            \((2 + \[Theta])\)\^4\ \((3 + \[Theta])\)\^3\)}, {11, 
        \(0.0523184637696182974`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^10\ 
            \((2 + \[Theta])\)\^3\ \((3 + \[Theta])\)\^3\)}, {1, 
        \(0.443999833842856261`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^3\ 
            \((2 + \[Theta])\)\^11\ \((3 + \[Theta])\)\^2\)}, {4, 
        \(0.122099954306785463`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^4\ 
            \((2 + \[Theta])\)\^10\ \((3 + \[Theta])\)\^2\)}, {26, 
        \(0.0497444258286903551`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^5\ 
            \((2 + \[Theta])\)\^9\ \((3 + \[Theta])\)\^2\)}, {67, 
        \(0.0284994106310205186`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^6\ 
            \((2 + \[Theta])\)\^8\ \((3 + \[Theta])\)\^2\)}, {79, 
        \(0.0223923940672304011`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^7\ 
            \((2 + \[Theta])\)\^7\ \((3 + \[Theta])\)\^2\)}, {107, 
        \(0.0239474214330102874`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^8\ 
            \((2 + \[Theta])\)\^6\ \((3 + \[Theta])\)\^2\)}, {49, 
        \(0.0351228847684150835`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^9\ 
            \((2 + \[Theta])\)\^5\ \((3 + \[Theta])\)\^2\)}, {18, 
        \(0.0724409498348561076`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^10\ 
            \((2 + \[Theta])\)\^4\ \((3 + \[Theta])\)\^2\)}, {3, 
        \(0.413261383807581506`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^5\ 
            \((2 + \[Theta])\)\^10\ \((3 + \[Theta])\)\)}, {22, 
        \(0.210457186198305334`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^6\ 
            \((2 + \[Theta])\)\^9\ \((3 + \[Theta])\)\)}, {35, 
        \(0.144689315511334921`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^7\ 
            \((2 + \[Theta])\)\^8\ \((3 + \[Theta])\)\)}, {43, 
        \(0.132631872552056973`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^8\ 
            \((2 + \[Theta])\)\^7\ \((3 + \[Theta])\)\)}, {23, 
        \(0.16210562200806966`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^9\ 
            \((2 + \[Theta])\)\^6\ \((3 + \[Theta])\)\)}, {4, 
        \(0.267474276313314884`\ \[Theta]\^13\)\/\(\((1 + \[Theta])\)\^10\ 
            \((2 + \[Theta])\)\^5\ \((3 + \[Theta])\)\)}}\)], "Output",
  CellLabel->"Out[192]="]
}, Closed]],

Cell[TextData[{
  "The standard errors are similar for the two values of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Theta]\^*\)\)]],
  ": ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Theta]\^*\)\)]],
  "=10 performs better for \[Theta]>3"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mn5 = Mean[ss5]; se5 = StandardErrorOfSampleMean[ss5]; \n
    LogLogPlot[{se, se5}, {\[Theta], 0, 50}, PlotStyle \[Rule] {Red, Blue}]; 
    \)], "Input",
  CellLabel->"In[193]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.245374 0.430153 1.95682 0.206086 [
[.11589 -0.0125 -11 -12 ]
[.11589 -0.0125 11 0 ]
[.24537 -0.0125 -5 -12 ]
[.24537 -0.0125 5 0 ]
[.54604 -0.0125 -5 -12 ]
[.54604 -0.0125 5 0 ]
[.67553 -0.0125 -8 -12 ]
[.67553 -0.0125 8 0 ]
[.97619 -0.0125 -8 -12 ]
[.97619 -0.0125 8 0 ]
[-0.0125 .10204 -47.0625 -6.40625 ]
[-0.0125 .10204 0 6.40625 ]
[-0.0125 .24609 -47.0625 -6.40625 ]
[-0.0125 .24609 0 6.40625 ]
[-0.0125 .30813 -47.0625 -6.40625 ]
[-0.0125 .30813 0 6.40625 ]
[-0.0125 .45218 -47.0625 -6.40625 ]
[-0.0125 .45218 0 6.40625 ]
[-0.0125 .51422 -47.0625 -6.34375 ]
[-0.0125 .51422 0 6.34375 ]
[ -0.0005 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11589 0 m
.11589 .00625 L
s
gsave
.11589 -0.0125 -72 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.24537 0 m
.24537 .00625 L
s
gsave
.24537 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.54604 0 m
.54604 .00625 L
s
gsave
.54604 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.67553 0 m
.67553 .00625 L
s
gsave
.67553 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
.02046 0 m
.02046 .00375 L
s
.0742 0 m
.0742 .00375 L
s
.14995 0 m
.14995 .00375 L
s
.17874 0 m
.17874 .00375 L
s
.20369 0 m
.20369 .00375 L
s
.22569 0 m
.22569 .00375 L
s
.37486 0 m
.37486 .00375 L
s
.45061 0 m
.45061 .00375 L
s
.50435 0 m
.50435 .00375 L
s
.5801 0 m
.5801 .00375 L
s
.6089 0 m
.6089 .00375 L
s
.63384 0 m
.63384 .00375 L
s
.65584 0 m
.65584 .00375 L
s
.80502 0 m
.80502 .00375 L
s
.88076 0 m
.88076 .00375 L
s
.9345 0 m
.9345 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10204 m
.00625 .10204 L
s
gsave
-0.0125 .10204 -108.062 -10.4062 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.812500 moveto
 558.000000 16.812500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.812500 lineto
closepath
clip newpath
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.) show
75.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
76.812500 13.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(\\264) show
84.625000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
96.625000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
96.625000 9.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
100.812500 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(9) show
105.000000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
0 .24609 m
.00625 .24609 L
s
gsave
-0.0125 .24609 -108.062 -10.4062 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.812500 moveto
 558.000000 16.812500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.812500 lineto
closepath
clip newpath
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5.) show
75.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
76.812500 13.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(\\264) show
84.625000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
96.625000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
96.625000 9.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
100.812500 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(9) show
105.000000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
0 .30813 m
.00625 .30813 L
s
gsave
-0.0125 .30813 -108.062 -10.4062 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.812500 moveto
 558.000000 16.812500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.812500 lineto
closepath
clip newpath
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.) show
75.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
76.812500 13.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(\\264) show
84.625000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
96.625000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
96.625000 9.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
100.812500 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
105.000000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
0 .45218 m
.00625 .45218 L
s
gsave
-0.0125 .45218 -108.062 -10.4062 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.812500 moveto
 558.000000 16.812500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.812500 lineto
closepath
clip newpath
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5.) show
75.000000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
76.812500 13.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(\\264) show
84.625000 13.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
96.625000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
96.625000 9.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
100.812500 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
105.000000 9.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
0 .51422 m
.00625 .51422 L
s
gsave
-0.0125 .51422 -108.062 -10.3438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.6875 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.687500 moveto
 558.000000 16.687500 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.687500 lineto
closepath
clip newpath
63.000000 13.687500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.687500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.) show
75.000000 13.687500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
76.812500 13.687500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(\\264) show
84.625000 13.687500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
96.625000 9.312500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
96.625000 9.312500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
100.812500 9.312500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(7) show
105.000000 9.312500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
.001 w
0 .16408 m
.00375 .16408 L
s
0 .20037 m
.00375 .20037 L
s
0 .22612 m
.00375 .22612 L
s
0 .26241 m
.00375 .26241 L
s
0 .27621 m
.00375 .27621 L
s
0 .28816 m
.00375 .28816 L
s
0 .2987 m
.00375 .2987 L
s
0 .37017 m
.00375 .37017 L
s
0 .40646 m
.00375 .40646 L
s
0 .43221 m
.00375 .43221 L
s
0 .4685 m
.00375 .4685 L
s
0 .48229 m
.00375 .48229 L
s
0 .49424 m
.00375 .49424 L
s
0 .50479 m
.00375 .50479 L
s
0 .57625 m
.00375 .57625 L
s
0 .61254 m
.00375 .61254 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.23013 0 m
.24301 .04784 L
.31991 .26206 L
.37749 .3872 L
.42558 .46867 L
.46188 .51663 L
.48969 .54576 L
.51526 .56696 L
.53604 .58041 L
.55654 .5905 L
.56485 .59373 L
.57341 .59654 L
.58058 .59851 L
.58794 .60017 L
.59598 .60157 L
.60314 .60247 L
.6074 .60285 L
.60945 .603 L
.61132 .6031 L
.61297 .60318 L
.61477 .60324 L
.6157 .60327 L
.61656 .60329 L
.61747 .6033 L
.61843 .60331 L
.6193 .60332 L
.62021 .60332 L
.62184 .60331 L
.62274 .60329 L
.62358 .60327 L
.62548 .60322 L
.62712 .60316 L
.62861 .60308 L
.63193 .60288 L
.63762 .60237 L
.64343 .60167 L
.65423 .59985 L
.66511 .59739 L
.68325 .59193 L
.70233 .58445 L
.71871 .57669 L
.74648 .56097 L
.77209 .54384 L
.79383 .52752 L
.81258 .51224 L
.83067 .49652 L
.84657 .48199 L
.86211 .46718 L
.87595 .45351 L
.88836 .44091 L
Mistroke
.90071 .42804 L
.91188 .41615 L
.92307 .40402 L
.93324 .39279 L
.94254 .38239 L
.95194 .37172 L
.96057 .36182 L
.9685 .35261 L
.97619 .34361 L
Mfstroke
0 0 1 r
.2206 0 m
.24301 .08149 L
.31991 .2849 L
.37749 .39999 L
.42558 .47243 L
.46188 .51357 L
.48938 .5374 L
.51526 .5544 L
.53591 .56437 L
.5467 .56837 L
.55628 .57125 L
.56586 .57351 L
.57421 .575 L
.57866 .5756 L
.5834 .57611 L
.58553 .5763 L
.58777 .57646 L
.58984 .57658 L
.59174 .57667 L
.59364 .57674 L
.59464 .57677 L
.5957 .57679 L
.59681 .5768 L
.59785 .57681 L
.59979 .57681 L
.60159 .57679 L
.60324 .57675 L
.60503 .57669 L
.60691 .57661 L
.61073 .57639 L
.61425 .5761 L
.62203 .57523 L
.62853 .57424 L
.6343 .57317 L
.64668 .57029 L
.66717 .56382 L
.68728 .55553 L
.72133 .53751 L
.74913 .51944 L
.77473 .50042 L
.79648 .48266 L
.81525 .46624 L
.83334 .44954 L
.84924 .4342 L
.86336 .42012 L
.8773 .40579 L
.8898 .39262 L
.90224 .37923 L
.91348 .36689 L
.92369 .35549 L
Mistroke
.93397 .34385 L
.94337 .33308 L
.95286 .32206 L
.96157 .31185 L
.96958 .30236 L
.97619 .29447 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[200]:=",
  ImageSize->{532, 328.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008D0001B1000`40O003h00Oogooogoo5Woo003o
OoooOolFOol00?mooomooaIoo`00ogooogoo5Woo003oOoooOolFOol00?mooomooaIoo`00ogooogoo
5Woo003oOoooOolFOol00?mooomooaIoo`00ogooogoo5Woo003oOoooOolFOol006Eoo`8000Aoo`80
00=oo`<003Eoo`<008eoo`<003Moo`<000Aoo`8008Moo`<000Aoo`8000Uoo`00I7oo00@007ooOol0
00=oo`8000Ioo`03001oogoo03=oo`03001oogoo08moo`03001oogoo03Eoo`03001oogoo009oo`04
001oogoo0029Ool01000Oomoo`000Woo00<007ooOol01Woo001TOol01000Oomoo`002goo00<007oo
Ool0<goo00<007ooOol0Sgoo00<007ooOol0=Goo00<007ooOol00Woo00@007ooOol008Uoo`04001o
ogoo0002Ool00`00Oomoo`06Ool006Aoo`04001oogoo0008Ool3000fOol00`00Oomoo`2<Ool3000h
Ool00`00Oomoo`02Ool01000Oomoo`00QWoo0`000goo00@007ooOol000Qoo`00I7oo00@007ooOol0
00Qoo`03001oogoo03Ioo`03001oogoo08aoo`03001oogoo03Qoo`03001oogoo009oo`04001oogoo
0026Ool00`00Oomoo`03Ool01000Oomoo`0027oo001UOol20009Ool4000dOol2002>Ool4000fOol2
0005Ool20027Ool40003Ool20009Ool00?mooomooaIoo`00ogooogoo5Woo003oOoooOolFOol00?mo
oomooaIoo`00ogooogoo5Woo003oOoooOolFOol00?mooomooaIoo`00ogooogoo5Woo000eOomY0000
0`0O0000000200000g`00000003o001^0001Ool003Eoo`03001oogoo00Ioo`03001oogoo01Moo`03
001oogoo015oo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo00Eoo`03
01moo`00009oo`03O01oogoo00Aoo`03001oogoo03]oo`03001oogoo025oo`03001oogoo01Moo`03
001oogoo015oo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Ioo`03001oogoo03]oo`03001oogoo029oo`03001oogoo01Ioo`03001oogoo015oo`03
001oogoo00Yoo`00=Goo00<007ooOol01Woo00<007ooOol05goo00<007ooOol04Goo00<007ooOol0
3Goo00<007ooOol02goo00<007ooOol02Goo00<007ooOol01Goo00<07goo00000Woo00=l07ooOol0
17oo00<007ooOol0>goo00<007ooOol08Goo00<007ooOol05goo00<007ooOol04Goo00<007ooOol0
3Goo00<007ooOol02goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01Woo00<007ooOol0
>goo00<007ooOol08Woo00<007ooOol05Woo00<007ooOol04Goo00<007ooOol02Woo000eOol00`00
Oomoo`0dOol00`00Oomoo`0`Ool00`0OOomoo`02Ool00g`0Oomoo`03Ool00`00Oomoo`2=Ool00`00
Oomoo`0jOol00`00Oomoo`2=Ool00`00Oomoo`0:Ool003Eoo`03001oogoo06Moo`0301moogoo009o
o`03O01oogoo0?moofioo`00=Goo00<007ooOol0Igoo00<07gooOol00Woo00=l07ooOol0ogooKWoo
000eOol00`00Oomoo`1XOol01@0OOomoogooO000ogooL7oo000eOol00`00Oomoo`1XOol00`0OOomo
o`02Ool00g`0Oomoo`3oOom]Ool003Eoo`03001oogoo06Qoo`0301moogoo009oo`03O01oogoo0?mo
ofeoo`00=Goo00<007ooOol0J7oo00<07gooOol00Woo00=l07ooOol0ogooKGoo000eOol00`00Oomo
o`1YOol01@0OOomoogooO000ogooKgoo000eOol00`00Oomoo`1YOol00`0OOomoo`02Ool00g`0Oomo
o`3oOom/Ool003Eoo`03001oogoo06Uoo`0301moogoo009oo`03O01oogoo0?moofaoo`00=Goo00<0
07ooOol0JWoo00D07gooOomoog`00?moofioo`00=Goo00<007ooOol0JWoo00<07gooOol00Woo00=l
07ooOol0ogooJgoo000eOol00`00Oomoo`1ZOol00`0OOomoo`02Ool00g`0Oomoo`3oOom[Ool003Eo
o`03001oogoo06Yoo`0301moogoo009oo`03O01oogoo0?moof]oo`00=Goo00<007ooOol0Jgoo00D0
7gooOomoog`00?moofeoo`00=Goo00<007ooOol0Jgoo00<07gooOol00Woo00=l07ooOol0ogooJWoo
000eOol00`00Oomoo`1[Ool00`0OOomoo`02Ool00g`0Oomoo`3oOomZOol003Eoo`03001oogoo06ao
o`0501moogooOoml003oOom/Ool003Eoo`03001oogoo06aoo`0501moogooOoml003oOom/Ool003Eo
o`03001oogoo06aoo`0301moogoo009oo`03O01oogoo0?moofUoo`00=Goo00<007ooOol0K7oo00<0
7gooOol00Woo00=l07ooOol0ogooJGoo000eOol00`00Oomoo`1]Ool01@0OOomoogooO000ogooJgoo
000eOol00`00Oomoo`1]Ool00`0OOomoo`02Ool00g`0Oomoo`3oOomXOol003Eoo`03001oogoo06eo
o`0301moogoo009oo`03O01oogoo0?moofQoo`00=Goo00<007ooOol0KGoo00<07gooOol00Woo00=l
07ooOol0ogooJ7oo000eOol00`00Oomoo`1^Ool00`0OOomoo`02Ool00g`0Oomoo`3oOomWOol003Eo
o`03001oogoo06ioo`0301moogoo009oo`03O01oogoo0?moofMoo`00=Goo00<007ooOol0KWoo00<0
7gooOol00Woo00=l07ooOol0ogooIgoo000eOol00`00Oomoo`1_Ool00`0OOomoo`02Ool00g`0Oomo
o`3oOomVOol003Eoo`03001oogoo06moo`0301moogoo009oo`03O01oogoo0?moofIoo`00=Goo00<0
07ooOol0Kgoo00<07gooOol00Woo00=l07ooOol0ogooIWoo000eOol00`00Oomoo`1_Ool00`0OOomo
o`03Ool00g`0Oomoo`3oOomUOol003Eoo`03001oogoo071oo`0301moogoo009oo`03O01oogoo0?mo
ofEoo`00=Goo00<007ooOol0L7oo00<07gooOol00Woo00=l07ooOol0ogooIGoo000eOol00`00Oomo
o`1`Ool00`0OOomoo`03Ool00g`0Oomoo`3oOomTOol003Eoo`03001oogoo075oo`0301moogoo009o
o`03O01oogoo0?moofAoo`00=Goo00<007ooOol0LGoo00<07gooOol00Woo00=l07ooOol0ogooI7oo
000eOol00`00Oomoo`1aOol00`0OOomoo`03Ool00g`0Oomoo`3oOomSOol003Eoo`03001oogoo079o
o`0301moogoo009oo`03O01oogoo0?moof=oo`00=Goo00<007ooOol0LWoo00<07gooOol00goo00=l
07ooOol0ogooHWoo000eOol00`00Oomoo`1bOol00`0OOomoo`03Ool00g`0Oomoo`3oOomROol003Eo
o`03001oogoo07=oo`0301moogoo009oo`03O01oogoo0?moof9oo`00=Goo00<007ooOol0Lgoo00<0
7gooOol00goo00=l07ooOol0ogooHGoo0003Ool30004Ool20004Ool01@00Oomoogoo00000goo0`00
17oo0P0057oo00<007ooOol0Lgoo00<07gooOol00goo00=l07ooOol0ogooHGoo0004Ool00`00Oomo
o`03Ool20005Ool00`00Ool00005Ool00`00Oomoo`02Ool01000Oomoo`004goo00<007ooOol0M7oo
00<07gooOol00Woo00=l07ooOol0ogooHGoo0004Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool01000Oomoo`004goo00<007ooOol0M7oo00<07gooOol00goo00=l07ooOol0ogooH7oo
0004Ool00`00Oomoo`0:Ool00`00Ool00005Ool00`00Oomoo`02Ool01000Oomoo`004goo1000M7oo
00<07gooOol00Woo00=l07ooOol0ogooH7oo0004Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo
00<007ooOol00Woo00@007ooOol001=oo`03001oogoo07Eoo`0301moogoo009oo`03O01oogoo0?mo
of1oo`000goo0P004goo0P001Goo0P001goo0P002goo00<007ooOol0MGoo00<07gooOol00goo00=l
07ooOol0ogooGgoo000TOol3000017oo000000002Woo00<007ooOol0MWoo00<07gooOol00Woo00=l
07ooOol0ogooGgoo000XOol00`00Ool0000:Ool00`00Oomoo`1fOol00`0OOomoo`02Ool00g`0Oomo
o`3oOomOOol002Qoo`<000Yoo`03001oogoo07Ioo`0301moogoo00=oo`03O01oogoo0?mooeioo`00
=Goo00<007ooOol0Mgoo00<07gooOol00Woo00=l07ooOol0ogooGWoo000eOol00`00Oomoo`1gOol0
0`0OOomoo`02Ool00g`0Oomoo`3oOomNOol003Eoo`03001oogoo07Moo`0301moogoo00=oo`03O01o
ogoo0?mooeeoo`00=Goo00<007ooOol0N7oo00<07gooOol00Woo00=l07ooOol0ogooGGoo000eOol0
0`00Oomoo`1hOol00`0OOomoo`03Ool00g`0Oomoo`3oOomLOol003Eoo`03001oogoo07Uoo`0301mo
ogoo009oo`03O01oogoo0?mooeaoo`00=Goo00<007ooOol0NGoo00<07gooOol00Woo00=l07ooOol0
ogooG7oo000eOol00`00Oomoo`1iOol00`0OOomoo`03Ool00g`0Oomoo`3oOomKOol003Eoo`03001o
ogoo07Yoo`0301moogoo009oo`03O01oogoo0?mooe]oo`00=Goo00<007ooOol0NWoo00<07gooOol0
0Woo00=l07ooOol0ogooFgoo000eOol00`00Oomoo`1jOol00`0OOomoo`03Ool00g`0Oomoo`3oOomJ
Ool003Eoo`03001oogoo07]oo`0301moogoo009oo`03O01oogoo0?mooeYoo`00=Goo00<007ooOol0
Ngoo00<07gooOol00Woo00=l07ooOol0ogooFWoo000eOol00`00Oomoo`1lOol00`0OOomoo`02Ool0
0g`0Oomoo`3oOomIOol003Eoo`03001oogoo07aoo`0301moogoo009oo`03O01oogoo0?mooeUoo`00
=Goo00<007ooOol0O7oo00<07gooOol00Woo00=l07ooOol0ogooFGoo000eOol00`00Oomoo`1mOol0
0`0OOomoo`02Ool00g`0Oomoo`3oOomHOol003Eoo`03001oogoo07eoo`0301moogoo009oo`03O01o
ogoo0?mooeQoo`00=Goo00<007ooOol0OGoo00<07gooOol00Woo00=l07ooOol0ogooF7oo000eOol0
0`00Oomoo`1nOol00`0OOomoo`02Ool00g`0Oomoo`3oOomGOol003Eoo`03001oogoo07ioo`0301mo
ogoo009oo`03O01oogoo0?mooeMoo`00=Goo00<007ooOol0Ogoo00<07gooOol00Woo00=l07ooOol0
ogooEWoo000eOol00`00Oomoo`1oOol00`0OOomoo`02Ool00g`0Oomoo`3oOomFOol003Eoo`80081o
o`0301moogoo009oo`03O01oogoo0?mooeIoo`00=Goo00<007ooOol0P7oo00<07gooOol00Woo00=l
07ooOol0ogooEGoo000eOol00`00Oomoo`20Ool00`0OOomoo`02Ool00g`0Oomoo`3oOomEOol003Eo
o`03001oogoo081oo`0301moogoo009oo`03O01oogoo0?mooeEoo`00=Goo00<007ooOol0PGoo00<0
7gooOol00Woo00=l07ooOol0ogooE7oo000eOol00`00Oomoo`21Ool00`0OOomoo`02Ool00g`0Oomo
o`3oOomDOol003Eoo`03001oogoo089oo`0501moogooOoml003oOomFOol003Eoo`03001oogoo089o
o`0301moogoo009oo`03O01oogoo0?mooe=oo`00=Goo00<007ooOol0PWoo00<07gooOol00Woo00=l
07ooOol0ogooDgoo000eOol00`00Oomoo`23Ool01@0OOomoogooO000ogooEGoo000eOol00`00Oomo
o`23Ool00`0OOomoo`02Ool00g`0Oomoo`3oOomBOol003Eoo`03001oogoo08=oo`0301moogoo009o
o`03O01oogoo0?mooe9oo`00=Goo00<007ooOol0Q7oo00D07gooOomoog`00?mooeAoo`00=Goo00<0
07ooOol0Q7oo00<07gooOol00Woo00=l07ooOol0ogooDGoo000eOol00`00Oomoo`24Ool00`0OOomo
o`02Ool00g`0Oomoo`3oOomAOol003Eoo`03001oogoo08Eoo`0301moogoo009oo`03O01oogoo0?mo
oe1oo`00=Goo00<007ooOol0QGoo00<07gooOol00Woo00=l07ooOol0ogooD7oo000eOol00`00Oomo
o`26Ool01@0OOomoogooO000ogooDWoo000eOol20027Ool00`0OOomoo`02Ool00g`0Oomoo`3oOom?
Ool003Eoo`03001oogoo08Ioo`0301moogoo009oo`03O01oogoo0?moodmoo`00=Goo00<007ooOol0
Qgoo00D07gooOomoog`00?mooe5oo`00=Goo00<007ooOol0Qgoo00<07gooOol00Woo00=l07ooOol0
ogooCWoo000eOol00`00Oomoo`27Ool00`0OOomoo`02Ool00g`0Oomoo`3oOom>Ool003Eoo`03001o
ogoo08Qoo`0501moogooOoml003oOom@Ool003Eoo`03001oogoo08Qoo`0301moogoo009oo`03O01o
ogoo0?moodeoo`00=Goo00<007ooOol0RGoo00D07gooOomoog`00?moodmoo`00=Goo00<007ooOol0
RGoo00D07gooOomoog`00?moodmoo`00=Goo00<007ooOol0RGoo00<07gooOol00Woo00=l07ooOol0
ogooC7oo000eOol00`00Oomoo`2:Ool01@0OOomoogooO000ogooCWoo000eOol00`00Oomoo`2:Ool0
1@0OOomoogooO000ogooCWoo000eOol2002;Ool00`0OOomoo`02Ool00g`0Oomoo`3oOom;Ool003Eo
o`03001oogoo08]oo`0501moogooOoml003oOom=Ool003Eoo`03001oogoo08]oo`0301moogoo009o
o`03O01oogoo0?moodYoo`00=Goo00<007ooOol0S7oo00D07gooOomoog`00?moodaoo`00=Goo00<0
07ooOol0S7oo00D07gooOomoog`00?moodaoo`00=Goo00<007ooOol0S7oo00<07gooOol00Woo00=l
07ooOol0ogooBGoo000eOol00`00Oomoo`2=Ool01@0OOomoogooO000ogooBgoo0003Ool30004Ool2
0004Ool01@00Oomoogoo00000goo0`0017oo0P0057oo00<007ooOol0SGoo00D07gooOomoog`00?mo
od]oo`001Woo00@007ooOomoo`8000Eoo`03001oo`0000Eoo`03001oogoo009oo`04001oogoo000C
Ool00`00Oomoo`2=Ool00`0OOomoo`02Ool00g`0Oomoo`3oOom8Ool000Ioo`03001oogoo00Uoo`03
001oogoo00Aoo`03001oogoo009oo`04001oogoo000COol00`00Oomoo`2>Ool01@0OOomoogooO000
ogooBWoo0003Ool3000;Ool00`00Ool00005Ool00`00Oomoo`02Ool01000Oomoo`004goo1000SGoo
00D07gooOomoog`00?moodYoo`000goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
009oo`04001oogoo000COol00`00Oomoo`2?Ool01@0OOomoogooO000ogooBGoo0003Ool4000AOol2
0005Ool20007Ool2000;Ool00`00Oomoo`2?Ool01@0OOomoogooO000ogooBGoo000TOol3000017oo
000000002Woo00<007ooOol0Sgoo00D07gooOomoog`00?moodUoo`00:7oo00<007oo00002Woo00<0
07ooOol0T7oo00D07gooOomoog`00?moodQoo`00:7oo0`002Woo00<007ooOol0T7oo00D07gooOomo
og`00?moodQoo`00=Goo00<007ooOol0T7oo00D07gooOomoog`00?moodQoo`00=Goo0P00TWoo00D0
7gooOomoog`00?moodMoo`00=Goo00<007ooOol0TGoo00D07gooOomoog`00?moodMoo`00=Goo00<0
07ooOol0TGoo00<07gooOol00Woo00=l07ooOol0ogooA7oo000eOol00`00Oomoo`2BOol01@0OOomo
ogooO000ogooAWoo000eOol00`00Oomoo`2BOol00`0OOomoo`02Ool00g`0Oomoo`3oOom3Ool003Eo
o`03001oogoo09=oo`0501moogooOoml003oOom5Ool003Eoo`03001oogoo09=oo`0301moogoo009o
o`03O01oogoo0?mood9oo`00=Goo0P00U7oo00<07gooOol00Woo00=l07ooOol0ogoo@Woo000eOol0
0`00Oomoo`2DOol00`0OOomoo`02Ool00g`0Oomoo`3oOom1Ool003Eoo`03001oogoo09Aoo`0301mo
ogoo009oo`03O01oogoo0?mood5oo`00=Goo00<007ooOol0U7oo00<07gooOol00Woo00=l07ooOol0
ogoo@Goo000eOol00`00Oomoo`2EOol00`0OOomoo`02Ool00g`0Oomoo`3oOom0Ool003Eoo`03001o
ogoo09Eoo`0301moogoo009oo`03O01oogoo0?mood1oo`00=Goo0P00Ugoo00<07gooOol00Woo00=l
07ooOol0ogoo?goo000eOol00`00Oomoo`2FOol00`0OOomoo`02Ool00g`0Oomoo`3oOoloOol003Eo
o`03001oogoo09Moo`0301moogoo009oo`03O01oogoo0?moocioo`00=Goo00<007ooOol0Ugoo00<0
7gooOol00Woo00=l07ooOol0ogoo<Goo00<07gooOol02Woo000eOol00`00Oomoo`2HOol00`0OOomo
o`02Ool00g`0Oomoo`3oOol_Ool00`0OOomoo`0;Ool003Eoo`8009Uoo`0301moogoo009oo`03O01o
ogoo0?moobioo`0301moogoo00aoo`00=Goo00<007ooOol0VGoo00<07gooOol00Woo00=l07ooOol0
ogoo;7oo00<07gooOol03Goo0003Ool30004Ool20004Ool01@00Oomoogoo00000goo0`0017oo0P00
57oo00<007ooOol0VGoo00<07gooOol00Woo00=l07ooOol0ogoo;7oo00<07gooOol03Goo0004Ool0
0`00Oomoo`03Ool20005Ool00`00Ool00005Ool00`00Oomoo`02Ool01000Oomoo`004goo00<007oo
Ool0VWoo00<07gooOol00Woo00=l07ooOol0ogoo:Woo00<07gooOol03Woo0004Ool00`00Oomoo`0;
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`004goo1000VGoo00<07gooOol00Woo00=l
07ooOol0ogoo:Goo00<07gooOol03goo0004Ool00`00Oomoo`0:Ool00`00Ool00005Ool00`00Oomo
o`02Ool01000Oomoo`004goo00<007ooOol0Vgoo00<07gooOol00Woo00=l07ooOol0ogoo9goo00<0
7gooOol047oo0004Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00<007ooOol00Woo00@007oo
Ool000Ioo`<000Yoo`03001oogoo09]oo`0301moogoo009oo`03O01oogoo0?moobIoo`0301moogoo
015oo`000goo0P004goo0P001Goo0P000goo0`0000Aoo`00Ool000Yoo`03001oogoo09aoo`0501mo
ogooOoml003oOolXOol00`0OOomoo`0AOol002Uoo`03001oogoo00Uoo`03001oogoo09aoo`0301mo
ogoo009oo`03O01oogoo0?moobAoo`0301moogoo019oo`00:7oo0`002Woo00<007ooOol0WGoo00D0
7gooOomoog`00?moobEoo`0301moogoo01=oo`00=Goo00<007ooOol0WGoo00<07gooOol00Woo00=l
07ooOol0ogoo8Goo00<07gooOol057oo000eOol00`00Oomoo`2NOol01@0OOomoogooO000ogoo8Woo
00<07gooOol05Goo000eOol00`00Oomoo`2NOol00`0OOomoo`02Ool00g`0Oomoo`3oOolNOol00`0O
Oomoo`0FOol003Eoo`03001oogoo09moo`0501moogooOoml003oOolOOol00`0OOomoo`0GOol003Eo
o`03001oogoo09moo`0301moogoo009oo`03O01oogoo0?mooa]oo`0301moogoo01Qoo`00=Goo00<0
07ooOol0X7oo00D07gooOomoog`00?mooaaoo`0301moogoo01Uoo`00=Goo00<007ooOol0X7oo00<0
7gooOol00Woo00=l07ooOol0ogoo67oo00<07gooOol06Woo000eOol00`00Oomoo`2QOol01@0OOomo
ogooO000ogoo6Woo00<07gooOol06Woo000eOol00`00Oomoo`2QOol00`0OOomoo`02Ool00g`0Oomo
o`3oOolFOol00`0OOomoo`0KOol003Eoo`03001oogoo0:9oo`0501moogooOoml003oOolGOol00`0O
Oomoo`0LOol003Eoo`03001oogoo0:9oo`0301moogoo009oo`03O01oogoo0?mooa=oo`0301moogoo
01eoo`00=Goo00<007ooOol0Xgoo00D07gooOomoog`00?mooaAoo`0301moogoo015oo`03O01oogoo
00Yoo`00=Goo00<007ooOol0Y7oo00@07gooOoml0?mooaAoo`0301moogoo011oo`03O01oogoo00]o
o`00=Goo00<007ooOol0Y7oo00D07gooOomoog`00?mooa9oo`0301moogoo011oo`03O01oogoo00ao
o`00=Goo00<007ooOol0YGoo00@07gooOoml0?mooa5oo`0301moogoo011oo`03O01oogoo00eoo`00
=Goo00<007ooOol0YGoo00D07gooOomoog`00?moo`moo`0301moogoo011oo`03O01oogoo00ioo`00
=Goo00<007ooOol0YWoo00@07gooOoml0?moo`ioo`0301moogoo015oo`03O01oogoo00ioo`00=Goo
00<007ooOol0YWoo00D07gooOomoog`00?moo`aoo`0301moogoo015oo`03O01oogoo00moo`00=Goo
00<007ooOol0Ygoo00@07gooOoml0?moo`]oo`0301moogoo015oo`03O01oogoo011oo`00=Goo00<0
07ooOol0Ygoo00D07gooOomoog`00?moo`Uoo`0301moogoo019oo`03O01oogoo011oo`00=Goo00<0
07ooOol0Z7oo00@07gooOoml0?moo`Qoo`0301moogoo019oo`03O01oogoo015oo`00=Goo00<007oo
Ool0Z7oo00D07gooOomoog`00?moo`Ioo`0301moogoo01=oo`03O01oogoo015oo`00=Goo00<007oo
Ool0ZGoo00@07gooOoml0?moo`Eoo`0301moogoo01=oo`03O01oogoo019oo`00=Goo00<007ooOol0
ZGoo00D07gooOomoog`00?moo`Aoo`0301moogoo019oo`03O01oogoo01=oo`00=Goo0P00Zgoo00@0
7gooOoml0?moo`=oo`0301moogoo019oo`03O01oogoo01Aoo`00=Goo00<007ooOol0ZWoo00D07goo
Oomoog`00?moo`5oo`0301moogoo019oo`03O01oogoo01Eoo`00=Goo00<007ooOol0Zgoo00@07goo
Ooml0?moo`0301moogoo019oo`03O01oogoo01Ioo`00=Goo00<007ooOol0Zgoo00@07gooOoml0?io
o`0301moogoo019oo`03O01oogoo01Moo`00=Goo00<007ooOol0[7oo00@07gooOoml0?aoo`0301mo
ogoo019oo`03O01oogoo01Qoo`00=Goo00<007ooOol0[7oo00@07gooOoml0?aoo`0301moogoo015o
o`03O01oogoo01Uoo`00=Goo00<007ooOol0[Goo00@07gooOoml0?Yoo`0301moogoo015oo`03O01o
ogoo01Yoo`00=Goo00<007ooOol0[Goo00@07gooOoml0?Uoo`0301moogoo019oo`03O01oogoo01Yo
o`00=Goo00<007ooOol0[Woo00@07gooOoml0?Moo`0301moogoo019oo`03O01oogoo01]oo`00=Goo
00<007ooOol0[Woo00@07gooOoml0?Ioo`0301moogoo019oo`03O01oogoo01aoo`00=Goo00<007oo
Ool0[goo00@07gooOoml0?Aoo`0301moogoo019oo`03O01oogoo01eoo`00=Goo00<007ooOol0[goo
00@07gooOoml0?=oo`0301moogoo019oo`03O01oogoo01ioo`00=Goo00<007ooOol0/7oo00@07goo
Ooml0?5oo`0301moogoo019oo`03O01oogoo01moo`00=Goo00<007ooOol0/7oo00D07gooOomoog`0
0>moo`0301moogoo019oo`03O01oogoo021oo`00=Goo00<007ooOol0/Goo00@07gooOoml0>ioo`03
01moogoo019oo`03O01oogoo025oo`00=Goo00<007ooOol0/Goo00D07gooOomoog`00>aoo`0301mo
ogoo019oo`03O01oogoo029oo`00=Goo00<007ooOol0/Woo00@07gooOoml0>]oo`0301moogoo019o
o`03O01oogoo02=oo`00=Goo0P00]7oo00@07gooOoml0>Uoo`0301moogoo019oo`03O01oogoo02Ao
o`00=Goo00<007ooOol0/goo00D07gooOomoog`00>Moo`0301moogoo019oo`03O01oogoo02Eoo`00
=Goo00<007ooOol0]7oo00@07gooOoml0>Ioo`0301moogoo019oo`03O01oogoo02Ioo`00=Goo00<0
07ooOol0]Goo00@07gooOoml0>Aoo`0301moogoo019oo`03O01oogoo02Moo`00=Goo00<007ooOol0
]Goo00@07gooOoml0>=oo`0301moogoo019oo`03O01oogoo02Qoo`00=Goo00<007ooOol0]Woo00@0
7gooOoml0>5oo`0301moogoo019oo`03O01oogoo02Uoo`00=Goo00<007ooOol0]goo00@07gooOoml
0=moo`0301moogoo01=oo`03O01oogoo02Uoo`00=Goo00<007ooOol0]goo00@07gooOoml0=eoo`80
7aEoo`03O01oogoo02Yoo`00=Goo00<007ooOol0^7oo00@07gooOoml0=]oo`0301moogoo01Aoo`03
O01oogoo02]oo`00=Goo00<007ooOol0^Goo00<07gooO000fWoo00<07gooOol057oo00=l07ooOol0
;7oo000eOol00`00Oomoo`2iOol0100OOomoog`0f7oo00<07gooOol057oo00=l07ooOol0;Goo000e
Ool00`00Oomoo`2jOol0100OOomoog`0eWoo00<07gooOol057oo00=l07ooOol0;Woo000eOol00`00
Oomoo`2kOol00`0OOoml003EOol00`0OOomoo`0DOol00g`0Oomoo`0_Ool003Eoo`800;aoo`0401mo
ogooO03COol00`0OOomoo`0DOol00g`0Oomoo`0`Ool003Eoo`03001oogoo0;aoo`0301moog`00==o
o`0301moogoo01=oo`03O01oogoo035oo`00=Goo00<007ooOol0_Goo00<07gooO000dGoo00<07goo
Ool04goo00=l07ooOol0<Woo000eOol00`00Oomoo`2mOol00`0OOoml003@Ool00`0OOomoo`0COol0
0g`0Oomoo`0cOol003Eoo`03001oogoo0;ioo`0301moog`00<ioo`0301moogoo01=oo`03O01oogoo
03Aoo`00=Goo00<007ooOol0_Woo00@07gooOoml0<aoo`0301moogoo01=oo`03O01oogoo03Eoo`00
=Goo00<007ooOol0_goo00<07gooO000bgoo00<07gooOol04goo00=l07ooOol0=Woo0003Ool30004
Ool20004Ool01@00Oomoogoo00000goo0`0017oo0P0057oo00<007ooOol0`7oo00<07gooO000bGoo
00<07gooOol04goo00=l07ooOol0=goo0006Ool01000Oomoogoo0P001Goo00<007oo00001Goo00<0
07ooOol00Woo00@007ooOol001=oo`03001oogoo0<1oo`0301moog`00<Moo`807aEoo`03O01oogoo
03Qoo`001Woo00<007ooOol02Goo00<007ooOol017oo00<007ooOol00Woo00@007ooOol001=oo`@0
0<1oo`0301moog`00<Eoo`0301moogoo01Aoo`03O01oogoo03Uoo`000goo0`002goo00<007oo0000
1Goo00<007ooOol00Woo00@007ooOol001=oo`03001oogoo0<9oo`0301moog`00<=oo`0301moogoo
01Aoo`03O01oogoo03Yoo`000goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo009o
o`04001oogoo0006Ool3000:Ool00`00Oomoo`32Ool00`0OOoml0032Ool00`0OOomoo`0DOol00g`0
Oomoo`0kOol000=oo`@0015oo`8000Eoo`8000=oo`<00004Ool007oo000:Ool00`00Oomoo`33Ool0
0`0OOoml0030Ool00`0OOomoo`0DOol00g`0Oomoo`0lOol002Uoo`03001oogoo00Uoo`03001oogoo
0<Aoo`0301ml07oo0;ioo`0301moogoo01Aoo`03O01oogoo03eoo`00:7oo0`002Woo00<007ooOol0
a7oo00<07gooO000_Goo00<07gooOol057oo00=l07ooOol0?Woo000eOol00`00Oomoo`35Ool00`0O
Ooml002kOol00`0OOomoo`0DOol00g`0Oomoo`0oOol003Eoo`03001oogoo0<Ioo`0301ml07oo0;Qo
o`807aEoo`9l049oo`00=Goo0P00agoo00<07gooO000]goo00<07gooOol057oo00=l07ooOol0@Woo
000eOol00`00Oomoo`37Ool00`0OO01oo`2eOol00`0OOomoo`0DOol00g`0Oomoo`13Ool003Eoo`03
001oogoo0<Qoo`0301ml07oo0;=oo`0301moogoo01Aoo`03O01oogoo04Aoo`00=Goo00<007ooOol0
b7oo00<07gooO000/Woo00<07gooOol057oo00=l07ooOol0AGoo000eOol00`00Oomoo`39Ool00`0O
Ooml002`Ool00`0OOomoo`0DOol00g`0Oomoo`16Ool003Eoo`03001oogoo0<Yoo`0301ml07oo0:io
o`0301moogoo01Aoo`03O01oogoo04Moo`00=Goo0P00c7oo00<07g`0Ool0[7oo00<07gooOol057oo
00=l07ooOol0B7oo000eOol00`00Oomoo`3<Ool00`0OO01oo`2YOol201lFOol00g`0Oomoo`19Ool0
03Eoo`03001oogoo0<eoo`0301ml07oo0:Moo`0301moogoo01Eoo`03O01oogoo04Yoo`00=Goo00<0
07ooOol0cWoo00<07gooOol0YGoo00<07gooOol05Goo00=l07ooOol0Bgoo000eOol00`00Oomoo`3?
Ool00`0OOomoo`2SOol00`0OOomoo`0EOol00g`0Oomoo`1<Ool003Eoo`03001oogoo0=1oo`0301mo
ogoo0:1oo`807aMoo`03O01oogoo04eoo`00=Goo0P00dWoo00<07gooOol0WWoo00<07gooOol05Woo
00=l07ooOol0CWoo000eOol00`00Oomoo`3AOol00`0OOomoo`2MOol00`0OOomoo`0EOol2O01AOol0
03Eoo`03001oogoo0=9oo`0301moogoo09]oo`0301moogoo01Eoo`03O01oogoo055oo`00=Goo00<0
07ooOol0dgoo00<07gooOol0V7oo0P0O5goo00=l07ooOol0DWoo000eOol00`00Oomoo`3COol00g`0
01moo`2GOol00`0OOomoo`0FOol00g`0Oomoo`1COol003Eoo`800=Eoo`03O0007goo09Eoo`0301mo
ogoo01Ioo`03O01oogoo05Aoo`00=Goo00<007ooOol0eGoo00=l000OOol0TWoo0P0O67oo00=l07oo
Ool0EGoo0003Ool30004Ool20004Ool01@00Oomoogoo00000goo0`0017oo0P0057oo00<007ooOol0
eWoo00=l000OOol0T7oo00<07gooOol05goo00=l07ooOol0EWoo0004Ool00`00Oomoo`03Ool20005
Ool00`00Ool00005Ool00`00Oomoo`02Ool01000Oomoo`004goo00<007ooOol0eWoo00=l07oo01l0
Sgoo00<07gooOol05goo00=l07ooOol0Egoo0004Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool01000Oomoo`004goo00<007ooOol0egoo00Al07oo01l07h]oo`807aQoo`9l05Yoo`00
17oo00<007ooOol02Woo00<007oo00001Goo00<007ooOol00Woo00@007ooOol001=oo`@00=Moo`04
O01oogoo01n9Ool00`0OOomoo`0GOol00g`0Oomoo`1JOol000Aoo`03001oogoo00Uoo`05001oogoo
Ool00004Ool00`00Oomoo`02Ool01000Oomoo`004goo00<007ooOol0fGoo00Al07ooOol07hMoo`03
01moogoo01Moo`03O01oogoo05]oo`000goo0P004goo0P001Goo0P0027oo00<007ooOol02Goo00<0
07ooOol0fWoo00Al07ooOol07hAoo`807aQoo`9l05ioo`0097oo0`000Woo00<007ooOol02Goo00<0
07ooOol0fgoo00Al07ooOol07h9oo`0301moogoo01Moo`03O01oogoo05ioo`00:Woo00<007ooOol0
27oo00<007ooOol0g7oo00Al07ooOol07gmoo`807aUoo`03O01oogoo05moo`00:7oo0`002Woo00<0
07ooOol0gGoo00Al07ooOol07geoo`0301moogoo01Qoo`03O01oogoo061oo`00=Goo00<007ooOol0
gWoo00Al07ooOol07gYoo`807aUoo`9l06=oo`00=Goo00<007ooOol0ggoo00Al07ooOol07gMoo`80
7aYoo`03O01oogoo06=oo`00=Goo00<007ooOol0h7oo00Al07ooOol07gEoo`0301moogoo01Uoo`03
O01oogoo06Aoo`00=Goo00<007ooOol0hGoo00Al07ooOol07g9oo`807a]oo`03O01oogoo06Eoo`00
=Goo00<007ooOol0hWoo00Al07ooOol07g1oo`0301moogoo01Uoo`9l06Qoo`00=Goo00<007ooOol0
hgoo00=l07ooOol00P0OK7oo0P0O6goo00=l07ooOol0J7oo000eOol00`00Oomoo`3TOol01G`0Oomo
ogoo01l0JGoo0P0O77oo00=l07ooOol0JGoo000eOol00`00Oomoo`3UOol017`0Oomoogoo0P0OIGoo
0P0O7Goo00=l07ooOol0JWoo000eOol00`00Oomoo`3VOol00g`0Oomoo`02Ool201mQOol201lMOol2
O01]Ool003Eoo`03001oogoo0>Moo`9l00Aoo`0301moogoo05aoo`807aioo`03O01oogoo06eoo`00
=Goo00<007ooOol0jGoo00=l07ooOol00Woo0P0OFWoo0P0O7Woo0W`0L7oo000eOol00`00Oomoo`3Z
Ool00g`0Oomoo`03Ool201mFOol201lNOol2O01bOol003Eoo`03001oogoo0>]oo`03O01oogoo00Ao
o`0301moogoo055oo`807amoo`03O01oogoo079oo`00=Goo00<007ooOol0k7oo00=l07ooOol017oo
0P0OCgoo0P0O7goo0W`0MGoo000eOol00`00Oomoo`3]Ool2O006Ool201m:Ool301lOOol2O01gOol0
03Eoo`03001oogoo0>moo`03O01oogoo00Eoo`807dIoo`807b5oo`03O01oogoo07Moo`00=Goo00<0
07ooOol0l7oo00=l07ooOol01Woo0P0O@Goo0`0O8Goo0W`0NWoo000eOol00`00Oomoo`3aOol00g`0
Oomoo`07Ool201lmOol201lSOol00g`0Oomoo`1jOol003Eoo`03001oogoo0?9oo`03O01oogoo00Qo
o`807cUoo`807b=oo`9l07eoo`00=Goo00<007ooOol0lgoo0W`02Woo0`0O<goo0`0O8goo0W`0Ogoo
000eOol00`00Oomoo`3eOol2O00;Ool301l^Ool201lUOol00g`0Oomoo`1oOol003Eoo`03001oogoo
0?Moo`03O01oogoo00]oo`D07bEoo`@07bEoo`9l089oo`00=Goo00<007ooOol0n7oo0W`047oo100O
6Woo1`0O9goo0W`0Q7oo000eOol2003kOol2O00BOol801l:Ool801l]Ool00g`0Oomoo`24Ool003Eo
o`03001oogoo0?aoo`03O01oogoo01Moo`X07c=oo`9l08Moo`00=Goo00<007ooOol0oGoo0W`0DGoo
0g`0RGoo000eOol00`00Oomoo`3oOol2O01<Ool3O02<Ool003Eoo`03001oogoo0?moo`9oo`9l04Qo
o`9l08moo`00=Goo00<007ooOol0ogoo17oo0W`0A7oo0W`0TGoo000eOol00`00Oomoo`3oOol6Ool2
O00oOol3O02COol003Eoo`03001oogoo0?moo`Qoo`9l03]oo`9l09Ioo`00=Goo00<007ooOol0ogoo
2Woo0W`0=Woo0g`0V7oo000eOol00`00Oomoo`3oOol<Ool3O00^Ool5O02KOol003Eoo`03001oogoo
0?moo`moo`Al02Moo`=l0:1oo`00=Goo00<007ooOol0ogoo4goo0g`08Goo0g`0Xgoo000eOol00`00
Oomoo`3oOolFOol7O00GOol3O02VOol003Eoo`03001oogoo0?mooaeooaMl0:Uoo`00=Goo00<007oo
Ool0ogoogGoo000eOol00`00Oomoo`3oOooMOol003Eoo`03001oogoo0?moomeoo`00=Goo00<007oo
Ool0ogoogGoo000eOol2003oOooNOol003Eoo`03001oogoo0?moomeoo`00=Goo00<007ooOol0ogoo
gGoo003oOoooOolFOol00?mooomooaIoo`00ogooogoo5Woo003oOoooOolFOol00?mooomooaIoo`00
ogooogoo5Woo003oOoooOolFOol00001\
\>"],
  ImageRangeCache->{{{0, 531}, {327.688, 0}} -> {-0.828414, -9.75034, 
  0.00486393, 0.0101522}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Estimating the probability for a randomly chosen order", \
"SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MonteCarloProbability[g, J, \[Theta], \(\[Theta]\^*\), ns]\), 
            \(chooses\ one\ random\ ordering\ for\ the\ \(estimates . \)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["\<\
This chooses the less likely of the two orderings, and doubles the \
result:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ss3 = MonteCarloProbability[g, jl2, 1. , 1. , 1000]; 
    \n{Mean[ss3], StandardErrorOfSampleMean[ss3]}\)], "Input",
  CellLabel->"In[204]:="],

Cell[BoxData[
    \({4.83085048756705148`*^-10, 3.28023881614043677`*^-11}\)], "Output",
  CellLabel->"Out[204]="]
}, Closed]],

Cell["\<\
This chooses the more likely ordering, and doubles the \
result:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ss3 = MonteCarloProbability[g, jl2, 1. , 1. , 1000]; 
    \n{Mean[ss3], StandardErrorOfSampleMean[ss3]}\)], "Input",
  CellLabel->"In[207]:="],

Cell[BoxData[
    \({7.5747112230624225`*^-9, 2.31585343686626998`*^-10}\)], "Output",
  CellLabel->"Out[207]="]
}, Closed]],

Cell["\<\
To estimate the overall probability, one must take the average of \
many trial orderings:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ss3 = Table[MonteCarloProbability[g, jl2, 1. , 1. , 100], {100}]; 
    \n{Mean[ss3 // Flatten], StandardErrorOfSampleMean[ss3 // Flatten], 
      StandardErrorOfSampleMean[Mean/@ss3]}\)], "Input",
  CellLabel->"In[208]:="],

Cell[BoxData[
    \({4.19341543516791226`*^-9, 7.29921238518112058`*^-11, 
      3.52666204088929946`*^-10}\)], "Output",
  CellLabel->"Out[213]="]
}, Closed]],

Cell["\<\
Note that the standard error of the overall list of 10000 values is \
misleadingly small (second figure).  This is because the main sampling error \
is across orderings rather than across replicates for a given ordering. \
\>",
   "Text"],

Cell["\<\
Where there are very many orderings, and some are much more likely \
than others, this procedure is extremely unreliable, because the likely \
orderings may be missed.  It is not clear to me whether the Griffiths & \
Tavare algorithm avoids this problem.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 653},
WindowMargins->{{Automatic, 0}, {Automatic, -1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "MonteCarloProbability"->{
    Cell[1818, 53, 1443, 28, 102, "DefinitionBox",
      CellTags->"MonteCarloProbability"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"MonteCarloProbability", 152006, 4761}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 76, 0, 36, "SubsectionIcon"],
Cell[1818, 53, 1443, 28, 102, "DefinitionBox",
  CellTags->"MonteCarloProbability"],
Cell[3264, 83, 113, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3402, 90, 117, 2, 27, "Input"],
Cell[3522, 94, 501, 10, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[4060, 109, 87, 2, 23, "Input"],
Cell[4150, 113, 9863, 275, 184, 3897, 196, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[14028, 391, 209, 4, 46, "MathCaption"],

Cell[CellGroupData[{
Cell[14262, 399, 211, 5, 57, "Input"],
Cell[14476, 406, 341, 10, 46, "Output"]
}, Closed]],
Cell[14832, 419, 157, 4, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[15014, 427, 161, 3, 42, "Input"],
Cell[15178, 432, 112, 2, 22, "Output"]
}, Closed]],
Cell[15305, 437, 56, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[15386, 441, 154, 3, 57, "Input"],
Cell[15543, 446, 341, 10, 46, "Output"]
}, Closed]],
Cell[15899, 459, 291, 9, 34, "MathCaption"],

Cell[CellGroupData[{
Cell[16215, 472, 166, 3, 42, "Input"],
Cell[16384, 477, 113, 2, 22, "Output"]
}, Closed]],
Cell[16512, 482, 119, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[16656, 489, 106, 2, 27, "Input"],
Cell[16765, 493, 111, 2, 22, "Output"]
}, Closed]],
Cell[16891, 498, 72, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[16988, 502, 234, 5, 42, "Input"],
Cell[17225, 509, 85, 2, 20, "Output"]
}, Closed]],
Cell[17325, 514, 278, 5, 46, "Text"],
Cell[17606, 521, 86, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[17717, 527, 168, 3, 42, "Input"],
Cell[17888, 532, 28564, 1139, 184, 9398, 897, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[46501, 1677, 79, 0, 36, "SubsectionIcon"],
Cell[46583, 1679, 558, 11, 64, "Text"],

Cell[CellGroupData[{
Cell[47166, 1694, 142, 3, 42, "Input"],
Cell[47311, 1699, 4322, 62, 320, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[51670, 1766, 94, 2, 23, "Input"],
Cell[51767, 1770, 586, 10, 58, "Output"]
}, Closed]],
Cell[52368, 1783, 76, 0, 18, "MathCaption"],
Cell[52447, 1785, 102, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[52574, 1791, 294, 6, 57, "Input"],
Cell[52871, 1799, 44510, 1446, 311, 27210, 1227, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[97396, 3248, 182, 4, 32, "Text"],
Cell[97581, 3254, 239, 6, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[97845, 3264, 144, 3, 42, "Input"],
Cell[97992, 3269, 5180, 74, 360, "Output"]
}, Closed]],
Cell[103187, 3346, 265, 8, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[103477, 3358, 199, 4, 42, "Input"],
Cell[103679, 3364, 45155, 1293, 335, 22816, 1012, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[148871, 4662, 85, 1, 20, "SubsubsectionIcon"],
Cell[148959, 4665, 253, 4, 37, "DefinitionBox"],
Cell[149215, 4671, 107, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[149347, 4678, 162, 3, 42, "Input"],
Cell[149512, 4683, 114, 2, 22, "Output"]
}, Closed]],
Cell[149641, 4688, 95, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[149761, 4695, 162, 3, 42, "Input"],
Cell[149926, 4700, 112, 2, 22, "Output"]
}, Closed]],
Cell[150053, 4705, 120, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[150198, 4712, 242, 4, 57, "Input"],
Cell[150443, 4718, 147, 3, 22, "Output"]
}, Closed]],
Cell[150605, 4724, 248, 5, 46, "Text"],
Cell[150856, 4731, 278, 5, 50, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

