(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     52626,       1536]*)
(*NotebookOutlinePosition[     53509,       1564]*)
(*  CellTagsIndexPosition[     53465,       1560]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["An example: four lineages", "SubsubsectionIcon"],

Cell["\<\
\tFor example, consider the genealogies that connect four lineages. \
 There are two kinds of topology.  Three genealogies have the form \
{{a,b},{c,d}}\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m1 = 
      MomentGeneratingFunction[
        Node[{a, b, c, 
            d}, {}, {Node[{a, b}, {}, {Node[{a}, {}, {}], 
                Node[{b}, {}, {}]}], 
            Node[{c, d}, {}, {Node[{c}, {}, {}], 
                Node[{d}, {}, {}]}]}], \[Omega], \[Theta]]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \(\((2/\((3\ \((2 + \[Theta])\)\ \((1 - \(\[Theta]\ \((\[Omega][{c}] + \
\[Omega][{d}] + \[Omega][{a, b}])\)\)\/\(3\ \((2 + \[Theta])\)\))\)\ \((1 + \
\[Theta]\ \((1 + 1\/2\ \((\(-\[Omega][{a, b}]\) - \[Omega][{c, 
                                    d}])\))\))\))\) + 
          2/\((3\ \((2 + \[Theta])\)\ \((1 + \[Theta]\ \((1 + 
                          1\/2\ \((\(-\[Omega][{a, b}]\) - \[Omega][{c, 
                                    d}])\))\))\)\ \((1 - \(\[Theta]\ \((\
\[Omega][{a}] + \[Omega][{b}] + \[Omega][{c, d}])\)\)\/\(3\ \((2 + \
\[Theta])\)\))\))\))\)/\((2\ \((3 + \[Theta])\)\ \((1 - \(\[Theta]\ \((\
\[Omega][{a}] + \[Omega][{b}] + \[Omega][{c}] + \[Omega][{d}])\)\)\/\(4\ \((3 \
+ \[Theta])\)\))\))\)\)], "Output",
  CellLabel->"Out[14]="]
}, Closed]],

Cell["This can be somewhat simplified as:", "Text"],

Cell[BoxData[{
    \(\((8 
           A\_\(12, 6\)[{a, b, c, d, {a, b}, {c, d}}])\)/\((A\_\(12, 4\)[{a, 
              b, c, d}] A\_\(6, 3\)[{c, d, {a, b}}] 
          A\_\(6, 3\)[{a, b, {c, d}}] 
          A\_\(2, 2\)[{{a, b}, {c, d}}])\)\), "\n", 
    \(where\ A\_\(\[Alpha], \[Beta]\)[
          S] \[Congruent] \[Alpha] + \[Theta] \((\[Beta] - \[Sum]\+\(i \
\[Element] S\)\[Omega]\_i)\)\)}], "Output"],

Cell["\<\
There are twelve genealogies with topology of the form \
{{{a,b},c},d}:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m2 = 
      MomentGeneratingFunction[
        Node[{a, b, c, 
            d}, {}, {Node[{a, b, 
                c}, {}, {Node[{a, b}, {}, {Node[{a}, {}, {}], 
                    Node[{b}, {}, {}]}], Node[{c}, {}, {}]}], 
            Node[{d}, {}, {}]}], \[Omega], \[Theta]]\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \(1/\((3\ \((2 + \[Theta])\)\ \((3 + \[Theta])\)\ \((1 - \(\[Theta]\ \((\
\[Omega][{a}] + \[Omega][{b}] + \[Omega][{c}] + \[Omega][{d}])\)\)\/\(4\ \((3 \
+ \[Theta])\)\))\)\ \((1 - \(\[Theta]\ \((\[Omega][{c}] + \[Omega][{d}] + \
\[Omega][{a, b}])\)\)\/\(3\ \((2 + \[Theta])\)\))\)\ \((1 + \[Theta]\ \((1 + 
                    1\/2\ \((\(-\[Omega][{d}]\) - \[Omega][{a, b, 
                              c}])\))\))\))\)\)], "Output",
  CellLabel->"Out[15]="]
}, Closed]],

Cell["\<\
Setting \[Omega][_]\[Rule]1 gives the net probability of each such \
configuration.  The overall probability does sum to 1\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({m1, m2, 3  m1 + 12  m2} /. \[Omega][_] :> 1 // Simplify\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \({1\/9, 1\/18, 1}\)], "Output",
  CellLabel->"Out[13]="]
}, Closed]],

Cell["\<\
The generating function for the total number of mutations (i.e. the \
number of segregating sites) is:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mt1 = m1 /. \[Omega][_] \[Rule] \[Nu] // Factor; 
    mt2 = m2 /. \[Omega][_] \[Rule] \[Nu] // Factor; {mt1, mt2}\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \({\(-\(2\/\(3\ \((\(-3\) - \[Theta] + \[Theta]\ \[Nu])\)\ \((\(-2\) - \
\[Theta] + \[Theta]\ \[Nu])\)\ \((\(-1\) - \[Theta] + \[Theta]\ \
\[Nu])\)\)\)\), \(-\(1\/\(3\ \((\(-3\) - \[Theta] + \[Theta]\ \[Nu])\)\ \
\((\(-2\) - \[Theta] + \[Theta]\ \[Nu])\)\ \((\(-1\) - \[Theta] + \[Theta]\ \
\[Nu])\)\)\)\)}\)], "Output",
  CellLabel->"Out[34]="]
}, Closed]],

Cell["\<\
Note that this has a form independent of the topology: the total  \
number of segregating sites depends only on the coalescence times, and not on \
which branches coalesce.  This distribution could of course be found more \
simply by ignoring the topology altogether.\
\>", "Text"],

Cell["The first few moments of the # of segregating sites, are:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[\(1\/\(j!\)\) D[mt1, {\[Nu], j}] /. \[Nu] -> 1, {j, 0, 
          4}]/\((mt1 /. \[Nu] \[Rule] 1)\)\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \({1, \(11\ \[Theta]\)\/6, \(85\ \[Theta]\^2\)\/36, \(575\ \
\[Theta]\^3\)\/216, \(3661\ \[Theta]\^4\)\/1296}\)], "Output",
  CellLabel->"Out[32]="]
}, Closed]],

Cell[TextData[{
  "The first few cumulants can be found by transforming ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] \[Rule] \[ExponentialE]\^z\)]],
  ", and differentiating the logarithm of the g.f.:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
        D[Log[mt1/\((mt1 /. \[Nu] \[Rule] 
                        1)\)] /. \[Nu] \[Rule] \[ExponentialE]\^z, {z, j}] /. 
          z -> 0, {j, 0, 4}] // Simplify\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \({0, \(11\ \[Theta]\)\/6, 1\/36\ \[Theta]\ \((66 + 49\ \[Theta])\), 
      1\/108\ \[Theta]\ \((198 + 441\ \[Theta] + 251\ \[Theta]\^2)\), 
      1\/216\ \[Theta]\ \((396 + 2058\ \[Theta] + 3012\ \[Theta]\^2 + 
            1393\ \[Theta]\^3)\)}\)], "Output",
  CellLabel->"Out[38]="]
}, Closed]],

Cell[TextData[{
  "The probability distribution itself can be recovered by successive \
differentiation.  Given the ordered topology {{a,b},{c,d}}, the chance of \
getting no mutations in the leaves ",
  Cell[BoxData[
      \(TraditionalForm\`\((j\_a, \ j\_b, j\_c, \ j\_d = 0)\)\)]],
  " and 4 mutations in each of the internal branches is:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pr = \(1\/\(\((m1 /. \[Omega][_] \[Rule] 1)\) \((\(4!\))\)\^2\)\) 
            D[m1 /. {\[Omega][{a}] \[Rule] 0, \[Omega][{b}] \[Rule] 
                      0, \[Omega][{c}] \[Rule] 0, \[Omega][{d}] \[Rule] 0} // 
                Factor, {\[Omega][{a, b}], 4}, {\[Omega][{c, d}], 
                4}] /. \[Omega][_] :> 0 // Simplify\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \(\(\[Theta]\^8\ \((54128 + 113312\ \[Theta] + 89148\ \[Theta]\^2 + 31247\
\ \[Theta]\^3 + 4118\ \[Theta]\^4)\)\)\/\(1728\ \((1 + \[Theta])\)\^9\ \((2 + \
\[Theta])\)\^5\ \((3 + \[Theta])\)\)\)], "Output",
  CellLabel->"Out[51]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[pr, {\[Theta], \ 0, 20}];\)\)], "Input",
  CellLabel->"In[54]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0147151 318.127 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .09425 -42 -4.5 ]
[.01131 .09425 0 4.5 ]
[.01131 .17378 -36 -4.5 ]
[.01131 .17378 0 4.5 ]
[.01131 .25331 -42 -4.5 ]
[.01131 .25331 0 4.5 ]
[.01131 .33284 -30 -4.5 ]
[.01131 .33284 0 4.5 ]
[.01131 .41237 -42 -4.5 ]
[.01131 .41237 0 4.5 ]
[.01131 .49191 -36 -4.5 ]
[.01131 .49191 0 4.5 ]
[.01131 .57144 -42 -4.5 ]
[.01131 .57144 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(10)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(15)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(20)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09425 m
.03006 .09425 L
s
[(0.00025)] .01131 .09425 1 0 Mshowa
.02381 .17378 m
.03006 .17378 L
s
[(0.0005)] .01131 .17378 1 0 Mshowa
.02381 .25331 m
.03006 .25331 L
s
[(0.00075)] .01131 .25331 1 0 Mshowa
.02381 .33284 m
.03006 .33284 L
s
[(0.001)] .01131 .33284 1 0 Mshowa
.02381 .41237 m
.03006 .41237 L
s
[(0.00125)] .01131 .41237 1 0 Mshowa
.02381 .49191 m
.03006 .49191 L
s
[(0.0015)] .01131 .49191 1 0 Mshowa
.02381 .57144 m
.03006 .57144 L
s
[(0.00175)] .01131 .57144 1 0 Mshowa
.125 Mabswid
.02381 .03062 m
.02756 .03062 L
s
.02381 .04653 m
.02756 .04653 L
s
.02381 .06243 m
.02756 .06243 L
s
.02381 .07834 m
.02756 .07834 L
s
.02381 .11015 m
.02756 .11015 L
s
.02381 .12606 m
.02756 .12606 L
s
.02381 .14197 m
.02756 .14197 L
s
.02381 .15787 m
.02756 .15787 L
s
.02381 .18968 m
.02756 .18968 L
s
.02381 .20559 m
.02756 .20559 L
s
.02381 .2215 m
.02756 .2215 L
s
.02381 .2374 m
.02756 .2374 L
s
.02381 .26922 m
.02756 .26922 L
s
.02381 .28512 m
.02756 .28512 L
s
.02381 .30103 m
.02756 .30103 L
s
.02381 .31694 m
.02756 .31694 L
s
.02381 .34875 m
.02756 .34875 L
s
.02381 .36465 m
.02756 .36465 L
s
.02381 .38056 m
.02756 .38056 L
s
.02381 .39647 m
.02756 .39647 L
s
.02381 .42828 m
.02756 .42828 L
s
.02381 .44419 m
.02756 .44419 L
s
.02381 .46009 m
.02756 .46009 L
s
.02381 .476 m
.02756 .476 L
s
.02381 .50781 m
.02756 .50781 L
s
.02381 .52372 m
.02756 .52372 L
s
.02381 .53962 m
.02756 .53962 L
s
.02381 .55553 m
.02756 .55553 L
s
.02381 .58734 m
.02756 .58734 L
s
.02381 .60325 m
.02756 .60325 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01473 L
.03279 .01475 L
.03395 .01478 L
.0352 .01485 L
.03638 .01496 L
.03746 .01512 L
.03873 .01538 L
.03944 .01558 L
.04011 .0158 L
.04132 .01632 L
.04262 .01705 L
.04396 .01804 L
.04519 .01919 L
.04797 .02276 L
.05042 .0272 L
.05302 .03336 L
.05751 .04793 L
.06244 .06964 L
.07296 .13318 L
.08424 .21744 L
.10458 .3712 L
.11475 .43635 L
.12582 .49431 L
.13627 .53634 L
.14092 .55128 L
.14594 .56494 L
.15096 .57624 L
.15557 .58464 L
.15997 .59105 L
.16461 .59621 L
.16707 .59834 L
.1697 .60017 L
.17219 .60149 L
.17444 .60237 L
.17583 .60277 L
.1771 .60303 L
.17777 .60314 L
.1785 .60323 L
.17926 .60329 L
.17998 .60332 L
.1813 .60331 L
.1825 .60322 L
.18316 .60314 L
Mistroke
.18389 .60303 L
.18521 .60277 L
.18654 .60243 L
.18777 .60205 L
.19054 .60094 L
.19555 .59818 L
.20011 .59488 L
.20492 .5907 L
.2259 .56589 L
.26393 .50647 L
.30441 .43942 L
.34337 .37981 L
.38478 .32469 L
.42468 .27979 L
.46306 .24344 L
.50389 .21108 L
.54321 .18505 L
.58101 .16396 L
.62127 .14499 L
.66001 .12954 L
.7012 .1156 L
.74088 .10417 L
.77904 .09471 L
.81965 .08603 L
.85875 .07879 L
.9003 .07212 L
.94033 .06653 L
.97619 .06211 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[54]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
IWoo0`00=Goo0`0017oo0P00<Woo0`000goo0`00<Woo10000goo0P000goo001YOol00`00Oomoo`0c
Ool00`00Oomoo`02Ool01000Oomoo`00<Woo00<007ooOol01Goo00<007ooOol0<7oo00<007ooOol0
0Woo00@007ooOol0009oo`00JGoo00<007ooOol0<goo00<007ooOol00Woo00@007ooOol0039oo`03
001oogoo00Eoo`03001oogoo035oo`05001oogooOol00002Ool10001Ool1Ool006Ioo`<003Ioo`03
001oogoo009oo`04001oogoo000bOol00`00Oomoo`02Ool3000eOol01000Oomoo`000Woo0@000Goo
0Goo001VOol00`00Oomoo`0fOol00`00Oomoo`02Ool01000Oomoo`00<Woo00<007ooOol00Woo00<0
07ooOol0<Woo00@007ooOol0009oo`04001oogoo0002Ool006Ioo`@003Aoo`8000Eoo`80039oo`80
00Aoo`@0039oo`8000Aoo`8000=oo`00ogoo8Goo000]Ool00`00Oomoo`3`Ool002eoo`03001oogoo
0?1oo`00;Goo00<007ooOol0l7oo000WOooh0001Ool002eoo`03001oogoo00<000Eoo`03001oogoo
00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo
00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo
00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo
00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Aoo`00;Goo00<0
07ooOol00goo00<007ooOol0<Woo00<007ooOol0>7oo00<007ooOol0>7oo00<007ooOol0>7oo00<0
07ooOol017oo000]Ool00`00Oomoo`03Ool00`00Oomoo`3ZOol002eoo`8000Aoo`03001oogoo0>Yo
o`00;Goo00<007ooOol017oo00<007ooOol0jGoo000]Ool00`00Oomoo`04Ool00`00Oomoo`3YOol0
02eoo`03001oogoo00Aoo`03001oogoo0>Uoo`00;Goo0P001Woo00<007ooOol0j7oo000]Ool00`00
Oomoo`05Ool00`00Oomoo`3XOol002eoo`03001oogoo00Eoo`03001oogoo0>Qoo`00;Goo00<007oo
Ool01Goo00<007ooOol0j7oo000]Ool20007Ool00`00Oomoo`3LOol50006Ool002eoo`03001oogoo
00Ioo`03001oogoo0=Eoo`L000]oo`00;Goo00<007ooOol01Woo00<007ooOol0d7oo1@004Woo000]
Ool00`00Oomoo`06Ool00`00Oomoo`38Ool8000GOol002eoo`8000Moo`03001oogoo0<1oo`P001mo
o`00;Goo00<007ooOol01Woo00<007ooOol0^goo1@009goo0002Ool20004Ool20004Ool20004Ool2
0004Ool20003Ool40002Ool30005Ool00`00Oomoo`07Ool00`00Oomoo`2fOol4000/Ool00005Ool0
07ooOol00003Ool20003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`2aOol5000`Ool00005Ool007oo
Ool00008Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool20008Ool00`00Oomoo`2/Ool5000eOol00005Ool007ooOol00008Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`030005Ool00`00Oomoo`07Ool0
0`00Oomoo`2YOol3000jOol00005Ool007ooOol00008Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol01goo00<007ooOol0
YWoo0`00?Goo0002Ool2000:Ool20004Ool20004Ool20004Ool20003Ool40004Ool00`00Oomoo`08
Ool00`00Oomoo`2QOol40010Ool002eoo`8000Uoo`03001oogoo09aoo`D004Aoo`00;Goo00<007oo
Ool027oo00<007ooOol0V7oo1000BGoo000]Ool00`00Oomoo`08Ool00`00Oomoo`2EOol3001=Ool0
02eoo`03001oogoo00Qoo`03001oogoo09=oo`80051oo`00;Goo0P002Woo00<007ooOol0Sgoo0`00
DWoo000]Ool00`00Oomoo`09Ool00`00Oomoo`2=Ool2001EOol002eoo`03001oogoo00Uoo`03001o
ogoo08]oo`8005Moo`00;Goo00<007ooOol02Goo00<007ooOol0R7oo0`00FGoo000]Ool2000:Ool0
0`00Oomoo`26Ool2001LOol002eoo`03001oogoo00Uoo`03001oogoo08Aoo`8005ioo`00;Goo00<0
07ooOol02Woo00<007ooOol0P7oo0`00H7oo000]Ool00`00Oomoo`0:Ool00`00Oomoo`1nOol2001S
Ool002eoo`8000]oo`03001oogoo07]oo`<006Eoo`00;Goo00<007ooOol02Woo00<007ooOol0NGoo
0P00J7oo0008Ool20004Ool20004Ool20004Ool20004Ool20003Ool30005Ool00`00Oomoo`0:Ool0
0`00Oomoo`1gOol2001ZOol000Moo`04001oogoo0003Ool20003Ool01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0005Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`1fOol00`00
Oomoo`1ZOol000Moo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
0005Ool00`00Oomoo`02Ool2000;Ool00`00Oomoo`1dOol2001]Ool000Moo`04001oogoo0008Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool30005Ool00`00Oomoo`0;Ool00`00
Oomoo`1aOol2001_Ool000Moo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`1`Ool00`00Oomoo`1_Ool0
00Qoo`8000Yoo`8000Aoo`8000Aoo`8000=oo`@000Aoo`03001oogoo00]oo`03001oogoo06ioo`80
079oo`00;Goo0P0037oo00<007ooOol0KGoo00<007ooOol0LWoo000]Ool00`00Oomoo`0;Ool00`00
Oomoo`1[Ool2001eOol002eoo`03001oogoo00]oo`03001oogoo06Yoo`03001oogoo07Eoo`00;Goo
00<007ooOol02goo00<007ooOol0J7oo0P00N7oo000]Ool2000=Ool00`00Oomoo`1VOol00`00Oomo
o`1hOol002eoo`03001oogoo00aoo`03001oogoo06Aoo`8007]oo`00;Goo00<007ooOol037oo00<0
07ooOol0Hgoo00<007ooOol0Ngoo000]Ool00`00Oomoo`0<Ool00`00Oomoo`1ROol00`00Oomoo`1l
Ool002eoo`8000eoo`03001oogoo061oo`8007moo`00;Goo00<007ooOol037oo00<007ooOol0Ggoo
00<007ooOol0Ogoo000]Ool00`00Oomoo`0<Ool00`00Oomoo`1MOol20022Ool002eoo`03001oogoo
00aoo`03001oogoo05aoo`03001oogoo089oo`00;Goo0P003Woo00<007ooOol0FWoo00<007ooOol0
Pgoo0002Ool20004Ool20004Ool20004Ool20004Ool20004Ool00`00Oomoo`02Ool30005Ool00`00
Oomoo`0=Ool00`00Oomoo`1IOol00`00Oomoo`24Ool00005Ool007ooOol00003Ool20003Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
0`00Oomoo`0=Ool00`00Oomoo`1HOol00`00Oomoo`25Ool00005Ool007ooOol00008Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`02Ool2000>
Ool00`00Oomoo`1GOol00`00Oomoo`26Ool00005Ool007ooOol00008Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo0004Ool01000Oomoogoo0`001Goo00<007ooOol03Goo00<007ooOol0
EWoo00<007ooOol0Qgoo00001Goo001oogoo000027oo00@007ooOol0009oo`04001oogoo0002Ool0
1000Oomoo`001Goo00@007ooOol000Moo`03001oogoo00eoo`03001oogoo05Eoo`03001oogoo08Qo
o`000Woo0P002Woo0P0017oo0P0017oo0P000goo10000Woo100017oo00<007ooOol03Goo00<007oo
Ool0E7oo00<007ooOol0RGoo000]Ool2000?Ool00`00Oomoo`1BOol00`00Oomoo`2:Ool002eoo`03
001oogoo00ioo`03001oogoo055oo`03001oogoo08]oo`00;Goo00<007ooOol03Woo00<007ooOol0
D7oo00<007ooOol0S7oo000]Ool00`00Oomoo`0>Ool00`00Oomoo`1?Ool00`00Oomoo`2=Ool002eo
o`8000moo`03001oogoo04moo`03001oogoo08eoo`00;Goo00<007ooOol03Woo00<007ooOol0CWoo
00<007ooOol0SWoo000]Ool00`00Oomoo`0>Ool00`00Oomoo`1=Ool00`00Oomoo`2?Ool002eoo`03
001oogoo00ioo`03001oogoo04aoo`03001oogoo091oo`00;Goo0P0047oo00<007ooOol0BWoo00<0
07ooOol0TGoo000]Ool00`00Oomoo`0?Ool00`00Oomoo`19Ool00`00Oomoo`2BOol002eoo`03001o
ogoo00moo`03001oogoo04Qoo`03001oogoo09=oo`00;Goo00<007ooOol03goo00<007ooOol0Agoo
00<007ooOol0U7oo000]Ool2000@Ool00`00Oomoo`16Ool00`00Oomoo`2EOol002eoo`03001oogoo
00moo`03001oogoo04Eoo`03001oogoo09Ioo`003Woo0P0017oo0P0017oo0P0017oo0P000goo0`00
1Goo00<007ooOol03goo00<007ooOol0A7oo00<007ooOol0Ugoo000=Ool01000Oomoo`000goo0P00
0goo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool00`00Oomo
o`14Ool00`00Oomoo`2GOol000eoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000=o
o`03001oogoo00Aoo`80015oo`03001oogoo049oo`03001oogoo09Qoo`003Goo00@007ooOol000Qo
o`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol017oo00<007ooOol047oo00<007ooOol0
@Goo00<007ooOol0VGoo000=Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Oomoo`04Ool00`00Oomoo`0@Ool00`00Oomoo`10Ool00`00Oomoo`2JOol000ioo`8000Yoo`80
00Aoo`8000=oo`8000Ioo`03001oogoo011oo`03001oogoo041oo`03001oogoo09Yoo`00;Goo0P00
4Goo00<007ooOol0?goo00<007ooOol0Vgoo000]Ool00`00Oomoo`0@Ool00`00Oomoo`0nOol00`00
Oomoo`2LOol002eoo`03001oogoo011oo`03001oogoo03ioo`03001oogoo09aoo`00;Goo00<007oo
Ool04Goo00<007ooOol0?7oo00<007ooOol0WGoo000]Ool2000BOol00`00Oomoo`0kOol00`00Oomo
o`2NOol002eoo`03001oogoo015oo`03001oogoo03Yoo`03001oogoo09moo`00;Goo00<007ooOol0
4Goo00<007ooOol0>Woo00<007ooOol0Wgoo000]Ool00`00Oomoo`0AOol00`00Oomoo`0iOol00`00
Oomoo`2POol002eoo`80019oo`03001oogoo03Qoo`03001oogoo0:5oo`00;Goo00<007ooOol04Goo
00<007ooOol0>7oo00<007ooOol0XGoo000]Ool00`00Oomoo`0AOol00`00Oomoo`0gOol00`00Oomo
o`2ROol002eoo`03001oogoo019oo`03001oogoo03Eoo`03001oogoo0:=oo`00;Goo0P004goo00<0
07ooOol0=Goo00<007ooOol0Xgoo000]Ool00`00Oomoo`0BOol00`00Oomoo`0dOol00`00Oomoo`2T
Ool0009oo`8000Aoo`8000Aoo`8000Aoo`8000=oo`<000=oo`@0009oo`<000Eoo`03001oogoo019o
o`03001oogoo03=oo`03001oogoo0:Eoo`0000Eoo`00Oomoo`0000=oo`8000=oo`04001oogoo0002
Ool01000Oomoo`000goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0
4Woo00<007ooOol0<goo00<007ooOol0YGoo00001Goo001oogoo000027oo00@007ooOol0009oo`04
001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`02Ool2000COol00`00Oomo
o`0bOol00`00Oomoo`2VOol00005Ool007ooOol00008Ool01000Oomoo`000Woo00@007ooOol000=o
o`03001oogoo00Eoo`03001oogoo00<000Eoo`03001oogoo019oo`03001oogoo035oo`03001oogoo
0:Moo`0000Eoo`00Oomoo`0000Qoo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol00Woo
00@007ooOol0009oo`03001oogoo00Eoo`03001oogoo019oo`03001oogoo035oo`03001oogoo0:Mo
o`000Woo0P002Woo0P0017oo0P000goo0P001Goo0P000goo100017oo00<007ooOol04goo00<007oo
Ool0;goo00<007ooOol0Z7oo000]Ool2000DOol00`00Oomoo`0^Ool00`00Oomoo`2YOol002eoo`03
001oogoo01=oo`03001oogoo02ioo`03001oogoo0:Uoo`00;Goo00<007ooOol04goo00<007ooOol0
;Goo00<007ooOol0ZWoo000]Ool00`00Oomoo`0COol00`00Oomoo`0/Ool00`00Oomoo`2[Ool002eo
o`8001Aoo`03001oogoo02aoo`03001oogoo0:]oo`00;Goo00<007ooOol057oo00<007ooOol0:Woo
00<007ooOol0[7oo000]Ool00`00Oomoo`0DOol00`00Oomoo`0YOol00`00Oomoo`2]Ool002eoo`03
001oogoo01Aoo`03001oogoo02Uoo`03001oogoo0:eoo`00;Goo0P005Goo00<007ooOol0:7oo00<0
07ooOol0[Woo000]Ool00`00Oomoo`0DOol00`00Oomoo`0XOol00`00Oomoo`2^Ool002eoo`03001o
ogoo01Eoo`03001oogoo02Ioo`03001oogoo0:moo`00;Goo00<007ooOol05Goo00<007ooOol09Goo
00<007ooOol0/7oo000]Ool2000FOol00`00Oomoo`0UOol00`00Oomoo`2`Ool002eoo`03001oogoo
01Eoo`03001oogoo02Aoo`03001oogoo0;5oo`0027oo0P0017oo0P0017oo0P0017oo0P000goo0`00
0goo0`001Goo00<007ooOol05Goo00<007ooOol08goo00<007ooOol0/Woo0007Ool01000Oomoo`00
0goo0P000goo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
0`00Oomoo`0FOol00`00Oomoo`0ROol00`00Oomoo`2bOol000Moo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo009oo`8001Moo`03001oogoo025o
o`03001oogoo0;=oo`001goo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000goo00<0
07ooOol00Woo0`001Goo00<007ooOol05Woo00<007ooOol08Goo00<007ooOol0/goo0007Ool01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`05Ool0
0`00Oomoo`0FOol00`00Oomoo`0POol00`00Oomoo`2dOol000Qoo`8000Yoo`8000Aoo`8000=oo`80
00Aoo`@000Aoo`8001Moo`03001oogoo01moo`03001oogoo0;Eoo`00;Goo00<007ooOol05goo00<0
07ooOol07Woo00<007ooOol0]Goo000]Ool00`00Oomoo`0GOol00`00Oomoo`0MOol00`00Oomoo`2f
Ool002eoo`03001oogoo01Moo`03001oogoo01aoo`03001oogoo0;Moo`00;Goo0P0067oo00<007oo
Ool077oo00<007ooOol0]goo000]Ool00`00Oomoo`0GOol00`00Oomoo`0KOol00`00Oomoo`2hOol0
02eoo`03001oogoo01Qoo`03001oogoo01Yoo`03001oogoo0;Qoo`00;Goo00<007ooOol067oo00<0
07ooOol06Goo00<007ooOol0^Goo000]Ool2000IOol00`00Oomoo`0HOol00`00Oomoo`2jOol002eo
o`03001oogoo01Qoo`03001oogoo01Qoo`03001oogoo0;Yoo`00;Goo00<007ooOol06Goo00<007oo
Ool05Woo00<007ooOol0^goo000]Ool00`00Oomoo`0JOol00`00Oomoo`0EOol00`00Oomoo`2kOol0
02eoo`8001]oo`03001oogoo01Aoo`03001oogoo0;aoo`00;Goo00<007ooOol06Woo00<007ooOol0
4goo00<007ooOol0_Goo0002Ool20004Ool20004Ool20004Ool20003Ool30004Ool00`00Oomoo`02
Ool30005Ool00`00Oomoo`0KOol00`00Oomoo`0BOol00`00Oomoo`2mOol00005Ool007ooOol00003
Ool20003Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00=oo`03001oogoo00Eoo`03
001oogoo009oo`03001oogoo01]oo`03001oogoo015oo`03001oogoo0;ioo`0000Eoo`00Oomoo`00
00Qoo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol017oo00<007ooOol017oo00<007oo
Ool00Woo0P0077oo00<007ooOol047oo00<007ooOol0_goo00001Goo001oogoo000027oo00@007oo
Ool0009oo`04001oogoo0003Ool00`00Oomoo`04Ool01000Oomoogoo0`001Goo00<007ooOol077oo
00<007ooOol03Woo00<007ooOol0`7oo00001Goo001oogoo000027oo00@007ooOol0009oo`04001o
ogoo0003Ool00`00Oomoo`05Ool01000Oomoo`001goo00<007ooOol077oo00<007ooOol03Goo00<0
07ooOol0`Goo0002Ool2000:Ool20004Ool20003Ool20004Ool40002Ool40004Ool00`00Oomoo`0M
Ool00`00Oomoo`0;Ool00`00Oomoo`32Ool002eoo`8001ioo`03001oogoo00Yoo`03001oogoo0<=o
o`00;Goo00<007ooOol07Woo00<007ooOol027oo00<007ooOol0a7oo000]Ool00`00Oomoo`0OOol0
0`00Oomoo`06Ool00`00Oomoo`35Ool002eoo`03001oogoo021oo`8000Eoo`03001oogoo0<Ioo`00
;Goo0P008Woo1P00bGoo000]Ool00`00Oomoo`3`Ool002eoo`03001oogoo0?1oo`00;Goo00<007oo
Ool0l7oo000]Ool00`00Oomoo`3`Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.8234, -0.00025123, \
0.0847812, 1.26905}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["An example: eight lineages", "SubsubsectionIcon"],

Cell["Now, consider a genealogy connecting eight lineages:", "Text"],

Cell[BoxData[
    \(\(tr = 
        Node[{a, b, c, d, e, f, g, 
            h}, {2.3}, {Node[{a, b}, {0.4}, {Node[{a}, {0}, {}], 
                Node[{b}, {0}, {}]}], 
            Node[{c, d, e, f, g, 
                h}, {1.8}, {Node[{c, d}, {1}, {Node[{c}, {0}, {}], 
                    Node[{d}, {0}, {}]}], 
                Node[{e, f, g, 
                    h}, {1.7}, {Node[{e, f, g}, {1.5}, {Node[{e}, {0}, {}], 
                        Node[{f, g}, {0}, {Node[{f}, {0}, {}], 
                            Node[{g}, {0}, {}]}]}], 
                    Node[{h}, {0}, {}]}]}]}];\)\)], "Input",
  CellLabel->"In[332]:="],

Cell["\<\
The generating function is calculated quickly, but is nevertheless \
a complicated expression.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[mgf = MomentGeneratingFunction[tr, \[Omega], \[Theta]]; 
      Short[mgf]]\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(0.883333333333212067`\ Second\), ",", 
        TagBox[\(\(\(2\ \((\(\[LeftSkeleton]1\[RightSkeleton] + \
\[LeftSkeleton]1\[RightSkeleton]\)\/\[LeftSkeleton]1\[RightSkeleton] + 2\/\
\[LeftSkeleton]1\[RightSkeleton])\)\)\/\(7\ \[LeftSkeleton]1\[RightSkeleton]\ \
\((1 - \(\[Theta]\ \((\[LeftSkeleton]1\[RightSkeleton])\)\)\/\(7\ \((6 + \
\[Theta])\)\))\)\) + \[LeftSkeleton]1\[RightSkeleton] + \[LeftSkeleton]1\
\[RightSkeleton]\/\[LeftSkeleton]1\[RightSkeleton]\)\/\(4\ \((7 + \[Theta])\)\
\ \((1 - \(\[Theta]\ \((\[Omega][{a}] + \[LeftSkeleton]6\[RightSkeleton] + \
\[Omega][{h}])\)\)\/\(8\ \((7 + \[Theta])\)\))\)\)\),
          Short]}], "}"}]], "Output",
  CellLabel->"Out[58]="]
}, Closed]],

Cell["The overall probability of this ordered topology:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mgf /. \[Omega][_] :> 1 // Factor\)], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    \(1\/66150\)], "Output",
  CellLabel->"Out[60]="]
}, Closed]],

Cell["The probability that there are no mutations:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mgf /. \[Omega][_] :> 0 // Factor\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \(8\/\(105\ \((1 + \[Theta])\)\ \((2 + \[Theta])\)\ \((3 + \[Theta])\)\ \
\((4 + \[Theta])\)\ \((5 + \[Theta])\)\ \((6 + \[Theta])\)\ \((7 + \
\[Theta])\)\)\)], "Output",
  CellLabel->"Out[61]="]
}, Closed]],

Cell["\<\
The generating functuon for the number of mutations in the \
leaves:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mL = \(mgf /. \[Omega][{_}] :> \[Nu]\) /. \[Omega][_] :> 1 // 
        Factor\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \(\(-\(\((\(-2592000\) - 2241000\ \[Theta] - 765150\ \[Theta]\^2 - 
            129233\ \[Theta]\^3 - 10820\ \[Theta]\^4 - 360\ \[Theta]\^5 + 
            2241000\ \[Theta]\ \[Nu] + 1530300\ \[Theta]\^2\ \[Nu] + 
            387699\ \[Theta]\^3\ \[Nu] + 43280\ \[Theta]\^4\ \[Nu] + 
            1800\ \[Theta]\^5\ \[Nu] - 765150\ \[Theta]\^2\ \[Nu]\^2 - 
            387699\ \[Theta]\^3\ \[Nu]\^2 - 64920\ \[Theta]\^4\ \[Nu]\^2 - 
            3600\ \[Theta]\^5\ \[Nu]\^2 + 129233\ \[Theta]\^3\ \[Nu]\^3 + 
            43280\ \[Theta]\^4\ \[Nu]\^3 + 3600\ \[Theta]\^5\ \[Nu]\^3 - 
            10820\ \[Theta]\^4\ \[Nu]\^4 - 1800\ \[Theta]\^5\ \[Nu]\^4 + 
            360\ \[Theta]\^5\ \[Nu]\^5)\)/\((180\ \((\(-12\) - \[Theta] + \
\[Theta]\ \[Nu])\)\ \((\(-10\) - \[Theta] + \[Theta]\ \[Nu])\)\ \((\(-7\) - \
\[Theta] + \[Theta]\ \[Nu])\)\^2\ \((\(-6\) - \[Theta] + \[Theta]\ \
\[Nu])\)\^2\ \((\(-5\) - \[Theta] + \[Theta]\ \[Nu])\)\ \((\(-3\) - \[Theta] \
+ \[Theta]\ \[Nu])\)\ \((\(-15\) - 2\ \[Theta] + 
                2\ \[Theta]\ \[Nu])\)\ \((\(-20\) - 3\ \[Theta] + 
                3\ \[Theta]\ \[Nu])\))\)\)\)\)], "Output",
  CellLabel->"Out[63]="]
}, Closed]],

Cell["\<\
The chance that there are no mutations in the leaves, conditional \
on this topology:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(mL /. \[Nu] \[Rule] 0\)\/\(mL /. \[Nu] \[Rule] 1\) // 
      Factor\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(\(735\ \((2592000 + 2241000\ \[Theta] + 765150\ \[Theta]\^2 + 129233\ \
\[Theta]\^3 + 10820\ \[Theta]\^4 + 360\ \[Theta]\^5)\)\)\/\(2\ \((3 + \
\[Theta])\)\ \((5 + \[Theta])\)\ \((6 + \[Theta])\)\^2\ \((7 + \[Theta])\)\^2\
\ \((10 + \[Theta])\)\ \((12 + \[Theta])\)\ \((15 + 2\ \[Theta])\)\ \((20 + 3\
\ \[Theta])\)\)\)], "Output",
  CellLabel->"Out[66]="]
}, Closed]],

Cell["The first few cumulants of the # of mutations in the leaves:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tt = 
      Table[D[Log[\(mL /. \[Nu] \[Rule] \[ExponentialE]\^z\)\/\(mL /. \[Nu] \
\[Rule] 1\)], {z, j}] /. z \[Rule] 0 // Factor, {j, 0, 4}]\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \({0, \(169\ \[Theta]\)\/224, \(\[Theta]\ \((5110560 + 999769\ \
\[Theta])\)\)\/6773760, \(\[Theta]\ \((4769856000 + 2799353200\ \[Theta] + \
471164501\ \[Theta]\^2)\)\)\/6322176000, \(1\/191182602240000\) \((\[Theta]\ \
\((144240445440000 + 197522361792000\ \[Theta] + 
                85488087061440\ \[Theta]\^2 + 
                12803159464951\ \[Theta]\^3)\))\)}\)], "Output",
  CellLabel->"Out[69]="]
}, Closed]],

Cell["\<\
Calculating particular probabilities is still slow, and increases \
catastrophically with the number of mutations.  For example, suppose we have \
the following numbers of mutations:\
\>", "Text"],

Cell[BoxData[
    \(j\_{a, b} = 4, j\_{c, d, e, f, g, h} = 2, \ j\_{c, d} = 2, \ 
    j\_{e, f, g, h} = 3\)], "DisplayMath"],

Cell["\<\
It is most efficient to eliminate first those variables that \
correspond to the fewest mutations: then, the multiple derivatives are \
carried out on simpler expressions.  The probability of the above topology, \
and this mutational configuration, is:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      m3 = mgf /. {\[Omega][{_}] \[Rule] 0, \[Omega][{f, g}] \[Rule] 
              0, \[Omega][{e, f, g}] \[Rule] 0}; \n
      m4 = D[m3, {\[Omega][{c, d}], 2}] /. {\[Omega][{c, d}] \[Rule] 0}; \n
      m5 = D[m4, {\[Omega][{c, d, e, f, g, h}], 
              2}] /. {\[Omega][{c, d, e, f, g, h}] \[Rule] 0}; \n
      m6 = D[m5, {\[Omega][{e, f, g, h}], 
              3}] /. {\[Omega][{e, f, g, h}] \[Rule] 0}; \n
      m7 = D[m6, {\[Omega][{a, b}], 4}] /. {\[Omega][{a, b}] \[Rule] 0}; \n
      m8 = m7 // Factor]\)], "Input",
  CellLabel->"In[89]:="],

Cell[BoxData[
    \({31.0500000000001818`\ Second, \((\[Theta]\^11\ \
\((2852369099438024756035584000000 + 
                24162495814875315635082362880000\ \[Theta] + 
                97686871984612738806640902144000\ \[Theta]\^2 + 
                250971169902493091294295797760000\ \[Theta]\^3 + 
                460269839985414347205338193838080\ \[Theta]\^4 + 
                641706673240168210089632298977280\ \[Theta]\^5 + 
                707245953753463838512370447680512\ \[Theta]\^6 + 
                632591323016584294250386880739840\ \[Theta]\^7 + 
                467778137895451424837341620921600\ \[Theta]\^8 + 
                289835054006894929325991524254464\ \[Theta]\^9 + 
                151958568429710512457958283527552\ \[Theta]\^10 + 
                67899001382131127543792632524736\ \[Theta]\^11 + 
                25986119522242579135151486263264\ \[Theta]\^12 + 
                8545972326238218161356354243560\ \[Theta]\^13 + 
                2419022244327028538575874249044\ \[Theta]\^14 + 
                589450881497221955238435781042\ \[Theta]\^15 + 
                123483911190968335536436304481\ \[Theta]\^16 + 
                22175192838680929198066937674\ \[Theta]\^17 + 
                3397686258774393704780092105\ \[Theta]\^18 + 
                441160292521576573740052674\ \[Theta]\^19 + 
                48081136691086603209174802\ \[Theta]\^20 + 
                4341318580505819450778436\ \[Theta]\^21 + 
                318875911552754554678974\ \[Theta]\^22 + 
                18564782450196657098830\ \[Theta]\^23 + 
                824077697852548221229\ \[Theta]\^24 + 
                26195673689114502042\ \[Theta]\^25 + 
                530960429710751269\ \[Theta]\^26 + 
                5154819515316334\ \[Theta]\^27)\))\)/\((441082908000000\ \((1 \
+ \[Theta])\)\^7\ \((2 + \[Theta])\)\^10\ \((3 + \[Theta])\)\^8\ \((4 + \
\[Theta])\)\^7\ \((5 + \[Theta])\)\^7\ \((6 + \[Theta])\)\^5\ \((7 + \
\[Theta])\))\)}\)], "Output",
  CellLabel->"Out[89]="]
}, Closed]],

Cell["This is the likelihood of \[Theta]:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[m8, {\[Theta], 0, 10}];\)\)], "Input",
  CellLabel->"In[88]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 4.27907e+06 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .1003 -33 -6.25 ]
[.01131 .1003 0 6.25 ]
[.01131 .18588 -33 -6.25 ]
[.01131 .18588 0 6.25 ]
[.01131 .27146 -33 -6.25 ]
[.01131 .27146 0 6.25 ]
[.01131 .35704 -33 -6.25 ]
[.01131 .35704 0 6.25 ]
[.01131 .44262 -33 -6.25 ]
[.01131 .44262 0 6.25 ]
[.01131 .5282 -45 -6.25 ]
[.01131 .5282 0 6.25 ]
[.01131 .61379 -45 -6.25 ]
[.01131 .61379 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .1003 m
.03006 .1003 L
s
gsave
.01131 .1003 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.02381 .18588 m
.03006 .18588 L
s
gsave
.01131 .18588 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.02381 .27146 m
.03006 .27146 L
s
gsave
.01131 .27146 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(6) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.02381 .35704 m
.03006 .35704 L
s
gsave
.01131 .35704 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(8) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.02381 .44262 m
.03006 .44262 L
s
gsave
.01131 .44262 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .5282 m
.03006 .5282 L
s
gsave
.01131 .5282 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .61379 m
.03006 .61379 L
s
gsave
.01131 .61379 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.125 Mabswid
.02381 .03611 m
.02756 .03611 L
s
.02381 .05751 m
.02756 .05751 L
s
.02381 .0789 m
.02756 .0789 L
s
.02381 .12169 m
.02756 .12169 L
s
.02381 .14309 m
.02756 .14309 L
s
.02381 .16448 m
.02756 .16448 L
s
.02381 .20727 m
.02756 .20727 L
s
.02381 .22867 m
.02756 .22867 L
s
.02381 .25006 m
.02756 .25006 L
s
.02381 .29285 m
.02756 .29285 L
s
.02381 .31425 m
.02756 .31425 L
s
.02381 .33565 m
.02756 .33565 L
s
.02381 .37844 m
.02756 .37844 L
s
.02381 .39983 m
.02756 .39983 L
s
.02381 .42123 m
.02756 .42123 L
s
.02381 .46402 m
.02756 .46402 L
s
.02381 .48541 m
.02756 .48541 L
s
.02381 .50681 m
.02756 .50681 L
s
.02381 .5496 m
.02756 .5496 L
s
.02381 .57099 m
.02756 .57099 L
s
.02381 .59239 m
.02756 .59239 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.03944 .01472 L
.04011 .01472 L
.04132 .01472 L
.04262 .01472 L
.04327 .01472 L
.04396 .01472 L
.04519 .01472 L
.04588 .01472 L
.04652 .01472 L
.04722 .01472 L
.04797 .01472 L
.04862 .01472 L
.04933 .01472 L
.05061 .01472 L
.05186 .01472 L
.05302 .01472 L
.05414 .01473 L
.05519 .01473 L
.05634 .01473 L
.05759 .01474 L
.05882 .01475 L
.06012 .01476 L
.06244 .01479 L
.0638 .01481 L
.06509 .01484 L
.06748 .01491 L
.07007 .01501 L
.07287 .01516 L
.07532 .01535 L
.07792 .0156 L
.08013 .01588 L
.08257 .01626 L
.08805 .01746 L
.09113 .0184 L
.09394 .01944 L
.0994 .02208 L
Mistroke
.10458 .02544 L
.10962 .02963 L
.11419 .0343 L
.12443 .04806 L
.13391 .06514 L
.14282 .08505 L
.18143 .20649 L
.22248 .3602 L
.24295 .42987 L
.26202 .48547 L
.28156 .53127 L
.30005 .56374 L
.30982 .57673 L
.32044 .58772 L
.32512 .59158 L
.33009 .59503 L
.33444 .59754 L
.33901 .59966 L
.34135 .60055 L
.34391 .60138 L
.34627 .60201 L
.3484 .60247 L
.35094 .60289 L
.35233 .60305 L
.35365 .60317 L
.35486 .60325 L
.35599 .6033 L
.35722 .60332 L
.35852 .60331 L
.35965 .60327 L
.36069 .60321 L
.36189 .60311 L
.36302 .603 L
.36504 .60273 L
.36723 .60236 L
.37221 .60117 L
.37681 .59969 L
.38642 .59547 L
.39545 .59025 L
.41604 .57446 L
.4547 .53433 L
.49581 .48353 L
.5354 .43238 L
.57348 .38444 L
.614 .33679 L
.65302 .29516 L
.69448 .25584 L
.73443 .22268 L
.77287 .19487 L
.81375 .16928 L
Mistroke
.85312 .1481 L
.89098 .13053 L
.93129 .11446 L
.97008 .10121 L
.97619 .0993 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[88]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol005aoo`@002ao
o`<002]oo`8002eoo`8002Uoo`<000Aoo`8000=oo`00GGoo00<007ooOol0;Goo00<007ooOol0:Goo
00@007ooOol002]oo`04001oogoo000YOol00`00Oomoo`02Ool01000Oomoo`000Woo001NOol00`00
Oomoo`0ZOol4000ZOol01000Oomoo`00:goo00@007ooOol002Uoo`03001oogoo009oo`04001oogoo
0002Ool005moo`03001oogoo02Uoo`03001oo`0002]oo`<002eoo`8002Yoo`03001oogoo009oo`04
001oogoo0002Ool005aoo`04001oogoo000[Ool00`00Ool0000[Ool00`00Oomoo`0/Ool01000Oomo
o`00:Goo00<007ooOol00Woo00@007ooOol0009oo`00GGoo0P00;Goo0P00;7oo0`00;7oo0P00:Goo
0P001Goo0P000goo000`Ool00`00Oomoo`3]Ool0031oo`03001oogoo0>eoo`00<7oo00<007ooOol0
kGoo000`Ool00`00Oomoo`3]Ool002YoooD0005oo`00<7oo00<007ooOol027oo00<007ooOol00Woo
0`0017oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol017oo000`Ool0
0`00Oomoo`0@Ool2003KOol0031oo`03001oogoo019oo`03001oogoo0=Qoo`00<7oo00<007ooOol0
4goo00<007ooOol0egoo000`Ool00`00Oomoo`0COol00`00Oomoo`3GOol0031oo`03001oogoo01Ao
o`03001oogoo0=Ioo`00<7oo00<007ooOol057oo00<007ooOol0eWoo000`Ool00`00Oomoo`0EOol0
0`00Oomoo`3EOol0031oo`03001oogoo01Eoo`03001oogoo0=Eoo`00<7oo00<007ooOol05Woo00<0
07ooOol0e7oo000`Ool00`00Oomoo`0FOol00`00Oomoo`3DOol0031oo`03001oogoo01Moo`03001o
ogoo0==oo`00<7oo00<007ooOol05goo00<007ooOol0dgoo000`Ool00`00Oomoo`0HOol00`00Oomo
o`3BOol0031oo`03001oogoo01Uoo`03001oogoo0=5oo`00<7oo00<007ooOol06Goo00<007ooOol0
dGoo000=Ool40002Ool01@00Oomoogoo00000Woo0`0017oo0P003Goo00<007ooOol06Woo00<007oo
Ool0d7oo000>Ool00`00Oomoo`03Ool00`00Ool00004Ool00`00Oomoo`02Ool01000Oomoo`0037oo
00<007ooOol06Woo00<007ooOol0d7oo000?Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool01000Oomoo`0037oo00<007ooOol06Woo00<007ooOol0d7oo000@Ool01`00Oomoogoo001o
o`0000Aoo`03001oogoo009oo`04001oogoo000<Ool00`00Oomoo`0KOol00`00Oomoo`37Ool20006
Ool000eoo`04001oogoo0002Ool01@00Oomoogoo00000goo00<007ooOol00Woo00@007ooOol000ao
o`8001aoo`03001oogoo0<Eoo`8000Qoo`003Woo0P002Woo0P001Goo0P003Goo00<007ooOol06goo
00<007ooOol0`Woo0`002Woo000[Ool30002Ool00`00Oomoo`0LOol00`00Oomoo`2nOol3000=Ool0
02Ioo`@00004Ool007oo0002Ool00`00Oomoo`0LOol00`00Oomoo`2kOol3000@Ool002aoo`05001o
ogooOol0000NOol00`00Oomoo`2hOol3000COol002]oo`03001oo`00009oo`03001oogoo01eoo`03
001oogoo0;Eoo`8001Ioo`00:goo0`000Woo00<007ooOol07Goo00<007ooOol0/Woo0`0067oo000`
Ool00`00Oomoo`0MOol00`00Oomoo`2`Ool2000KOol0031oo`03001oogoo01eoo`03001oogoo0:eo
o`<001eoo`00<7oo00<007ooOol07Woo00<007ooOol0ZWoo0P0087oo000`Ool00`00Oomoo`0NOol0
0`00Oomoo`2WOol3000ROol0031oo`03001oogoo01ioo`03001oogoo0:Eoo`8002Eoo`00<7oo00<0
07ooOol07goo00<007ooOol0XWoo0P009goo000`Ool00`00Oomoo`0OOol00`00Oomoo`2POol2000Y
Ool0031oo`03001oogoo01moo`03001oogoo09moo`03001oogoo02Uoo`00<7oo00<007ooOol087oo
00<007ooOol0W7oo0P00;7oo000`Ool00`00Oomoo`0POol00`00Oomoo`2JOol2000^Ool000ioo`<0
009oo`05001oogooOol00002Ool30004Ool2000=Ool00`00Oomoo`0POol00`00Oomoo`2IOol00`00
Oomoo`0^Ool000moo`03001oogoo009oo`03001oo`0000Aoo`03001oogoo009oo`04001oogoo000<
Ool00`00Oomoo`0POol00`00Oomoo`2GOol2000aOol000eoo`@000Aoo`03001oogoo00=oo`03001o
ogoo009oo`04001oogoo000<Ool00`00Oomoo`0QOol00`00Oomoo`2EOol00`00Oomoo`0aOol000eo
o`03001oo`0000Aoo`03001oo`0000Aoo`03001oogoo009oo`04001oogoo000<Ool00`00Oomoo`0Q
Ool00`00Oomoo`2DOol00`00Oomoo`0bOol000eoo`03001oo`0000=oo`05001oogooOol00003Ool0
0`00Oomoo`02Ool01000Oomoo`0037oo0P008Woo00<007ooOol0TWoo0P00=Goo000>Ool2000:Ool2
0005Ool2000=Ool00`00Oomoo`0ROol00`00Oomoo`2@Ool00`00Oomoo`0eOol002]oo`<0009oo`03
001oogoo029oo`03001oogoo08ioo`8003Qoo`009Woo100000Aoo`00Ool0009oo`03001oogoo029o
o`03001oogoo08eoo`03001oogoo03Qoo`00;7oo00D007ooOomoo`0002Eoo`03001oogoo08Yoo`80
03]oo`00:goo00<007oo00000Woo00<007ooOol08goo00<007ooOol0RGoo00<007ooOol0>goo000[
Ool30002Ool00`00Oomoo`0SOol00`00Oomoo`28Ool00`00Oomoo`0lOol0031oo`03001oogoo02=o
o`03001oogoo08Ioo`8003moo`00<7oo00<007ooOol097oo00<007ooOol0Q7oo00<007ooOol0?goo
000`Ool00`00Oomoo`0TOol00`00Oomoo`22Ool20012Ool0031oo`03001oogoo02Aoo`03001oogoo
085oo`03001oogoo049oo`00<7oo00<007ooOol097oo00<007ooOol0P7oo00<007ooOol0@goo000`
Ool00`00Oomoo`0UOol00`00Oomoo`1nOol00`00Oomoo`14Ool0031oo`03001oogoo02Eoo`03001o
ogoo07eoo`03001oogoo04Eoo`00<7oo00<007ooOol09Goo00<007ooOol0O7oo00<007ooOol0AWoo
000`Ool00`00Oomoo`0VOol00`00Oomoo`1jOol00`00Oomoo`17Ool0031oo`03001oogoo02Ioo`03
001oogoo07Uoo`03001oogoo04Qoo`003Woo0P000goo00D007ooOomoo`00009oo`<000Aoo`8000eo
o`03001oogoo02Ioo`03001oogoo07Moo`8004]oo`003Goo00@007ooOol000=oo`03001oo`0000Ao
o`03001oogoo009oo`04001oogoo000<Ool00`00Oomoo`0VOol00`00Oomoo`1fOol00`00Oomoo`1;
Ool000eoo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`0037oo00<0
07ooOol09goo00<007ooOol0M7oo00<007ooOol0C7oo000=Ool30004Ool00`00Ool00004Ool00`00
Oomoo`02Ool01000Oomoo`0037oo0P00:7oo00<007ooOol0Lgoo00<007ooOol0CGoo000=Ool00`00
Oomoo`03Ool01@00Oomoogoo00000goo00<007ooOol00Woo00@007ooOol000aoo`03001oogoo02Mo
o`03001oogoo075oo`80051oo`003Woo0`002Goo0P001Goo0P0027oo0`000Woo00<007ooOol09goo
00<007ooOol0L7oo00<007ooOol0D7oo000VOol4000017oo001oo`000Woo00<007ooOol0:7oo00<0
07ooOol0KWoo00<007ooOol0DGoo000/Ool01@00Oomoogoo0000:Woo00<007ooOol0KGoo00<007oo
Ool0DWoo000[Ool00`00Ool00002Ool00`00Oomoo`0XOol00`00Oomoo`1/Ool00`00Oomoo`1COol0
02]oo`<0009oo`03001oogoo02Uoo`03001oogoo06Yoo`03001oogoo05Aoo`00<7oo00<007ooOol0
:Goo00<007ooOol0JWoo00<007ooOol0E7oo000`Ool00`00Oomoo`0YOol00`00Oomoo`1YOol00`00
Oomoo`1EOol0031oo`03001oogoo02Uoo`03001oogoo06Qoo`03001oogoo05Ioo`00<7oo00<007oo
Ool0:Woo00<007ooOol0IWoo00<007ooOol0Egoo000`Ool00`00Oomoo`0ZOol00`00Oomoo`1UOol0
0`00Oomoo`1HOol0031oo`03001oogoo02Yoo`03001oogoo06Aoo`03001oogoo05Uoo`00<7oo00<0
07ooOol0:Woo00<007ooOol0Hgoo00<007ooOol0FWoo000`Ool00`00Oomoo`0[Ool00`00Oomoo`1Q
Ool00`00Oomoo`1KOol0031oo`03001oogoo02]oo`03001oogoo061oo`03001oogoo05aoo`00<7oo
00<007ooOol0:goo00<007ooOol0Ggoo00<007ooOol0GGoo000`Ool00`00Oomoo`0/Ool00`00Oomo
o`1NOol00`00Oomoo`1MOol000ioo`8000=oo`05001oogooOol00002Ool30004Ool2000=Ool00`00
Oomoo`0/Ool00`00Oomoo`1MOol00`00Oomoo`1NOol000eoo`04001oogoo0003Ool00`00Ool00004
Ool00`00Oomoo`02Ool01000Oomoo`0037oo00<007ooOol0;7oo00<007ooOol0G7oo00<007ooOol0
Ggoo000=Ool01000Oomoo`0017oo00<007ooOol00goo00<007ooOol00Woo00@007ooOol000aoo`03
001oogoo02aoo`03001oogoo05]oo`03001oogoo061oo`003Woo0P0017oo00<007oo000017oo00<0
07ooOol00Woo00@007ooOol000aoo`8002ioo`03001oogoo05Uoo`03001oogoo065oo`003Goo00@0
07ooOol0009oo`05001oogooOol00003Ool00`00Oomoo`02Ool01000Oomoo`0037oo00<007ooOol0
;Goo00<007ooOol0F7oo00<007ooOol0HWoo000>Ool2000:Ool20005Ool20008Ool30002Ool00`00
Oomoo`0]Ool00`00Oomoo`1HOol00`00Oomoo`1ROol002Ioo`@00004Ool007oo0002Ool00`00Oomo
o`0]Ool00`00Oomoo`1GOol00`00Oomoo`1SOol002aoo`05001oogooOol0000`Ool00`00Oomoo`1E
Ool00`00Oomoo`1TOol002]oo`03001oo`00009oo`03001oogoo02ioo`03001oogoo05Aoo`03001o
ogoo06Eoo`00:goo0`000Woo00<007ooOol0;Woo00<007ooOol0Dgoo00<007ooOol0IWoo000`Ool0
0`00Oomoo`0_Ool00`00Oomoo`1AOol00`00Oomoo`1WOol0031oo`03001oogoo02moo`03001oogoo
055oo`03001oogoo06Moo`00<7oo00<007ooOol0;goo00<007ooOol0D7oo00<007ooOol0J7oo000`
Ool00`00Oomoo`0`Ool00`00Oomoo`1>Ool00`00Oomoo`1YOol0031oo`03001oogoo031oo`03001o
ogoo04eoo`03001oogoo06Yoo`00<7oo00<007ooOol0<7oo00<007ooOol0CGoo00<007ooOol0JWoo
000`Ool00`00Oomoo`0`Ool00`00Oomoo`1<Ool00`00Oomoo`1[Ool0031oo`03001oogoo035oo`03
001oogoo04Yoo`03001oogoo06aoo`00<7oo00<007ooOol0<Goo00<007ooOol0BGoo00<007ooOol0
KGoo000`Ool00`00Oomoo`0aOol00`00Oomoo`19Ool00`00Oomoo`1]Ool0031oo`03001oogoo039o
o`03001oogoo04Moo`03001oogoo06ioo`003Goo0`000goo00D007ooOomoo`00009oo`<000Aoo`80
00eoo`03001oogoo039oo`03001oogoo04Ioo`03001oogoo06moo`003Woo00<007ooOol00goo00<0
07oo000017oo00<007ooOol00Woo00@007ooOol000aoo`03001oogoo039oo`03001oogoo04Eoo`03
001oogoo071oo`003Woo00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo00@007ooOol0
00aoo`03001oogoo03=oo`03001oogoo04Aoo`03001oogoo071oo`003Woo00<007ooOol00goo00<0
07oo000017oo00<007ooOol00Woo00@007ooOol000aoo`8003Aoo`03001oogoo04=oo`03001oogoo
075oo`003Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo009oo`04001oogoo000<
Ool00`00Oomoo`0cOol00`00Oomoo`12Ool00`00Oomoo`1bOol000eoo`8000]oo`8000Eoo`8000Uo
o`05001oogooOol0000fOol00`00Oomoo`10Ool00`00Oomoo`1cOol002Ioo`@0009oo`05001oogoo
Ool0000fOol00`00Oomoo`0oOol00`00Oomoo`1dOol002aoo`05001oogooOol0000fOol00`00Oomo
o`0nOol00`00Oomoo`1eOol002eoo`04001oogoo000gOol00`00Oomoo`0mOol00`00Oomoo`1eOol0
02]oo`<0009oo`03001oogoo03Eoo`03001oogoo03aoo`03001oogoo07Ioo`00<7oo00<007ooOol0
=Goo00<007ooOol0>goo00<007ooOol0Mgoo000`Ool00`00Oomoo`0fOol00`00Oomoo`0iOol00`00
Oomoo`1hOol0031oo`03001oogoo03Ioo`03001oogoo03Qoo`03001oogoo07Uoo`00<7oo00<007oo
Ool0=Woo00<007ooOol0=goo00<007ooOol0NWoo000`Ool00`00Oomoo`0gOol00`00Oomoo`0fOol0
0`00Oomoo`1jOol0031oo`03001oogoo03Moo`03001oogoo03Eoo`03001oogoo07]oo`00<7oo00<0
07ooOol0>7oo00<007ooOol0<goo00<007ooOol0O7oo000`Ool00`00Oomoo`0hOol00`00Oomoo`0b
Ool00`00Oomoo`1mOol0031oo`03001oogoo03Uoo`03001oogoo035oo`03001oogoo07eoo`00<7oo
00<007ooOol0>Goo00<007ooOol0<7oo00<007ooOol0OWoo000`Ool00`00Oomoo`0jOol00`00Oomo
o`0^Ool00`00Oomoo`1oOol00004Ool000000004Ool20003Ool40002Ool01@00Oomoogoo00000Woo
0`0017oo0P003Goo00<007ooOol0>Woo00<007ooOol0;Goo00<007ooOol0P7oo0002Ool00`00Oomo
o`03Ool20004Ool00`00Oomoo`03Ool00`00Ool00004Ool00`00Oomoo`02Ool01000Oomoo`0037oo
00<007ooOol0>Woo00<007ooOol0;7oo00<007ooOol0PGoo0002Ool00`00Oomoo`0:Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`0037oo00<007ooOol0>goo00<007oo
Ool0:goo00<007ooOol0PGoo0002Ool00`00Oomoo`0;Ool01`00Oomoogoo001oo`0000Aoo`03001o
ogoo009oo`04001oogoo000<Ool2000lOol00`00Oomoo`0ZOol00`00Oomoo`22Ool0009oo`03001o
ogoo00Qoo`04001oogoo0002Ool01@00Oomoogoo00000goo00<007ooOol00Woo00@007ooOol000ao
o`03001oogoo03aoo`03001oogoo02Qoo`03001oogoo08=oo`0000=oo`0000002goo0P002Woo0P00
1Goo0P002Goo00D007ooOomoo`0003ioo`03001oogoo02Moo`03001oogoo08Aoo`009Woo10000Woo
00D007ooOomoo`0003moo`03001oogoo02Eoo`03001oogoo08Eoo`00;7oo00D007ooOomoo`0003mo
o`03001oogoo02Aoo`03001oogoo08Ioo`00;Goo00@007ooOol0041oo`03001oogoo029oo`03001o
ogoo08Moo`00:goo0`000Woo00<007ooOol0?Woo00<007ooOol08Goo00<007ooOol0R7oo000`Ool0
0`00Oomoo`0oOol00`00Oomoo`0OOol00`00Oomoo`29Ool0031oo`03001oogoo03moo`03001oogoo
01ioo`03001oogoo08Yoo`00<7oo00<007ooOol0@7oo00<007ooOol077oo00<007ooOol0Rgoo000`
Ool00`00Oomoo`11Ool00`00Oomoo`0JOol00`00Oomoo`2<Ool0031oo`03001oogoo049oo`03001o
ogoo01Qoo`03001oogoo08eoo`00<7oo00<007ooOol0@goo00<007ooOol05Goo0P00T7oo000`Ool0
0`00Oomoo`13Ool00`00Oomoo`0COol2002BOol0031oo`03001oogoo04Aoo`03001oogoo015oo`03
001oogoo099oo`00<7oo00<007ooOol0AGoo00<007ooOol03goo00<007ooOol0Tgoo000`Ool00`00
Oomoo`16Ool00`00Oomoo`0=Ool00`00Oomoo`2DOol0031oo`03001oogoo04Moo`<000Yoo`8009Mo
o`0000Aoo`00000000Aoo`8000Aoo`<0009oo`05001oogooOol00002Ool30004Ool2000=Ool00`00
Oomoo`1:Ool30003Ool4002IOol0009oo`03001oogoo00=oo`8000Eoo`03001oogoo009oo`03001o
o`0000Aoo`03001oogoo009oo`04001oogoo000<Ool00`00Oomoo`1=Ool4002LOol0009oo`03001o
ogoo00Qoo`@000Aoo`03001oogoo00=oo`03001oogoo009oo`04001oogoo000<Ool00`00Oomoo`3]
Ool0009oo`03001oogoo00Qoo`03001oo`0000Aoo`03001oo`0000Aoo`03001oogoo009oo`04001o
ogoo000<Ool2003^Ool0009oo`03001oogoo00Qoo`03001oo`0000=oo`05001oogooOol00003Ool0
0`00Oomoo`02Ool01000Oomoo`0037oo00<007ooOol0kGoo00000goo0000000;Ool2000:Ool20005
Ool20009Ool00`00Oomoo`3aOol002Ioo`@0009oo`03001oogoo0?5oo`00;7oo00<007ooOol0lGoo
000]Ool00`00Oomoo`3`Ool002]oo`<00?9oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.06312, -1.73023, \
0.0429294, 9.55468}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{1084, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 54, 0, 24, "SubsubsectionIcon"],
Cell[1796, 53, 176, 4, 22, "Text"],

Cell[CellGroupData[{
Cell[1997, 61, 325, 8, 42, "Input"],
Cell[2325, 71, 780, 12, 159, "Output"]
}, Closed]],
Cell[3120, 86, 51, 0, 18, "Text"],
Cell[3174, 88, 405, 8, 64, "Output"],
Cell[3582, 98, 95, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[3702, 105, 332, 8, 42, "Input"],
Cell[4037, 115, 477, 7, 72, "Output"]
}, Closed]],
Cell[4529, 125, 146, 3, 18, "Text"],

Cell[CellGroupData[{
Cell[4700, 132, 114, 2, 26, "Input"],
Cell[4817, 136, 75, 2, 36, "Output"]
}, Closed]],
Cell[4907, 141, 126, 3, 18, "Text"],

Cell[CellGroupData[{
Cell[5058, 148, 171, 3, 26, "Input"],
Cell[5232, 153, 363, 6, 38, "Output"]
}, Closed]],
Cell[5610, 162, 291, 5, 32, "Text"],
Cell[5904, 169, 73, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[6002, 173, 162, 3, 43, "Input"],
Cell[6167, 178, 166, 3, 38, "Output"]
}, Closed]],
Cell[6348, 184, 218, 5, 18, "Text"],

Cell[CellGroupData[{
Cell[6591, 193, 227, 5, 26, "Input"],
Cell[6821, 200, 302, 5, 36, "Output"]
}, Closed]],
Cell[7138, 208, 354, 7, 32, "Text"],

Cell[CellGroupData[{
Cell[7517, 219, 391, 6, 61, "Input"],
Cell[7911, 227, 248, 4, 40, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[8196, 236, 92, 2, 22, "Input"],
Cell[8291, 240, 17000, 490, 184, 4794, 334, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[25340, 736, 55, 0, 24, "SubsubsectionIcon"],
Cell[25398, 738, 68, 0, 22, "Text"],
Cell[25469, 740, 626, 13, 58, "Input"],
Cell[26098, 755, 118, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[26241, 762, 139, 3, 26, "Input"],
Cell[26383, 767, 730, 12, 76, "Output"]
}, Closed]],
Cell[27128, 782, 65, 0, 18, "Text"],

Cell[CellGroupData[{
Cell[27218, 786, 91, 2, 26, "Input"],
Cell[27312, 790, 67, 2, 36, "Output"]
}, Closed]],
Cell[27394, 795, 60, 0, 18, "Text"],

Cell[CellGroupData[{
Cell[27479, 799, 91, 2, 26, "Input"],
Cell[27573, 803, 213, 4, 38, "Output"]
}, Closed]],
Cell[27801, 810, 92, 3, 18, "Text"],

Cell[CellGroupData[{
Cell[27918, 817, 135, 3, 26, "Input"],
Cell[28056, 822, 1174, 17, 75, "Output"]
}, Closed]],
Cell[29245, 842, 109, 3, 18, "Text"],

Cell[CellGroupData[{
Cell[29379, 849, 127, 3, 42, "Input"],
Cell[29509, 854, 376, 6, 40, "Output"]
}, Closed]],
Cell[29900, 863, 76, 0, 18, "Text"],

Cell[CellGroupData[{
Cell[30001, 867, 200, 4, 43, "Input"],
Cell[30204, 873, 425, 7, 75, "Output"]
}, Closed]],
Cell[30644, 883, 206, 4, 18, "Text"],
Cell[30853, 889, 124, 2, 30, "DisplayMath"],
Cell[30980, 893, 276, 5, 36, "Text"],

Cell[CellGroupData[{
Cell[31281, 902, 582, 11, 106, "Input"],
Cell[31866, 915, 2014, 33, 226, "Output"]
}, Closed]],
Cell[33895, 951, 51, 0, 18, "Text"],

Cell[CellGroupData[{
Cell[33971, 955, 90, 2, 26, "Input"],
Cell[34064, 959, 18534, 573, 184, 6739, 422, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

