(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    358703,       7986]*)
(*NotebookOutlinePosition[    567301,      15271]*)
(*  CellTagsIndexPosition[    567257,      15267]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Introduction", "Subsubsection"],

Cell[CellGroupData[{

Cell["Saving work", "SubsubsectionIcon"],

Cell[TextData[{
  StyleBox["Note",
    FontWeight->"Bold"],
  ": If you work within the Help Browser, changes you make will ",
  StyleBox["NOT",
    FontWeight->"Bold"],
  " be saved.  To save your work, you can make a copy in a new notebook.  \
Choose Style Sheet->Help Browser to get the right format"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Tips", "SubsubsectionIcon"],

Cell[TextData[{
  "For some quick hints on how to use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", look up ",
  ButtonBox["Using Packages:Tips",
    ButtonData:>{
      FrontEnd`FileName[ {
        ParentDirectory[ 
          ParentDirectory[ 
            ParentDirectory[ ]]], "Using packages", "Documentation", 
        "English"}, "UsingMathematica.nb", CharacterEncoding -> 
        "MacintoshRoman"], None},
    ButtonStyle->"Hyperlink"],
  " in the Help Browser"
}], "Text"],

Cell["\<\
More extensive help can be found using the Master Index, or by \
looking through the section on Genealogies:Genealogies:\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Load packages",
  FontColor->RGBColor[1, 0, 0]]], "SubsubsectionIcon"],

Cell["\<\
This loads the packages that will be needed in these \
exercises\
\>", "Text"],

Cell[BoxData[
    \(<< Statistics`; << Graphics`; << Genealogies`Genealogies`;\)], "Input",
  CellLabel->"In[35]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Basic structures", "SubsubsectionIcon"],

Cell[TextData[{
  "This generates a random genealogy, according to the coalescent process.  \
It describes the ancestry of 10 ",
  StyleBox["leaves",
    FontSlant->"Italic"],
  ", {x1,\[Ellipsis]}:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(lvs = {x1, x2, x3, x4, x5, x6, x7, x8, x9, x10};\)\), "\n", 
    \(rg = RandomGenealogy[lvs]\)}], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(Node[
      10, {0.6814628971777537`}, {Node[
          9, {0.6814628971777537`}, {Node[
              8, {0.33894753696113394`}, {Node[x4, {0}, {}], 
                Node[6, {0.24858020659182367`}, {Node[x3, {0}, {}], 
                    Node[x10, {0}, {}]}]}], 
            Node[7, {0.25658995784049987`}, {Node[x1, {0}, {}], 
                Node[5, {0.21751271605564315`}, {Node[
                      3, {0.12561679052953426`}, {Node[x2, {0}, {}], 
                        Node[x5, {0}, {}]}], 
                    Node[4, {0.18286155754690495`}, {Node[
                          1, {0.09750465984208453`}, {Node[x6, {0}, {}], 
                            Node[x8, {0}, {}]}], 
                        Node[2, {0.10834256569991146`}, {Node[x7, {0}, {}], 
                            Node[x9, {0}, {}]}]}]}]}]}]}]\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell["\<\
The structure is a nested set of \
Node[label,{time,\[Ellipsis]},{Node[\[Ellipsis]], Node[\[Ellipsis]]}].  The \
first element names the node.  The second element gives information, such as \
the coalescence time.  The last element lists the descendant nodes.\
\>", \
"Text"],

Cell[TextData[{
  "Note:",
  StyleBox["  Throughout, time is scaled relative to the effective number of \
genes, ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`2  N\_e\)]],
  ".  "
}], "Text",
  FontWeight->"Bold"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plotting genealogies", "SubsubsectionIcon"],

Cell["This plots the genealogy:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[PlotGenealogy[rg]];\)\)], "Input",
  CellLabel->"In[33]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0909091 0.0909091 0.0772542 0.0772542 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.68182 .15451 m
.63636 .07725 L
s
.68182 .15451 m
.72727 .07725 L
s
.86364 .15451 m
.81818 .07725 L
s
.86364 .15451 m
.90909 .07725 L
s
.5 .15451 m
.45455 .07725 L
s
.5 .15451 m
.54545 .07725 L
s
.77273 .23176 m
.68182 .15451 L
s
.77273 .23176 m
.86364 .15451 L
s
.68182 .30902 m
.5 .15451 L
s
.68182 .30902 m
.77273 .23176 L
s
.22727 .15451 m
.18182 .07725 L
s
.22727 .15451 m
.27273 .07725 L
s
.63636 .38627 m
.36364 .07725 L
s
.63636 .38627 m
.68182 .30902 L
s
.18182 .23176 m
.09091 .07725 L
s
.18182 .23176 m
.22727 .15451 L
s
.5 .46353 m
.18182 .23176 L
s
.5 .46353 m
.63636 .38627 L
s
.5 .54078 m
.5 .46353 L
s
[(1)] .66364 .16996 0 0 Mshowa
[(2)] .84545 .16996 0 0 Mshowa
[(3)] .48182 .16996 0 0 Mshowa
[(4)] .75455 .24721 0 0 Mshowa
[(5)] .66364 .32447 0 0 Mshowa
[(6)] .20909 .16996 0 0 Mshowa
[(7)] .61818 .40172 0 0 Mshowa
[(8)] .16364 .24721 0 0 Mshowa
[(9)] .48182 .47898 0 0 Mshowa
[(10)] .48182 .55623 0 0 Mshowa
gsave
.09091 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x4) show
1.000 setlinewidth
grestore
gsave
.18182 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x3) show
1.000 setlinewidth
grestore
gsave
.27273 .0618 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x10) show
1.000 setlinewidth
grestore
gsave
.36364 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x1) show
1.000 setlinewidth
grestore
gsave
.45455 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
1.000 setlinewidth
grestore
gsave
.54545 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x5) show
1.000 setlinewidth
grestore
gsave
.63636 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x6) show
1.000 setlinewidth
grestore
gsave
.72727 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x8) show
1.000 setlinewidth
grestore
gsave
.81818 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x7) show
1.000 setlinewidth
grestore
gsave
.90909 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x9) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[33]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`005?ooool2
o`000003ooooool0003o000000?ooooo0ol0000?ooooo`;o000000?oooooo`000?l000000_ooool3
o`0000gooooo0_l000000ooooooo0000o`000002ooooo`?o00001?ooool2o`0000gooooo0_l00000
0ooooooo0000o`000002ooooo`?o00004?ooool2o`000004ooooool0003o0000ooooo`Go00003ooo
ool2o`000003ooooool0003o000000;ooooo0ol0000@ooooo`;o000000?oooooo`000?l000000_oo
ool3o`00013ooooo0_l000000ooooooo0000o`000002ooooo`?o00004?ooool2o`000003ooooool0
003o000000?ooooo00?o0000ooooooooool03oooool2o`000003ooooool0003o000000;ooooo0_l0
000Iooooo`005Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooool000000_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooool000001?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooool00000
1?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo
00004?ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000004?ooool00ol0
003oooooo`000002ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooo`000002
ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooo`000004ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0Fooooo`005_ooool0
1?l0003oooooooooooooool5o`00017ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0?ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0?ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01Gooooo000Eooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00004Oooool00ol0
003oooooo`000004ooooo`;o00003_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00003Oooool00ol0003oooooo`000004ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooooooool03_ooool00ol0003oooooo`000002ooooo`Co00004Oooool0
0ol0003oooooo`000003ooooo`?o00004Oooool00ol0003oooooo`000005ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooool000000oooool4o`0001Oooooo000Dooooo`;o000000?oooooo`00
0?l000000_ooool00ol0003oooooo`00000@ooooo`;o000000?oooooo`000?l000001Oooool00ol0
003oooooooooo`0:ooooo`;o000000?oooooo`000?l000000oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000cooooo0_l000000ooooooo0000o`000003ooooo`03o`000?oooooo
oooo00oooooo0_l000001Ooooooo0000o`000?oooooo000000?ooooo00?o0000ooooooooool03Ooo
ool2o`000004ooooool0003o0000ooooo`Co00004?ooool2o`000005ooooool0003o0000ooooool0
00004oooool2o`000005ooooool0003o0000ooooool000000oooool00ol0003oooooooooo`0=oooo
o`;o000000?oooooo`000?l000001Oooool00ol0003oooooooooo`0=ooooo`;o000000Goooooo`00
0?l0003oooooo`000003ooooo`03o`000?oooooooooo01Gooooo000Looooo`;o00005_ooool01Ol0
003ooooooooooooooooo000001?ooooo0_l00004ooooo`04o`000?ooooooooooo`0001?ooooo0_l0
000Gooooo`05o`000?ooooooooooooooool000005Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01Kooooo00Go0000ooooooooooooooooo`00000Eooooo`05o`000?oooooooooooooo
ool000005Oooool01Ol0003ooooooooooooooooo000001Oooooo000Mooooo`03o`000?oooooooooo
01Gooooo0ol0000Eooooo`03o`000?oooooooooo00?ooooo0_l0000Eooooo`03o`000?oooooooooo
01Kooooo0ol0000Fooooo`Go00005oooool2o`0001Oooooo0ol0000Fooooo`Go00005_ooool3o`00
01Sooooo000Jooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool05oooool00`00003o
ooooooooo`0Gooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool05oooool00`00003o
ooooooooo`0Gooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool05oooool00`00003o
ooooooooo`0Gooooo`0300000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo01Oooooo
00<00000ooooooooool05oooool00`00003oooooooooo`0Gooooo`0300000?oooooooooo01Oooooo
00<00000ooooooooool05oooool00`00003oooooooooo`0Gooooo`0300000?oooooooooo01Oooooo
00<00000ooooooooool05oooool00`00003oooooooooo`0Gooooo`0300000?oooooooooo01Wooooo
000Kooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool05Oooool00`00003ooooooooo
o`0Iooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool05Oooool00`00003ooooooooo
o`0Iooooo`0300000?oooooooooo01Gooooo00<00000ooooooooool06Oooool00`00003ooooooooo
o`0Eooooo`0300000?oooooooooo01[ooooo000Kooooo`0300000?oooooooooo01Oooooo00<00000
ooooooooool05Oooool00`00003oooooooooo`0Jooooo`0300000?oooooooooo01Kooooo00<00000
ooooooooool05Oooool00`00003oooooooooo`0Iooooo`0300000?oooooooooo01Gooooo00<00000
ooooooooool06Oooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo01[ooooo000Loooo
o`0300000?oooooooooo01Oooooo00<00000ooooooooool04oooool00`00003oooooooooo`0Loooo
o`0300000?oooooooooo01Kooooo00<00000ooooooooool04oooool00`00003oooooooooo`0Koooo
o`0300000?oooooooooo01?ooooo00<00000ooooooooool06oooool00`00003oooooooooo`0Coooo
o`0300000?oooooooooo01_ooooo000Mooooo`0300000?oooooooooo01Oooooo00<00000oooooooo
ool04Oooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo01Kooooo00<00000oooooooo
ool04Oooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo00<00000oooooooo
ool07Oooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo01cooooo000Mooooo`030000
0?oooooooooo01Oooooo00<00000ooooooooool04Oooool00`00003oooooooooo`0Oooooo`030000
0?oooooooooo01Gooooo00<00000ooooooooool04Oooool00`00003oooooooooo`0Mooooo`030000
0?oooooooooo017ooooo00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`030000
0?oooooooooo01cooooo000Nooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`0Qooooo`0300000?oooooooooo01Gooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`0Oooooo`0300000?oooooooooo00oooooo00<00000ooooooooool07ooo
ool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01gooooo000Nooooo`0300000?oooooo
oooo01Oooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Rooooo`0300000?oooooo
oooo01Cooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Oooooo`0300000?oooooo
oooo00oooooo00<00000ooooooooool07oooool00`00003oooooooooo`0?ooooo`0300000?oooooo
oooo01gooooo000Oooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool03Oooool00`00
003oooooooooo`0Tooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool03Oooool00`00
003oooooooooo`0Qooooo`0300000?oooooooooo00gooooo00<00000ooooooooool08Oooool00`00
003oooooooooo`0=ooooo`0300000?oooooooooo01kooooo000Pooooo`0300000?oooooooooo01Oo
oooo00<00000ooooooooool02oooool00`00003oooooooooo`0Uooooo`0300000?oooooooooo01Go
oooo00<00000ooooooooool02oooool00`00003oooooooooo`0Sooooo`0300000?oooooooooo00_o
oooo00<00000ooooooooool08oooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo01oo
oooo000Pooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool02oooool00`00003ooooo
ooooo`0Vooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool02oooool00`00003ooooo
ooooo`0Sooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool08oooool00`00003ooooo
ooooo`0;ooooo`0300000?oooooooooo01oooooo000Qooooo`0300000?oooooooooo01Oooooo00<0
0000ooooooooool02Oooool00`00003oooooooooo`0Xooooo`0300000?oooooooooo01Cooooo00<0
0000ooooooooool02Oooool00`00003oooooooooo`0Uooooo`0300000?oooooooooo00Wooooo00<0
0000ooooooooool09Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo023ooooo000Q
ooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool02Oooool00`00003oooooooooo`0Y
ooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool02Oooool00`00003oooooooooo`0U
ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool09Oooool00`00003oooooooooo`09
ooooo`0300000?oooooooooo023ooooo000Rooooo`0300000?oooooooooo01Oooooo00<00000oooo
ooooool01oooool00`00003oooooooooo`0[ooooo`0300000?oooooooooo01?ooooo00<00000oooo
ooooool01oooool00`00003oooooooooo`0Wooooo`0300000?oooooooooo00Oooooo00<00000oooo
ooooool09oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo027ooooo000Sooooo`03
00000?oooooooooo01Oooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0]ooooo`03
00000?oooooooooo01?ooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0Yooooo`03
00000?oooooooooo00Gooooo00<00000ooooooooool0:Oooool00`00003oooooooooo`05ooooo`03
00000?oooooooooo02;ooooo000Sooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool0
1Oooool00`00003oooooooooo`0^ooooo`0300000?oooooooooo01;ooooo00<00000ooooooooool0
1Oooool00`00003oooooooooo`0Yooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool0
:Oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo02;ooooo000Tooooo`0300000?oo
oooooooo01Oooooo00<00000ooooooooool00oooool00`00003oooooooooo`0`ooooo`0300000?oo
oooooooo01;ooooo00<00000ooooooooool00oooool00`00003oooooooooo`0[ooooo`0300000?oo
oooooooo00?ooooo00<00000ooooooooool0:oooool00`00003oooooooooo`03ooooo`0300000?oo
oooooooo02?ooooo000Tooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool00oooool0
0`00003oooooooooo`0aooooo`0300000?oooooooooo017ooooo00<00000ooooooooool00oooool0
0`00003oooooooooo`0[ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool0:oooool0
0`00003oooooooooo`03ooooo`0300000?oooooooooo02?ooooo000Uooooo`0300000?oooooooooo
01Oooooo00D00000oooooooooooooooo0000000dooooo`0300000?oooooooooo01;ooooo00D00000
oooooooooooooooo0000000_ooooo`0500000?ooooooooooooooo`000000;oooool01@00003ooooo
ooooooooool0000002Kooooo000Vooooo`0300000?oooooooooo01Oooooo00<00000ooooo`000000
=_ooool00`00003oooooooooo`0Booooo`0300000?ooool00000037ooooo00<00000ooooo`000000
<Oooool00`00003ooooo0000000Wooooo`009_ooool00`00003oooooooooo`0Gooooo`0300000?oo
ool0000003Oooooo00<00000ooooooooool04Oooool00`00003ooooo0000000aooooo`0300000?oo
ool00000037ooooo00<00000ooooo`0000009oooool002Oooooo00<00000ooooooooool05oooool0
0`00003oooooooooo`0gooooo`0300000?oooooooooo017ooooo0P00000booooo`800000<Oooool2
000002Sooooo000Wooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool0>?ooool00`00
003oooooooooo`0Booooo`0300000?oooooooooo037ooooo00<00000ooooooooool0;Oooool00`00
003oooooooooo`0Xooooo`00:?ooool00`00003oooooooooo`0?ooooo`?o00000oooool00`00003o
ooooooooo`0jooooo`0300000?oooooooooo00Sooooo0ol00007ooooo`0300000?oooooooooo02Oo
oooo0ol00007ooooo`0300000?oooooooooo02Kooooo1Ol000000`00003oooooooooo`0Yooooo`00
:?ooool00`00003oooooooooo`0>ooooo`05o`000?ooooooooooooooool000000_ooool00`00003o
ooooooooo`0kooooo`0300000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000007oooo
o`0300000?oooooooooo02Oooooo00?o0000ooooooooool01oooool00`00003oooooooooo`0Voooo
o`04o`000?ooooooooooo`0002cooooo000Yooooo`0300000?oooooooooo00gooooo00Oo0000oooo
ooooooooooooo`000?ooool0000003oooooo00<00000ooooooooool02Oooool00ol0003ooooooooo
o`06ooooo`0300000?oooooooooo02Kooooo00?o0000ooooooooool02?ooool00`00003ooooooooo
o`0Vooooo`03o`000000003ooooo02cooooo000Zooooo`0300000?oooooooooo00cooooo1?l00000
0oooool00000ooooo`0oooooo`0300000?oooooooooo00Oooooo0_l0000:ooooo`8000009_ooool0
0ol0003oooooooooo`09ooooo`8000009Oooool200000003o`000?oooooooooo02_ooooo000Zoooo
o`0300000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00`00003oooooooooo`0ooooo
o`0300000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00`00003oooooooooo`0Soooo
o`03o`000?oooooooooo00_ooooo00<00000ooooooooool08Oooool01Ol0003ooooooooooooooooo
000002cooooo000[ooooo`0300000?oooooooooo00cooooo00Co0000ooooooooool00000@oooool0
0`00003oooooooooo`03ooooo`05o`000?ooooooooooooooool000003?ooool00`00003ooooooooo
o`0Qooooo`;o00003_ooool00`00003oooooooooo`0Oooooo`0300000?l0003ooooo00;ooooo00?o
0000ooooooooool0:_ooool002_ooooo00<00000ooooooooool03Oooool2o`00000300000?oooooo
oooo04;ooooo00<00000ooooooooool00oooool3o`0000kooooo00<00000ooooooooool08Oooool0
0ol0003oooooooooo`0=ooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00ol0000]
ooooo`00;?ooool00`00003oooooooooo`0=ooooo`0300000?oooooooooo04Cooooo00<00000oooo
ooooool05?ooool00`00003oooooooooo`0aooooo`0300000?oooooooooo01_ooooo00<00000oooo
ooooool0<Oooool002gooooo00<00000ooooooooool02oooool00`00003oooooooooo`16ooooo`03
00000?oooooooooo01Cooooo00<00000ooooooooool0<Oooool00`00003oooooooooo`0Iooooo`03
00000?oooooooooo03;ooooo000]ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool0
Aoooool00`00003oooooooooo`0Dooooo`800000<_ooool2000001Oooooo0P00000eooooo`00;_oo
ool00`00003oooooooooo`09ooooo`0300000?oooooooooo04Wooooo00<00000ooooooooool05Ooo
ool00`00003oooooooooo`0aooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool0=Ooo
ool002kooooo00<00000ooooooooool02Oooool00`00003oooooooooo`1:ooooo`0300000?oooooo
oooo01Gooooo00<00000ooooooooool0<Oooool00`00003oooooooooo`0Aooooo`0300000?oooooo
oooo03Kooooo000_ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool0Boooool00`00
003oooooooooo`0Fooooo`0300000?oooooooooo037ooooo00<00000ooooooooool03oooool00`00
003oooooooooo`0gooooo`00<?ooool00`00003oooooooooo`05ooooo`0300000?oooooooooo04go
oooo00<00000ooooooooool05_ooool00`00003oooooooooo`0aooooo`0300000?oooooooooo00go
oooo00<00000ooooooooool0>?ooool0033ooooo00<00000ooooooooool01Oooool00`00003ooooo
ooooo`1>ooooo`0300000?oooooooooo01Kooooo0P00000booooo`8000002oooool2000003_ooooo
000aooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool0D?ooool00`00003ooooooooo
o`0Gooooo`0300000?oooooooooo037ooooo00<00000ooooooooool01oooool00`00003ooooooooo
o`0kooooo`00<Oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo057ooooo00<00000
ooooooooool05oooool00`00003oooooooooo`0aooooo`0300000?oooooooooo00Gooooo00<00000
ooooooooool0??ooool003;ooooo00D00000oooooooooooooooo0000001Eooooo`0300000?oooooo
oooo01Oooooo00<00000ooooooooool0<Oooool00`00003oooooooooo`03ooooo`0300000?oooooo
oooo03gooooo000cooooo`0300000?ooool0000005Oooooo00<00000ooooooooool05oooool00`00
003oooooooooo`0aooooo`0500000?ooooooooooooooo`000000@?ooool003?ooooo00<00000oooo
o`000000F?ooool00`00003oooooooooo`0Gooooo`0300000?oooooooooo037ooooo00<00000oooo
o`000000@Oooool003Cooooo0P00001Iooooo`0300000?oooooooooo01Oooooo0P00000aooooo`80
0000@_ooool003Kooooo00<00000ooooooooool0E_ooool00`00003oooooooooo`0Iooooo`030000
0?oooooooooo02gooooo00<00000ooooooooool0@_ooool002gooooo0ol00007ooooo`0300000?oo
oooooooo05Kooooo00<00000ooooooooool06Oooool00`00003oooooooooo`0Xooooo`?o000000<0
0000ooooooooool0@oooool002cooooo00Go0000ooooooooooooooooo`000007ooooo`800000Eooo
ool00`00003oooooooooo`0Iooooo`0300000?oooooooooo02Sooooo00?o000000000?ooool0AOoo
ool002cooooo00Go0000ooooooooooooooooo`000009ooooo`0300000?oooooooooo05Gooooo00<0
0000ooooooooool06Oooool00`00003oooooooooo`0Tooooo`Go0000A_ooool002gooooo0ol0000;
ooooo`800000E_ooool00`00003oooooooooo`0Iooooo`8000009?ooool01?l00000000000000?l0
0017ooooo`00;?ooool01Ol0003ooooooooooooooooo000000cooooo00<00000ooooooooool0E?oo
ool00`00003oooooooooo`0Jooooo`0300000?oooooooooo027ooooo00@00000o`000?oooooo0000
Aoooool002cooooo00Go0000ooooooooooooooooo`00000=ooooo`0300000?oooooooooo05Cooooo
00<00000ooooooooool06_ooool00`00003oooooooooo`0Oooooo`0300000?oooooooooo00;o0000
Aoooool002gooooo0ol0000?ooooo`800000EOooool00`00003oooooooooo`0Jooooo`0300000?oo
oooooooo01gooooo00<00000ooooooooool00_ooool00ol0003oooooooooo`15ooooo`00@Oooool0
0`00003oooooooooo`1Cooooo`0300000?oooooooooo01[ooooo00<00000ooooooooool06oooool0
0`00003oooooooooo`1;ooooo`00@_ooool00`00003oooooooooo`1Booooo`0300000?oooooooooo
01_ooooo00<00000ooooooooool06Oooool00`00003oooooooooo`1<ooooo`00@oooool2000005?o
oooo00<00000ooooooooool06oooool2000001Oooooo0P00001?ooooo`00AOooool00`00003ooooo
ooooo`1Aooooo`0300000?oooooooooo01cooooo00<00000ooooooooool04oooool00`00003ooooo
ooooo`1?ooooo`00A_ooool2000005;ooooo00<00000ooooooooool07?ooool00`00003ooooooooo
o`0Aooooo`0300000?oooooooooo053ooooo0018ooooo`0300000?oooooooooo053ooooo00<00000
ooooooooool07?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo057ooooo0019oooo
o`0300000?oooooooooo053ooooo00<00000ooooooooool07?ooool00`00003oooooooooo`0=oooo
o`0300000?oooooooooo05;ooooo001:ooooo`800000DOooool00`00003oooooooooo`0Looooo`80
00002oooool2000005Gooooo001<ooooo`0300000?oooooooooo04oooooo00<00000ooooooooool0
7Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo05Gooooo001=ooooo`800000D?oo
ool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool0E_oo
ool004oooooo00<00000ooooooooool0COooool00`00003oooooooooo`0Nooooo`0300000?oooooo
oooo00?ooooo00<00000ooooooooool0Eoooool0053ooooo00<00000ooooooooool0COooool00`00
003oooooooooo`0Nooooo`0500000?ooooooooooooooo`000000F_ooool0057ooooo0P00001>oooo
o`0300000?oooooooooo01kooooo00<00000ooooo`000000Foooool005?ooooo00<00000oooooooo
ool0C?ooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo05[ooooo001Dooooo`030000
0?oooooooooo04cooooo00<00000ooooooooool07Oooool00`00003oooooooooo`1Jooooo`00EOoo
ool2000004gooooo00<00000ooooooooool05Oooool3o`0000?ooooo00<00000ooooooooool0Fooo
ool005Oooooo00<00000ooooooooool0Boooool00`00003oooooooooo`0Cooooo`05o`000?oooooo
ooooooooool000000_ooool00`00003oooooooooo`1Kooooo`00F?ooool2000004cooooo00<00000
ooooooooool05_ooool00ol0003ooooo0000001Nooooo`00F_ooool00`00003oooooooooo`19oooo
o`0300000?oooooooooo01Kooooo00?o000000000?ooool0G_ooool005_ooooo00<00000oooooooo
ool0BOooool00`00003oooooooooo`0Aooooo`Co000000?ooooo00000?ooool0G_ooool005cooooo
0P00001:ooooo`0300000?oooooooooo013ooooo00Go0000oooooooooooooooo0000001Pooooo`00
G_ooool00`00003oooooooooo`18ooooo`0300000?oooooooooo00oooooo1Ol0001Pooooo`00Gooo
ool00`00003oooooooooo`18ooooo`0300000?oooooooooo017ooooo00<00000ooooooooool0Gooo
ool0063ooooo0P000019ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0H?ooool0
06;ooooo00<00000ooooooooool0Aoooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo
063ooooo001Sooooo`800000B?ooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo067o
oooo001Uooooo`0300000?oooooooooo04Kooooo00<00000ooooooooool02oooool00`00003ooooo
ooooo`1Qooooo`00I_ooool00`00003oooooooooo`15ooooo`0300000?oooooooooo00[ooooo00<0
0000ooooooooool0H_ooool006Oooooo0P000016ooooo`0300000?oooooooooo00Sooooo00<00000
ooooooooool0Hoooool006Wooooo00<00000ooooooooool0A?ooool00`00003oooooooooo`07oooo
o`0300000?oooooooooo06?ooooo001Zooooo`0300000?oooooooooo04Cooooo00<00000oooooooo
ool01Oooool00`00003oooooooooo`1Tooooo`00Joooool2000004Gooooo00<00000ooooooooool0
1?ooool00`00003oooooooooo`1Tooooo`00KOooool00`00003oooooooooo`13ooooo`0300000?oo
oooooooo00;ooooo00<00000ooooooooool0IOooool006kooooo0P000014ooooo`0400000?oooooo
oooo000006Sooooo001`ooooo`0300000?oooooooooo04;ooooo00<00000ooooo`000000J?ooool0
077ooooo00<00000ooooooooool0@Oooool2000006Wooooo001booooo`800000?oooool2000006_o
oooo001dooooo`0300000?oooooooooo03Wooooo00?o0000ooooo`000000KOooool007Gooooo00<0
0000ooooooooool0>?ooool00ol000000000ooooo`1]ooooo`00M_ooool2000003Kooooo0P000000
0ooooooo0000ooooo`1]ooooo`00N?ooool00`00003oooooooooo`0aooooo`8000000oooool00ol0
003oooooooooo`1/ooooo`00NOooool2000002oooooo0P000006ooooo`03o`000?oooooooooo06_o
oooo001kooooo`0300000?oooooooooo02_ooooo00<00000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000006gooooo001looooo`0300000?oooooooooo02Sooooo0P000005ooooo`Go0000
KOooool007gooooo0P00000Vooooo`800000NOooool007oooooo00<00000ooooooooool08Oooool2
000007_ooooo0020ooooo`8000008?ooool00`00003oooooooooo`1kooooo`00P_ooool00`00003o
ooooooooo`0Kooooo`800000O_ooool008?ooooo00<00000ooooooooool06?ooool20000083ooooo
0024ooooo`8000005_ooool2000008;ooooo0026ooooo`0300000?oooooooooo01;ooooo00<00000
ooooooooool0P_ooool008Oooooo00<00000ooooooooool03oooool2000008Gooooo0028ooooo`80
00003Oooool2000008Oooooo002:ooooo`0300000?oooooooooo00Sooooo0P000029ooooo`00Rooo
ool2000000Kooooo0P00002;ooooo`00SOooool00`00003oooooooooo`02ooooo`0300000?oooooo
oooo08_ooooo002>ooooo`0400000?ooool00000000008kooooo002?ooooo`0300000?oooooooooo
08kooooo002?ooooo`0300000?oooooooooo08kooooo0028ooooo`;o00001Oooool00`00003ooooo
ooooo`2>ooooo`00R_ooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo08kooooo002;
ooooo`05o`000?ooooooooooooooo`000000T?ooool008Sooooo1?l00003ooooo`0300000?oooooo
oooo08kooooo0027ooooo`05o`000?ooooooooooooooool000000oooool00`00003oooooooooo`2>
ooooo`00Qoooool01Ol0003ooooooooooooooooo000000?ooooo00<00000ooooooooool0S_ooool0
08Sooooo0ol00004ooooo`0300000?oooooooooo08kooooo002?ooooo`0300000?oooooooooo08ko
oooo002?ooooo`0300000?oooooooooo08kooooo002?ooooo`0300000?oooooooooo08kooooo002?
ooooo`0300000?oooooooooo08kooooo002?ooooo`0300000?oooooooooo08kooooo002?ooooo`03
00000?oooooooooo08kooooo002?ooooo`0300000?oooooooooo08kooooo002?ooooo`0300000?oo
oooooooo08kooooo002?ooooo`0300000?oooooooooo08kooooo002?ooooo`0300000?oooooooooo
08kooooo002?ooooo`0300000?oooooooooo08kooooo002?ooooo`0300000?oooooooooo08kooooo
002?ooooo`0300000?oooooooooo08kooooo002?ooooo`0300000?oooooooooo08kooooo003ooooo
ob7ooooo0025ooooo`?o00001?ooool2o`0009;ooooo0026ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000TOooool008Kooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0002Aooooo`00Q_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00097o
oooo0026ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000TOooool008Gooooo
0_l00004ooooo`04o`000?ooooooooooo`00097ooooo0026ooooo`03o`000?oooooooooo00?ooooo
0_l0002Booooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
\
\>"],
  ImageRangeCache->{{{0, 358.75}, {221.125, 0}} -> {-1.01364, -1.00004, \
0.0384226, 0.0452139}}]
}, Open  ]],

Cell["Internal nodes are labelled by numbers.", "Text"],

Cell["\<\
This somewhat obscure code plots the vertical coordinate at 5 times \
the coalescence time.  (You can adjust the factor 5 to get a sensible \
vertical scale)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        PlotGenealogy[rg, 
          NodeFunction \[Rule] \(({#2\[LeftDoubleBracket]\(-1\), 
                    1\[RightDoubleBracket], 
                  5\ #2\[LeftDoubleBracket]1\[RightDoubleBracket]} \
&)\)]];\)\)], "Input",
  CellLabel->"In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0909091 0.0909091 0.0772542 0.0772542 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.68182 .11492 m
.63636 .07725 L
s
.68182 .11492 m
.72727 .07725 L
s
.86364 .1191 m
.81818 .07725 L
s
.86364 .1191 m
.90909 .07725 L
s
.5 .12578 m
.45455 .07725 L
s
.5 .12578 m
.54545 .07725 L
s
.77273 .14789 m
.68182 .11492 L
s
.77273 .14789 m
.86364 .1191 L
s
.68182 .16127 m
.5 .12578 L
s
.68182 .16127 m
.77273 .14789 L
s
.22727 .17327 m
.18182 .07725 L
s
.22727 .17327 m
.27273 .07725 L
s
.63636 .17637 m
.36364 .07725 L
s
.63636 .17637 m
.68182 .16127 L
s
.18182 .20818 m
.09091 .07725 L
s
.18182 .20818 m
.22727 .17327 L
s
.5 .34048 m
.18182 .20818 L
s
.5 .34048 m
.63636 .17637 L
s
.5 .34048 m
.5 .34048 L
s
[(1)] .66364 .13037 0 0 Mshowa
[(2)] .84545 .13455 0 0 Mshowa
[(3)] .48182 .14123 0 0 Mshowa
[(4)] .75455 .16334 0 0 Mshowa
[(5)] .66364 .17672 0 0 Mshowa
[(6)] .20909 .18872 0 0 Mshowa
[(7)] .61818 .19182 0 0 Mshowa
[(8)] .16364 .22363 0 0 Mshowa
[(9)] .48182 .35593 0 0 Mshowa
[(10)] .48182 .35593 0 0 Mshowa
gsave
.09091 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x4) show
1.000 setlinewidth
grestore
gsave
.18182 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x3) show
1.000 setlinewidth
grestore
gsave
.27273 .0618 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x10) show
1.000 setlinewidth
grestore
gsave
.36364 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x1) show
1.000 setlinewidth
grestore
gsave
.45455 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
1.000 setlinewidth
grestore
gsave
.54545 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x5) show
1.000 setlinewidth
grestore
gsave
.63636 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x6) show
1.000 setlinewidth
grestore
gsave
.72727 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x8) show
1.000 setlinewidth
grestore
gsave
.81818 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x7) show
1.000 setlinewidth
grestore
gsave
.90909 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x9) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`005?ooool2
o`000003ooooool0003o000000?ooooo0ol0000?ooooo`;o000000?oooooo`000?l000000_ooool3
o`0000gooooo0_l000000ooooooo0000o`000002ooooo`?o00001?ooool2o`0000gooooo0_l00000
0ooooooo0000o`000002ooooo`?o00004?ooool2o`000004ooooool0003o0000ooooo`Go00003ooo
ool2o`000003ooooool0003o000000;ooooo0ol0000@ooooo`;o000000?oooooo`000?l000000_oo
ool3o`00013ooooo0_l000000ooooooo0000o`000002ooooo`?o00004?ooool2o`000003ooooool0
003o000000?ooooo00?o0000ooooooooool03oooool2o`000003ooooool0003o000000;ooooo0_l0
000Iooooo`005Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooool000000_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooool000001?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooool00000
1?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo
00004?ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000004?ooool00ol0
003oooooo`000002ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooo`000002
ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooo`000004ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0Fooooo`005_ooool0
1?l0003oooooooooooooool5o`00017ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0?ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0?ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01Gooooo000Eooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00004Oooool00ol0
003oooooo`000004ooooo`;o00003_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00003Oooool00ol0003oooooo`000004ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooooooool03_ooool00ol0003oooooo`000002ooooo`Co00004Oooool0
0ol0003oooooo`000003ooooo`?o00004Oooool00ol0003oooooo`000005ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooool000000oooool4o`0001Oooooo000Dooooo`;o000000?oooooo`00
0?l000000_ooool00ol0003oooooo`00000@ooooo`;o000000?oooooo`000?l000001Oooool00ol0
003oooooooooo`0:ooooo`;o000000?oooooo`000?l000000oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000cooooo0_l000000ooooooo0000o`000003ooooo`03o`000?oooooo
oooo00oooooo0_l000001Ooooooo0000o`000?oooooo000000?ooooo00?o0000ooooooooool03Ooo
ool2o`000004ooooool0003o0000ooooo`Co00004?ooool2o`000005ooooool0003o0000ooooool0
00004oooool2o`000005ooooool0003o0000ooooool000000oooool00ol0003oooooooooo`0=oooo
o`;o000000?oooooo`000?l000001Oooool00ol0003oooooooooo`0=ooooo`;o000000Goooooo`00
0?l0003oooooo`000003ooooo`03o`000?oooooooooo01Gooooo000Looooo`;o00005_ooool01Ol0
003ooooooooooooooooo000001?ooooo0_l00004ooooo`04o`000?ooooooooooo`0001?ooooo0_l0
000Gooooo`05o`000?ooooooooooooooool000005Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01Kooooo00Go0000ooooooooooooooooo`00000Eooooo`05o`000?oooooooooooooo
ool000005Oooool01Ol0003ooooooooooooooooo000001Oooooo000Mooooo`03o`000?oooooooooo
01Gooooo0ol0000Eooooo`03o`000?oooooooooo00?ooooo0_l0000Eooooo`03o`000?oooooooooo
01Kooooo0ol0000Fooooo`Go00005oooool2o`0001Oooooo0ol0000Fooooo`Go00005_ooool3o`00
01Sooooo000Jooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool05oooool00`00003o
ooooooooo`0Gooooo`8000006?ooool00`00003oooooooooo`0Gooooo`0300000?oooooooooo01Oo
oooo0P00000Gooooo`8000006Oooool2000001Oooooo0P00000Kooooo`006_ooool00`00003ooooo
ooooo`0Gooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool06Oooool3000001Gooooo
00<00000ooooooooool05oooool00`00003oooooooooo`0Iooooo`0300000?oooooooooo01?ooooo
00<00000ooooooooool06oooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo01_ooooo
000Kooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool05Oooool00`00003ooooooooo
o`0Mooooo`<000004oooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo01_ooooo00<0
0000ooooooooool04Oooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo00<0
0000ooooooooool07?ooool001cooooo00<00000ooooooooool05_ooool00`00003oooooooooo`0E
ooooo`0300000?oooooooooo023ooooo0`00000Aooooo`0300000?oooooooooo01?ooooo00<00000
ooooooooool07Oooool2000000oooooo0P00000Qooooo`0300000?oooooooooo00oooooo00<00000
ooooooooool07Oooool001cooooo00<00000ooooooooool05oooool00`00003oooooooooo`0Coooo
o`0300000?oooooooooo02Cooooo0`00000?ooooo`0300000?oooooooooo017ooooo00<00000oooo
ooooool08?ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo02;ooooo00<00000oooo
ooooool03Oooool00`00003oooooooooo`0Nooooo`007Oooool00`00003oooooooooo`0Fooooo`03
00000?oooooooooo01?ooooo00<00000ooooooooool09oooool2000000kooooo00<00000oooooooo
ool03oooool00`00003oooooooooo`0Rooooo`0300000?oooooooooo00Wooooo00<00000oooooooo
ool09?ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo01oooooo000Nooooo`030000
0?oooooooooo01Kooooo00<00000ooooooooool04Oooool00`00003oooooooooo`0Zooooo`<00000
3?ooool00`00003oooooooooo`0=ooooo`0300000?oooooooooo02Cooooo00<00000ooooooooool0
1oooool00`00003oooooooooo`0Vooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool0
8?ooool001oooooo00<00000ooooooooool05Oooool00`00003oooooooooo`0Aooooo`0300000?oo
oooooooo02gooooo0`00000:ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool09_oo
ool2000000Gooooo0P00000Zooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool08Ooo
ool001oooooo00<00000ooooooooool05_ooool00`00003oooooooooo`0?ooooo`0300000?oooooo
oooo037ooooo0`000008ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool0:Oooool0
1@00003oooooooooooooool0000002gooooo00<00000ooooooooool01Oooool00`00003ooooooooo
o`0Rooooo`008?ooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo00oooooo00<00000
ooooooooool0=?ooool2000000Oooooo00<00000ooooooooool01oooool00`00003oooooooooo`0[
ooooo`0300000?ooool0000002oooooo00<00000ooooooooool00oooool00`00003oooooooooo`0S
ooooo`008Oooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo00gooooo00<00000oooo
ooooool0=oooool3000000Gooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0]oooo
o`800000<?ooool01@00003oooooooooooooool0000002Kooooo000Qooooo`0300000?oooooooooo
01Gooooo00<00000ooooooooool03Oooool00`00003oooooooooo`0jooooo`<000000oooool00`00
003oooooooooo`03ooooo`0300000?oooooooooo033ooooo0`00000^ooooo`0300000?ooool00000
02Oooooo000Rooooo`0300000?oooooooooo01Gooooo00<00000ooooooooool02oooool00`00003o
ooooooooo`0nooooo`<0000000?ooooo00000?ooool00_ooool00`00003oooooooooo`0Xooooo`?o
00002Oooool3000002[ooooo0`00000Xooooo`008oooool00`00003oooooooooo`0Dooooo`030000
0?oooooooooo00_ooooo00<00000ooooooooool0@Oooool300000003ooooo`00003ooooo02_ooooo
00?o0000ooooooooool02oooool2000002Gooooo0`00000[ooooo`008oooool00`00003ooooooooo
o`0Eooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool0AOooool4000002[ooooo00?o
0000ooooooooool03Oooool3000001oooooo1Ol0000/ooooo`009?ooool00`00003oooooooooo`0D
ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool0?_ooool3o`0000Kooooo1`00000U
ooooo`03o`000?oooooooooo013ooooo0P00000Jooooo`<0000000Goooooo`000?ooooooooooo`00
000/ooooo`009Oooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo00Wooooo00<00000
ooooooooool0?Oooool01Ol0003ooooooooooooooooo000000Sooooo0`0000000oooool000000000
00030000023ooooo00?o0000ooooooooool04_ooool3000001?ooooo10000005ooooo`03o`000?oo
oooooooo02cooooo000Vooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool01oooool0
0`00003oooooooooo`12ooooo`03o`000?oooooooooo00Wooooo0`000003ooooo`D000006_ooool2
o`0001Oooooo0`00000=ooooo`<000002_ooool00ol0003oooooooooo`0[ooooo`009_ooool00`00
003oooooooooo`0Cooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool0@?ooool2o`00
00oooooo0`000005ooooo`D000005_ooool00ol0003oooooooooo`0Hooooo`8000002?ooool30000
00[ooooo00Go0000ooooooooooooooooo`00000/ooooo`009oooool00`00003oooooooooo`0Coooo
o`0300000?oooooooooo00Gooooo00<00000ooooooooool0@oooool00ol0003oooooooooo`0?oooo
o`8000002?ooool6000002gooooo0`000002ooooo`<000003Oooool01Ol0003ooooooooooooooooo
000002cooooo000Xooooo`0300000?oooooooooo01;ooooo00<00000ooooooooool01Oooool00`00
003oooooooooo`0oooooo`05o`000?ooooooooooooooool000004oooool3000000_ooooo1@00000X
ooooo`D000004Oooool3o`0002gooooo000Xooooo`0300000?oooooooooo01?ooooo00<00000oooo
ooooool00oooool00`00003oooooooooo`11ooooo`?o00005oooool3000000gooooo1@00000Loooo
o`L00000A_ooool002Wooooo00<00000ooooooooool04_ooool00`00003oooooooooo`03ooooo`03
00000?oooooooooo05kooooo0`00000?ooooo`D000004Oooool6000000Cooooo0ol00016ooooo`00
:_ooool00`00003oooooooooo`0Booooo`0500000?ooooooooooooooo`000000I?ooool2000001;o
oooo1@000005ooooo`L000002oooool00ol0003oooooooooo`15ooooo`00:oooool00`00003ooooo
ooooo`0Aooooo`0500000?ooooooooooooooo`000000I_ooool3000001Cooooo1@00000?ooooo`Go
0000A_ooool002_ooooo00<00000ooooooooool04_ooool00`00003ooooo0000001Zooooo`<00000
3_ooool3000001Cooooo00Co0000oooooooooooo0000Aoooool002cooooo00<00000ooooooooool0
4Oooool00`00003ooooo0000001]ooooo`<000002?ooool01000003o0000o`000?l0000Gooooo`03
o`000?oooooo000004Oooooo000]ooooo`0300000?oooooooooo013ooooo0P00001aooooo`<00000
0_ooool300000005o`000?ooooooooooooooool000005oooool2o`0004Oooooo000]ooooo`030000
0?oooooooooo00oooooo00<00000ooooooooool0M?ooool2000000Oooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`15ooooo`00;_ooool00`00003oooooooooo`09ooooo`?o000000?o
oooo00000?ooool0M_ooool00`00003oooooooooo`06ooooo`03o`000?oooooooooo05kooooo000_
ooooo`0300000?oooooooooo00Oooooo00Go0000ooooooooool00000o`00001booooo`03o`000?oo
oooooooo00;ooooo00<00000ooooooooool00oooool4o`00067ooooo000_ooooo`0300000?oooooo
oooo00Oooooo00Go0000ooooo`00003oooooo`00001booooo`05o`000?ooooooooooooooo`000000
1_ooool00ol0003oooooooooo`1Rooooo`00<?ooool00`00003oooooooooo`06ooooo`Co0000M?oo
ool00ol0003ooooo00000007ooooo`Go0000H?ooool0037ooooo00<00000ooooooooool01Oooool0
0ol0003oooooooooo`1eooooo`03o`000000003ooooo06cooooo000booooo`0300000?oooooooooo
00;ooooo0P0000000ooooooo0000ooooo`1eooooo`0300000?l0003ooooo06cooooo000booooo`05
00000?ooooooooooooooo`0000001?ooool2o`00077ooooo00Go0000ooooooooool00000o`00001]
ooooo`00<oooool00`00003ooooo0000001hooooo`Go0000KOooool003Cooooo0P00001iooooo`03
00000?oooooooooo06kooooo000fooooo`<00000MOooool00`00003oooooooooo`1_ooooo`00;Ooo
ool3o`0000Wooooo0P00001booooo`0300000?oooooooooo073ooooo000/ooooo`05o`000?oooooo
ooooooooool000002_ooool2000006oooooo00<00000ooooooooool0LOooool002cooooo00Go0000
ooooooooooooooooo`00000<ooooo`<00000K?ooool00`00003oooooooooo`1aooooo`00;Oooool3
o`00013ooooo0P00001Yooooo`0300000?oooooooooo07;ooooo000/ooooo`05o`000?oooooooooo
ooooool000004Oooool3000006Gooooo00<00000ooooooooool0Loooool002cooooo00Go0000oooo
ooooooooooooo`00000Dooooo`800000H_ooool00`00003oooooooooo`1dooooo`00;Oooool3o`00
01Oooooo0P00001Oooooo`0300000?oooooooooo07Gooooo0019ooooo`<00000Foooool00`00003o
ooooooooo`1fooooo`00C?ooool2000005Wooooo00<00000ooooooooool0M_ooool004kooooo0`00
001Eooooo`0300000?oooooooooo07Oooooo001Aooooo`800000D_ooool00`00003oooooooooo`1h
ooooo`00Doooool2000004oooooo00<00000ooooooooool0NOooool005Gooooo0`00001;ooooo`03
00000?oooooooooo07[ooooo001Hooooo`800000B?ooool00`00003oooooooooo`1kooooo`00F_oo
ool3000004Gooooo00<00000ooooooooool0Noooool005gooooo0P000012ooooo`0300000?oooooo
oooo07cooooo001Oooooo`800000?oooool00`00003oooooooooo`1mooooo`00HOooool3000003_o
oooo00<00000ooooooooool0O_ooool006Cooooo0P00000hooooo`0300000?oooooooooo07oooooo
001Vooooo`800000=_ooool00`00003oooooooooo`1oooooo`00J?ooool3000003;ooooo00<00000
ooooooooool0P?ooool006_ooooo0P00000_ooooo`0300000?oooooooooo087ooooo001]ooooo`<0
0000:oooool00`00003oooooooooo`22ooooo`00L?ooool2000002Sooooo00<00000ooooooooool0
Poooool007;ooooo0P00000Uooooo`0300000?oooooooooo08Cooooo001dooooo`<000008_ooool0
0`00003oooooooooo`24ooooo`00Moooool2000001oooooo00<00000ooooooooool0QOooool007Wo
oooo0`00000Kooooo`0300000?oooooooooo08Kooooo001looooo`8000006?ooool00`00003ooooo
ooooo`27ooooo`00O_ooool2000001Gooooo00<00000ooooooooool0R?ooool0083ooooo0`00000A
ooooo`0300000?oooooooooo08Wooooo0023ooooo`8000003oooool00`00003oooooooooo`29oooo
o`00QOooool3000000_ooooo00<00000ooooooooool0R_ooool008Sooooo0P000008ooooo`030000
0?oooooooooo08_ooooo002:ooooo`8000001Oooool00`00003oooooooooo`2<ooooo`00S?ooool3
00000003ooooo`00003ooooo08kooooo002?ooooo`03o`000?oooooooooo08kooooo003oooooob7o
oooo0025ooooo`Go00000_ooool2o`0009;ooooo0026ooooo`04o`000?ooooooooooooooo`;o0000
0_ooool00ol0003oooooooooo`2?ooooo`00Q_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`00097ooooo0026ooooo`03o`000?oooooo000000?o00000_ooool00ol0003ooooooooo
o`2?ooooo`00Q_ooool2o`0000?ooooo00Co0000oooooooooooo0000TOooool008Gooooo0ol00003
ooooo`04o`000?ooooooooooo`00097ooooo0026ooooo`03o`000?oooooo000000;o000000?ooooo
o`000?l00000T_ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 358.75}, {221.125, 0}} -> {-1.01364, -1.00004, \
0.0384226, 0.0452139}}]
}, Open  ]],

Cell[TextData[{
  "Note: ",
  StyleBox[" The coalescence events are concentrated in the recent past",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"]
}, Closed]],

Cell[CellGroupData[{

Cell["Describing genealogies", "SubsubsectionIcon"],

Cell["This describes properties of the genealogy:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ct = ExtractCoalescenceTimes[rg]\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \({0, 0.09750465984208453`, 0.10834256569991146`, 0.12561679052953426`, 
      0.18286155754690495`, 0.21751271605564315`, 0.24858020659182367`, 
      0.25658995784049987`, 0.33894753696113394`, 
      0.6814628971777537`}\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({LengthOfGenealogy[rg], DepthOfGenealogy[rg], 
      Mean[PairwiseDivergence[rg]]}\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \({2.938881785423043`, 0.6814628971777537`, 
      0.4351055076220936`}\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]]
}, Closed]],

Cell["Properties of the coalescent process", "Subsubsection"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Making a sample",
  FontColor->RGBColor[1, 0, 0]]], "SubsubsectionIcon"],

Cell["\<\
This makes a sample of 200 genealogies.  (Use a ; at the end of the \
line to suppress output):\
\>", "Text"],

Cell[BoxData[{
    \(\(lvs = {x1, x2, x3, x4, x5, x6, x7, x8, x9, x10};\)\), "\n", 
    \(\(sample = Table[RandomGenealogy[lvs], {200}];\)\)}], "Input",
  CellLabel->"In[8]:="],

Cell["\<\
This lists the depths of all the 200 genealogies (type \[EnterKey] \
to evaluate):\
\>", "Text"],

Cell[BoxData[
    \(depthList = DepthOfGenealogy /@ sample\)], "Input",
  CellLabel->"In[10]:="],

Cell["This lists the total lengths of all the 200 genealogies:", "Text"],

Cell[BoxData[
    \(lengthList = LengthOfGenealogy /@ sample\)], "Input",
  CellLabel->"In[11]:="],

Cell["\<\
This lists the mean pairwise divergence (ie the time back to the \
common ancestor of a random pair of genes:\
\>", "Text"],

Cell[BoxData[
    \(pdList = MeanPairwiseDivergence /@ sample\)], "Input",
  CellLabel->"In[12]:="],

Cell[TextData[{
  "Note: ",
  StyleBox[" this can be slow, because all 45 pairs of leaves must be \
compared for each of the 200 replicates",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell["This is the overall mean, averaged over replicates:", "Text"],

Cell[BoxData[
    \(Mean[pdList]\)], "Input",
  CellLabel->"In[13]:="],

Cell["\<\
This plots the distribution of pairwise divergence times - highly \
variable\
\>", "Text"],

Cell[BoxData[
    \(\(PairwiseDivergencePlot[sample, {3, 0.04}, 
        PlotJoined \[Rule] True];\)\)], "Input",
  CellLabel->"In[14]:="]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Basic properties of the coalescent ",
  FontColor->RGBColor[0, 0, 1]]], "SubsubsectionIcon"],

Cell[TextData[{
  StyleBox["Q1:",
    FontColor->RGBColor[0, 0, 1]],
  " Compare the mean depth, length, and pairwise divergence with the \
theoretical expectation"
}], "Text"],

Cell[TextData[{
  StyleBox["Q2:",
    FontColor->RGBColor[0, 0, 1]],
  " How variable are these measures?  Would they become less variable if more \
genes were sampled (say, 20 instead of 10)?"
}], "Text"],

Cell[TextData[{
  "Hint: ",
  StyleBox["Use Mean[], Variance[] to summarise the lists",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"]
}, Closed]],

Cell[CellGroupData[{

Cell["Growing populations: derivation", "SubsubsectionIcon"],

Cell["\<\
The \"scaled time\" in these simulations is really a measure of the \
total amount of genetic drift that has occurred:\
\>", "Text"],

Cell[BoxData[
    \(T\  = \ \[Integral]\_0\%t\[DifferentialD]t\/\(2  N\)\)], "DisplayMath"],

Cell[TextData[{
  "For a constant population size, ",
  Cell[BoxData[
      \(TraditionalForm\`T = \ t/\((2  N)\)\)]],
  ".  If the population is growing at a rate \[Lambda], and the present size \
is ",
  Cell[BoxData[
      \(TraditionalForm\`N\_0\)]],
  ", then N = ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\_0\) \[ExponentialE]\^\(\(-\[Lambda]\)\
\[VeryThinSpace]t\)\)]],
  ", and so:"
}], "Text"],

Cell[BoxData[
    \(T\  = \ \(\[Integral]\_0\%t\( \[ExponentialE]\^\(\[Lambda]\
\[VeryThinSpace]t\)\/\(2 
                   N\_0\)\) \[DifferentialD]t\  = \ \(\(1\/\(2 \( 
                    N\_0\) \[Lambda]\)\) \((\[ExponentialE]\^\(\[Lambda]\
\[VeryThinSpace]t\) - 1)\)\(\ \ \ \)\)\)\)], "DisplayMath"],

Cell["\<\
Turning this round, and scaling time relative to the current \
population size:\
\>", "Text"],

Cell[BoxData[
    \(\(\(\(T\)\(\ \)\)\^*\) = \ \(t\/\(2  N\_0\)\  = 
        1\/\(\[Lambda]\^*\)\ Log[
              1 + \(\[Lambda]\^*\) T]\ \ where\ \(\[Lambda]\^*\) \[Congruent] 
          2 \( N\_0\) \[Lambda]\)\)], "DisplayMath"],

Cell[TextData[{
  "This gives us a way of taking the measures of accumulated drift, T, that \
are given in the genealogies generated by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", and changing them to the actual (scaled) coalescence time ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\^*\)\)]],
  "in a growing population.  The efect is to push coalescence times back to \
when the population was smaller, by a change in timescale.  "
}], "Text"],

Cell[TextData[{
  "The parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\^*\)\)]],
  " is a measure of the amount of population growth over the current \
timescale set by population size, ",
  Cell[BoxData[
      \(TraditionalForm\`2  N\_0\)]],
  ".  Here is the transformation for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\^*\) = 5\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[\(1\/\[Lambda]\) Log[1 + \[Lambda]\ T] /. \[Lambda] \[Rule] 
            5, {T, 0, 5}];\)\)], "Input",
  CellLabel->"In[121]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0147151 0.903294 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .10504 -18 -4.5 ]
[.01131 .10504 0 4.5 ]
[.01131 .19537 -18 -4.5 ]
[.01131 .19537 0 4.5 ]
[.01131 .2857 -18 -4.5 ]
[.01131 .2857 0 4.5 ]
[.01131 .37603 -18 -4.5 ]
[.01131 .37603 0 4.5 ]
[.01131 .46636 -18 -4.5 ]
[.01131 .46636 0 4.5 ]
[.01131 .55669 -18 -4.5 ]
[.01131 .55669 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(1)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(2)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(3)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(4)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10504 m
.03006 .10504 L
s
[(0.1)] .01131 .10504 1 0 Mshowa
.02381 .19537 m
.03006 .19537 L
s
[(0.2)] .01131 .19537 1 0 Mshowa
.02381 .2857 m
.03006 .2857 L
s
[(0.3)] .01131 .2857 1 0 Mshowa
.02381 .37603 m
.03006 .37603 L
s
[(0.4)] .01131 .37603 1 0 Mshowa
.02381 .46636 m
.03006 .46636 L
s
[(0.5)] .01131 .46636 1 0 Mshowa
.02381 .55669 m
.03006 .55669 L
s
[(0.6)] .01131 .55669 1 0 Mshowa
.125 Mabswid
.02381 .03278 m
.02756 .03278 L
s
.02381 .05085 m
.02756 .05085 L
s
.02381 .06891 m
.02756 .06891 L
s
.02381 .08698 m
.02756 .08698 L
s
.02381 .12311 m
.02756 .12311 L
s
.02381 .14118 m
.02756 .14118 L
s
.02381 .15924 m
.02756 .15924 L
s
.02381 .17731 m
.02756 .17731 L
s
.02381 .21344 m
.02756 .21344 L
s
.02381 .23151 m
.02756 .23151 L
s
.02381 .24957 m
.02756 .24957 L
s
.02381 .26764 m
.02756 .26764 L
s
.02381 .30377 m
.02756 .30377 L
s
.02381 .32184 m
.02756 .32184 L
s
.02381 .3399 m
.02756 .3399 L
s
.02381 .35797 m
.02756 .35797 L
s
.02381 .3941 m
.02756 .3941 L
s
.02381 .41216 m
.02756 .41216 L
s
.02381 .43023 m
.02756 .43023 L
s
.02381 .4483 m
.02756 .4483 L
s
.02381 .48443 m
.02756 .48443 L
s
.02381 .50249 m
.02756 .50249 L
s
.02381 .52056 m
.02756 .52056 L
s
.02381 .53863 m
.02756 .53863 L
s
.02381 .57476 m
.02756 .57476 L
s
.02381 .59282 m
.02756 .59282 L
s
.02381 .61089 m
.02756 .61089 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.04262 .08721 L
.06244 .14121 L
.08255 .18326 L
.10458 .22029 L
.14509 .27327 L
.18408 .31281 L
.22553 .34709 L
.26546 .37491 L
.30387 .39816 L
.34474 .41999 L
.38409 .43878 L
.42192 .45517 L
.46221 .47113 L
.50098 .48526 L
.54221 .49916 L
.58192 .51162 L
.62011 .52283 L
.66075 .53405 L
.69988 .54423 L
.74147 .55446 L
.78153 .56379 L
.82008 .57233 L
.86109 .581 L
.90057 .58897 L
.93855 .59632 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[121]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00Aoooool3o`00033ooooo1Ol0000_ooooo`?o0000<_ooool3o`00033ooooo0ol00007oooo
o`00B?ooool00ol0003oooooooooo`0`ooooo`04o`000?ooooooooooo`0002kooooo00Go0000oooo
ooooooooooooo`00000booooo`03o`000?oooooooooo02kooooo00Go0000ooooooooooooooooo`00
0006ooooo`00B?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0;Oooool5o`0003?ooooo00?o0000ooooooooool01?ooool004Sooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0_ooooo`;o0000<?ooool01?l0003oooooooooool0000d
ooooo`03o`000?oooooooooo00Cooooo0018ooooo`03o`000?oooooooooo02oooooo00Go0000oooo
ooooooooooooo`00000booooo`03o`000?oooooooooo02kooooo00?o0000ooooool00000<?ooool4
o`0000Oooooo0017ooooo`;o0000<Oooool01Ol0003ooooooooooooooooo000002kooooo00Go0000
ooooooooooooooooo`00000aooooo`;o0000<?ooool00ol0003oooooooooo`08ooooo`00B?ooool0
0ol0003oooooooooo`0`ooooo`?o0000<?ooool3o`0003?ooooo00?o0000ooooooooool0;_ooool5
o`0000Kooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Gooooo00?o0000oooooooo
ool0ooooool9ooooo`005Oooool00ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oo
oooooooo0?oooooo2Oooool000koooooool0000Co`0000005Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00<00000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo037ooooo00<00000oooooooo
ool0<Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`05ooooo`005Oooool2o`000?oooooo2_ooool001Gooooo0_l0
003oooooo`[ooooo000Eooooo`;o0000ooooool:ooooo`005Oooool2o`000?oooooo2_ooool001Go
oooo00?o0000ooooool00000ooooool9ooooo`005Oooool00ol0003oooooo`00003oooooo`Wooooo
000Eooooo`03o`000?oooooo00000?oooooo2Oooool001Gooooo0ol0003oooooo`Wooooo000Eoooo
o`04o`000?ooooooooooo`000?oooooo2?ooool001Gooooo00Co0000oooooooooooo0000ooooool8
ooooo`005Oooool01?l0003oooooooooool0003oooooo`Sooooo000Eooooo`04o`000?oooooooooo
o`000?oooooo2?ooool001Gooooo0_l00002ooooo`03o`000?oooooooooo0?oooooo1Oooool001Go
oooo00Go0000ooooooooooooooooo`00003oooooo`Oooooo000Eooooo`05o`000?oooooooooooooo
ool00000ooooool7ooooo`005Oooool01Ol0003ooooooooooooooooo00000?oooooo1oooool001Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`Cooooo000Eooooo`;o0000
0oooool00ol0003oooooooooo`3oooooo`Cooooo000Eooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0ooooool4ooooo`000_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooo`?ooooo00001Ooo
oooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0?oooooo0oooool00005ooooool0003oooooooooool000002Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0ooooool3
ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`03o`000?oooooooooo00Cooooo0ol00004
ooooo`03o`000?oooooooooo0?oooooo0_ooool00005ooooool0003oooooooooool000002Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool2
ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`;o00001_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?oooooo0_ooool000;ooooo0_l0000:ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooo`7ooooo000Eooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0ooooool1ooooo`005Oooool2o`0000Kooooo
00?o0000ooooooooool0ooooool1ooooo`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo000Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool0
01Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`005Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0?kooooo000Eooooo`;o00002?ooool00ol0003ooooo
ooooo`3nooooo`005Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?kooooo000E
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0oOooool001Gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`3mooooo`005Oooool2o`0000[ooooo00?o0000oooooooo
ool0o?ooool001Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3looooo`005Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0?_ooooo000Eooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0n_ooool001Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`3jooooo`005Oooool2o`0000gooooo00?o0000ooooooooool0nOooool001Gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`3iooooo`005Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo0?Sooooo0002ooooo`;o00001?ooool01?l0003ooooooooooooo
ool5o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3hooooo`0000Gooooo
o`000?ooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`3gooooo`0000Goooooo`000?ooooooooooo`000009ooooo`03o`00
0?oooooooooo00Cooooo0ol0000?ooooo`03o`000?oooooooooo0?Kooooo00001Ooooooo0000oooo
oooooooo000000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0?Kooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0mOooool00005oooo
ool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`3eooooo`000_ooool2o`0000Wooooo0ol00005ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0m?ooool001Gooooo0_l0000Cooooo`03o`00
0?oooooooooo0??ooooo000Eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0looo
ool001Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`3booooo`005Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo0?;ooooo000Eooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0lOooool001Gooooo0_l0000Fooooo`03o`000?oooooooooo0?3ooooo
000Eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0koooool001Gooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`3_ooooo`005Oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo0>kooooo000Eooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0kOooool001Gooooo0_l0000Jooooo`03o`000?oooooooooo0>cooooo000Eooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0k?ooool001Gooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`3[ooooo`005Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
0>[ooooo000Eooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0j_ooool001Gooooo
0_l0000Mooooo`03o`000?oooooooooo0>Wooooo000Eooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0j?ooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005
ooooo`03o`000?oooooooooo01kooooo0_l0003Xooooo`0000Goooooo`000?ooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo0>Gooooo00001Ooooooo0000oooooooooooo000000_ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0>Cooooo00001Ooooooo0000oooooooo
oooo000000Wooooo0_l00005ooooo`?o00008_ooool00ol0003oooooooooo`3Sooooo`0000Gooooo
o`000?ooooooooooo`00000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`3Rooooo`0000Goooooo`000?ooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0>7ooooo
0002ooooo`;o00002Oooool3o`0000Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`3Pooooo`005Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0=oooooo000Eoooo
o`;o0000:?ooool00ol0003oooooooooo`3Nooooo`005Oooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo0=gooooo000Eooooo`03o`000?oooooooooo02Wooooo0_l0003Mooooo`005Ooo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0=[ooooo000Eooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0fOooool001Gooooo0_l0000^ooooo`03o`000?oooooooooo
0=Sooooo000Eooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0eoooool001Gooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`3Fooooo`005Oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo0=Gooooo000Eooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0e?ooool001Gooooo0_l0000cooooo`03o`000?oooooooooo0=?ooooo000Eooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0d_ooool001Gooooo00?o0000ooooooooool0
=?ooool2o`000=;ooooo000Eooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0cooo
ool001Gooooo00?o0000ooooooooool0=oooool2o`000<oooooo000Eooooo`;o0000>_ooool2o`00
0<gooooo000Eooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0b_ooool000;ooooo
0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03o`000?oooooooooo03cooooo
0_l0003:ooooo`0000Goooooo`000?ooooooooooo`00000:ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`37ooooo`0000Goooooo`000?oooooooooo
o`000007ooooo`Go00001?ooool3o`0003oooooo0_l00037ooooo`0000Goooooo`000?oooooooooo
o`000007ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0@Oooool2o`000<Go
oooo00001Ooooooo0000oooooooooooo000000Sooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo0<;ooooo00001Ooooooo0000oooooooooooo000000Wo
oooo0_l00005ooooo`03o`000?oooooooooo04Cooooo0_l00032ooooo`000_ooool2o`0000_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`16ooooo`;o0000`?ooool001Gooooo0_l0
0019ooooo`03o`000?oooooooooo0;gooooo000Eooooo`03o`000?oooooooooo04Wooooo0_l0002m
ooooo`005Oooool00ol0003oooooooooo`1;ooooo`;o0000^oooool001Gooooo00?o0000oooooooo
ool0COooool2o`000;Wooooo000Eooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0
]_ooool001Gooooo0_l0001Aooooo`;o0000]_ooool001Gooooo00?o0000ooooooooool0D_ooool2
o`000;Cooooo000Eooooo`03o`000?oooooooooo05Cooooo0_l0002booooo`005Oooool00ol0003o
ooooooooo`1Fooooo`;o0000/?ooool001Gooooo00?o0000ooooooooool0F?ooool2o`000:kooooo
000Eooooo`;o0000Foooool00ol0003oooooooooo`2[ooooo`005Oooool00ol0003oooooooooo`1K
ooooo`;o0000Zoooool001Gooooo00?o0000ooooooooool0GOooool2o`000:Wooooo000Eooooo`03
o`000?oooooooooo05oooooo0_l0002Wooooo`005Oooool00ol0003oooooooooo`1Qooooo`?o0000
Y?ooool001Gooooo0_l0001Uooooo`;o0000X_ooool001Gooooo00?o0000ooooooooool0I_ooool3
o`0009oooooo000Eooooo`03o`000?oooooooooo06Wooooo0_l0002Mooooo`000_ooool2o`0000Co
oooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0Joooool3o`0009[o
oooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo06kooooo0ol0002Gooooo`0000Goooooo`000?ooooooooooo`00000;oooo
o`03o`000?oooooooooo00;ooooo0ol0001aooooo`?o0000U?ooool00005ooooool0003ooooooooo
ool000002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Cooooo0_l0002Boooo
o`0000Goooooo`000?ooooooooooo`000007ooooo`Co00001Oooool00ol0003oooooooooo`1foooo
o`?o0000Soooool00005ooooool0003oooooooooool000001oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo07Wooooo0ol0002<ooooo`000_ooool2o`0000Sooooo1Ol00004ooooo`03
o`000?oooooooooo07cooooo0ol00029ooooo`005Oooool2o`00083ooooo0_l00027ooooo`005Ooo
ool00ol0003oooooooooo`21ooooo`?o0000Q?ooool001Gooooo00?o0000ooooooooool0Q?ooool3
o`00087ooooo000Eooooo`03o`000?oooooooooo08Oooooo0ol0001nooooo`005Oooool00ol0003o
ooooooooo`2:ooooo`?o0000Noooool001Gooooo0_l0002>ooooo`Co0000Moooool001Gooooo00?o
0000ooooooooool0TOooool3o`0007Cooooo000Eooooo`03o`000?oooooooooo09Cooooo1?l0001`
ooooo`005Oooool00ol0003oooooooooo`2Hooooo`?o0000KOooool001Gooooo00?o0000oooooooo
ool0Voooool3o`0006[ooooo000Eooooo`;o0000Woooool4o`0006Kooooo000Eooooo`03o`000?oo
oooooooo0:;ooooo1?l0001Rooooo`005Oooool00ol0003oooooooooo`2Vooooo`?o0000Goooool0
01Gooooo00?o0000ooooooooool0ZOooool4o`0005_ooooo000Eooooo`03o`000?oooooooooo0:go
oooo1?l0001Gooooo`005Oooool2o`000;;ooooo0ol0001Dooooo`005Oooool00ol0003ooooooooo
o`2dooooo`Co0000D?ooool000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005
ooooo`03o`000?oooooooooo0;Sooooo1?l0001<ooooo`0000Goooooo`000?ooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`2looooo`?o0000BOoo
ool00005ooooool0003oooooooooool000001oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0_oooool4o`0004Gooooo00001Ooooooo0000oooooooooooo000000Oooooo
1?l00005ooooo`?o0000`oooool4o`00047ooooo00001Ooooooo0000oooooooooooo000000Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`37ooooo`?o0000?_ooool00005ooooool0
003oooooooooool000002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0<[ooooo
1Ol0000iooooo`000_ooool2o`0000[ooooo0_l00005ooooo`03o`000?oooooooooo0<oooooo1Ol0
000dooooo`005Oooool00ol0003oooooooooo`3Dooooo`Ko0000;_ooool001Gooooo0_l0003Koooo
o`Go0000:Oooool001Gooooo00?o0000ooooooooool0goooool6o`0002?ooooo000Eooooo`03o`00
0?oooooooooo0>Gooooo1Ol0000Nooooo`005Oooool00ol0003oooooooooo`3Zooooo`Go00006Ooo
ool001Gooooo0_l0003`ooooo`Go00005?ooool001Gooooo00?o0000ooooooooool0m?ooool6o`00
00kooooo000Eooooo`03o`000?oooooooooo0?[ooooo1Ol00009ooooo`005Oooool00ol0003ooooo
ooooo`3oooooo`;o00001oooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2
o`000?oooooo2_ooool001Gooooo00?o0000ooooooooool0ooooool9ooooo`005Oooool00ol0003o
ooooooooo`3oooooo`Wooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.41298, -0.0512496, \
0.0192962, 0.00406896}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Sampling from a growing population",
  FontColor->RGBColor[0, 0, 1]]], "SubsubsectionIcon"],

Cell[TextData[{
  "This code just carries out this scale transformation, with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\^*\) = \(2 \( N\_e\) \[Lambda] = 
          5\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\(f[\[Lambda]_]\)[_, {t_}] := {\(1\/\[Lambda]\) 
            Log[1 + \[Lambda]\ \ t]};\)\)], "Input",
  CellLabel->"In[113]:="],

Cell[BoxData[
    \(\(growingSample = \(TransformInformation[#, f[5]] &\) /@ 
          sample;\)\)], "Input",
  CellLabel->"In[114]:="],

Cell["\<\
This shows an example from the sample, with the vertical axis \
giving coalescence time.  Coalescence tends to be more recent, simply because \
the population was smaller in the past (Note the change of scaling factor to \
15 to reflect the shorter coalescence times).\
\>", "Text"],

Cell[BoxData[
    \(\(Show[
        PlotGenealogy[
          growingSample\[LeftDoubleBracket]1\[RightDoubleBracket], 
          NodeFunction \[Rule] \(({#2\[LeftDoubleBracket]\(-1\), 
                    1\[RightDoubleBracket], 
                  15\ #2\[LeftDoubleBracket]1\[RightDoubleBracket]} &)\)]];\)\
\)], "Input",
  CellLabel->"In[115]:="],

Cell["\<\
This shows the distribution of pairwise divergence times in one \
replicate:\
\>", "Text"],

Cell[BoxData[
    \(\(PairwiseDivergencePlot[
        growingSample\[LeftDoubleBracket]1\[RightDoubleBracket], {3, 0.04}, 
        PlotJoined \[Rule] True];\)\)], "Input",
  CellLabel->"In[120]:="],

Cell["\<\
This shows the overall average - much more tightly clustered than \
for a steady population, above\
\>", "Text"],

Cell[BoxData[
    \(\(PairwiseDivergencePlot[growingSample, {3, 0.04}, 
        PlotJoined \[Rule] True];\)\)], "Input",
  CellLabel->"In[116]:="],

Cell[TextData[{
  StyleBox["Q3:",
    FontColor->RGBColor[0, 0, 1]],
  " Could you use the distribution of pairwise divergence times to detect a \
history of past population growth?  What sort of sample size would you need?"
}], "Text"]
}, Closed]],

Cell["Infinite sites mutation", "Subsubsection"],

Cell[CellGroupData[{

Cell["Representing mutation", "SubsubsectionIcon"],

Cell[TextData[{
  "This generates a random genealogy, with infinite-sites mutation thrown \
down at a rate \[Theta] = ",
  Cell[BoxData[
      \(TraditionalForm\`4 \( N\_e\) \[Mu]\)]],
  "=10:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rg = RandomGenealogy[lvs, MutationRate \[Rule] 10]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(Node[
      10, {2.119944149759364`, {}}, {Node[
          9, {2.119944149759364`, {}}, {Node[
              6, {0.35627402306150585`, {1, 2, 3, 4, 5, 6}}, {Node[
                  x9, {0, {1, 2, 3, 4, 5, 6, 13, 14, 15, 16}}, {}], 
                Node[x10, {0, {1, 2, 3, 4, 5, 6, 21, 22, 23}}, {}]}], 
            Node[8, {0.8732553053738877`, {7, 8, 9, 10, 11, 12}}, {Node[
                  3, {0.07330684875472837`, {7, 8, 9, 10, 11, 12, 17, 18, 19, 
                      20}}, {Node[
                      x8, {0, {7, 8, 9, 10, 11, 12, 17, 18, 19, 20, 
                          24}}, {}], 
                    Node[2, {0.0344741284830228`, {7, 8, 9, 10, 11, 12, 17, 
                          18, 19, 20, 28}}, {Node[
                          x2, {0, {7, 8, 9, 10, 11, 12, 17, 18, 19, 20, 
                              28}}, {}], 
                        Node[x3, {0, {7, 8, 9, 10, 11, 12, 17, 18, 19, 20, 
                              28}}, {}]}]}], 
                Node[7, {0.6305876052375985`, {7, 8, 9, 10, 11, 12}}, {Node[
                      x4, {0, {7, 8, 9, 10, 11, 12, 25, 26, 27}}, {}], 
                    Node[5, {0.2596284612441885`, {7, 8, 9, 10, 11, 
                          12}}, {Node[
                          1, {0.02712273966825519`, {7, 8, 9, 10, 11, 12, 29, 
                              30, 31}}, {Node[
                              x5, {0, {7, 8, 9, 10, 11, 12, 29, 30, 
                                  31}}, {}], 
                            Node[x6, {0, {7, 8, 9, 10, 11, 12, 29, 30, 
                                  31}}, {}]}], 
                        Node[4, {0.11485080094855135`, {7, 8, 9, 10, 11, 12, 
                              32, 33}}, {Node[
                              x1, {0, {7, 8, 9, 10, 11, 12, 32, 33, 
                                  34}}, {}], 
                            Node[x7, {0, {7, 8, 9, 10, 11, 12, 32, 
                                  33}}, {}]}]}]}]}]}]}]\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[PlotGenealogy[rg]];\)\)], "Input",
  CellLabel->"In[37]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0909091 0.0909091 0.0772542 0.0772542 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.68182 .15451 m
.63636 .07725 L
s
.68182 .15451 m
.72727 .07725 L
s
.40909 .15451 m
.36364 .07725 L
s
.40909 .15451 m
.45455 .07725 L
s
.36364 .23176 m
.27273 .07725 L
s
.36364 .23176 m
.40909 .15451 L
s
.86364 .15451 m
.81818 .07725 L
s
.86364 .15451 m
.90909 .07725 L
s
.77273 .23176 m
.68182 .15451 L
s
.77273 .23176 m
.86364 .15451 L
s
.13636 .15451 m
.09091 .07725 L
s
.13636 .15451 m
.18182 .07725 L
s
.72727 .30902 m
.54545 .07725 L
s
.72727 .30902 m
.77273 .23176 L
s
.59091 .38627 m
.36364 .23176 L
s
.59091 .38627 m
.72727 .30902 L
s
.5 .46353 m
.13636 .15451 L
s
.5 .46353 m
.59091 .38627 L
s
.5 .54078 m
.5 .46353 L
s
[(1)] .66364 .16996 0 0 Mshowa
[(2)] .39091 .16996 0 0 Mshowa
[(3)] .34545 .24721 0 0 Mshowa
[(4)] .84545 .16996 0 0 Mshowa
[(5)] .75455 .24721 0 0 Mshowa
[(6)] .11818 .16996 0 0 Mshowa
[(7)] .70909 .32447 0 0 Mshowa
[(8)] .57273 .40172 0 0 Mshowa
[(9)] .48182 .47898 0 0 Mshowa
[(10)] .48182 .55623 0 0 Mshowa
gsave
.09091 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x9) show
1.000 setlinewidth
grestore
gsave
.18182 .0618 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x10) show
1.000 setlinewidth
grestore
gsave
.27273 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x8) show
1.000 setlinewidth
grestore
gsave
.36364 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
1.000 setlinewidth
grestore
gsave
.45455 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x3) show
1.000 setlinewidth
grestore
gsave
.54545 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x4) show
1.000 setlinewidth
grestore
gsave
.63636 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x5) show
1.000 setlinewidth
grestore
gsave
.72727 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x6) show
1.000 setlinewidth
grestore
gsave
.81818 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x1) show
1.000 setlinewidth
grestore
gsave
.90909 .0618 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x7) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[37]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`006_ooool2
o`0000;ooooo0_l00002ooooo`04oa0@4?l0003oA4A4olc<c17ooooo0_l00002ooooo`;o00000ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h?ooooo`;o00000_ooool2o`00
00;ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Dooooo`;o00000_ooool2o`0000;ooooo1Ol0000C
ooooo`;o00000_ooool2o`0000;ooooo00GoV9RHoa0@4?l0003o<S8bolc<c00Dooooo`;o00000_oo
ool2o`0000Cooooo0_l000000ol@413oooooooooo`0Aooooo`;o00000_ooool2o`0000?ooooo00Go
A4A4o`000?l0003o<S8bomgMg@0Cooooo`;o00000_ooool2o`0000;ooooo00Gok^k^oc8b<_l0003o
410@olc<c00Cooooo`;o00000_ooool2o`0000?ooooo1?l000000ol@413oooooooooo`0Aooooo`;o
00000_ooool2o`0000Cooooo00?o0000onk^k_ooool07?ooool001[ooooo00Kok^k^ob4Q8On7QhOo
^[Zjo`000?oMgMd4ooooo`03oiRHV?l@413ogMgM013ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd5ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0?ooooo`06onk^
k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q01Cooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@04oooool01_o^k^ko
8B4QohN7Qonj^[[o0000omgMg@;ooooo00Go410@okZj^_ooooooMgMgoc8b<P0Dooooo`06onk^k_lQ
8B7oQhN7okZj^_l0003ogMgM1Oooool00ol0003oooooooooo`0Booooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM1_ooool00omgMgOo<S8booooo`0Booooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM
0_ooool01OmEEEGoMgMgoooooonHV9So8B4Q01?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5
ooooo`03o`000?oooooooooo01?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`03oeEE
EOnYZJWooooo01cooooo000Kooooo`04omgMgOl0003o410@olc<c0Kooooo00?oQhN7oeEEEOooool0
4?ooool01?oMgMgo0000oa0@4?o<c<`6ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400@ooooo`04omgMgOl0003o410@olc<c0?ooooo00Go0000ooooooooooooooooo`00
000Eooooo`04omgMgOl0003o410@olc<c0Cooooo00?oV9RHob4Q8Oo^k^h05Oooool01?oMgMgo0000
oa0@4?o<c<`7ooooo`03o`000?oooooooooo01?ooooo00CogMgMo`000?l@413oc<c<0oooool5o`00
01Cooooo00CogMgMo`000?l@413oc<c<2?ooool00ol0003oooooooooo`0Booooo`04omgMgOl0003o
410@olc<c0?ooooo00Go0000ooooooooooooooooo`00000Dooooo`04omgMgOl0003o410@olc<c0Ko
oooo00?o0000ooooooooool05?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`03ojVYZOmEEEGooooo
01cooooo000Kooooo`04onk^k_lQ8B7o410@onk^kP?ooooo00Goc<c<ob4Q8Ol0003oEEEEo`00000A
ooooo`04onk^k_lQ8B7o410@onk^kPKooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo0000013ooooo00Cok^k^ob4Q8Ol@413ok^k^0oooool01Olb<S;oV9RHoooooonHV9So<S8b
01Gooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool00onHV9So8B4Qonk^kP0Dooooo`04onk^k_lQ8B7o
410@onk^kPKooooo00?oZJVYoa0@4?ooool05?ooool01?o^k^ko8B4Qoa0@4?o^k^h3ooooo`04odA4
A?oMgMgoooooo`0001Gooooo00Cok^k^ob4Q8Ol@413ok^k^1oooool00omgMgOo<S8booooo`0Coooo
o`04onk^k_lQ8B7o410@onk^kP?ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Dooooo`04onk^k_lQ
8B7o410@onk^kPKooooo00?o0000ooooooooool05?ooool01?o^k^ko8B4Qoa0@4?o^k^h6ooooo`03
ob4Q8Ooooooooooo01_ooooo000Kooooo`04ob4Q8OmgMgOoMgMgoc8b<P?ooooo00Go8B4QohN7Qooo
ooooV9RHo`00000Aooooo`04ob4Q8OmgMgOoMgMgoc8b<PKooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo0000013ooooo00Co8B4QogMgMomgMgOo<S8b0oooool01Oo<c<co0000
o`000?l0003oc<c<01Gooooo00Co8B4QogMgMomgMgOo<S8b1_ooool00omgMgOoIVIVooooo`0Coooo
o`04ob4Q8OmgMgOoMgMgoc8b<PGooooo00?o410@o`000?nj^[X05Oooool01?lQ8B7oMgMgogMgMolb
<S83ooooo`04omgMgOmEEEGoooooo`0001Gooooo00Co8B4QogMgMomgMgOo<S8b1?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<01Cooooo00Co8B4QogMgMomgMgOo<S8b0oooool01Ol0003oEEEEo`000?l@
413oc<c<01Cooooo00Co8B4QogMgMomgMgOo<S8b1_ooool00ol0003oooooooooo`0Dooooo`04ob4Q
8OmgMgOoMgMgoc8b<PKooooo00?oEEEEolc<c?ooool06oooool001[ooooo0_l00002ooooo`;o0000
0_ooool01Ol0003ooooooooooooooooo0000013ooooo0_l00002ooooo`;o00001Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003oooool2o`0000;ooooo0_l00002oooo
o`05oa0@4?nj^[[ooooookZj^_l@41005?ooool2o`0000;ooooo0_l00006ooooo`03o`000?oooooo
oooo017ooooo0_l00002ooooo`;o00001Oooool00onj^[[o8B4Qooooo`0Cooooo`;o00000_ooool2
o`0000?ooooo00?oMgMgolc<c?l000005?ooool2o`0000;ooooo0_l00003ooooo`03o`000?oooooo
oooo01Gooooo0_l00002ooooo`;o00000_ooool00omEEEGoQhN7ooooo`0Eooooo`;o00000_ooool2
o`0000Gooooo00?o0000ooooooooool04oooool2o`0000;ooooo0_l00005ooooo`03ojVYZOmgMgOo
oooo01_ooooo000Rooooo`05ob4Q8OnHV9SoooooogMgMomEEED06oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05oooool01Ol0003o^[Zjoooooonj^[[o000001cooooo
00Go0000okZj^_ooooooV9RHoa0@400Kooooo`05oa0@4?nHV9SooooookZj^_l000007Oooool00oo^
k^koA4A4o`00000Mooooo`03o`000?oooooooooo01gooooo00?ogMgMoa0@4?nHV9P08?ooool00ol0
003oooooooooo`0Kooooo`05oa0@4?oooooooooooooooolb<S807?ooool002;ooooo00Goc<c<oa0@
4?l0003o<S8bonk^kP0Iooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Gooooo`05ojVYZOl@413o0000oa0@4?nYZJT07?ooool01OnHV9So410@o`000?lQ8B7oc<c<01_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Nooooo`03ogMgMol0003ooooo01cooooo1?l0000Moooo
o`04olc<c?m4A4Co0000oa0@41cooooo00?oEEEEofIVI_l000007Oooool5o`0001cooooo000Poooo
o`0300000?oooooooooo01kooooo00<00000ooooooooool07_ooool00`00003oooooooooo`0Moooo
o`0300000?oooooooooo01kooooo00<00000ooooooooool07Oooool00`00003oooooooooo`0Noooo
o`0300000?oooooooooo01gooooo00<00000ooooooooool07_ooool00`00003oooooooooo`0Noooo
o`0300000?oooooooooo01oooooo000Pooooo`0300000?oooooooooo01kooooo00<00000oooooooo
ool07_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo01kooooo00<00000oooooooo
ool07Oooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo01gooooo00<00000oooooooo
ool07_ooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo01oooooo000Qooooo`030000
0?oooooooooo01cooooo00<00000ooooooooool08?ooool00`00003oooooooooo`0Mooooo`030000
0?oooooooooo01cooooo00<00000ooooooooool07oooool00`00003oooooooooo`0Nooooo`030000
0?oooooooooo01_ooooo00<00000ooooooooool08?ooool00`00003oooooooooo`0Looooo`030000
0?oooooooooo023ooooo000Rooooo`0300000?oooooooooo01_ooooo00<00000ooooooooool08?oo
ool00`00003oooooooooo`0Mooooo`0300000?oooooooooo01_ooooo00<00000ooooooooool08Ooo
ool00`00003oooooooooo`0Mooooo`0300000?oooooooooo01_ooooo00<00000ooooooooool08?oo
ool00`00003oooooooooo`0Kooooo`0300000?oooooooooo027ooooo000Rooooo`0300000?oooooo
oooo01[ooooo00<00000ooooooooool08_ooool00`00003oooooooooo`0Mooooo`0300000?oooooo
oooo01[ooooo00<00000ooooooooool08_ooool00`00003oooooooooo`0Mooooo`0300000?oooooo
oooo01Wooooo00<00000ooooooooool08_ooool00`00003oooooooooo`0Jooooo`0300000?oooooo
oooo027ooooo000Sooooo`0300000?oooooooooo01Sooooo00<00000ooooooooool09?ooool00`00
003oooooooooo`0Mooooo`0300000?oooooooooo01Sooooo00<00000ooooooooool09?ooool00`00
003oooooooooo`0Mooooo`0300000?oooooooooo01Oooooo00<00000ooooooooool09?ooool00`00
003oooooooooo`0Hooooo`0300000?oooooooooo02;ooooo000Sooooo`0300000?oooooooooo01So
oooo00<00000ooooooooool09?ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo01So
oooo00<00000ooooooooool09?ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo01Oo
oooo00<00000ooooooooool09?ooool00`00003oooooooooo`0Hooooo`0300000?oooooooooo02;o
oooo000Tooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool09_ooool00`00003ooooo
ooooo`0Mooooo`0300000?oooooooooo01Kooooo00<00000ooooooooool09_ooool00`00003ooooo
ooooo`0Mooooo`0300000?oooooooooo01Gooooo00<00000ooooooooool09_ooool00`00003ooooo
ooooo`0Fooooo`0300000?oooooooooo02?ooooo000Uooooo`0300000?oooooooooo01Gooooo00<0
0000ooooooooool09_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo01Gooooo00<0
0000ooooooooool0:?ooool00`00003oooooooooo`0Looooo`0300000?oooooooooo01Gooooo00<0
0000ooooooooool09_ooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo02Cooooo000U
ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool0:?ooool00`00003oooooooooo`0M
ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool0:Oooool00`00003oooooooooo`0L
ooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool0:?ooool00`00003oooooooooo`0D
ooooo`0300000?oooooooooo02Cooooo000Vooooo`0300000?oooooooooo01;ooooo00<00000oooo
ooooool0:_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo01;ooooo00<00000oooo
ooooool0:_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo00<00000oooo
ooooool0:_ooool00`00003oooooooooo`0Booooo`0300000?oooooooooo02Gooooo000Wooooo`03
00000?oooooooooo017ooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0Mooooo`03
00000?oooooooooo017ooooo00<00000ooooooooool0;?ooool00`00003oooooooooo`0Looooo`03
00000?oooooooooo017ooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0Aooooo`03
00000?oooooooooo02Kooooo000Wooooo`0300000?oooooooooo013ooooo00<00000ooooooooool0
;?ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo013ooooo00<00000ooooooooool0
;Oooool00`00003oooooooooo`0Looooo`0300000?oooooooooo00oooooo00<00000ooooooooool0
;?ooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo02Kooooo000Xooooo`0300000?oo
oooooooo00oooooo00<00000ooooooooool0;?ooool00`00003oooooooooo`0Mooooo`0300000?oo
oooooooo00oooooo00<00000ooooooooool0;oooool00`00003oooooooooo`0Kooooo`0300000?oo
oooooooo00oooooo00<00000ooooooooool0;?ooool00`00003oooooooooo`0?ooooo`0300000?oo
oooooooo02Oooooo000Yooooo`0300000?oooooooooo00gooooo00<00000ooooooooool0;_ooool0
0`00003oooooooooo`0Mooooo`0300000?oooooooooo00gooooo00<00000ooooooooool0<Oooool0
0`00003oooooooooo`0Kooooo`0300000?oooooooooo00gooooo00<00000ooooooooool0;_ooool0
0`00003oooooooooo`0=ooooo`0300000?oooooooooo02Sooooo000Yooooo`0300000?oooooooooo
00cooooo00<00000ooooooooool0;oooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo
00cooooo00<00000ooooooooool0<Oooool00`00003oooooooooo`0Looooo`0300000?oooooooooo
00_ooooo00<00000ooooooooool0<?ooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo
02Sooooo000Zooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool0<?ooool00`00003o
ooooooooo`0Mooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool0<oooool00`00003o
ooooooooo`0Kooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool0<?ooool00`00003o
ooooooooo`0;ooooo`0300000?oooooooooo02Wooooo000Zooooo`0300000?oooooooooo00[ooooo
00<00000ooooooooool0<_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00[ooooo
00<00000ooooooooool0=?ooool00`00003oooooooooo`0Kooooo`0300000?oooooooooo00Wooooo
00<00000ooooooooool0<_ooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo02Wooooo
000[ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool0<_ooool00`00003ooooooooo
o`0Mooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool0=_ooool00`00003ooooooooo
o`0Jooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool0<_ooool00`00003ooooooooo
o`09ooooo`0300000?oooooooooo02[ooooo000/ooooo`0300000?oooooooooo00Oooooo00<00000
ooooooooool0=?ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00Oooooo00<00000
ooooooooool0=oooool00`00003oooooooooo`0Kooooo`0300000?oooooooooo00Oooooo00<00000
ooooooooool0=?ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo02_ooooo000/oooo
o`0300000?oooooooooo00Kooooo00<00000ooooooooool0=Oooool00`00003oooooooooo`0Noooo
o`0300000?oooooooooo00Kooooo00<00000ooooooooool0>?ooool00`00003oooooooooo`0Koooo
o`0300000?oooooooooo00Gooooo00<00000ooooooooool0=_ooool00`00003oooooooooo`06oooo
o`0300000?oooooooooo02_ooooo000]ooooo`0300000?oooooooooo00Gooooo00<00000oooooooo
ool0=_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00Gooooo00<00000oooooooo
ool0>_ooool00`00003oooooooooo`0Jooooo`0300000?oooooooooo00Gooooo00<00000oooooooo
ool0=_ooool00`00003oooooooooo`05ooooo`0300000?oooooooooo02cooooo000^ooooo`030000
0?oooooooooo00?ooooo00<00000ooooooooool0>?ooool00`00003oooooooooo`0Mooooo`030000
0?oooooooooo00?ooooo00<00000ooooooooool0??ooool00`00003oooooooooo`0Jooooo`030000
0?oooooooooo00?ooooo00<00000ooooooooool0>?ooool00`00003oooooooooo`03ooooo`030000
0?oooooooooo02gooooo000^ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool0>?oo
ool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool0?Ooo
ool00`00003oooooooooo`0Iooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool0>?oo
ool00`00003oooooooooo`03ooooo`0300000?oooooooooo02gooooo000_ooooo`0500000?oooooo
ooooooooo`000000??ooool00`00003oooooooooo`0Mooooo`0500000?ooooooooooooooo`000000
@?ooool00`00003oooooooooo`0Jooooo`0500000?ooooooooooooooo`000000??ooool01@00003o
ooooooooooooool00000033ooooo000_ooooo`0400000?oooooooooo000003gooooo00<00000oooo
ooooool07_ooool01000003oooooooooo`000011ooooo`0300000?oooooooooo01[ooooo00<00000
ooooo`000000?_ooool01000003oooooooooo`00000`ooooo`00<?ooool00`00003ooooo0000000n
ooooo`0300000?oooooooooo01gooooo00<00000ooooo`000000@oooool00`00003oooooooooo`0I
ooooo`0300000?ooool0000003kooooo00<00000ooooo`000000<Oooool0037ooooo0P00000noooo
o`0300000?oooooooooo01kooooo00<00000ooooooooool0@oooool00`00003oooooooooo`0Ioooo
o`800000?_ooool2000003;ooooo000cooooo`0300000?oooooooooo03cooooo00<00000oooooooo
ool07Oooool00`00003oooooooooo`14ooooo`0300000?oooooooooo01[ooooo00<00000oooooooo
ool0>_ooool00`00003oooooooooo`0booooo`00=?ooool00`00003oooooooooo`0looooo`030000
0?oooooooooo01_ooooo00<00000ooooooooool0AOooool00`00003oooooooooo`0Kooooo`030000
0?oooooooooo03Sooooo00<00000ooooooooool0<oooool003Gooooo00<00000ooooooooool0>ooo
ool00`00003oooooooooo`0Kooooo`0300000?oooooooooo04Kooooo00<00000ooooooooool06ooo
ool00`00003oooooooooo`0fooooo`0300000?oooooooooo03Cooooo000Wooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`02_ooool00`00003oooooooooo`0kooooo`0300000?oooooooooo01;ooooo1Ol0
0002ooooo`0300000?oooooooooo04Sooooo00<00000ooooooooool03_ooool4o`000003oa0@4?oo
oooooooo00Kooooo00<00000ooooooooool0<_ooool3o`0003Oooooo000Wooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B402oooool00`00003oooooooooo`0jooooo`0300000?oooooooooo01;ooooo00Oo
V9RHob4Q8Oo^k^koooooodA4A?ooool0000004cooooo00<00000ooooooooool03oooool00ol0003o
ooooooooo`09ooooo`0300000?oooooooooo03;ooooo00?o0000ooooooooool0=_ooool002Oooooo
00Go0000ooooooooooooooooo`00000<ooooo`800000>oooool00`00003oooooooooo`0Booooo`03
oiRHV?lQ8B7ok^k^00;ooooo00<00000ooooooooool0B_ooool00`00003oooooooooo`0?ooooo`03
o`000?oooooooooo00[ooooo0P00000_ooooo`Go0000=oooool002Oooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0>ooooo`0300000?oooooooooo03Sooooo00<00000ooooooooool04oooool01?nHV9So
8B4Qonk^kP00001>ooooo`0300000?oooooooooo00kooooo00?o0000ooooooooool03?ooool00`00
003oooooooooo`0/ooooo`;o000000?oooooo`000?ooool0=oooool002Oooooo00Go0000oeEEEOl0
003o410@olc<c00?ooooo`0300000?oooooooooo03Sooooo00<00000ooooooooool04oooool00omg
MgOoIVIV0000001?ooooo`0300000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00`00
003oooooooooo`0Zooooo`0500000?oMgMgoEEEEooooool00000>?ooool002Oooooo00?oEEEEohN7
Qoooool04_ooool00`00003oooooooooo`0hooooo`0300000?oooooooooo01?ooooo00?o0000oooo
ooooool0Coooool00`00003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo00<00000oooo
ooooool0:?ooool01P00003ooooooooooomgMgOoc<c<o`0003Sooooo000Wooooo`03omgMgOl@413o
V9RH01?ooooo00<00000ooooooooool0=oooool00`00003oooooooooo`0?ooooo`05o`000?nj^[[o
oooooiRHV?l00000D_ooool00`00003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00<0
0000ooooooooool09_ooool01`00003oooooooooooooooook^k^odA4A?l00000>?ooool002Sooooo
00Coc<c<odA4A?l0003o410@4_ooool00`00003oooooooooo`0gooooo`0300000?oooooooooo00ko
oooo00GoV9RHoa0@4?l0003o0000olc<c01Booooo`0300000?oooooooooo00Wooooo00?oEEEEofIV
I_l000004_ooool2000002Gooooo00<00000ooooooooool00oooool00omgMgOo0000ooooo`0goooo
o`00?oooool2000003Oooooo00<00000ooooooooool04?ooool00`00003oooooooooo`1Cooooo`03
00000?oooooooooo01oooooo00<00000ooooooooool08Oooool00`00003oooooooooo`0nooooo`00
@Oooool00`00003oooooooooo`0eooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0
E?ooool00`00003oooooooooo`0Oooooo`0300000?oooooooooo01oooooo00<00000ooooooooool0
?oooool004;ooooo00<00000ooooooooool0=Oooool00`00003oooooooooo`0=ooooo`0300000?oo
oooooooo05Kooooo00<00000ooooooooool07oooool00`00003oooooooooo`0Looooo`800000@_oo
ool004?ooooo00<00000ooooooooool0=?ooool00`00003oooooooooo`0=ooooo`0300000?oooooo
oooo05Oooooo00<00000ooooooooool07oooool00`00003oooooooooo`0Jooooo`0300000?oooooo
oooo04;ooooo0014ooooo`0300000?oooooooooo03Cooooo00<00000ooooooooool02oooool00`00
003oooooooooo`1Hooooo`0300000?oooooooooo023ooooo00<00000ooooooooool06?ooool00`00
003oooooooooo`13ooooo`00AOooool00`00003oooooooooo`0cooooo`0300000?oooooooooo00_o
oooo00<00000ooooooooool0FOooool00`00003oooooooooo`0Pooooo`8000005oooool00`00003o
ooooooooo`14ooooo`00A_ooool2000003Cooooo00<00000ooooooooool02Oooool00`00003ooooo
ooooo`1Kooooo`0300000?oooooooooo027ooooo00<00000ooooooooool04oooool00`00003ooooo
ooooo`15ooooo`00B?ooool00`00003oooooooooo`0aooooo`0300000?oooooooooo00Sooooo00<0
0000ooooooooool0GOooool00`00003oooooooooo`0Qooooo`0300000?oooooooooo017ooooo00<0
0000ooooooooool0A_ooool004Wooooo00<00000ooooooooool0<Oooool00`00003oooooooooo`07
ooooo`0300000?oooooooooo05gooooo00<00000ooooooooool08_ooool00`00003oooooooooo`0?
ooooo`0300000?oooooooooo04Oooooo001:ooooo`0300000?oooooooooo037ooooo00<00000oooo
ooooool01Oooool00`00003oooooooooo`1Oooooo`0300000?oooooooooo02;ooooo00<00000oooo
ooooool03?ooool2000004[ooooo001;ooooo`0300000?oooooooooo033ooooo00<00000oooooooo
ool01Oooool00`00003oooooooooo`1Pooooo`0300000?oooooooooo02;ooooo0P00000;ooooo`03
00000?oooooooooo04[ooooo001<ooooo`800000<Oooool00`00003oooooooooo`03ooooo`030000
0?oooooooooo06;ooooo00<00000ooooooooool08oooool00`00003oooooooooo`07ooooo`030000
0?oooooooooo04_ooooo001>ooooo`0300000?oooooooooo02kooooo00<00000ooooooooool00ooo
ool00`00003oooooooooo`1Sooooo`0300000?oooooooooo02?ooooo00<00000ooooooooool01Ooo
ool00`00003oooooooooo`1<ooooo`00Coooool00`00003oooooooooo`0^ooooo`0500000?oooooo
ooooooooo`000000I_ooool00`00003oooooooooo`0Tooooo`0300000?oooooooooo00?ooooo00<0
0000ooooooooool0COooool0053ooooo00<00000ooooooooool0;_ooool00`00003ooooo0000001X
ooooo`0300000?oooooooooo02Cooooo00D00000oooooooooooooooo0000001@ooooo`00DOooool0
0`00003oooooooooo`0]ooooo`0300000?ooool0000006Wooooo00<00000ooooooooool09?ooool0
0`00003ooooo0000001Aooooo`00D_ooool00`00003oooooooooo`0]ooooo`800000J_ooool00`00
003oooooooooo`0Tooooo`0300000?oooooooooo053ooooo001Cooooo`800000;oooool00`00003o
ooooooooo`1Wooooo`0300000?oooooooooo02Cooooo00<00000ooooooooool0D?ooool005Gooooo
00<00000ooooooooool0;Oooool2000006Sooooo00<00000ooooooooool08_ooool00`00003ooooo
ooooo`1Aooooo`00E_ooool00`00003oooooooooo`0Pooooo`05oiRHV?l@413o0000oc8b<_o<c<`0
2Oooool00`00003oooooooooo`1Vooooo`0300000?oooooooooo01Wooooo00GoA4A4o`000?l0003o
<S8bomgMg@02ooooo`0300000?oooooooooo05;ooooo001Gooooo`0300000?oooooooooo01oooooo
00Go410@okZj^_ooooooMgMgoc8b<P0:ooooo`800000Ioooool00`00003oooooooooo`0Kooooo`05
ogMgMolb<S;oooooooooo`000000E?ooool005Sooooo00<00000ooooooooool08_ooool00ol0003o
ooooooooo`0:ooooo`0300000?oooooooooo06Gooooo00<00000ooooooooool06oooool00ol0003o
oooo0000001Eooooo`00FOooool00`00003oooooooooo`0Pooooo`03ojVYZOl@413ooooo00cooooo
0P00001Uooooo`0300000?oooooooooo01[ooooo00CoMgMgoc8b<_ooool00000EOooool005[ooooo
0P00000Oooooo`03oa0@4?l0003o^[Zj00oooooo00<00000ooooooooool0Hoooool00`00003ooooo
ooooo`0Fooooo`06o`000?lQ8B7o0000oc8b<_o<c<`00000E_ooool005cooooo00<00000oooooooo
ool07Oooool00onj^[[o8B4Qooooo`0?ooooo`800000I?ooool00`00003oooooooooo`0Eooooo`05
o`000?ooooooooooooooo`000000Eoooool005gooooo00<00000ooooooooool06Oooool01Ol@413o
V9RHoooooonj^[[o000001;ooooo00<00000ooooooooool0H_ooool00`00003oooooooooo`0Doooo
o`05o`000?ooooooooooooooo`000000Eoooool005kooooo00<00000ooooooooool06?ooool01OnY
ZJWo410@o`000?l@413oZJVY01?ooooo0P00001Sooooo`0300000?oooooooooo01?ooooo1?l0001H
ooooo`00Goooool00`00003oooooooooo`0aooooo`0300000?oooooooooo063ooooo00<00000oooo
ooooool05_ooool00`00003oooooooooo`1Fooooo`00H?ooool00`00003oooooooooo`0aooooo`80
0000HOooool00`00003oooooooooo`0Dooooo`0300000?oooooooooo05Oooooo001Qooooo`800000
<oooool00`00003oooooooooo`1Oooooo`0300000?oooooooooo01;ooooo00<00000ooooooooool0
F?ooool006?ooooo00<00000ooooooooool0<Oooool20000063ooooo00<00000ooooooooool04Ooo
ool00`00003oooooooooo`1Hooooo`00I?ooool00`00003oooooooooo`0booooo`0300000?oooooo
oooo05gooooo00<00000ooooooooool04?ooool00`00003oooooooooo`1Iooooo`00IOooool00`00
003oooooooooo`0booooo`800000G_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
05Wooooo001Vooooo`0300000?oooooooooo03?ooooo00<00000ooooooooool0G?ooool00`00003o
ooooooooo`0=ooooo`0300000?oooooooooo05[ooooo001Wooooo`0300000?oooooooooo03?ooooo
0P00001Mooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool0Foooool006Sooooo0P00
000eooooo`0300000?oooooooooo05_ooooo00<00000ooooooooool02_ooool00`00003ooooooooo
o`1Kooooo`00J_ooool00`00003oooooooooo`0cooooo`800000Foooool00`00003oooooooooo`09
ooooo`0300000?oooooooooo05cooooo001[ooooo`0300000?oooooooooo03Cooooo00<00000oooo
ooooool0FOooool00`00003oooooooooo`08ooooo`0300000?oooooooooo05cooooo001/ooooo`03
00000?oooooooooo03Cooooo0P00001Jooooo`0300000?oooooooooo00Kooooo00<00000oooooooo
ool0GOooool006gooooo00<00000ooooooooool0=Oooool00`00003oooooooooo`1Hooooo`030000
0?oooooooooo00Cooooo00<00000ooooooooool0G_ooool006kooooo00<00000ooooooooool0=Ooo
ool2000005Sooooo00<00000ooooooooool01?ooool00`00003oooooooooo`1Nooooo`00Koooool2
000003Oooooo00<00000ooooooooool0E_ooool00`00003oooooooooo`02ooooo`0300000?oooooo
oooo05oooooo001aooooo`0300000?oooooooooo03Gooooo0P00001Gooooo`0500000?oooooooooo
ooooo`000000HOooool007;ooooo00<00000ooooooooool0=_ooool00`00003oooooooooo`1Eoooo
o`0300000?ooool0000006;ooooo001cooooo`0300000?oooooooooo03Kooooo00<00000oooooooo
ool0E?ooool2000006?ooooo001dooooo`0300000?oooooooooo03Kooooo0P00001Booooo`800000
IOooool007Gooooo0P00000hooooo`0300000?oooooooooo04kooooo00<00000ooooooooool0IOoo
ool007Oooooo00<00000ooooooooool0=_ooool2000004_ooooo0_l000000`00003oooooooooo`1V
ooooo`00N?ooool00`00003oooooooooo`0gooooo`0300000?oooooooooo04Oooooo00<00000o`00
0?nYZJT0JOooool007Wooooo00<00000ooooooooool0=oooool2000004Gooooo0P0000000ooooooo
ZJVYoeEEE@1Yooooo`00N_ooool00`00003oooooooooo`0hooooo`0300000?oooooooooo043ooooo
0P000004ooooo`03ob4Q8Ooooooooooo06Oooooo001kooooo`0300000?oooooooooo03Sooooo0P00
000oooooo`0300000?oooooooooo00Cooooo00?oEEEEolc<c?ooool0Ioooool007cooooo0P00000j
ooooo`0300000?oooooooooo03[ooooo0P000007ooooo`03ojVYZOmgMgOooooo06Oooooo001noooo
o`0300000?oooooooooo03Sooooo0P00000hooooo`8000001_ooool01Ol@413ooooooooooooooooo
<S8b06Sooooo001oooooo`0300000?oooooooooo03Wooooo00<00000ooooooooool0<oooool20000
00Sooooo1Ol0001Xooooo`00P?ooool00`00003oooooooooo`0iooooo`800000<_ooool00`00003o
ooooooooo`1eooooo`00POooool00`00003oooooooooo`0jooooo`0300000?oooooooooo02gooooo
0P00001hooooo`00P_ooool00`00003oooooooooo`0jooooo`800000:oooool2000007[ooooo0023
ooooo`800000??ooool00`00003oooooooooo`0Vooooo`800000O?ooool008Gooooo00<00000oooo
ooooool0>_ooool2000002Cooooo0P00001nooooo`00Q_ooool00`00003oooooooooo`0kooooo`03
00000?oooooooooo023ooooo00<00000ooooooooool0O_ooool008Oooooo00<00000ooooooooool0
>oooool2000001kooooo0P000021ooooo`00R?ooool00`00003oooooooooo`0looooo`0300000?oo
oooooooo01Wooooo0P000023ooooo`00ROooool00`00003oooooooooo`0looooo`8000005oooool2
000008Gooooo002:ooooo`800000?_ooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo
08Gooooo002<ooooo`0300000?oooooooooo03cooooo0P00000Aooooo`800000R?ooool008gooooo
00<00000ooooooooool0?Oooool00`00003oooooooooo`0<ooooo`800000R_ooool008kooooo00<0
0000ooooooooool0?Oooool2000000[ooooo0P00002<ooooo`00Soooool00`00003oooooooooo`0n
ooooo`0300000?oooooooooo00Gooooo0P00002>ooooo`00T?ooool00`00003oooooooooo`0noooo
o`8000001?ooool00`00003oooooooooo`2>ooooo`00TOooool20000043ooooo00@00000ooooo`00
00000000TOooool009?ooooo00<00000ooooooooool0?Oooool2000009?ooooo002Dooooo`030000
0?oooooooooo03_ooooo00<00000ooooooooool0Toooool009Gooooo00<00000ooooooooool0>Ooo
ool00`00003oooooooooo`2Dooooo`00U_ooool00`00003oooooooooo`0gooooo`0300000?oooooo
oooo09Gooooo002Gooooo`0300000?oooooooooo033ooooo00Koc<c<ob4Q8Ol0003o8B4Qolc<c000
002Hooooo`00V?ooool20000033ooooo00Go8B4QoiRHV?ooooooV9RHo`00002Iooooo`00V_ooool0
0`00003oooooooooo`0]ooooo`05o`000?ooool0000000000?l00000VOooool009_ooooo00<00000
ooooooooool0;?ooool01Olb<S;o0000oooooonHV9So<S8b09Wooooo002Looooo`0300000?oooooo
oooo02_ooooo1?l000000oo<c<coooooooooo`2Gooooo`00WOooool00`00003oooooooooo`0Yoooo
o`0600000?l@413o^[Zjoooooonj^[[o410@VOooool009kooooo0P00000Xooooo`0700000?oooooo
0000okZj^_oooooo^[Zjo`00002Iooooo`00X?ooool00`00003oooooooooo`0Sooooo`8000000_oo
ool01OnYZJWo410@o`000?l@413oZJVY09Wooooo002Qooooo`0300000?oooooooooo027ooooo00<0
0000ooooooooool0X?ooool00:;ooooo00<00000ooooooooool07oooool00`00003oooooooooo`2Q
ooooo`00Xoooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo0:;ooooo002Tooooo`03
00000?oooooooooo01_ooooo00<00000ooooooooool0Xoooool00:Gooooo0P00000Jooooo`030000
0?oooooooooo0:Cooooo002Wooooo`0300000?oooooooooo01Gooooo0P00002Wooooo`00Z?ooool0
0`00003oooooooooo`0Cooooo`0300000?oooooooooo0:Oooooo002Yooooo`0300000?oooooooooo
017ooooo00<00000ooooooooool0Z?ooool00:[ooooo00<00000ooooooooool03oooool00`00003o
ooooooooo`2Yooooo`00Zoooool00`00003oooooooooo`0=ooooo`0300000?oooooooooo0:[ooooo
002/ooooo`8000002oooool200000:gooooo002^ooooo`0300000?oooooooooo00Oooooo00<00000
ooooooooool0[Oooool00:oooooo00<00000ooooooooool01Oooool00`00003oooooooooo`2^oooo
o`00/?ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo0:oooooo002aooooo`050000
0?ooooooooooooooo`000000/_ooool00;;ooooo00<00000ooooo`000000/oooool00;?ooooo00<0
0000ooooooooool0/_ooool00;?ooooo00<00000ooooooooool0/_ooool00;?ooooo00<00000oooo
ooooool0/_ooool00:Wooooo00Co410@o`000?m4A4Coc<c<1_ooool00`00003oooooooooo`2boooo
o`00Zoooool00onHV9So410@omgMg@05ooooo`0300000?oooooooooo0;;ooooo002/ooooo`03ohN7
QomEEEGooooo00Cooooo00<00000ooooooooool0/_ooool00:Wooooo00Goc<c<ob4Q8Ol0003oEEEE
o`000005ooooo`0300000?oooooooooo0;;ooooo002Yooooo`05ob4Q8On7QhOooooooiRHV?l00000
1Oooool00`00003oooooooooo`2booooo`00ZOooool01Ol0003ooooooooooooooooo000000Gooooo
00<00000ooooooooool0/_ooool00:Wooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@05ooooo`030000
0?oooooooooo0;;ooooo002Yooooo`05olc<c?l@413o0000oc8b<_o^k^h01Oooool00`00003ooooo
ooooo`2booooo`00/oooool00`00003oooooooooo`2booooo`00/oooool00`00003oooooooooo`2b
ooooo`00/oooool00`00003oooooooooo`2booooo`00/oooool00`00003oooooooooo`2booooo`00
/oooool00`00003oooooooooo`2booooo`00/oooool00`00003oooooooooo`2booooo`00/oooool0
0`00003oooooooooo`2booooo`00/oooool00`00003oooooooooo`2booooo`00/oooool00`00003o
ooooooooo`2booooo`00/oooool00`00003oooooooooo`2booooo`00/oooool00`00003ooooooooo
o`2booooo`00/oooool00`00003oooooooooo`2booooo`00/oooool00`00003oooooooooo`2boooo
o`00/oooool00`00003oooooooooo`2booooo`00/oooool00`00003oooooooooo`2booooo`00/ooo
ool00`00003oooooooooo`2booooo`00/oooool00`00003oooooooooo`2booooo`00/oooool00`00
003oooooooooo`2booooo`00oooooomYooooo`00oooooomYooooo`00Y_ooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^jfooooo`00Z?ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0]_ooool00:Sooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@0;Kooooo002Xooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00002fooooo`00Z?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000]_ooool00:Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
0;Kooooo002Xooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2foooo
o`00Y_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0]_ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1.01242, -1.00004, \
0.0383873, 0.0451724}}]
}, Open  ]],

Cell["\<\
The second element of the information list carries a list of the \
mutations.  Mutations are labelled by an integer.\
\>", "Text"],

Cell["These are the mutations that occurred in the genealogy:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ms = Mutations[rg]\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
      21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34}\)], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell["There are 34 segregating sites:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[ms]\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \(34\)], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell["\<\
This shows the number of sites which differ between each pair of \
leaves:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pd = PairwiseDifference[rg]\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \({18, 8, 8, 6, 6, 6, 1, 8, 19, 20, 20, 18, 18, 18, 17, 20, 7, 0, 8, 8, 
      8, 7, 2, 21, 8, 8, 8, 7, 2, 21, 6, 6, 5, 8, 19, 0, 5, 8, 19, 5, 8, 19, 
      7, 18, 21}\)], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell["\<\
This is the mean pairwise difference.  The measure of nucleotide \
diversity, \[Pi], would be obtained by dividing by the length of the sequence \
in base pairs:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mean[pd] // N\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \(10.666666666666666`\)], "Output",
  CellLabel->"Out[41]="]
}, Open  ]],

Cell["\<\
This shows the distribution of numbers of differences between pairs \
of genes:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PairwiseDifferencePlot[rg, {50, 1}, 
        PlotJoined \[Rule] True];\)\)], "Input",
  CellLabel->"In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.01924 0.0147151 0.117721 [
[.21621 .00222 -6 -9 ]
[.21621 .00222 6 0 ]
[.40861 .00222 -6 -9 ]
[.40861 .00222 6 0 ]
[.60101 .00222 -6 -9 ]
[.60101 .00222 6 0 ]
[.79341 .00222 -6 -9 ]
[.79341 .00222 6 0 ]
[.98581 .00222 -6 -9 ]
[.98581 .00222 6 0 ]
[.01131 .13244 -6 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -6 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -6 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -6 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21621 .01472 m
.21621 .02097 L
s
[(10)] .21621 .00222 0 1 Mshowa
.40861 .01472 m
.40861 .02097 L
s
[(20)] .40861 .00222 0 1 Mshowa
.60101 .01472 m
.60101 .02097 L
s
[(30)] .60101 .00222 0 1 Mshowa
.79341 .01472 m
.79341 .02097 L
s
[(40)] .79341 .00222 0 1 Mshowa
.98581 .01472 m
.98581 .02097 L
s
[(50)] .98581 .00222 0 1 Mshowa
.125 Mabswid
.06229 .01472 m
.06229 .01847 L
s
.10077 .01472 m
.10077 .01847 L
s
.13925 .01472 m
.13925 .01847 L
s
.17773 .01472 m
.17773 .01847 L
s
.25469 .01472 m
.25469 .01847 L
s
.29317 .01472 m
.29317 .01847 L
s
.33165 .01472 m
.33165 .01847 L
s
.37013 .01472 m
.37013 .01847 L
s
.44709 .01472 m
.44709 .01847 L
s
.48557 .01472 m
.48557 .01847 L
s
.52405 .01472 m
.52405 .01847 L
s
.56253 .01472 m
.56253 .01847 L
s
.63949 .01472 m
.63949 .01847 L
s
.67797 .01472 m
.67797 .01847 L
s
.71645 .01472 m
.71645 .01847 L
s
.75493 .01472 m
.75493 .01847 L
s
.83189 .01472 m
.83189 .01847 L
s
.87037 .01472 m
.87037 .01847 L
s
.90885 .01472 m
.90885 .01847 L
s
.94733 .01472 m
.94733 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(1)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(2)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(3)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(4)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(5)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03826 m
.02756 .03826 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .08535 m
.02756 .08535 L
s
.02381 .10889 m
.02756 .10889 L
s
.02381 .15598 m
.02756 .15598 L
s
.02381 .17952 m
.02756 .17952 L
s
.02381 .20307 m
.02756 .20307 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .2737 m
.02756 .2737 L
s
.02381 .29724 m
.02756 .29724 L
s
.02381 .32079 m
.02756 .32079 L
s
.02381 .34433 m
.02756 .34433 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .41497 m
.02756 .41497 L
s
.02381 .43851 m
.02756 .43851 L
s
.02381 .46205 m
.02756 .46205 L
s
.02381 .50914 m
.02756 .50914 L
s
.02381 .53269 m
.02756 .53269 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57977 m
.02756 .57977 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03343 .13244 m
.05267 .25016 L
.07191 .01472 L
.09115 .01472 L
.11039 .36788 L
.12963 .60332 L
.14887 .4856 L
s
.14887 .4856 m
.15158 .61803 L
s
.17913 .61803 m
.18735 .01472 L
.20659 .01472 L
.22583 .01472 L
.24507 .01472 L
.26431 .01472 L
.28355 .01472 L
.30279 .01472 L
.32203 .01472 L
.34127 .13244 L
.36051 .60332 L
.37975 .4856 L
.39899 .36788 L
.41823 .36788 L
.43747 .01472 L
.45671 .01472 L
.47595 .01472 L
.49519 .01472 L
.51443 .01472 L
.53367 .01472 L
.55291 .01472 L
.57215 .01472 L
.59139 .01472 L
.61063 .01472 L
.62987 .01472 L
.64911 .01472 L
.66835 .01472 L
.68759 .01472 L
.70683 .01472 L
.72607 .01472 L
.74531 .01472 L
.76455 .01472 L
.78379 .01472 L
.80303 .01472 L
.82227 .01472 L
.84151 .01472 L
.86075 .01472 L
.87999 .01472 L
.89923 .01472 L
.91847 .01472 L
.93771 .01472 L
.95695 .01472 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00COooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^hdooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Gooooo00GoV9RHoa0@4?l0003o
<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0=_ooool2o`000009oa0@4?oooooooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^03Kooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02Oooool004oooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0=Oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0gooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0ioooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00Wooooo001?ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400eooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@400iooooo`05o`000?ooooooooooooooool@41000oooool00ol@
413oooooooooo`0booooo`Go00000oooool01Ol@413ooooooooooooooooo410@03[ooooo00Co0000
oooooooooooo410@0oooool00ol@413oooooooooo`07ooooo`00Coooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool00000=_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oo
ooooooooooooool00000>?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool0
0000=?ooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool00000>Oooool0
1OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool01oooool004oooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000003Oooooo00?oMgMgofIVI_ooool00_oo
ool01Ol0003ooooooooooooooooo000003Oooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooo
oooooooooooo000003Cooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo
000003Kooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool00000
2Oooool004oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03Sooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo03Kooooo00?o^[Zjob4Q8Ooo
ool00_ooool01Ol@413ooooooooooooooooo410@03Gooooo00?oMgMgolc<c?l000001?ooool01Ol@
413ooooooooooooooooo410@03Kooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooo
oooo410@00Wooooo001?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0dooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg03Go
oooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=Oooool0
0oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooooooo
o`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool004gooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^03Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0=Oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0fooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0fooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Wooooo003oooooofWooooo
000Aooooo`03o`000?oooooooooo0?ooooooEOooool0017ooooo00?o0000ooooooooool0oooooomE
ooooo`004Oooool00ol0003oooooooooo`3ooooooeGooooo000Aooooo`03o`000?oooooooooo0?oo
ooooEOooool0017ooooo00?o0000ooooooooool0oooooomEooooo`002Oooooooo`0005Oo00002Ooo
ool0017ooooo00?o0000ooooooooool02oooool01?l0003oooooooooool00005ooooo`05o`000?oo
ooooooooooooool000003?ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Wo
oooo00<00000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oo
oooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Oooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00cooooo000Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo00<00000ooooooooool08Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool03?ooool0017o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0<Oo
oooo000Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`37ooooo`004Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0aoooool0017ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo0<Oooooo000Aooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`37ooooo`004Oooool3o`0000gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`37ooooo`004Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0aoooool0017ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0<Oooooo000Aooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`38ooooo`004Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0b?ooool0017o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0<So
oooo000Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`38ooooo`004Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0b?ooool0017ooooo0ol0000=ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0b?ooool0017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo0<Sooooo000Aooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`38ooooo`004Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0b?ooool0017ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0<Sooooo000Aooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`38ooooo`004Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0b?ooool0017o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0<So
oooo000Aooooo`?o00003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0<Sooooo
000Aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`38ooooo`004Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0b?ooool0017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo0<Sooooo000Aooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`38ooooo`004Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0b?ooool0017ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0<Sooooo000Aooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`39ooooo`004Oooool3o`00
00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`39ooooo`004Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0bOooool0017ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0<Wooooo
000Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`39ooooo`004Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0bOooool000Oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`39ooooo`002Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`39ooooo`002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`39ooooo`002Oooool00ol0003ooooooooo
o`05ooooo`Go00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0<Wooooo0009
ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0bOooool000Wooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`39ooooo`002Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0<Wooooo0007ooooo`03oeEEEOmVIVKo
000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0bOooool0017ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0bOooool0017o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0bOooool0017ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0bOooool0017ooooo0ol0
0002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`39ooooo`004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`39ooooo`004Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`39oooo
o`004Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`3:ooooo`004Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`3:ooooo`004Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`3:ooooo`004Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`3:ooooo`004Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`3:ooooo`004Oooool3o`0000?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo0<[ooooo000Aooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0<[ooooo
000Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo0<[ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0<[ooooo000Aoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo0<[ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0<[ooooo000Aooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo0<[ooooo000Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0<[ooooo000Aooooo`?o00001Oooool0
1?l0003oooooooooool0000?ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0<[ooooo000Aooooo`03o`000?oooooo
oooo00Gooooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`3:ooooo`004Oooool0
0ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0b_oo
ool0017ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0000?ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo0<[ooooo000Aooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00003ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`3:ooooo`004Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooo
ooooo`0000oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0b_ooool0017ooooo00?o0000ooooooooool01Oooool0
1?l0003oooooooooool0000?ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0<[ooooo000Aooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooool000003oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`3;ooooo`004Oooool3o`00
00Kooooo00?o0000ooooool000003oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`3;ooooo`004Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0boooool0017ooooo
00?o0000ooooooooool01_ooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0<_ooooo
000Aooooo`03o`000?oooooooooo00Kooooo0_l0000@ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0<_ooooo000A
ooooo`03o`000?oooooooooo00Kooooo0_l0000@ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0<_ooooo0006oooo
o`Go00001_ooool00ol0003oooooooooo`06ooooo`;o00004?ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`3;oooo
o`001_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo0<_ooooo0007ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0<_o
oooo0008ooooo`03oiRHV?lQ8B7ok^k^00Kooooo1?l00006ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0boooool000Wooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo0<_ooooo000:ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`3;ooooo`001_ooool01Ol0003o^[ZjoooooonHV9So
410@00Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`3;ooooo`001_ooool01OnH
V9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`3;
ooooo`004Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0<_ooooo000Aooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0boooool0017ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`3;ooooo`004Oooool3o`0001Wooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0booo
ool0017ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`3;ooooo`004Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo0<_ooooo000Aooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0c?ooool0017ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`3<ooooo`004Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<cooooo000A
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0c?ooool0017ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`3<ooooo`004Oooool3o`0001[ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0c?ooool0017ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`3<ooooo`004Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0<cooooo000Aooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0c?ooool0017ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`3<ooooo`004Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0<co
oooo000Aooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0c?ooool0017ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`3<ooooo`004Oooool3o`0001[ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0c?ooool0017ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3<oooo
o`004Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0<cooooo000Aooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0c?ooool0017ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`3<ooooo`004Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo0<cooooo000Aooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0c?ooool0017o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`3=ooooo`004Oooool3o`0001_ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0cOooool0017ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`3=ooooo`004Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0<gooooo000Aoooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0cOooool0017ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`3=ooooo`001_ooool01OnHV9So410@o`000?lb<S;oc<c<00Ko
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`3=ooooo`001_ooool01Ol@413o^[Zj
oooooomgMgOo<S8b00Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`3=ooooo`00
2_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
cOooool000Wooooo00?oZJVYoa0@4?ooool01Oooool4o`0001[ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00kooooo2?l0003?ooooo`002?ooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0e?ooool0
00Wooooo00?o^[Zjob4Q8Oooool01Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
0=Cooooo0006ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo0=Cooooo0006ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo0=Gooooo000Aooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0eOooool0017ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`3Eooooo`004Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0=Gooooo000A
ooooo`?o00007?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`3Eooooo`004Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo0=Gooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0eOooool0017ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3Fooooo`004Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0=Kooooo000Aooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0e_ooool0017ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`3Fooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0=Ko
oooo000Aooooo`?o00007?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`3Fooooo`004Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo0=Kooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0eoooool0017ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3Goooo
o`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0=Oooooo000Aooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0eoooool0017ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`3Gooooo`004Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo0=Oooooo000Aooooo`?o00007Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3Hooooo`004Oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo0=Sooooo000Aooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0f?ooool0017ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`3Hooooo`004Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0=Sooooo000Aoooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0f?ooool0017ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`3Hooooo`004Oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0=Wooooo000Aooooo`?o00007Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Iooooo`004Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=Wooooo000Aooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0fOooool0017ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3Iooooo`004Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=Wooooo
0008ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0=Wooooo0009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3Jooooo`001_ooool5o`0000Kooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3Jooooo`001_ooool01?m4A4CogMgMooooool00007ooooo`Co00007Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0=[ooooo0006ooooo`04omgMgOmEEEGoooooo`00
00Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0=[ooooo0007ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0=[ooooo0007ooooo`03onk^k_m4A4Co000000Oooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=[ooooo
0008ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`06ooooo`;o00002_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0foooool0017ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`06
ooooo`;o00002_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0foooool0017ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`06oooo
o`;o00002_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0foooool0017ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`06ooooo`;o
00002_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0foooool0017ooooo0ol0000Oooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Kooooo`004Ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Kooooo`004Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000002_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0g?ooool0
017ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo0000
00[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0=cooooo000Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooo`000009ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`3Looooo`004Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooool000002Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0g?ooool0017ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0=cooooo000Aooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool00oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`3Mooooo`004Oooool3o`0001oooooo00?o0000
ooooooooool00oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`3Mooooo`004Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0gOooool0017ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0=gooooo000A
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`3Mooooo`004Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0gOooool0017ooooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0jooooo`05o`000?oo
ooooooooooooool00000h?ooool0017ooooo00?o0000ooooooooool08?ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0jooooo`05o`00
0?ooooooooooooooool00000h?ooool0017ooooo00?o0000ooooooooool08?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0jooooo`05
o`000?ooooooooooooooool00000h?ooool0017ooooo0ol0000Pooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03[ooooo00Go0000oooo
ooooooooooooo`00003Pooooo`004Oooool00ol0003oooooooooo`0Pooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03[ooooo00Go0000
ooooooooooooooooo`00003Pooooo`004Oooool00ol0003oooooooooo`0Pooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03[ooooo00Go
0000ooooooooooooooooo`00003Pooooo`004Oooool00ol0003oooooooooo`0Pooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0jooooo`04o`00
0?ooooooooooo`000>7ooooo000Aooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03[ooooo00Co0000oooooooo
oooo0000hOooool0017ooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00005oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>_ooool01?l0003oooooooooool0003Q
ooooo`004Oooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo00000>7ooooo000Aoooo
o`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool00000hOooool0017ooooo0ol0000Poooo
o`03o`000?oooooo000000Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0koooo
o`;o0000h_ooool0017ooooo00?o0000ooooooooool08?ooool00ol0003oooooo`000006ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0>oooool2o`000>;ooooo000Aooooo`03o`00
0?oooooooooo027ooooo0_l00006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
>oooool2o`000>;ooooo000Aooooo`03o`000?oooooooooo027ooooo0_l00006ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0>oooool2o`000>;ooooo000Aooooo`03o`000?oooooo
oooo027ooooo0_l00006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>oooool2
o`000>;ooooo0007ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Q
ooooo`;o00001_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03_ooooo0_l0003R
ooooo`002_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0hOooool000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0>7ooooo000:ooooo`03ogMgMolb<S;ooooo00Cooooo1?l0000Pooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0>7ooooo0007ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolPooooo`001ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooob3ooooo0007ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo8?ooool0
00Oooooo1?l00006ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`3oooooob3ooooo000Aooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`3oooooob3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2.74796, -0.38707, \
0.190969, 0.0312114}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Reconstructing genealogies",
  FontColor->RGBColor[0, 0, 1]]], "SubsubsectionIcon"],

Cell["\<\
This gives a matrix that represents what would actually be \
observed: the mutations carried by each of the 10 sampled leaves:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(S = GenealogyToMatrix[rg, MutationLabels \[Rule] ms]; 
    S // MatrixForm\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "1", "1", "1", "1", "1", "0", "0", "0", "0", "0", "0", "1", 
              "1", "1", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0", "0", "0", "0", "0", "0", "0", "0"},
            {"1", "1", "1", "1", "1", "1", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "1", "1", "1", "0", "0", "0",
               "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", "1", "0", 
              "0", "0", "0", "1", "1", "1", "1", "0", "0", "0", "1", "0", "0",
               "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", "1", "0", 
              "0", "0", "0", "1", "1", "1", "1", "0", "0", "0", "0", "0", "0",
               "0", "1", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", "1", "0", 
              "0", "0", "0", "1", "1", "1", "1", "0", "0", "0", "0", "0", "0",
               "0", "1", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", "1", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "1", "1",
               "1", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", "1", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0", "0", "1", "1", "1", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", "1", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0", "0", "1", "1", "1", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", "1", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0", "0", "0", "0", "0", "1", "1", "1"},
            {"0", "0", "0", "0", "0", "0", "1", "1", "1", "1", "1", "1", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0",
               "0", "0", "0", "0", "0", "1", "1", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[45]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Q4: ",
    FontColor->RGBColor[0, 0, 1]],
  "Can you reconstruct the genealogy from the observed mutation rate?  What \
mutation rate \[Theta] is needed for reconstruction to be possible most of \
the time?"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Making a sample",
  FontColor->RGBColor[0, 0, 1]]], "SubsubsectionIcon"],

Cell["\<\
This generates a sample of 200 genealogies, with \[Theta]=10:\
\>", \
"Text"],

Cell[BoxData[{
    \(\(lvs = {x1, x2, x3, x4, x5, x6, x7, x8, x9, x10};\)\), "\n", 
    \(\(mutatedSample = 
        Table[RandomGenealogy[lvs, 
            MutationRate \[Rule] 10], {200}];\)\)}], "Input",
  CellLabel->"In[123]:="],

Cell["\<\
This is the number of mutations (i.e., the number of segregating \
sites) in each of those replicates:\
\>", "Text"],

Cell[BoxData[
    \(numberOfMutationsList = \(Length[Mutations[#]] &\) /@ 
        mutatedSample\)], "Input",
  CellLabel->"In[133]:="],

Cell[TextData[{
  StyleBox["Q5: ",
    FontColor->RGBColor[0, 0, 1]],
  "What is the mean number of segregating sites?  How does it compare with \
the theoretical expectation?  Use this relation to estimate \[Theta] from \
these data.  How accurate are your estimates?"
}], "Text"],

Cell["This is the mean pairwise difference for each replicate:", "Text"],

Cell[BoxData[
    \(mpd = \(N[Mean[PairwiseDifference[#]]] &\) /@ mutatedSample\)], "Input",\

  CellLabel->"In[164]:="],

Cell["This plots the overall distribution of pairwise differences:", "Text"],

Cell[BoxData[
    \(\(PairwiseDifferencePlot[mutatedSample, {80, 1}, 
        PlotJoined \[Rule] True];\)\)], "Input",
  CellLabel->"In[176]:="],

Cell["This is the mean over all the replicates:", "Text"],

Cell[BoxData[
    \(Mean[mpd]\)], "Input",
  CellLabel->"In[166]:="],

Cell[TextData[{
  StyleBox["Q6:",
    FontColor->RGBColor[0, 0, 1]],
  " How does this compare with theory?  How variable are estimates of \
\[Theta] based on pairwise divergence, relative to estimates based on the \
number of segregating sites?"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Further questions", "SubsubsectionIcon"],

Cell["\<\
There are many other questions to be investigated.  For \
example:\
\>", "Text"],

Cell["\<\
 What is the effect of a population bottleneck on the shape of the \
genealogy and the pattern of mutations?\
\>", "Text",
  CellDingbat->"\[GrayCircle]"],

Cell["\<\
 Can the distribution of numbers of pairwise differences be used to \
detect a history of population growth? (see Q3 above)\
\>", "Text",
  CellDingbat->"\[GrayCircle]"]
}, Closed]],

Cell["Recombination", "Subsubsection"],

Cell[CellGroupData[{

Cell["Describing ancestral graphs", "SubsubsectionIcon"],

Cell[TextData[{
  "This generates an ",
  StyleBox["ancestral graph",
    FontSlant->"Italic"],
  " which describes the coalescent with recombination.  The map length is ",
  Cell[BoxData[
      \(TraditionalForm\`2 \( N\_e\) r = \(R = 4\)\)]],
  ".  It is run for T=10 time units, and with an upper limit of ",
  Cell[BoxData[
      \(TraditionalForm\`10\^4\)]],
  " recombination or coalescence events.  This runs much more slowly than a \
genealogy at a single locus, because very large numbers of events occur:"
}], "Text"],

Cell[BoxData[{
    \(\(lvs = {x1, x2, x3, x4, x5, x6, x7, x8, x9, x10};\)\), "\n", 
    \(\(ag = 
        RandomGenealogy[lvs, 10\^4, 4, MaxTime \[Rule] 10];\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell[TextData[{
  "The ",
  StyleBox["ancestral graph",
    FontSlant->"Italic"],
  " is a list of AncestralLineage[\[Ellipsis]] structures, each with five \
elements:\n\t- label\n\t- times for which the lineage exists\n\t- the leaves \
which descend from each block of genome\n\t- the rightmost positions of these \
blocks in the genome\n\t- a list of information (eg which mutations originate \
in each lineage)"
}], "Text"],

Cell["\<\
For example, this lineage has 3 blocks, one of which is ancestral \
to three descendants:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ag\[LeftDoubleBracket]101\[RightDoubleBracket]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(AncestralLineage[
      152, {0.8724182868199729`, 
        0.9803683540787855`}, {{}, {x2, x3, x6}, {}}, {1.2487116745591904`, 
        1.8233446910135906`, 4}, {}]\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell["These are the sizes of the blocks:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BlockSizes[ag\[LeftDoubleBracket]101\[RightDoubleBracket]]\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \({1.2487116745591904`, 0.5746330164544002`, 
      2.176655308986409`}\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell["\<\
About half the ancestral lineages are 'nulls' - they appear in the \
graph yet are not ancestral to anything.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Length[ag], 
      Length[Cases[ag, 
          AncestralLineage[_, {_, _}, {{}}, {_}, {}]]]}\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \({805, 402}\)], "Output",
  CellLabel->"Out[34]="]
}, Open  ]],

Cell["Five lineages are present at T=10:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LineagesPresent[ag, 10]\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \({1306, 1308, 1319, 1323, 1325}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell["These are the lineages themselves:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(agEnd = \(ExtractLineage[ag, #] &\) /@ 
        LineagesPresent[ag, 10]\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"1306", ",", 
            RowBox[{"{", 
              RowBox[{"9.700640871564927`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], 
            ",", \({{}, {x7, x1, x8, x6, x2, x5, x9, x3, x10, x4}, {x7, x1, 
                x8, x5, x9, x3, x10, x4, x6, x2}, {x9, x3, x10, x4, x6, x2, 
                x7, x1, x8, x5}, {}, {x9, x10, x3, x4, x7, x1, x8, x5, x6, 
                x2}, {x9, x10, x3, x4, x5, x7, x1, x8, x6, x2}, {x9, x10, x3, 
                x4, x7, x1, x8, x6, x2, x5}, {x5, x9, x10, x3, x4, x7, x1, 
                x8, x6, x2}}\), 
            ",", \({0.615949373524602`, 0.9858482098914348`, 
              1.0523116111725406`, 1.1282671232325412`, 2.8240168682218827`, 
              2.8346554949441782`, 2.861500704860933`, 3.129251498089458`, 
              4}\), ",", \({}\)}], "]"}], 
        ",", \(AncestralLineage[
          1308, {9.724761474486893`, 10.00594554251728`}, {{}}, {4}, {}]\), 
        ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"1319", ",", 
            RowBox[{"{", 
              RowBox[{"9.825835452826828`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), ",", \({4}\),
             ",", \({}\)}], "]"}], 
        ",", \(AncestralLineage[
          1323, {9.861754224364217`, 
            10.00594554251728`}, {{}, {x9, x3, x10, x4, x6, x2, x7, x1, x8, 
              x5}, {x9, x3, x10, x4, x7, x1, x8, x6, x2, x5}, {x9, x3, x10, 
              x4, x7, x1, x8, x5, x6, x2}, {x9, x10, x3, x4, x7, x1, x8, x5, 
              x6, x2}, {}, {x9, x10, x3, x4, x7, x1, x8, x5, x6, 
              x2}, {}}, {1.1282671232325412`, 1.6650535632886254`, 
            1.8228305062583756`, 2.001206795392987`, 2.698975054344557`, 
            2.7305627494171794`, 2.8240168682218827`, 4}, {}]\), ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"1325", ",", 
            RowBox[{"{", 
              RowBox[{"9.903945935869748`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], 
            ",", \({{x9, x3, x10, x4, x2, x7, x1, x8, x6, x5}, {x7, x1, x8, 
                x6, x5, x9, x3, x10, x4, x2}, {x7, x1, x8, x6, x2, x5, x9, 
                x3, x10, x4}, {}, {x9, x10, x3, x4, x7, x1, x8, x5, x6, 
                x2}, {}}\), 
            ",", \({0.2774573093820705`, 0.29467924111484667`, 
              0.615949373524602`, 2.698975054344557`, 2.7305627494171794`, 
              4}\), ",", \({}\)}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[27]="]
}, Closed]],

Cell["\<\
This lists the junctions present in each of the 5 lineages present \
at the end (recall that two lineages had no ancestral material)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Junctions /@ agEnd\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \({{0.615949373524602`, 0.9858482098914348`, 1.0523116111725406`, 
        1.1282671232325412`, 2.8240168682218827`, 2.8346554949441782`, 
        2.861500704860933`, 
        3.129251498089458`}, {}, {}, {1.1282671232325412`, 
        1.6650535632886254`, 1.8228305062583756`, 2.001206795392987`, 
        2.698975054344557`, 2.7305627494171794`, 
        2.8240168682218827`}, {0.2774573093820705`, 0.29467924111484667`, 
        0.615949373524602`, 2.698975054344557`, 
        2.7305627494171794`}}\)], "Output",
  CellLabel->"Out[71]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plotting the graphs", "SubsubsectionIcon"],

Cell[TextData[{
  "This plots the segments ancestral to leaf x1.  The ancestral genome of x1 \
occurs on 3 different individuals.  .The other 2 genomes are 'nulls' which \
are not in fact ancestral to anything.  Examination of the three non-trivial \
ancestral lineages shows that each is ancestral to all 10 leaves - in other \
words, every part of the genome is ",
  StyleBox["identical by descent",
    FontSlant->"Italic"],
  " relative to the population at T=-10."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cls = {Red, Brown, Purple, Blue, Black, DarkGreen, Green, Magenta, 
          Cyan, Maroon};\)\), "\[IndentingNewLine]", 
    \(\(Show[\[IndentingNewLine]Table[
          PlotSegments[agEnd, 
            lvs\[LeftDoubleBracket]j\[RightDoubleBracket], {0.005  j, 
              1 + 0.005  j}, 
            SegmentStyle -> {cls\[LeftDoubleBracket]
                  j\[RightDoubleBracket]}], {j, 10}]];\)\)}], "Input",
  CellLabel->"In[43]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0147151 0.560575 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.5 Mabswid
[ ] 0 setdash
.08987 .01752 m
.08987 .57809 L
s
.09397 .01752 m
.09397 .57809 L
s
.17046 .01752 m
.17046 .57809 L
s
.25854 .01752 m
.25854 .57809 L
s
.27436 .01752 m
.27436 .57809 L
s
.29244 .01752 m
.29244 .57809 L
s
.42025 .01752 m
.42025 .57809 L
s
.45782 .01752 m
.45782 .57809 L
s
.50029 .01752 m
.50029 .57809 L
s
.66642 .01752 m
.66642 .57809 L
s
.67394 .01752 m
.67394 .57809 L
s
.69619 .01752 m
.69619 .57809 L
s
.69873 .01752 m
.69873 .57809 L
s
.70512 .01752 m
.70512 .57809 L
s
.76887 .01752 m
.76887 .57809 L
s
1 1 0 r
.02381 .01752 m
.97619 .01752 L
s
.02381 .15766 m
.97619 .15766 L
s
.02381 .29781 m
.97619 .29781 L
s
.02381 .43795 m
.97619 .43795 L
s
.02381 .57809 m
.97619 .57809 L
s
1 0 0 r
.17046 .01752 m
.29244 .01752 L
s
.69619 .01752 m
.97619 .01752 L
s
.29244 .43795 m
.66642 .43795 L
s
.67394 .43795 m
.69619 .43795 L
s
.02381 .57809 m
.17046 .57809 L
s
.66642 .57809 m
.67394 .57809 L
s
0 0 0 r
.08987 .02032 m
.08987 .5809 L
s
.09397 .02032 m
.09397 .5809 L
s
.17046 .02032 m
.17046 .5809 L
s
.25854 .02032 m
.25854 .5809 L
s
.27436 .02032 m
.27436 .5809 L
s
.29244 .02032 m
.29244 .5809 L
s
.42025 .02032 m
.42025 .5809 L
s
.45782 .02032 m
.45782 .5809 L
s
.50029 .02032 m
.50029 .5809 L
s
.66642 .02032 m
.66642 .5809 L
s
.67394 .02032 m
.67394 .5809 L
s
.69619 .02032 m
.69619 .5809 L
s
.69873 .02032 m
.69873 .5809 L
s
.70512 .02032 m
.70512 .5809 L
s
.76887 .02032 m
.76887 .5809 L
s
1 1 0 r
.02381 .02032 m
.97619 .02032 L
s
.02381 .16046 m
.97619 .16046 L
s
.02381 .30061 m
.97619 .30061 L
s
.02381 .44075 m
.97619 .44075 L
s
.02381 .5809 m
.97619 .5809 L
s
.5 .165 .165 r
.17046 .02032 m
.29244 .02032 L
s
.69619 .02032 m
.97619 .02032 L
s
.29244 .44075 m
.66642 .44075 L
s
.67394 .44075 m
.69619 .44075 L
s
.02381 .5809 m
.17046 .5809 L
s
.66642 .5809 m
.67394 .5809 L
s
0 0 0 r
.08987 .02312 m
.08987 .5837 L
s
.09397 .02312 m
.09397 .5837 L
s
.17046 .02312 m
.17046 .5837 L
s
.25854 .02312 m
.25854 .5837 L
s
.27436 .02312 m
.27436 .5837 L
s
.29244 .02312 m
.29244 .5837 L
s
.42025 .02312 m
.42025 .5837 L
s
.45782 .02312 m
.45782 .5837 L
s
.50029 .02312 m
.50029 .5837 L
s
.66642 .02312 m
.66642 .5837 L
s
.67394 .02312 m
.67394 .5837 L
s
.69619 .02312 m
.69619 .5837 L
s
.69873 .02312 m
.69873 .5837 L
s
.70512 .02312 m
.70512 .5837 L
s
.76887 .02312 m
.76887 .5837 L
s
1 1 0 r
.02381 .02312 m
.97619 .02312 L
s
.02381 .16327 m
.97619 .16327 L
s
.02381 .30341 m
.97619 .30341 L
s
.02381 .44356 m
.97619 .44356 L
s
.02381 .5837 m
.97619 .5837 L
s
.628 .126 .941 r
.17046 .02312 m
.29244 .02312 L
s
.69619 .02312 m
.97619 .02312 L
s
.29244 .44356 m
.66642 .44356 L
s
.67394 .44356 m
.69619 .44356 L
s
.02381 .5837 m
.17046 .5837 L
s
.66642 .5837 m
.67394 .5837 L
s
0 0 0 r
.08987 .02593 m
.08987 .5865 L
s
.09397 .02593 m
.09397 .5865 L
s
.17046 .02593 m
.17046 .5865 L
s
.25854 .02593 m
.25854 .5865 L
s
.27436 .02593 m
.27436 .5865 L
s
.29244 .02593 m
.29244 .5865 L
s
.42025 .02593 m
.42025 .5865 L
s
.45782 .02593 m
.45782 .5865 L
s
.50029 .02593 m
.50029 .5865 L
s
.66642 .02593 m
.66642 .5865 L
s
.67394 .02593 m
.67394 .5865 L
s
.69619 .02593 m
.69619 .5865 L
s
.69873 .02593 m
.69873 .5865 L
s
.70512 .02593 m
.70512 .5865 L
s
.76887 .02593 m
.76887 .5865 L
s
1 1 0 r
.02381 .02593 m
.97619 .02593 L
s
.02381 .16607 m
.97619 .16607 L
s
.02381 .30621 m
.97619 .30621 L
s
.02381 .44636 m
.97619 .44636 L
s
.02381 .5865 m
.97619 .5865 L
s
0 0 1 r
.17046 .02593 m
.29244 .02593 L
s
.69619 .02593 m
.97619 .02593 L
s
.29244 .44636 m
.66642 .44636 L
s
.67394 .44636 m
.69619 .44636 L
s
.02381 .5865 m
.17046 .5865 L
s
.66642 .5865 m
.67394 .5865 L
s
0 0 0 r
.08987 .02873 m
.08987 .5893 L
s
.09397 .02873 m
.09397 .5893 L
s
.17046 .02873 m
.17046 .5893 L
s
.25854 .02873 m
.25854 .5893 L
s
.27436 .02873 m
.27436 .5893 L
s
.29244 .02873 m
.29244 .5893 L
s
.42025 .02873 m
.42025 .5893 L
s
.45782 .02873 m
.45782 .5893 L
s
.50029 .02873 m
.50029 .5893 L
s
.66642 .02873 m
.66642 .5893 L
s
.67394 .02873 m
.67394 .5893 L
s
.69619 .02873 m
.69619 .5893 L
s
.69873 .02873 m
.69873 .5893 L
s
.70512 .02873 m
.70512 .5893 L
s
.76887 .02873 m
.76887 .5893 L
s
1 1 0 r
.02381 .02873 m
.97619 .02873 L
s
.02381 .16887 m
.97619 .16887 L
s
.02381 .30902 m
.97619 .30902 L
s
.02381 .44916 m
.97619 .44916 L
s
.02381 .5893 m
.97619 .5893 L
s
0 0 0 r
.17046 .02873 m
.29244 .02873 L
s
.69619 .02873 m
.97619 .02873 L
s
.29244 .44916 m
.66642 .44916 L
s
.67394 .44916 m
.69619 .44916 L
s
.02381 .5893 m
.17046 .5893 L
s
.66642 .5893 m
.67394 .5893 L
s
.08987 .03153 m
.08987 .59211 L
s
.09397 .03153 m
.09397 .59211 L
s
.17046 .03153 m
.17046 .59211 L
s
.25854 .03153 m
.25854 .59211 L
s
.27436 .03153 m
.27436 .59211 L
s
.29244 .03153 m
.29244 .59211 L
s
.42025 .03153 m
.42025 .59211 L
s
.45782 .03153 m
.45782 .59211 L
s
.50029 .03153 m
.50029 .59211 L
s
.66642 .03153 m
.66642 .59211 L
s
.67394 .03153 m
.67394 .59211 L
s
.69619 .03153 m
.69619 .59211 L
s
.69873 .03153 m
.69873 .59211 L
s
.70512 .03153 m
.70512 .59211 L
s
.76887 .03153 m
.76887 .59211 L
s
1 1 0 r
.02381 .03153 m
.97619 .03153 L
s
.02381 .17168 m
.97619 .17168 L
s
.02381 .31182 m
.97619 .31182 L
s
.02381 .45196 m
.97619 .45196 L
s
.02381 .59211 m
.97619 .59211 L
s
0 .392 0 r
.17046 .03153 m
.29244 .03153 L
s
.69619 .03153 m
.97619 .03153 L
s
.29244 .45196 m
.66642 .45196 L
s
.67394 .45196 m
.69619 .45196 L
s
.02381 .59211 m
.17046 .59211 L
s
.66642 .59211 m
.67394 .59211 L
s
0 0 0 r
.08987 .03434 m
.08987 .59491 L
s
.09397 .03434 m
.09397 .59491 L
s
.17046 .03434 m
.17046 .59491 L
s
.25854 .03434 m
.25854 .59491 L
s
.27436 .03434 m
.27436 .59491 L
s
.29244 .03434 m
.29244 .59491 L
s
.42025 .03434 m
.42025 .59491 L
s
.45782 .03434 m
.45782 .59491 L
s
.50029 .03434 m
.50029 .59491 L
s
.66642 .03434 m
.66642 .59491 L
s
.67394 .03434 m
.67394 .59491 L
s
.69619 .03434 m
.69619 .59491 L
s
.69873 .03434 m
.69873 .59491 L
s
.70512 .03434 m
.70512 .59491 L
s
.76887 .03434 m
.76887 .59491 L
s
1 1 0 r
.02381 .03434 m
.97619 .03434 L
s
.02381 .17448 m
.97619 .17448 L
s
.02381 .31462 m
.97619 .31462 L
s
.02381 .45477 m
.97619 .45477 L
s
.02381 .59491 m
.97619 .59491 L
s
0 1 0 r
.17046 .03434 m
.29244 .03434 L
s
.69619 .03434 m
.97619 .03434 L
s
.29244 .45477 m
.66642 .45477 L
s
.67394 .45477 m
.69619 .45477 L
s
.02381 .59491 m
.17046 .59491 L
s
.66642 .59491 m
.67394 .59491 L
s
0 0 0 r
.08987 .03714 m
.08987 .59771 L
s
.09397 .03714 m
.09397 .59771 L
s
.17046 .03714 m
.17046 .59771 L
s
.25854 .03714 m
.25854 .59771 L
s
.27436 .03714 m
.27436 .59771 L
s
.29244 .03714 m
.29244 .59771 L
s
.42025 .03714 m
.42025 .59771 L
s
.45782 .03714 m
.45782 .59771 L
s
.50029 .03714 m
.50029 .59771 L
s
.66642 .03714 m
.66642 .59771 L
s
.67394 .03714 m
.67394 .59771 L
s
.69619 .03714 m
.69619 .59771 L
s
.69873 .03714 m
.69873 .59771 L
s
.70512 .03714 m
.70512 .59771 L
s
.76887 .03714 m
.76887 .59771 L
s
1 1 0 r
.02381 .03714 m
.97619 .03714 L
s
.02381 .17728 m
.97619 .17728 L
s
.02381 .31743 m
.97619 .31743 L
s
.02381 .45757 m
.97619 .45757 L
s
.02381 .59771 m
.97619 .59771 L
s
1 0 1 r
.17046 .03714 m
.29244 .03714 L
s
.69619 .03714 m
.97619 .03714 L
s
.29244 .45757 m
.66642 .45757 L
s
.67394 .45757 m
.69619 .45757 L
s
.02381 .59771 m
.17046 .59771 L
s
.66642 .59771 m
.67394 .59771 L
s
0 0 0 r
.08987 .03994 m
.08987 .60052 L
s
.09397 .03994 m
.09397 .60052 L
s
.17046 .03994 m
.17046 .60052 L
s
.25854 .03994 m
.25854 .60052 L
s
.27436 .03994 m
.27436 .60052 L
s
.29244 .03994 m
.29244 .60052 L
s
.42025 .03994 m
.42025 .60052 L
s
.45782 .03994 m
.45782 .60052 L
s
.50029 .03994 m
.50029 .60052 L
s
.66642 .03994 m
.66642 .60052 L
s
.67394 .03994 m
.67394 .60052 L
s
.69619 .03994 m
.69619 .60052 L
s
.69873 .03994 m
.69873 .60052 L
s
.70512 .03994 m
.70512 .60052 L
s
.76887 .03994 m
.76887 .60052 L
s
1 1 0 r
.02381 .03994 m
.97619 .03994 L
s
.02381 .18008 m
.97619 .18008 L
s
.02381 .32023 m
.97619 .32023 L
s
.02381 .46037 m
.97619 .46037 L
s
.02381 .60052 m
.97619 .60052 L
s
0 1 1 r
.17046 .03994 m
.29244 .03994 L
s
.69619 .03994 m
.97619 .03994 L
s
.29244 .46037 m
.66642 .46037 L
s
.67394 .46037 m
.69619 .46037 L
s
.02381 .60052 m
.17046 .60052 L
s
.66642 .60052 m
.67394 .60052 L
s
0 0 0 r
.08987 .04274 m
.08987 .60332 L
s
.09397 .04274 m
.09397 .60332 L
s
.17046 .04274 m
.17046 .60332 L
s
.25854 .04274 m
.25854 .60332 L
s
.27436 .04274 m
.27436 .60332 L
s
.29244 .04274 m
.29244 .60332 L
s
.42025 .04274 m
.42025 .60332 L
s
.45782 .04274 m
.45782 .60332 L
s
.50029 .04274 m
.50029 .60332 L
s
.66642 .04274 m
.66642 .60332 L
s
.67394 .04274 m
.67394 .60332 L
s
.69619 .04274 m
.69619 .60332 L
s
.69873 .04274 m
.69873 .60332 L
s
.70512 .04274 m
.70512 .60332 L
s
.76887 .04274 m
.76887 .60332 L
s
1 1 0 r
.02381 .04274 m
.97619 .04274 L
s
.02381 .18289 m
.97619 .18289 L
s
.02381 .32303 m
.97619 .32303 L
s
.02381 .46318 m
.97619 .46318 L
s
.02381 .60332 m
.97619 .60332 L
s
.69 .188 .377 r
.17046 .04274 m
.29244 .04274 L
s
.69619 .04274 m
.97619 .04274 L
s
.29244 .46318 m
.66642 .46318 L
s
.67394 .46318 m
.69619 .46318 L
s
.02381 .60332 m
.17046 .60332 L
s
.66642 .60332 m
.67394 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[43]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`002?oooole0?oo02d0o`00S`3oo`1V0?l000Wooooo0008ooooocD0ool0;@1o:RZ?0?oo06H0
ObXZ2Oooool000Sooooo=@3oo`0]0:0Pl8l0ool0IP2P8?09ooooo`002?oooole0?oo02d0003oS`3o
o`1V0000o`Wooooo0008ooooocD0ool0;@00002?0?oo06H000002Oooool000Sooooo=@3oo`0]001T
08l0ool0IP00I009ooooo`002?oooole0?oo02d00?l0S`3oo`1V003o00Wooooo0008ooooocD0ool0
;@3o0?n?0?oo06H0o`3o2Oooool000Sooooo=@3oo`0]003oohl0ool0IP00ool9ooooo`002?oooole
0?oo02d0/31PS`3oo`1V0;0`H0Wooooo000Pooooo`0300000?ooool0000001[ooooo00<00000oooo
ooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000oooo
ooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000oooo
ooooool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00
003oooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oooooooooo01go
oooo00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02[o
oooo00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wo
oooo00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo00<00000oooooooo
ool0D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0Mooooo`030000
0?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Zooooo`030000
0?oooooooooo00_ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0iooooo`030000
0?ooool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo
000Pooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00003ooooooooo
o`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00003ooooooooo
o`0;ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00003ooooo0000
0007ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1Booooo`008?ooool0
0`00003ooooo0000000Jooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00_ooool0
0`00003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool02oooool0
0`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`0000001oooool2
00000003ooooo`00003ooooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo00<00000oooo
o`0000006_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo00<00000oooo
ooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo00<00000oooo
ooooool03?ooool00`00003oooooooooo`0iooooo`0300000?ooool0000000Oooooo0P0000000ooo
ool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000Pooooo`0300000?ooool0000001[o
oooo00<00000ooooooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Co
oooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00co
oooo00<00000ooooooooool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?oo
ool05Oooool00`00003oooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`030000
0?oooooooooo01gooooo00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`030000
0?oooooooooo02[ooooo00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`030000
0?oooooooooo03Wooooo00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo
00<00000ooooooooool0D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003ooooooooo
o`0Mooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003ooooooooo
o`0Zooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool00`00003ooooooooo
o`0iooooo`0300000?ooool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oo
oooooooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool0
0`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool0
0`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool0
0`00003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1B
ooooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oooooooooo01gooooo00<00000oooo
ooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo00<00000oooo
ooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo00<00000oooo
o`0000001oooool200000003ooooo`00003ooooo01Gooooo00<00000ooooooooool0D_ooool0023o
oooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00;o
oooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00_o
oooo00<00000ooooooooool03?ooool00`00003oooooooooo`0iooooo`0300000?ooool0000000Oo
oooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000Pooooo`030000
0?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00003oooooooooo`02ooooo`030000
0?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`030000
0?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00003ooooo00000007ooooo`800000
00?ooooo00000?ooool05Oooool00`00003oooooooooo`1Booooo`008?ooool00`00003ooooo0000
000Jooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00_ooool00`00003ooooooooo
o`04ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool02oooool00`00003ooooooooo
o`0<ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`0000001oooool200000003ooooo`00
003ooooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo00<00000ooooo`0000006_ooool0
0`00003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool0
0`00003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool0
0`00003oooooooooo`0iooooo`0300000?ooool0000000Oooooo0P0000000oooool00000ooooo`0E
ooooo`0300000?oooooooooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo00<00000oooo
ooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000oooo
ooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000oooo
ooooool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00
003oooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oooooooooo01go
oooo00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02[o
oooo00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wo
oooo00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo00<00000oooooooo
ool0D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0Mooooo`030000
0?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Zooooo`030000
0?oooooooooo00_ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0iooooo`030000
0?ooool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo
000Pooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00003ooooooooo
o`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00003ooooooooo
o`0;ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00003ooooo0000
0007ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1Booooo`008?ooool0
0`00003ooooo0000000Jooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00_ooool0
0`00003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool02oooool0
0`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`0000001oooool2
00000003ooooo`00003ooooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo00<00000oooo
o`0000006_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo00<00000oooo
ooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo00<00000oooo
ooooool03?ooool00`00003oooooooooo`0iooooo`0300000?ooool0000000Oooooo0P0000000ooo
ool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000Pooooo`0300000?ooool0000001[o
oooo00<00000ooooooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Co
oooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00co
oooo00<00000ooooooooool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?oo
ool05Oooool00`00003oooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`030000
0?oooooooooo01gooooo00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`030000
0?oooooooooo02[ooooo00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`030000
0?oooooooooo03Wooooo00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo
00<00000ooooooooool0D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003ooooooooo
o`0Mooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003ooooooooo
o`0Zooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool00`00003ooooooooo
o`0iooooo`0300000?ooool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oo
oooooooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool0
0`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool0
0`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool0
0`00003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1B
ooooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oooooooooo01gooooo00<00000oooo
ooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo00<00000oooo
ooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo00<00000oooo
o`0000001oooool200000003ooooo`00003ooooo01Gooooo00<00000ooooooooool0D_ooool0023o
oooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00;o
oooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00_o
oooo00<00000ooooooooool03?ooool00`00003oooooooooo`0iooooo`0300000?ooool0000000Oo
oooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000Pooooo`030000
0?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00003oooooooooo`02ooooo`030000
0?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`030000
0?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00003ooooo00000007ooooo`800000
00?ooooo00000?ooool05Oooool00`00003oooooooooo`1Booooo`008?ooool00`00003ooooo0000
000Jooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00_ooool00`00003ooooooooo
o`04ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool02oooool00`00003ooooooooo
o`0<ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`0000001oooool200000003ooooo`00
003ooooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo00<00000ooooo`0000006_ooool0
0`00003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool0
0`00003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool0
0`00003oooooooooo`0iooooo`0300000?ooool0000000Oooooo0P0000000oooool00000ooooo`0E
ooooo`0300000?oooooooooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo00<00000oooo
ooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000oooo
ooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000oooo
ooooool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00
003oooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oooooooooo01go
oooo00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02[o
oooo00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wo
oooo00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo00<00000oooooooo
ool0D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0Mooooo`030000
0?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Zooooo`030000
0?oooooooooo00_ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0iooooo`030000
0?ooool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo
000Pooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00003ooooooooo
o`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00003ooooooooo
o`0;ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00003ooooo0000
0007ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1Booooo`008?ooool0
0`00003ooooo0000000Jooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00_ooool0
0`00003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool02oooool0
0`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`0000001oooool2
00000003ooooo`00003ooooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo00<00000oooo
o`0000006_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo00<00000oooo
ooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo00<00000oooo
ooooool03?ooool00`00003oooooooooo`0iooooo`0300000?ooool0000000Oooooo0P0000000ooo
ool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000Pooooo`0300000?ooool0000001[o
oooo00<00000ooooooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Co
oooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00co
oooo00<00000ooooooooool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?oo
ool05Oooool00`00003oooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`030000
0?oooooooooo01gooooo00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`030000
0?oooooooooo02[ooooo00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`030000
0?oooooooooo03Wooooo00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo
00<00000ooooooooool0D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003ooooooooo
o`0Mooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003ooooooooo
o`0Zooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool00`00003ooooooooo
o`0iooooo`0300000?ooool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oo
oooooooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool0
0`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool0
0`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool0
0`00003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1B
ooooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oooooooooo01gooooo00<00000oooo
ooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo00<00000oooo
ooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo00<00000oooo
o`0000001oooool200000003ooooo`00003ooooo01Gooooo00<00000ooooooooool0D_ooool000So
oooo603oo`000`000000ool00000000J0?oo00030000003oo`00ool001d0ool000<000000?oo003o
o`000P3oo`000`000000ool00?oo00040?oo00030000003oo`00ool002X0ool000<000000?oo003o
o`002`3oo`000`000000ool00?oo000<0?oo00030000003oo`00ool003T0ool000<000000?oo0000
00001`3oo`02000000030?oo00000000ool001D0ool000<000000?oo003oo`00B@3oo`09ooooo`00
2?oooolH0?oo00030000003oo`00000001X0ool000<000000?oo003oo`007@3oo`000`000000ool0
0?oo00020?oo00030000003oo`00ool000@0ool000<000000?oo003oo`00:P3oo`000`000000ool0
0?oo000;0?oo00030000003oo`00ool000`0ool000<000000?oo003oo`00>@3oo`000`000000ool0
000000070?oo0080000000<0ool00000003oo`005@3oo`000`000000ool00?oo00190?oo00Wooooo
0008oooooaP0ool000<000000?oo000000006P3oo`000`000000ool00?oo000M0?oo00030000003o
o`00ool00080ool000<000000?oo003oo`00103oo`000`000000ool00?oo000Z0?oo00030000003o
o`00ool000/0ool000<000000?oo003oo`00303oo`000`000000ool00?oo000i0?oo00030000003o
o`00000000L0ool00P0000000`3oo`0000000?oo000E0?oo00030000003oo`00ool004T0ool02Ooo
ool000Sooooo603oo`000`000000ool00000000J0?oo00030000003oo`00ool001d0ool000<00000
0?oo003oo`000P3oo`000`000000ool00?oo00040?oo00030000003oo`00ool002X0ool000<00000
0?oo003oo`002`3oo`000`000000ool00?oo000<0?oo00030000003oo`00ool003T0ool000<00000
0?oo000000001`3oo`02000000030?oo00000000ool001D0ool000<000000?oo003oo`00B@3oo`09
ooooo`002?oooolH0?oo00030000003oo`00000001X0ool000<000000?oo003oo`007@3oo`000`00
0000ool00?oo00020?oo00030000003oo`00ool000@0ool000<000000?oo003oo`00:P3oo`000`00
0000ool00?oo000;0?oo00030000003oo`00ool000`0ool000<000000?oo003oo`00>@3oo`000`00
0000ool0000000070?oo0080000000<0ool00000003oo`005@3oo`000`000000ool00?oo00190?oo
00Wooooo0008oooooaP0ool000<000000?oo000000006P3oo`000`000000ool00?oo000M0?oo0003
0000003oo`00ool00080ool000<000000?oo003oo`00103oo`000`000000ool00?oo000Z0?oo0003
0000003oo`00ool000/0ool000<000000?oo003oo`00303oo`000`000000ool00?oo000i0?oo0003
0000003oo`00000000L0ool00P0000000`3oo`0000000?oo000E0?oo00030000003oo`00ool004T0
ool02Oooool000Sooooo603oo`000`000000ool00000000J0?oo00030000003oo`00ool001d0ool0
00<000000?oo003oo`000P3oo`000`000000ool00?oo00040?oo00030000003oo`00ool002X0ool0
00<000000?oo003oo`002`3oo`000`000000ool00?oo000<0?oo00030000003oo`00ool003T0ool0
00<000000?oo000000001`3oo`02000000030?oo00000000ool001D0ool000<000000?oo003oo`00
B@3oo`09ooooo`002?oooolH0?oo00030000003oo`00000001X0ool000<000000?oo003oo`007@3o
o`000`000000ool00?oo00020?oo00030000003oo`00ool000@0ool000<000000?oo003oo`00:P3o
o`000`000000ool00?oo000;0?oo00030000003oo`00ool000`0ool000<000000?oo003oo`00>@3o
o`000`000000ool0000000070?oo0080000000<0ool00000003oo`005@3oo`000`000000ool00?oo
00190?oo00Wooooo0008oooooaP0ool000<000000?oo000000006P3oo`000`000000ool00?oo000M
0?oo00030000003oo`00ool00080ool000<000000?oo003oo`00103oo`000`000000ool00?oo000Z
0?oo00030000003oo`00ool000/0ool000<000000?oo003oo`00303oo`000`000000ool00?oo000i
0?oo00030000003oo`00000000L0ool00P0000000`3oo`0000000?oo000E0?oo00030000003oo`00
ool004T0ool02Oooool000Soooooo`3oo`1H0?oo00Wooooo000Pooooo`0300000?ooool0000001[o
oooo00<00000ooooooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Co
oooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00co
oooo00<00000ooooooooool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?oo
ool05Oooool00`00003oooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`030000
0?oooooooooo01gooooo00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`030000
0?oooooooooo02[ooooo00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`030000
0?oooooooooo03Wooooo00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo
00<00000ooooooooool0D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003ooooooooo
o`0Mooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003ooooooooo
o`0Zooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool00`00003ooooooooo
o`0iooooo`0300000?ooool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oo
oooooooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool0
0`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool0
0`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool0
0`00003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1B
ooooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oooooooooo01gooooo00<00000oooo
ooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo00<00000oooo
ooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo00<00000oooo
o`0000001oooool200000003ooooo`00003ooooo01Gooooo00<00000ooooooooool0D_ooool0023o
oooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00;o
oooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00_o
oooo00<00000ooooooooool03?ooool00`00003oooooooooo`0iooooo`0300000?ooool0000000Oo
oooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000Pooooo`030000
0?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00003oooooooooo`02ooooo`030000
0?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`030000
0?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00003ooooo00000007ooooo`800000
00?ooooo00000?ooool05Oooool00`00003oooooooooo`1Booooo`008?ooool00`00003ooooo0000
000Jooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00_ooool00`00003ooooooooo
o`04ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool02oooool00`00003ooooooooo
o`0<ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`0000001oooool200000003ooooo`00
003ooooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo00<00000ooooo`0000006_ooool0
0`00003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool0
0`00003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool0
0`00003oooooooooo`0iooooo`0300000?ooool0000000Oooooo0P0000000oooool00000ooooo`0E
ooooo`0300000?oooooooooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo00<00000oooo
ooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000oooo
ooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000oooo
ooooool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00
003oooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oooooooooo01go
oooo00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02[o
oooo00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wo
oooo00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo00<00000oooooooo
ool0D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0Mooooo`030000
0?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Zooooo`030000
0?oooooooooo00_ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0iooooo`030000
0?ooool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo
000Pooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00003ooooooooo
o`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00003ooooooooo
o`0;ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00003ooooo0000
0007ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1Booooo`008?ooool0
0`00003ooooo0000000Jooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00_ooool0
0`00003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool02oooool0
0`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`0000001oooool2
00000003ooooo`00003ooooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo00<00000oooo
o`0000006_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo00<00000oooo
ooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo00<00000oooo
ooooool03?ooool00`00003oooooooooo`0iooooo`0300000?ooool0000000Oooooo0P0000000ooo
ool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000Pooooo`0300000?ooool0000001[o
oooo00<00000ooooooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Co
oooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00co
oooo00<00000ooooooooool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?oo
ool05Oooool00`00003oooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`030000
0?oooooooooo01gooooo00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`030000
0?oooooooooo02[ooooo00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`030000
0?oooooooooo03Wooooo00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo
00<00000ooooooooool0D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003ooooooooo
o`0Mooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003ooooooooo
o`0Zooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool00`00003ooooooooo
o`0iooooo`0300000?ooool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oo
oooooooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool0
0`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool0
0`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool0
0`00003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1B
ooooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oooooooooo01gooooo00<00000oooo
ooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo00<00000oooo
ooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo00<00000oooo
o`0000001oooool200000003ooooo`00003ooooo01Gooooo00<00000ooooooooool0D_ooool0023o
oooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00;o
oooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00_o
oooo00<00000ooooooooool03?ooool00`00003oooooooooo`0iooooo`0300000?ooool0000000Oo
oooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000Pooooo`030000
0?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00003oooooooooo`02ooooo`030000
0?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`030000
0?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00003ooooo00000007ooooo`800000
00?ooooo00000?ooool05Oooool00`00003oooooooooo`1Booooo`008?ooool00`00003ooooo0000
000Jooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00_ooool00`00003ooooooooo
o`04ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool02oooool00`00003ooooooooo
o`0<ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`0000001oooool200000003ooooo`00
003ooooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo00<00000ooooo`0000006_ooool0
0`00003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool0
0`00003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool0
0`00003oooooooooo`0iooooo`0300000?ooool0000000Oooooo0P0000000oooool00000ooooo`0E
ooooo`0300000?oooooooooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo00<00000oooo
ooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000oooo
ooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000oooo
ooooool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00
003oooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oooooooooo01go
oooo00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02[o
oooo00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wo
oooo00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo00<00000oooooooo
ool0D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0Mooooo`030000
0?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Zooooo`030000
0?oooooooooo00_ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0iooooo`030000
0?ooool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo
000Pooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00003ooooooooo
o`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00003ooooooooo
o`0;ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00003ooooo0000
0007ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1Booooo`008?ooool0
0`00003ooooo0000000Jooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00_ooool0
0`00003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool02oooool0
0`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`0000001oooool2
00000003ooooo`00003ooooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo00<00000oooo
o`0000006_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo00<00000oooo
ooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo00<00000oooo
ooooool03?ooool00`00003oooooooooo`0iooooo`0300000?ooool0000000Oooooo0P0000000ooo
ool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000Pooooo`0300000?ooool0000001[o
oooo00<00000ooooooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Co
oooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00co
oooo00<00000ooooooooool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?oo
ool05Oooool00`00003oooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`030000
0?oooooooooo01gooooo00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`030000
0?oooooooooo02[ooooo00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`030000
0?oooooooooo03Wooooo00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo
00<00000ooooooooool0D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003ooooooooo
o`0Mooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003ooooooooo
o`0Zooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool00`00003ooooooooo
o`0iooooo`0300000?ooool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oo
oooooooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool0
0`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool0
0`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool0
0`00003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1B
ooooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oooooooooo01gooooo00<00000oooo
ooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo00<00000oooo
ooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo00<00000oooo
o`0000001oooool200000003ooooo`00003ooooo01Gooooo00<00000ooooooooool0D_ooool0023o
oooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00;o
oooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00_o
oooo00<00000ooooooooool03?ooool00`00003oooooooooo`0iooooo`0300000?ooool0000000Oo
oooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000Pooooo`030000
0?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00003oooooooooo`02ooooo`030000
0?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`030000
0?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00003ooooo00000007ooooo`800000
00?ooooo00000?ooool05Oooool00`00003oooooooooo`1Booooo`008?ooool00`00003ooooo0000
000Jooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00_ooool00`00003ooooooooo
o`04ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool02oooool00`00003ooooooooo
o`0<ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`0000001oooool200000003ooooo`00
003ooooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo00<00000ooooo`0000006_ooool0
0`00003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool0
0`00003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool0
0`00003oooooooooo`0iooooo`0300000?ooool0000000Oooooo0P0000000oooool00000ooooo`0E
ooooo`0300000?oooooooooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo00<00000oooo
ooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000oooo
ooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000oooo
ooooool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00
003oooooooooo`1Booooo`002?oooolH0?oo00030000003oo`00000001X0ool000<000000?oo003o
o`007@3oo`000`000000ool00?oo00020?oo00030000003oo`00ool000@0ool000<000000?oo003o
o`00:P3oo`000`000000ool00?oo000;0?oo00030000003oo`00ool000`0ool000<000000?oo003o
o`00>@3oo`000`000000ool0000000070?oo0080000000<0ool00000003oo`005@3oo`000`000000
ool00?oo00190?oo00Wooooo0008oooooaP0ool000<000000?oo000000006P3oo`000`000000ool0
0?oo000M0?oo00030000003oo`00ool00080ool000<000000?oo003oo`00103oo`000`000000ool0
0?oo000Z0?oo00030000003oo`00ool000/0ool000<000000?oo003oo`00303oo`000`000000ool0
0?oo000i0?oo00030000003oo`00000000L0ool00P0000000`3oo`0000000?oo000E0?oo00030000
003oo`00ool004T0ool02Oooool000Sooooo603oo`000`000000ool00000000J0?oo00030000003o
o`00ool001d0ool000<000000?oo003oo`000P3oo`000`000000ool00?oo00040?oo00030000003o
o`00ool002X0ool000<000000?oo003oo`002`3oo`000`000000ool00?oo000<0?oo00030000003o
o`00ool003T0ool000<000000?oo000000001`3oo`02000000030?oo00000000ool001D0ool000<0
00000?oo003oo`00B@3oo`09ooooo`002?oooolH0?oo00030000003oo`00000001X0ool000<00000
0?oo003oo`007@3oo`000`000000ool00?oo00020?oo00030000003oo`00ool000@0ool000<00000
0?oo003oo`00:P3oo`000`000000ool00?oo000;0?oo00030000003oo`00ool000`0ool000<00000
0?oo003oo`00>@3oo`000`000000ool0000000070?oo0080000000<0ool00000003oo`005@3oo`00
0`000000ool00?oo00190?oo00Wooooo0008oooooaP0ool000<000000?oo000000006P3oo`000`00
0000ool00?oo000M0?oo00030000003oo`00ool00080ool000<000000?oo003oo`00103oo`000`00
0000ool00?oo000Z0?oo00030000003oo`00ool000/0ool000<000000?oo003oo`00303oo`000`00
0000ool00?oo000i0?oo00030000003oo`00000000L0ool00P0000000`3oo`0000000?oo000E0?oo
00030000003oo`00ool004T0ool02Oooool000Sooooo603oo`000`000000ool00000000J0?oo0003
0000003oo`00ool001d0ool000<000000?oo003oo`000P3oo`000`000000ool00?oo00040?oo0003
0000003oo`00ool002X0ool000<000000?oo003oo`002`3oo`000`000000ool00?oo000<0?oo0003
0000003oo`00ool003T0ool000<000000?oo000000001`3oo`02000000030?oo00000000ool001D0
ool000<000000?oo003oo`00B@3oo`09ooooo`002?oooolH0?oo00030000003oo`00000001X0ool0
00<000000?oo003oo`007@3oo`000`000000ool00?oo00020?oo00030000003oo`00ool000@0ool0
00<000000?oo003oo`00:P3oo`000`000000ool00?oo000;0?oo00030000003oo`00ool000`0ool0
00<000000?oo003oo`00>@3oo`000`000000ool0000000070?oo0080000000<0ool00000003oo`00
5@3oo`000`000000ool00?oo00190?oo00Wooooo0008oooooaP0ool000<000000?oo000000006P3o
o`000`000000ool00?oo000M0?oo00030000003oo`00ool00080ool000<000000?oo003oo`00103o
o`000`000000ool00?oo000Z0?oo00030000003oo`00ool000/0ool000<000000?oo003oo`00303o
o`000`000000ool00?oo000i0?oo00030000003oo`00000000L0ool00P0000000`3oo`0000000?oo
000E0?oo00030000003oo`00ool004T0ool02Oooool000Sooooo603oo`000`000000ool00000000J
0?oo00030000003oo`00ool001d0ool000<000000?oo003oo`000P3oo`000`000000ool00?oo0004
0?oo00030000003oo`00ool002X0ool000<000000?oo003oo`002`3oo`000`000000ool00?oo000<
0?oo00030000003oo`00ool003T0ool000<000000?oo000000001`3oo`02000000030?oo00000000
ool001D0ool000<000000?oo003oo`00B@3oo`09ooooo`002?oooooo0?oo05P0ool02Oooool0023o
oooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00;o
oooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00_o
oooo00<00000ooooooooool03?ooool00`00003oooooooooo`0iooooo`0300000?ooool0000000Oo
oooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000Pooooo`030000
0?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00003oooooooooo`02ooooo`030000
0?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`030000
0?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00003ooooo00000007ooooo`800000
00?ooooo00000?ooool05Oooool00`00003oooooooooo`1Booooo`008?ooool00`00003ooooo0000
000Jooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00_ooool00`00003ooooooooo
o`04ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool02oooool00`00003ooooooooo
o`0<ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`0000001oooool200000003ooooo`00
003ooooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo00<00000ooooo`0000006_ooool0
0`00003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool0
0`00003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool0
0`00003oooooooooo`0iooooo`0300000?ooool0000000Oooooo0P0000000oooool00000ooooo`0E
ooooo`0300000?oooooooooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo00<00000oooo
ooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000oooo
ooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000oooo
ooooool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00
003oooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oooooooooo01go
oooo00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02[o
oooo00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wo
oooo00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo00<00000oooooooo
ool0D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0Mooooo`030000
0?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Zooooo`030000
0?oooooooooo00_ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0iooooo`030000
0?ooool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo
000Pooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00003ooooooooo
o`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00003ooooooooo
o`0;ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00003ooooo0000
0007ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1Booooo`008?ooool0
0`00003ooooo0000000Jooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00_ooool0
0`00003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool02oooool0
0`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`0000001oooool2
00000003ooooo`00003ooooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo00<00000oooo
o`0000006_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo00<00000oooo
ooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo00<00000oooo
ooooool03?ooool00`00003oooooooooo`0iooooo`0300000?ooool0000000Oooooo0P0000000ooo
ool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000Pooooo`0300000?ooool0000001[o
oooo00<00000ooooooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Co
oooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00co
oooo00<00000ooooooooool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?oo
ool05Oooool00`00003oooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`030000
0?oooooooooo01gooooo00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`030000
0?oooooooooo02[ooooo00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`030000
0?oooooooooo03Wooooo00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo
00<00000ooooooooool0D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003ooooooooo
o`0Mooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003ooooooooo
o`0Zooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool00`00003ooooooooo
o`0iooooo`0300000?ooool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oo
oooooooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool0
0`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool0
0`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool0
0`00003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1B
ooooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oooooooooo01gooooo00<00000oooo
ooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo00<00000oooo
ooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo00<00000oooo
o`0000001oooool200000003ooooo`00003ooooo01Gooooo00<00000ooooooooool0D_ooool0023o
oooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00;o
oooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00_o
oooo00<00000ooooooooool03?ooool00`00003oooooooooo`0iooooo`0300000?ooool0000000Oo
oooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000Pooooo`030000
0?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00003oooooooooo`02ooooo`030000
0?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`030000
0?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00003ooooo00000007ooooo`800000
00?ooooo00000?ooool05Oooool00`00003oooooooooo`1Booooo`008?ooool00`00003ooooo0000
000Jooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00_ooool00`00003ooooooooo
o`04ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool02oooool00`00003ooooooooo
o`0<ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`0000001oooool200000003ooooo`00
003ooooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo00<00000ooooo`0000006_ooool0
0`00003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool0
0`00003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool0
0`00003oooooooooo`0iooooo`0300000?ooool0000000Oooooo0P0000000oooool00000ooooo`0E
ooooo`0300000?oooooooooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo00<00000oooo
ooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000oooo
ooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000oooo
ooooool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00
003oooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oooooooooo01go
oooo00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02[o
oooo00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wo
oooo00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo00<00000oooooooo
ool0D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0Mooooo`030000
0?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Zooooo`030000
0?oooooooooo00_ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0iooooo`030000
0?ooool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo
000Pooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00003ooooooooo
o`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00003ooooooooo
o`0;ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00003ooooo0000
0007ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1Booooo`008?ooool0
0`00003ooooo0000000Jooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00_ooool0
0`00003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool02oooool0
0`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`0000001oooool2
00000003ooooo`00003ooooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo00<00000oooo
o`0000006_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo00<00000oooo
ooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo00<00000oooo
ooooool03?ooool00`00003oooooooooo`0iooooo`0300000?ooool0000000Oooooo0P0000000ooo
ool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000Pooooo`0300000?ooool0000001[o
oooo00<00000ooooooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Co
oooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00co
oooo00<00000ooooooooool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?oo
ool05Oooool00`00003oooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`030000
0?oooooooooo01gooooo00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`030000
0?oooooooooo02[ooooo00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`030000
0?oooooooooo03Wooooo00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo
00<00000ooooooooool0D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003ooooooooo
o`0Mooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003ooooooooo
o`0Zooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool00`00003ooooooooo
o`0iooooo`0300000?ooool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oo
oooooooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool0
0`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool0
0`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool0
0`00003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1B
ooooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oooooooooo01gooooo00<00000oooo
ooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo00<00000oooo
ooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo00<00000oooo
o`0000001oooool200000003ooooo`00003ooooo01Gooooo00<00000ooooooooool0D_ooool0023o
oooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00;o
oooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00_o
oooo00<00000ooooooooool03?ooool00`00003oooooooooo`0iooooo`0300000?ooool0000000Oo
oooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000Pooooo`030000
0?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00003oooooooooo`02ooooo`030000
0?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`030000
0?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00003ooooo00000007ooooo`800000
00?ooooo00000?ooool05Oooool00`00003oooooooooo`1Booooo`008?ooool00`00003ooooo0000
000Jooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00_ooool00`00003ooooooooo
o`04ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool02oooool00`00003ooooooooo
o`0<ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`0000001oooool200000003ooooo`00
003ooooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo00<00000ooooo`0000006_ooool0
0`00003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool0
0`00003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool0
0`00003oooooooooo`0iooooo`0300000?ooool0000000Oooooo0P0000000oooool00000ooooo`0E
ooooo`0300000?oooooooooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo00<00000oooo
ooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000oooo
ooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000oooo
ooooool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00
003oooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oooooooooo01go
oooo00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02[o
oooo00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wo
oooo00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo00<00000oooooooo
ool0D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0Mooooo`030000
0?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Zooooo`030000
0?oooooooooo00_ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0iooooo`030000
0?ooool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo
000Pooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00003ooooooooo
o`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00003ooooooooo
o`0;ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00003ooooo0000
0007ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1Booooo`008?ooool0
0`00003ooooo0000000Jooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00_ooool0
0`00003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool02oooool0
0`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`0000001oooool2
00000003ooooo`00003ooooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo00<00000oooo
o`0000006_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo00<00000oooo
ooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo00<00000oooo
ooooool03?ooool00`00003oooooooooo`0iooooo`0300000?ooool0000000Oooooo0P0000000ooo
ool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo0008oooooaP0ool000<000000?oo0000
00006P3oo`000`000000ool00?oo000M0?oo00030000003oo`00ool00080ool000<000000?oo003o
o`00103oo`000`000000o`000?l0000Z0?l000030000003o0000o`0000/0o`0000<000000?l0003o
0000303o00000`000000o`000?l0000i0?l000030000003oo`00000000L0o`000P0000000`3oo`00
00000?oo000E0?oo00030000003oo`00ool004T0ool02Oooool000Sooooo603oo`000`000000ool0
0000000J0?oo00030000003oo`00ool001d0ool000<000000?oo003oo`000P3oo`000`000000ool0
0?oo00040?oo00030000001o:RX0ObXZ02X0ObXZ00<0000007lZ:P1o:RX02`1o:RX00`000000ObXZ
07lZ:P0<07lZ:P030000001o:RX0ObXZ03T0ObXZ00<000000?oo000000001`1o:RX2000000030?oo
00000000ool001D0ool000<000000?oo003oo`00B@3oo`09ooooo`002?oooolH0?oo00030000003o
o`00000001X0ool000<000000?oo003oo`007@3oo`000`000000ool00?oo00020?oo00030000003o
o`00ool000@0ool000<000000:0Pl02P8?00:P2P8?000`000000X23`0:0Pl00;0:0Pl0030000002P
8?00X23`00`0X23`00<000000:0Pl02P8?00>@2P8?000`000000ool0000000070:0Pl080000000<0
ool00000003oo`005@3oo`000`000000ool00?oo00190?oo00Wooooo0008oooooaP0ool000<00000
0?oo000000006P3oo`000`000000ool00?oo000M0?oo00030000003oo`00ool00080ool000<00000
0?oo003oo`00103oo`000`000000003o0000o`0Z0000o`03000000000?l0003o00/0003o00<00000
0000o`000?l030000?l00`000000003o0000o`0i0000o`030000003oo`00000000L0003o0P000000
0`3oo`0000000?oo000E0?oo00030000003oo`00ool004T0ool02Oooool000Sooooo603oo`000`00
0000ool00000000J0?oo00030000003oo`00ool001d0ool000<000000?oo003oo`000P3oo`000`00
0000ool00?oo00040?oo08L0000000<0ool0000000000000200000000`3oo`0000000?oo000E0?oo
00030000003oo`00ool004T0ool02Oooool000Sooooo603oo`000`000000ool00000000J0?oo0003
0000003oo`00ool001d0ool000<000000?oo003oo`000P3oo`000`000000ool00?oo00040?oo0003
00000000I00006@002X006@000<00000001T0000I0002`00I0000`00000006@0001T000<001T0003
00000000I00006@003T006@000<000000?oo000000001`00I002000000030?oo00000000ool001D0
ool000<000000?oo003oo`00B@3oo`09ooooo`002?oooolH0?oo00030000003oo`00000001X0ool0
00<000000?oo003oo`007@3oo`000`000000ool00?oo00020?oo00030000003oo`00ool000@0ool0
00<00000003o0000o`00:P00o`000`0000000?l0003o000;003o000300000000o`000?l000`00?l0
00<00000003o0000o`00>@00o`000`000000ool000000007003o0080000000<0ool00000003oo`00
5@3oo`000`000000ool00?oo00190?oo00Wooooo0008oooooaP0ool000<000000?oo000000006P3o
o`000`000000ool00?oo000M0?oo00030000003oo`00ool00080ool000<000000?oo003oo`00103o
o`000`000000o`3o0?l0o`0Z0?l0o`030000003o0?l0o`3o00/0o`3o00<000000?l0o`3o0?l0303o
0?l00`000000o`3o0?l0o`0i0?l0o`030000003oo`00000000L0o`3o0P0000000`3oo`0000000?oo
000E0?oo00030000003oo`00ool004T0ool02Oooool000Sooooo603oo`000`000000ool00000000J
0?oo00030000003oo`00ool001d0ool000<000000?oo003oo`000P3oo`000`000000ool00?oo0004
0?oo000300000000ool00?oo02X00?oo00<00000003oo`00ool02`00ool00`0000000?oo003oo`0<
003oo`0300000000ool00?oo03T00?oo00<000000?oo000000001`00ool2000000030?oo00000000
ool001D0ool000<000000?oo003oo`00B@3oo`09ooooo`002?oooomQ0?oo08L0/31P00<0ool00;0`
H02`<6001`2`<61U0?oo00Wooooo000Pooooo`0300000?ooool0000001[ooooo00<00000oooooooo
ool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000oooooooo
ool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000oooooooo
ool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00003o
ooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oooooooooo01gooooo
00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo
00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo
00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo00<00000ooooooooool0
D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0Mooooo`0300000?oo
oooooooo00;ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oo
oooooooo00_ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0iooooo`0300000?oo
ool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000P
ooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00003oooooooooo`02
ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0;
ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00003ooooo00000007
ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1Booooo`008?ooool00`00
003ooooo0000000Jooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00_ooool00`00
003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool02oooool00`00
003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`0000001oooool20000
0003ooooo`00003ooooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo00<00000ooooo`00
00006_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo00<00000oooooooo
ool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo00<00000oooooooo
ool03?ooool00`00003oooooooooo`0iooooo`0300000?ooool0000000Oooooo0P0000000oooool0
0000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo
00<00000ooooooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo
00<00000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo
00<00000ooooooooool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?ooool0
5Oooool00`00003oooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oo
oooooooo01gooooo00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oo
oooooooo02[ooooo00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oo
oooooooo03Wooooo00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo00<0
0000ooooooooool0D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0M
ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Z
ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0i
ooooo`0300000?ooool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooo
oooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00
003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00
003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00
003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1Boooo
o`008?ooool00`00003ooooo0000000Jooooo`0300000?oooooooooo01gooooo00<00000oooooooo
ool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo00<00000oooooooo
ool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`00
00001oooool200000003ooooo`00003ooooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo
00<00000ooooo`0000006_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo
00<00000ooooooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo
00<00000ooooooooool03?ooool00`00003oooooooooo`0iooooo`0300000?ooool0000000Oooooo
0P0000000oooool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000Pooooo`0300000?oo
ool0000001[ooooo00<00000ooooooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oo
oooooooo00Cooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oo
oooooooo00cooooo00<00000ooooooooool0>Oooool00`00003ooooo00000007ooooo`80000000?o
oooo00000?ooool05Oooool00`00003oooooooooo`1Booooo`008?ooool00`00003ooooo0000000J
ooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00_ooool00`00003oooooooooo`04
ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool02oooool00`00003oooooooooo`0<
ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`0000001oooool200000003ooooo`00003o
oooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00
003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00
003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool00`00
003oooooooooo`0iooooo`0300000?ooool0000000Oooooo0P0000000oooool00000ooooo`0Eoooo
o`0300000?oooooooooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo00<00000oooooooo
ool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000oooooooo
ool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000oooooooo
ool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00003o
ooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oooooooooo01gooooo
00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo
00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo
00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo00<00000ooooooooool0
D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0Mooooo`0300000?oo
oooooooo00;ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oo
oooooooo00_ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0iooooo`0300000?oo
ool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000P
ooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00003oooooooooo`02
ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0;
ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00003ooooo00000007
ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1Booooo`008?ooool00`00
003ooooo0000000Jooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00_ooool00`00
003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool02oooool00`00
003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`0000001oooool20000
0003ooooo`00003ooooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo00<00000ooooo`00
00006_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo00<00000oooooooo
ool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo00<00000oooooooo
ool03?ooool00`00003oooooooooo`0iooooo`0300000?ooool0000000Oooooo0P0000000oooool0
0000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo
00<00000ooooooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo
00<00000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo
00<00000ooooooooool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?ooool0
5Oooool00`00003oooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oo
oooooooo01gooooo00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oo
oooooooo02[ooooo00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oo
oooooooo03Wooooo00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo00<0
0000ooooooooool0D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0M
ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Z
ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0i
ooooo`0300000?ooool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooo
oooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00
003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00
003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00
003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1Boooo
o`008?ooool00`00003ooooo0000000Jooooo`0300000?oooooooooo01gooooo00<00000oooooooo
ool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo00<00000oooooooo
ool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`00
00001oooool200000003ooooo`00003ooooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo
00<00000ooooo`0000006_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo
00<00000ooooooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo
00<00000ooooooooool03?ooool00`00003oooooooooo`0iooooo`0300000?ooool0000000Oooooo
0P0000000oooool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000Pooooo`0300000?oo
ool0000001[ooooo00<00000ooooooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oo
oooooooo00Cooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oo
oooooooo00cooooo00<00000ooooooooool0>Oooool00`00003ooooo00000007ooooo`80000000?o
oooo00000?ooool05Oooool00`00003oooooooooo`1Booooo`008?ooool00`00003ooooo0000000J
ooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00_ooool00`00003oooooooooo`04
ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool02oooool00`00003oooooooooo`0<
ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`0000001oooool200000003ooooo`00003o
oooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00
003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00
003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool00`00
003oooooooooo`0iooooo`0300000?ooool0000000Oooooo0P0000000oooool00000ooooo`0Eoooo
o`0300000?oooooooooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo00<00000oooooooo
ool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000oooooooo
ool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000oooooooo
ool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00003o
ooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oooooooooo01gooooo
00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo
00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo
00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo00<00000ooooooooool0
D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0Mooooo`0300000?oo
oooooooo00;ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Zooooo`0300000?oo
oooooooo00_ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0iooooo`0300000?oo
ool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000P
ooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00003oooooooooo`02
ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0;
ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00003ooooo00000007
ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1Booooo`008?ooool00`00
003ooooo0000000Jooooo`0300000?oooooooooo01gooooo00<00000ooooooooool00_ooool00`00
003oooooooooo`04ooooo`0300000?oooooooooo02[ooooo00<00000ooooooooool02oooool00`00
003oooooooooo`0<ooooo`0300000?oooooooooo03Wooooo00<00000ooooo`0000001oooool20000
0003ooooo`00003ooooo01Gooooo00<00000ooooooooool0D_ooool0023ooooo00<00000ooooo`00
00006_ooool00`00003oooooooooo`0Mooooo`0300000?oooooooooo00;ooooo00<00000oooooooo
ool01?ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo00_ooooo00<00000oooooooo
ool03?ooool00`00003oooooooooo`0iooooo`0300000?ooool0000000Oooooo0P0000000oooool0
0000ooooo`0Eooooo`0300000?oooooooooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo
00<00000ooooooooool07Oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo
00<00000ooooooooool0:_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo
00<00000ooooooooool0>Oooool00`00003ooooo00000007ooooo`80000000?ooooo00000?ooool0
5Oooool00`00003oooooooooo`1Booooo`008?ooool00`00003ooooo0000000Jooooo`0300000?oo
oooooooo01gooooo00<00000ooooooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oo
oooooooo02[ooooo00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oo
oooooooo03Wooooo00<00000ooooo`0000001oooool200000003ooooo`00003ooooo01Gooooo00<0
0000ooooooooool0D_ooool0023ooooo00<00000ooooo`0000006_ooool00`00003oooooooooo`0M
ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Z
ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0i
ooooo`0300000?ooool0000000Oooooo0P0000000oooool00000ooooo`0Eooooo`0300000?oooooo
oooo05;ooooo000Pooooo`0300000?ooool0000001[ooooo00<00000ooooooooool07Oooool00`00
003oooooooooo`02ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0:_ooool00`00
003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0>Oooool00`00
003ooooo00000007ooooo`80000000?ooooo00000?ooool05Oooool00`00003oooooooooo`1Boooo
o`002?oooolH0?l000030000003o0000000001X0o`0000<000000?oo003oo`007@3oo`000`000000
ool00?oo00020?oo00030000003oo`00ool000@0ool000<000000?oo003oo`00:P3oo`000`000000
ool00?oo000;0?oo00030000003oo`00ool000`0ool000<000000?oo003oo`00>@3oo`000`000000
o`00000000070?oo0080000000<0ool00000003oo`005@3oo`000`000000ool00?oo00190?oo00Wo
oooo0008oooooaP0ObXZ00<0000007lZ:P0000006P1o:RX00`000000ool00?oo000M0?oo00030000
003oo`00ool00080ool000<000000?oo003oo`00103oo`000`000000ool00?oo000Z0?oo00030000
003oo`00ool000/0ool000<000000?oo003oo`00303oo`000`000000ool00?oo000i0?oo00030000
001o:RX0000000L0ool00P0000000`3oo`0000000?oo000E0?oo00030000003oo`00ool004T0ool0
2Oooool000Sooooo602P8?000`000000X23`0000000J0:0Pl0030000003oo`00ool001d0ool000<0
00000?oo003oo`000P3oo`000`000000ool00?oo00040?oo00030000003oo`00ool002X0ool000<0
00000?oo003oo`002`3oo`000`000000ool00?oo000<0?oo00030000003oo`00ool003T0ool000<0
00000:0Pl00000001`3oo`02000000030?oo00000000ool001D0ool000<000000?oo003oo`00B@3o
o`09ooooo`002?oooolH0000o`03000000000?l0000001X0003o00<000000?oo003oo`007@3oo`00
0`000000ool00?oo00020?oo00030000003oo`00ool000@0ool000<000000?oo003oo`00:P3oo`00
0`000000ool00?oo000;0?oo00030000003oo`00ool000`0ool000<000000?oo003oo`00>@3oo`00
0`000000003o000000070?oo0080000000<0ool00000003oo`005@3oo`000`000000ool00?oo0019
0?oo00Wooooo0008ooooocH000007`3oo`000`000000ool00?oo00020?oo00030000003oo`00ool0
00@0ool000<000000?oo003oo`00:P3oo`000`000000ool00?oo000;0?oo00030000003oo`00ool0
00`0ool000<000000?oo003oo`00>@3oo`03000000L0ool00P0000000`3oo`0000000?oo000E0?oo
00030000003oo`00ool004T0ool02Oooool000Sooooo6000I0000`00000006@00000000J001T0003
0000003oo`00ool001d0ool000<000000?oo003oo`000P3oo`000`000000ool00?oo00040?oo0003
0000003oo`00ool002X0ool000<000000?oo003oo`002`3oo`000`000000ool00?oo000<0?oo0003
0000003oo`00ool003T0ool000<00000001T000000001`3oo`02000000030?oo00000000ool001D0
ool000<000000?oo003oo`00B@3oo`09ooooo`002?oooolH003o000300000000o`00000001X00?l0
00<000000?oo003oo`007@3oo`000`000000ool00?oo00020?oo00030000003oo`00ool000@0ool0
00<000000?oo003oo`00:P3oo`000`000000ool00?oo000;0?oo00030000003oo`00ool000`0ool0
00<000000?oo003oo`00>@3oo`000`0000000?l0000000070?oo0080000000<0ool00000003oo`00
5@3oo`000`000000ool00?oo00190?oo00Wooooo0008oooooaP0o`3o00<000000?l0o`0000006P3o
0?l00`000000ool00?oo000M0?oo00030000003oo`00ool00080ool000<000000?oo003oo`00103o
o`000`000000ool00?oo000Z0?oo00030000003oo`00ool000/0ool000<000000?oo003oo`00303o
o`000`000000ool00?oo000i0?oo00030000003o0?l0000000L0ool00P0000000`3oo`0000000?oo
000E0?oo00030000003oo`00ool004T0ool02Oooool000Sooooo6000ool00`0000000?oo0000000J
003oo`030000003oo`00ool001d0ool000<000000?oo003oo`000P3oo`000`000000ool00?oo0004
0?oo00030000003oo`00ool002X0ool000<000000?oo003oo`002`3oo`000`000000ool00?oo000<
0?oo00030000003oo`00ool003T0ool000<00000003oo`0000001`3oo`02000000030?oo00000000
ool001D0ool000<000000?oo003oo`00B@3oo`09ooooo`002?oooolf0;0`H;40ool00`2`<61]0?oo
00Wooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.104743, -0.0262555, \
0.014657, 0.00622532}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(agEnd = \(ExtractLineage[ag, #] &\) /@ 
        LineagesPresent[ag, 10]\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"1306", ",", 
            RowBox[{"{", 
              RowBox[{"9.700640871564927`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], 
            ",", \({{}, {x7, x1, x8, x6, x2, x5, x9, x3, x10, x4}, {x7, x1, 
                x8, x5, x9, x3, x10, x4, x6, x2}, {x9, x3, x10, x4, x6, x2, 
                x7, x1, x8, x5}, {}, {x9, x10, x3, x4, x7, x1, x8, x5, x6, 
                x2}, {x9, x10, x3, x4, x5, x7, x1, x8, x6, x2}, {x9, x10, x3, 
                x4, x7, x1, x8, x6, x2, x5}, {x5, x9, x10, x3, x4, x7, x1, 
                x8, x6, x2}}\), 
            ",", \({0.615949373524602`, 0.9858482098914348`, 
              1.0523116111725406`, 1.1282671232325412`, 2.8240168682218827`, 
              2.8346554949441782`, 2.861500704860933`, 3.129251498089458`, 
              4}\), ",", \({}\)}], "]"}], 
        ",", \(AncestralLineage[
          1308, {9.724761474486893`, 10.00594554251728`}, {{}}, {4}, {}]\), 
        ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"1319", ",", 
            RowBox[{"{", 
              RowBox[{"9.825835452826828`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], ",", \({{}}\), ",", \({4}\),
             ",", \({}\)}], "]"}], 
        ",", \(AncestralLineage[
          1323, {9.861754224364217`, 
            10.00594554251728`}, {{}, {x9, x3, x10, x4, x6, x2, x7, x1, x8, 
              x5}, {x9, x3, x10, x4, x7, x1, x8, x6, x2, x5}, {x9, x3, x10, 
              x4, x7, x1, x8, x5, x6, x2}, {x9, x10, x3, x4, x7, x1, x8, x5, 
              x6, x2}, {}, {x9, x10, x3, x4, x7, x1, x8, x5, x6, 
              x2}, {}}, {1.1282671232325412`, 1.6650535632886254`, 
            1.8228305062583756`, 2.001206795392987`, 2.698975054344557`, 
            2.7305627494171794`, 2.8240168682218827`, 4}, {}]\), ",", 
        RowBox[{"AncestralLineage", "[", 
          RowBox[{"1325", ",", 
            RowBox[{"{", 
              RowBox[{"9.903945935869748`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]]}], "}"}], 
            ",", \({{x9, x3, x10, x4, x2, x7, x1, x8, x6, x5}, {x7, x1, x8, 
                x6, x5, x9, x3, x10, x4, x2}, {x7, x1, x8, x6, x2, x5, x9, 
                x3, x10, x4}, {}, {x9, x10, x3, x4, x7, x1, x8, x5, x6, 
                x2}, {}}\), 
            ",", \({0.2774573093820705`, 0.29467924111484667`, 
              0.615949373524602`, 2.698975054344557`, 2.7305627494171794`, 
              4}\), ",", \({}\)}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[27]="]
}, Closed]],

Cell[TextData[{
  "This plots the segments ancestral to leaf x1.  The ancestral genome of x1 \
occurs on 3 different individuals.  .The other 2 genomes are 'nulls' which \
are not in fact ancestral to anything.  Examination of the three non-trivial \
ancestral lineages shows that each is ancestral to all 10 leaves - in other \
words, every part of the genome is ",
  StyleBox["identical by descent",
    FontSlant->"Italic"],
  " relative to the population at T=-10."
}], "Text"],

Cell["\<\
This shows the same, but at T=1.  At this time, no part of the \
genome is IBD:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cls = {Red, Brown, Purple, Blue, Black, DarkGreen, Green, Magenta, 
          Cyan, Maroon};\)\), "\[IndentingNewLine]", 
    \(\(Show[\[IndentingNewLine]Table[
          PlotSegments[\(ExtractLineage[ag, #] &\) /@ LineagesPresent[ag, 1], 
            lvs\[LeftDoubleBracket]j\[RightDoubleBracket], {0.005  j, 
              1 + 0.005  j}, 
            SegmentStyle -> {cls\[LeftDoubleBracket]
                  j\[RightDoubleBracket]}], {j, 10}]];\)\)}], "Input",
  CellLabel->"In[47]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0147151 0.560575 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.5 Mabswid
[ ] 0 setdash
.03091 .01752 m
.03091 .57809 L
s
.08987 .01752 m
.08987 .57809 L
s
.09397 .01752 m
.09397 .57809 L
s
.25854 .01752 m
.25854 .57809 L
s
.27436 .01752 m
.27436 .57809 L
s
.42025 .01752 m
.42025 .57809 L
s
.45782 .01752 m
.45782 .57809 L
s
.50029 .01752 m
.50029 .57809 L
s
.69873 .01752 m
.69873 .57809 L
s
.76887 .01752 m
.76887 .57809 L
s
.94775 .01752 m
.94775 .57809 L
s
1 1 0 r
.02381 .01752 m
.97619 .01752 L
s
.02381 .11095 m
.97619 .11095 L
s
.02381 .20438 m
.97619 .20438 L
s
.02381 .29781 m
.97619 .29781 L
s
.02381 .39123 m
.97619 .39123 L
s
.02381 .48466 m
.97619 .48466 L
s
.02381 .57809 m
.97619 .57809 L
s
1 0 0 r
.02381 .01752 m
.42025 .01752 L
s
.69873 .11095 m
.94775 .11095 L
s
.94775 .29781 m
.97619 .29781 L
s
.42025 .48466 m
.69873 .48466 L
s
0 0 0 r
.03091 .02032 m
.03091 .5809 L
s
.08987 .02032 m
.08987 .5809 L
s
.09397 .02032 m
.09397 .5809 L
s
.25854 .02032 m
.25854 .5809 L
s
.27436 .02032 m
.27436 .5809 L
s
.42025 .02032 m
.42025 .5809 L
s
.45782 .02032 m
.45782 .5809 L
s
.50029 .02032 m
.50029 .5809 L
s
.69873 .02032 m
.69873 .5809 L
s
.76887 .02032 m
.76887 .5809 L
s
.94775 .02032 m
.94775 .5809 L
s
1 1 0 r
.02381 .02032 m
.97619 .02032 L
s
.02381 .11375 m
.97619 .11375 L
s
.02381 .20718 m
.97619 .20718 L
s
.02381 .30061 m
.97619 .30061 L
s
.02381 .39404 m
.97619 .39404 L
s
.02381 .48747 m
.97619 .48747 L
s
.02381 .5809 m
.97619 .5809 L
s
.5 .165 .165 r
.09397 .02032 m
.25854 .02032 L
s
.45782 .11375 m
.94775 .11375 L
s
.03091 .20718 m
.08987 .20718 L
s
.02381 .30061 m
.03091 .30061 L
s
.94775 .30061 m
.97619 .30061 L
s
.08987 .39404 m
.09397 .39404 L
s
.25854 .39404 m
.27436 .39404 L
s
.27436 .48747 m
.45782 .48747 L
s
0 0 0 r
.03091 .02312 m
.03091 .5837 L
s
.08987 .02312 m
.08987 .5837 L
s
.09397 .02312 m
.09397 .5837 L
s
.25854 .02312 m
.25854 .5837 L
s
.27436 .02312 m
.27436 .5837 L
s
.42025 .02312 m
.42025 .5837 L
s
.45782 .02312 m
.45782 .5837 L
s
.50029 .02312 m
.50029 .5837 L
s
.69873 .02312 m
.69873 .5837 L
s
.76887 .02312 m
.76887 .5837 L
s
.94775 .02312 m
.94775 .5837 L
s
1 1 0 r
.02381 .02312 m
.97619 .02312 L
s
.02381 .11655 m
.97619 .11655 L
s
.02381 .20998 m
.97619 .20998 L
s
.02381 .30341 m
.97619 .30341 L
s
.02381 .39684 m
.97619 .39684 L
s
.02381 .49027 m
.97619 .49027 L
s
.02381 .5837 m
.97619 .5837 L
s
.628 .126 .941 r
.03091 .20998 m
.08987 .20998 L
s
.02381 .30341 m
.03091 .30341 L
s
.08987 .39684 m
.27436 .39684 L
s
.27436 .49027 m
.97619 .49027 L
s
0 0 0 r
.03091 .02593 m
.03091 .5865 L
s
.08987 .02593 m
.08987 .5865 L
s
.09397 .02593 m
.09397 .5865 L
s
.25854 .02593 m
.25854 .5865 L
s
.27436 .02593 m
.27436 .5865 L
s
.42025 .02593 m
.42025 .5865 L
s
.45782 .02593 m
.45782 .5865 L
s
.50029 .02593 m
.50029 .5865 L
s
.69873 .02593 m
.69873 .5865 L
s
.76887 .02593 m
.76887 .5865 L
s
.94775 .02593 m
.94775 .5865 L
s
1 1 0 r
.02381 .02593 m
.97619 .02593 L
s
.02381 .11936 m
.97619 .11936 L
s
.02381 .21278 m
.97619 .21278 L
s
.02381 .30621 m
.97619 .30621 L
s
.02381 .39964 m
.97619 .39964 L
s
.02381 .49307 m
.97619 .49307 L
s
.02381 .5865 m
.97619 .5865 L
s
0 0 1 r
.03091 .21278 m
.08987 .21278 L
s
.02381 .30621 m
.03091 .30621 L
s
.08987 .39964 m
.27436 .39964 L
s
.27436 .49307 m
.97619 .49307 L
s
0 0 0 r
.03091 .02873 m
.03091 .5893 L
s
.08987 .02873 m
.08987 .5893 L
s
.09397 .02873 m
.09397 .5893 L
s
.25854 .02873 m
.25854 .5893 L
s
.27436 .02873 m
.27436 .5893 L
s
.42025 .02873 m
.42025 .5893 L
s
.45782 .02873 m
.45782 .5893 L
s
.50029 .02873 m
.50029 .5893 L
s
.69873 .02873 m
.69873 .5893 L
s
.76887 .02873 m
.76887 .5893 L
s
.94775 .02873 m
.94775 .5893 L
s
1 1 0 r
.02381 .02873 m
.97619 .02873 L
s
.02381 .12216 m
.97619 .12216 L
s
.02381 .21559 m
.97619 .21559 L
s
.02381 .30902 m
.97619 .30902 L
s
.02381 .40245 m
.97619 .40245 L
s
.02381 .49588 m
.97619 .49588 L
s
.02381 .5893 m
.97619 .5893 L
s
0 0 0 r
.02381 .02873 m
.76887 .02873 L
s
.76887 .49588 m
.97619 .49588 L
s
.03091 .03153 m
.03091 .59211 L
s
.08987 .03153 m
.08987 .59211 L
s
.09397 .03153 m
.09397 .59211 L
s
.25854 .03153 m
.25854 .59211 L
s
.27436 .03153 m
.27436 .59211 L
s
.42025 .03153 m
.42025 .59211 L
s
.45782 .03153 m
.45782 .59211 L
s
.50029 .03153 m
.50029 .59211 L
s
.69873 .03153 m
.69873 .59211 L
s
.76887 .03153 m
.76887 .59211 L
s
.94775 .03153 m
.94775 .59211 L
s
1 1 0 r
.02381 .03153 m
.97619 .03153 L
s
.02381 .12496 m
.97619 .12496 L
s
.02381 .21839 m
.97619 .21839 L
s
.02381 .31182 m
.97619 .31182 L
s
.02381 .40525 m
.97619 .40525 L
s
.02381 .49868 m
.97619 .49868 L
s
.02381 .59211 m
.97619 .59211 L
s
0 .392 0 r
.02381 .03153 m
.25854 .03153 L
s
.45782 .12496 m
.94775 .12496 L
s
.94775 .31182 m
.97619 .31182 L
s
.25854 .40525 m
.27436 .40525 L
s
.27436 .49868 m
.45782 .49868 L
s
0 0 0 r
.03091 .03434 m
.03091 .59491 L
s
.08987 .03434 m
.08987 .59491 L
s
.09397 .03434 m
.09397 .59491 L
s
.25854 .03434 m
.25854 .59491 L
s
.27436 .03434 m
.27436 .59491 L
s
.42025 .03434 m
.42025 .59491 L
s
.45782 .03434 m
.45782 .59491 L
s
.50029 .03434 m
.50029 .59491 L
s
.69873 .03434 m
.69873 .59491 L
s
.76887 .03434 m
.76887 .59491 L
s
.94775 .03434 m
.94775 .59491 L
s
1 1 0 r
.02381 .03434 m
.97619 .03434 L
s
.02381 .12776 m
.97619 .12776 L
s
.02381 .22119 m
.97619 .22119 L
s
.02381 .31462 m
.97619 .31462 L
s
.02381 .40805 m
.97619 .40805 L
s
.02381 .50148 m
.97619 .50148 L
s
.02381 .59491 m
.97619 .59491 L
s
0 1 0 r
.02381 .03434 m
.42025 .03434 L
s
.69873 .12776 m
.94775 .12776 L
s
.94775 .31462 m
.97619 .31462 L
s
.42025 .50148 m
.69873 .50148 L
s
0 0 0 r
.03091 .03714 m
.03091 .59771 L
s
.08987 .03714 m
.08987 .59771 L
s
.09397 .03714 m
.09397 .59771 L
s
.25854 .03714 m
.25854 .59771 L
s
.27436 .03714 m
.27436 .59771 L
s
.42025 .03714 m
.42025 .59771 L
s
.45782 .03714 m
.45782 .59771 L
s
.50029 .03714 m
.50029 .59771 L
s
.69873 .03714 m
.69873 .59771 L
s
.76887 .03714 m
.76887 .59771 L
s
.94775 .03714 m
.94775 .59771 L
s
1 1 0 r
.02381 .03714 m
.97619 .03714 L
s
.02381 .13057 m
.97619 .13057 L
s
.02381 .224 m
.97619 .224 L
s
.02381 .31743 m
.97619 .31743 L
s
.02381 .41085 m
.97619 .41085 L
s
.02381 .50428 m
.97619 .50428 L
s
.02381 .59771 m
.97619 .59771 L
s
1 0 1 r
.02381 .03714 m
.42025 .03714 L
s
.69873 .13057 m
.94775 .13057 L
s
.94775 .31743 m
.97619 .31743 L
s
.42025 .50428 m
.69873 .50428 L
s
0 0 0 r
.03091 .03994 m
.03091 .60052 L
s
.08987 .03994 m
.08987 .60052 L
s
.09397 .03994 m
.09397 .60052 L
s
.25854 .03994 m
.25854 .60052 L
s
.27436 .03994 m
.27436 .60052 L
s
.42025 .03994 m
.42025 .60052 L
s
.45782 .03994 m
.45782 .60052 L
s
.50029 .03994 m
.50029 .60052 L
s
.69873 .03994 m
.69873 .60052 L
s
.76887 .03994 m
.76887 .60052 L
s
.94775 .03994 m
.94775 .60052 L
s
1 1 0 r
.02381 .03994 m
.97619 .03994 L
s
.02381 .13337 m
.97619 .13337 L
s
.02381 .2268 m
.97619 .2268 L
s
.02381 .32023 m
.97619 .32023 L
s
.02381 .41366 m
.97619 .41366 L
s
.02381 .50709 m
.97619 .50709 L
s
.02381 .60052 m
.97619 .60052 L
s
0 1 1 r
.03091 .2268 m
.08987 .2268 L
s
.02381 .32023 m
.03091 .32023 L
s
.08987 .41366 m
.27436 .41366 L
s
.27436 .50709 m
.97619 .50709 L
s
0 0 0 r
.03091 .04274 m
.03091 .60332 L
s
.08987 .04274 m
.08987 .60332 L
s
.09397 .04274 m
.09397 .60332 L
s
.25854 .04274 m
.25854 .60332 L
s
.27436 .04274 m
.27436 .60332 L
s
.42025 .04274 m
.42025 .60332 L
s
.45782 .04274 m
.45782 .60332 L
s
.50029 .04274 m
.50029 .60332 L
s
.69873 .04274 m
.69873 .60332 L
s
.76887 .04274 m
.76887 .60332 L
s
.94775 .04274 m
.94775 .60332 L
s
1 1 0 r
.02381 .04274 m
.97619 .04274 L
s
.02381 .13617 m
.97619 .13617 L
s
.02381 .2296 m
.97619 .2296 L
s
.02381 .32303 m
.97619 .32303 L
s
.02381 .41646 m
.97619 .41646 L
s
.02381 .50989 m
.97619 .50989 L
s
.02381 .60332 m
.97619 .60332 L
s
.69 .188 .377 r
.03091 .2296 m
.08987 .2296 L
s
.02381 .32303 m
.03091 .32303 L
s
.08987 .41646 m
.27436 .41646 L
s
.27436 .50989 m
.97619 .50989 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[47]:=",
  ImageSize->{428.75, 264.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008G0001Bb000`400?l00000o`00003ooooooooo
oooooaWooooo003ooooooooooooo6Oooool00?oooooooooooolIooooo`00oooooooooooooaWooooo
003ooooooooooooo6Oooool00?oooooooooooolIooooo`00oooooooooooooaWooooo003ooooooooo
oooo6Oooool00?oooooooooooolIooooo`00oooooooooooooaWooooo000=ooooomCoo`00ooooo`0Z
oooo00gooooo000=ooooobGoool0FOmo:R[ooooo083oool03Oooool0017ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo
ool06_ooool000goooooooooo`3noooo00gooooo000=ooooooooool0o_ooo`0=ooooo`004Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool0
0ol0003oooooooooo`0Jooooo`003Oooooooo`00093o0000K_ooo`0=ooooo`003Ooooomno`1T0?oo
ool0P?ooo`0=ooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`003OoooooDo`3o0?ooool0:_oo
o`0=ooooo`003OoooooDool0ooooool0:_ooo`0=ooooo`004Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooo000005Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Woooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Joooo
o`003Ooooooooooo0?koool03Oooool000goooooooooo`3noooo00gooooo000Aooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo
01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo
01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo
00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo
000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000
ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Loooo
o`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool0
0000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooo
oooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01co
oooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[o
oooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o
0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000A
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1L
ooooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03
o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03
o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000
Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo
01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo
01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo
00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo
000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000
ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Loooo
o`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool0
0000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooo
oooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01co
oooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[o
oooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o
0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000=
ooooo`Coool000?o0000oooo0?ooo`007?ooo`000ol0003oool0o`00001Goooo0003o`000?ooo`3o
ool000Goool000?o0000oooo0?ooo`00Boooo`000ol0003oool0oooo000Aoooo0003o`000?ooo`3o
ool001Coool000?o0000oooo0?ooo`00Ioooo`000ol0003oo`00ool0000Sool00003o`000?oo003o
o`0005coo`0000?o0000oooo0?ooo`003Oooo`0=ooooo`003Oooool4oooo0003o`000?ooo`3oool0
01coool000?o0000oooo0?l00000Eoooo`000ol0003oool0oooo0005oooo0003o`000?ooo`3oool0
04_oool000?o0000oooo0?ooo`004Oooo`000ol0003oObXZoglZ:P0DoglZ:P03o`000?mo:R[oObXZ
06OoObXZ00?o0000oglZ:_mo:RX08omo:RX00ol0003oObXZoglZ:P1LoglZ:P03o`000?ooo`3oool0
00goool03Oooool0017ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool000gooooo1?ooo`000ol0003oool0
oooo000Loooo0003o`000?ooo`3o000005Ooool000?o0000oooo0?ooo`001Oooo`000ol0003oool0
oooo001;oooo0003o`000?ooo`3oool0017oool000?o0000oooo0?ooo`005?ooo`000ol0003oool0
oooo001Woooo0003o`000?ooo`3oool002?oool000?o0000oooo0?ooo`00G?ooo`000ol0003oool0
oooo000=oooo00gooooo000=ooooo`Coool000?o0000oooo0?ooo`007?ooo`000ol0003oool0o`00
001Goooo0003o`000?ooo`3oool000Goool000?o0000oooo0?ooo`00Boooo`000ol0003oool0oooo
000Aoooo0003o`000?ooo`3oool001Coool000?o0000oooo0?ooo`00Ioooo`000ol0003oool0oooo
000Soooo0003o`000?ooo`3oool005coool000?o0000oooo0?ooo`003Oooo`0=ooooo`004Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool0
0ol0003oooooooooo`0Jooooo`003Oooool4oooo0003o`000?ooo`3oool001coool000?o0000oooo
0?l00000Eoooo`000ol0003oool0oooo0005oooo0003o`000?ooo`3oool004_oool000?o0000oooo
0?ooo`004Oooo`000ol0003oool0oooo000Doooo0003o`000?ooo`3oool006Ooool000?o0000oooo
0?ooo`008oooo`000ol0003oool0oooo001Loooo0003o`000?ooo`3oool000goool03Oooool000go
oooo1?ooo`000ol0003oool0oooo000Loooo0003o`000?ooo`3o000005Ooool000?o0000oooo0?oo
o`001Oooo`000ol0003oool0oooo001;oooo0003o`000?ooo`3oool0017oool000?o0000o`1T0?l0
I0005?l0I0000ol0003o06@0o`1T001Wo`1T0003o`000?l0I03o06@002?o06@000?o0000o`1T0?l0
I000G?l0I0000ol0003oool0oooo000=oooo00gooooo000Aooooo`03o`000?oooooooooo01cooooo
00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo
000=ooooo`Coool000?o0000oooo0?ooo`007?ooo`000ol0003oool0o`00001Goooo0003o`000?oo
o`3oool000Goool000?o0000oooo0?ooo`00Boooo`000ol0003oool0oooo000Aoooo0003o`000?oo
o`3oool001Coool000?o0000oooo0?ooo`00Ioooo`000ol0003o0?l0o`3o000So`3o0003o`000?l0
o`3o0?l005co0?l000?o0000oooo0?ooo`003Oooo`0=ooooo`003Oooool4oooo0003o`000?ooo`3o
ool001coool000?o0000oooo0?l00000Eoooo`000ol0003oool0oooo0005oooo0003o`000?ooo`3o
ool004_oool000?o0000oooo0?ooo`004Oooo`000ol0003oool0oooo000Doooo0003o`000?ooo`3o
ool006Ooool000?o0000ool0oooo0?l08ooo0?l00ol0003oo`3oool0o`1Lool0o`03o`000?ooo`3o
ool000goool03Oooool0017ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00001Goooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool000gooooo1?ooo`000ol0003o
ool0oooo000Loooo0003o`000?ooo`3o000005Ooool000?o0000oooo0?ooo`001Oooo`000ol0003o
ool0oooo001;oooo0003o`000?ooo`3oool0017oool000?o0000oooo0?ooo`005?ooo`000ol0003o
ool0oooo001Woooo0003o`000?ooo`3oool002?oool000?o0000oooo0?ooo`00G?ooo`000ol0003o
ool0oooo000=oooo00gooooo000=ooooooooool0o_ooo`0=ooooo`004Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooo000005Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003ooooooooo
o`0Jooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`004Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooo000005Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Woooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Joooo
o`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0G?ooool00ol0003oooooooooo`0Jooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooo000005Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`004Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?oo
ool00ol0003oooooooooo`0Jooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
000005Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`004Oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0
003oooooooooo`0Jooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`004Oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooo000005Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003ooooo
ooooo`0Jooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`004Oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooo000005Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1W
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0J
ooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool0G?ooool00ol0003oooooooooo`0Jooooo`004Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooo000005Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`00
4Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
G?ooool00ol0003oooooooooo`0Jooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooo000005Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`004Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool0
0ol0003oooooooooo`0Jooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo0000
05Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`004Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003o
ooooooooo`0Jooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`004Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooo000005Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003ooooooooo
o`0Jooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`004Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooo000005Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Woooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Joooo
o`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0G?ooool00ol0003oooooooooo`0Jooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooo000005Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`004Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?oo
ool00ol0003oooooooooo`0Jooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
000005Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`004Oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0
003oooooooooo`0Jooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`004Oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooo000005Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003ooooo
ooooo`0Jooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`004Oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooo000005Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1W
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0J
ooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool0G?ooool00ol0003oooooooooo`0Jooooo`004Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooo000005Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`00
4Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
G?ooool00ol0003oooooooooo`0Jooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooo000005Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`003Oooool4
oooo0003o`000?ooo`3oool001coool000?o0000oooo0?l00000Eoooo`000ol0003oool0oooo0005
oooo0003o`000?ooo`3oool004_oool000?o0000oooo0?ooo`004Oooo`000ol0003oool0oooo000D
oooo0003o`000?ooo`3oool006Ooool000?o0000oooo0?ooo`008oooo`000ol0003oool0oooo001L
oooo0003o`000?ooo`3oool000goool03Oooool000gooooo1?ooo`000ol0003oObXZoglZ:P0LoglZ
:P03o`000?ooo`3o000005Ooool000?o0000oooo0?ooo`001Oooo`000ol0003oool0oooo001;oooo
0003o`000?ooo`3oool0017oool000?o0000oooo0?ooo`005?ooo`000ol0003oool0oooo001Woooo
0003o`000?ooo`3oool002?oool000?o0000oooo0?ooo`00G?ooo`000ol0003oool0oooo000=oooo
00gooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000=ooooo`Coool000?o0000oj0Pl?nP8?00
7?nP8?000ol0003oool0o`00001Goooo0003o`000?ooo`3oool000Goool000?o0000oooo0?ooo`00
Boooo`000ol0003oool0oooo000Aoooo0003o`000?ooo`3oool001Coool000?o0000oooo0?ooo`00
Ioooo`000ol0003oool0oooo000Soooo0003o`000?ooo`3oool005coool000?o0000oooo0?ooo`00
3Oooo`0=ooooo`003Oooool4oooo0003o`000?l00?oo003o01co003o00?o0000oooo0?l00000Eooo
o`000ol0003oool0oooo0005oooo0003o`000?ooo`3oool004_oool000?o0000oooo0?ooo`004Ooo
o`000ol0003oool0oooo000Doooo0003o`000?ooo`3oool006Ooool000?o0000oooo0?ooo`008ooo
o`000ol0003oool0oooo001Loooo0003o`000?ooo`3oool000goool03Oooool0017ooooo00?o0000
ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05cooooo00?o0000
ooooooooool06_ooool000gooooo1?ooo`000ol0003oool0oooo000Loooo0003o`000?ooo`3o0000
05Ooool000?o0000oooo0?ooo`001Oooo`000ol0003oool0oooo001;oooo0003o`000?ooo`3oool0
017oool000?o0000oooo0?ooo`005?ooo`000ol0003oool0oooo001Woooo0003o`000?ooo`3oool0
02?oool000?o0000oooo0?ooo`00G?ooo`000ol0003oool0oooo000=oooo00gooooo000=ooooo`Co
ool000?o0000oooo0?ooo`007?ooo`000ol0003oool0o`00001Goooo0003o`000?ooo`3oool000Go
ool000?o0000oooo0?ooo`00Boooo`000ol0003oool0oooo000Aoooo0003o`000?ooo`3oool001Co
ool000?o0000oooo0?ooo`00Ioooo`000ol0003oool0oooo000Soooo0003o`000?ooo`3oool005co
ool000?o0000oooo0?ooo`003Oooo`0=ooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooo000005Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`003Ooo
ool4oooo0003o`000?ooo`3oool001coool000?o0000oooo0?l00000Eoooo`000ol0003oool0oooo
0005oooo0003o`000?ooo`3oool004_oool000?o0000oooo0?ooo`004Oooo`000ol0003oool0oooo
000Doooo0003o`000?ooo`3oool006Ooool000?o0000oooo0?ooo`008oooo`000ol0003oool0oooo
001Loooo0003o`000?ooo`3oool000goool03Oooool000gooooo1?ooo`000ol0003oool0oooo000L
oooo0003o`000?ooo`3o000005Ooool000?o0000oooo0?ooo`001Oooo`000ol0003oool0oooo001;
oooo0003o`000?ooo`3oool0017oool000?o0000oooo0?ooo`005?ooo`000ol0003oool0oooo001W
oooo0003o`000?ooo`3oool002?oool000?o0000oooo0?ooo`00G?ooo`000ol0003oool0oooo000=
oooo00gooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000=ooooo`Coool000?o0000o`3oool0
ool07?l0ool00ol0003oool0o`00001Goooo0003o`000?ooo`3oool000Goool000?o0000oooo0?oo
o`00Boooo`000ol0003oool0oooo000Aoooo0003o`000?ooo`3oool001Coool000?o0000oooo0?oo
o`00Ioooo`000ol0003oool0oooo000Soooo0003o`000?ooo`3oool005coool000?o0000oooo0?oo
o`003Oooo`0=ooooo`003Oooool4oooo023o/31Pooooo`3Joooo00gooooo000Aooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo
01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo
01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo
00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo
000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000
ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Loooo
o`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool0
0000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooo
oooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01co
oooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[o
oooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o
0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000A
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1L
ooooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03
o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03
o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000
Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo
01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo
01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo
00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo
000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000
ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Loooo
o`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool0
0000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooo
oooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01co
oooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[o
oooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o
0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000=
ooooo`Coool000?o0000oooo0?ooo`007?ooo`000ol0003oool0o`00001Goooo0003o`000?ooo`3o
ool000Goool000?o0000oooo0?ooo`00Boooo`000ol0003oool0oooo000Aoooo0003o`000?ooo`3o
ool001Coool000?o0000oooo0?ooo`00Ioooo`000ol0003oool0oooo000Soooo0003o`000?ooo`3o
ool005coool000?o0000ool00?oo00003Ooo000=ooooo`003Oooool4oglZ:P03o`000?ooo`3oool0
01coool000?o0000oooo0?l00000Eoooo`000ol0003oool0oooo0005oooo0003o`000?ooo`3oool0
04_oool000?o0000oooo0?ooo`004Oooo`000ol0003oool0oooo000Doooo0003o`000?ooo`3oool0
06Ooool000?o0000oooo0?ooo`008oooo`000ol0003oool0oooo001Loooo0003o`000?mo:R[oObXZ
00goObXZ3Oooool0017ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool000gooooo1?nP8?000ol0003oool0
oooo000Loooo0003o`000?ooo`3o000005Ooool000?o0000oooo0?ooo`001Oooo`000ol0003oool0
oooo001;oooo0003o`000?ooo`3oool0017oool000?o0000oooo0?ooo`005?ooo`000ol0003oool0
oooo001Woooo0003o`000?ooo`3oool002?oool000?o0000oooo0?ooo`00G?ooo`000ol0003oool0
oooo000=oooo00gooooo000=ooooo`Co003o00?o0000oooo0?ooo`007?ooo`000ol0003oool0o`00
001Goooo0003o`000?ooo`3oool000Goool000?o0000oooo0?ooo`00Boooo`000ol0003oool0oooo
000Aoooo0003o`000?ooo`3oool001Coool000?o0000oooo0?ooo`00Ioooo`000ol0003oool0oooo
000Soooo0003o`000?ooo`3oool005coool000?o0000oooo0?ooo`003Oooo`0=ooooo`004Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool0
0ol0003oooooooooo`0Jooooo`003Oooool4oooo0003o`000?ooo`3oool001coool000?o0000oooo
0?l00000Eoooo`000ol0003oool0oooo0005oooo0003o`000?ooo`3oool004_oool000?o0000oooo
0?ooo`004Oooo`000ol0003oool0oooo000Doooo0003o`000?ooo`3oool006Ooool000?o0000oooo
0?ooo`008oooo`000ol0003oool0oooo001Loooo0003o`000?ooo`3oool000goool03Oooool000go
oooo1?ooo`000ol0003oool0oooo000Loooo0003o`000?ooo`3o000005Ooool000?o0000oooo0?oo
o`001Oooo`000ol0003oool0oooo001;oooo0003o`000?ooo`3oool0017oool000?o0000oooo0?oo
o`005?ooo`000ol0003oool0oooo001Woooo0003o`000?ooo`3oool002?oool000?o0000oooo0?oo
o`00G?ooo`000ol0003o06@0o`1T000=o`1T00gooooo000=ooooo`Coool000?o0000oooo0?ooo`00
7?ooo`000ol0003oool0o`00001Goooo0003o`000?ooo`3oool000Goool000?o0000oooo0?ooo`00
Boooo`000ol0003oool0oooo000Aoooo0003o`000?ooo`3oool001Coool000?o0000oooo0?ooo`00
Ioooo`000ol0003oool0oooo000Soooo0003o`000?ooo`3oool005coool000?o0000o`3o0?l0o`00
3Ol0o`0=ooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`003Oooool4oooo0003o`000?ooo`3o
ool001coool000?o0000oooo0?l00000Eoooo`000ol0003oool0oooo0005oooo0003o`000?ooo`3o
ool004_oool000?o0000oooo0?ooo`004Oooo`000ol0003oool0oooo000Doooo0003o`000?ooo`3o
ool006Ooool000?o0000oooo0?ooo`008oooo`000ol0003oool0oooo001Loooo0003o`000?oo0?oo
o`3o00goo`3o3Oooool000gooooo1?l0ool00ol0003oool0oooo000Loooo0003o`000?ooo`3o0000
05Ooool000?o0000oooo0?ooo`001Oooo`000ol0003oool0oooo001;oooo0003o`000?ooo`3oool0
017oool000?o0000oooo0?ooo`005?ooo`000ol0003oool0oooo001Woooo0003o`000?ooo`3oool0
02?oool000?o0000oooo0?ooo`00G?ooo`000ol0003oool0oooo000=oooo00gooooo000Aooooo`03
o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03
o`000?oooooooooo01[ooooo000=ooooo`Go/31Pooooo`3ioooo00gooooo000Aooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo
01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo
01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo
00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo
000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000
ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Loooo
o`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool0
0000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooo
oooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01co
oooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[o
oooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o
0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000A
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1L
ooooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03
o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03
o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000
Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo
01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo
01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo
00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo
000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000
ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Loooo
o`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool0
0000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooo
oooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01co
oooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[o
oooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo01[ooooo000=ooooo`Coool000?o0000oooo0?ooo`007?oo
o`000ol0003oool0o`00001Goooo0003o`000?ooo`3oool000Goool000?o0000oooo0?ooo`00Booo
o`000ol0003oool0oooo000Aoooo0003o`000?ooo`3oool001Coool000?o0000oooo0?ooo`00Iooo
o`000ol0003oool0oooo000Soooo0003o`000?ooo`3oool005coool000?o0000oooo0?ooo`003Ooo
o`0=ooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`003Oooool4oooo0003o`000?ooo`3oool0
01coool000?o0000oglZ:_l00000Eoooo`000ol0003oObXZoglZ:P05oglZ:P03o`000?ooo`3oool0
04_oool000?o0000oooo0?ooo`004Oooo`000ol0003oool0oooo000Doooo0003o`000?ooo`3oool0
06Ooool000?o0000oooo0?ooo`008oooo`000ol0003oool0oooo001Loooo0003o`000?ooo`3oool0
00goool03Oooool000gooooo1?ooo`000ol0003oool0oooo000Loooo0003o`000?nP8?3o000005Oo
X23`00?o0000oj0Pl?nP8?001OnP8?000ol0003oool0oooo001;oooo0003o`000?ooo`3oool0017o
ool000?o0000oooo0?ooo`005?ooo`000ol0003oool0oooo001Woooo0003o`000?ooo`3oool002?o
ool000?o0000oooo0?ooo`00G?ooo`000ol0003oool0oooo000=oooo00gooooo000Aooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooooooo01[ooooo000=ooooo`Coool000?o0000oooo0?ooo`007?ooo`000ol0003o003oo`00
001Go`00o`03o`000?l00?oo003o00Go003o00?o0000oooo0?ooo`00Boooo`000ol0003oool0oooo
000Aoooo0003o`000?ooo`3oool001Coool000?o0000oooo0?ooo`00Ioooo`000ol0003oool0oooo
000Soooo0003o`000?ooo`3oool005coool000?o0000oooo0?ooo`003Oooo`0=ooooo`003Oooool4
oooo0003o`000?ooo`3oool001coool000?o0000oooo0?l00000Eoooo`000ol0003oool0oooo0005
oooo0003o`000?ooo`3oool004_oool000?o0000oooo0?ooo`004Oooo`000ol0003oool0oooo000D
oooo0003o`000?ooo`3oool006Ooool000?o0000oooo0?ooo`008oooo`000ol0003oool0oooo001L
oooo0003o`000?ooo`3oool000goool03Oooool0017ooooo00?o0000ooooooooool07?ooool00ol0
003oooooo`00001Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool000go
oooo1?ooo`000ol0003oool0oooo000Loooo0003o`000?ooo`3o000005Ooool000?o0000o`1T0?l0
I0001Ol0I0000ol0003oool0oooo001;oooo0003o`000?ooo`3oool0017oool000?o0000oooo0?oo
o`005?ooo`000ol0003oool0oooo001Woooo0003o`000?ooo`3oool002?oool000?o0000oooo0?oo
o`00G?ooo`000ol0003oool0oooo000=oooo00gooooo000=ooooo`Coool000?o0000oooo0?ooo`00
7?ooo`000ol0003oool0o`00001Goooo0003o`000?ooo`3oool000Goool000?o0000oooo0?ooo`00
Boooo`000ol0003oool0oooo000Aoooo0003o`000?ooo`3oool001Coool000?o0000oooo0?ooo`00
Ioooo`000ol0003oool0oooo000Soooo0003o`000?ooo`3oool005coool000?o0000oooo0?ooo`00
3Oooo`0=ooooo`004Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000005Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0G?ooool00ol0003oooooooooo`0Jooooo`003Oooool4oooo0003o`000?ooo`3o
ool001coool000?o0000oooo0?l00000Eoooo`000ol0003oool0oooo0005oooo0003o`000?ooo`3o
ool004_oool000?o0000oooo0?ooo`004Oooo`000ol0003oool0oooo000Doooo0003o`000?ooo`3o
ool006Ooool000?o0000oooo0?ooo`008oooo`000ol0003oool0oooo001Loooo0003o`000?ooo`3o
ool000goool03Oooool000gooooo1?ooo`000ol0003oool0oooo000Loooo0003o`000?l0oooo0000
05Oo0?oo00?o0000o`3oool0ool01Ol0ool00ol0003oool0oooo001;oooo0003o`000?ooo`3oool0
017oool000?o0000oooo0?ooo`005?ooo`000ol0003oool0oooo001Woooo0003o`000?ooo`3oool0
02?oool000?o0000oooo0?ooo`00G?ooo`000ol0003oool0oooo000=oooo00gooooo000Aooooo`03
o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03
o`000?oooooooooo01[ooooo000=ooooob?oool0Hon`<63ooooo07Soool03Oooool0017ooooo00?o
0000ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05cooooo00?o
0000ooooooooool06_ooool0017ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00001G
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool0017ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05cooooo00?o0000oooo
ooooool06_ooool0017ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool0017ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0
6_ooool0017ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo05cooooo00?o0000ooooooooool06_ooool0017ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooo`00001Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool0
017ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
05cooooo00?o0000ooooooooool06_ooool0017ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooo`00001Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool0017ooooo
00?o0000ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05cooooo
00?o0000ooooooooool06_ooool0017ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00
001Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool0017ooooo00?o0000
ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05cooooo00?o0000
ooooooooool06_ooool0017ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00001Goooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool0017ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo
ool06_ooool0017ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool06_ooool0017ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Iooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool06_oo
ool0017ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo05cooooo00?o0000ooooooooool06_ooool0017ooooo00?o0000ooooooooool07?ooool00ol0
003oooooo`00001Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool0017o
oooo00?o0000ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05co
oooo00?o0000ooooooooool06_ooool0017ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
o`00001Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool0017ooooo00?o
0000ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05cooooo00?o
0000ooooooooool06_ooool0017ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00001G
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool0017ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05cooooo00?o0000oooo
ooooool06_ooool0017ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool0017ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0
6_ooool0017ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo05cooooo00?o0000ooooooooool06_ooool0017ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooo`00001Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool0
017ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
05cooooo00?o0000ooooooooool06_ooool0017ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooo`00001Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool0017ooooo
00?o0000ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05cooooo
00?o0000ooooooooool06_ooool0017ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00
001Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool0017ooooo00?o0000
ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05cooooo00?o0000
ooooooooool06_ooool0017ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00001Goooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo05cooooo00?o0000ooooooooool06_ooool0017ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo
ool06_ooool0017ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool06_ooool000gooooo1?ooo`000ol0003oool0oooo
000Loooo0003o`000?ooo`3o000005Ooool000?o0000oooo0?ooo`001Oooo`000ol0003oool0oooo
001;oooo0003o`000?oo003oo`00017oo`0000?o0000ool00?oo00005?oo00000ol0003oo`00ool0
001Wool00003o`000?ooo`3oool002?oool000?o0000oooo0?ooo`00G?ooo`000ol0003oool0oooo
000=oooo00gooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000=ooooo`Coool000?o0000oooo
0?ooo`007?ooo`000ol0003oool0o`00001Goooo0003o`000?ooo`3oool000Goool000?o0000oglZ
:_mo:RX0Bomo:RX00ol0003oObXZoglZ:P0AoglZ:P03o`000?ooo`3oool001Coool000?o0000oooo
0?ooo`00Ioooo`000ol0003oool0oooo000Soooo0003o`000?ooo`3oool005coool000?o0000oooo
0?ooo`003Oooo`0=ooooo`003Oooool4oooo0003o`000?ooo`3oool001coool000?o0000oooo0?l0
0000Eoooo`000ol0003oool0oooo0005oooo0003o`000?nP8?3oX23`04_oX23`00?o0000oj0Pl?nP
8?004OnP8?000ol0003oX23`oj0Pl00Doj0Pl003o`000?nP8?3oX23`06OoX23`00?o0000oj0Pl?nP
8?008onP8?000ol0003oX23`oj0Pl01Loj0Pl003o`000?nP8?3oX23`00goX23`3Oooool0017ooooo
00?o0000ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo05cooooo
00?o0000ooooooooool06_ooool000gooooo1?ooo`000ol0003oool0oooo000Loooo0003o`000?oo
o`3o000005Ooool000?o0000oooo0?ooo`001Oooo`000ol0003o003oo`00o`1;o`00o`03o`000?l0
0?oo003o017o003o00?o0000o`00ool00?l05?l00?l00ol0003o003oo`00o`1Wo`00o`03o`000?l0
0?oo003o02?o003o00?o0000o`00ool00?l0G?l00?l00ol0003o003oo`00o`0=o`00o`gooooo000=
ooooo`Coool000?o0000oooo0?ooo`007?ooo`000ol0003oool0o`00001Goooo0003o`000?ooo`3o
ool000Goool000?o0000oooo0?ooo`00Boooo`000ol0003oool0oooo000Aoooo0003o`000?ooo`3o
ool001Coool000?o0000oooo0?ooo`00Ioooo`000ol0003oool0oooo000Soooo06oo00003Oooool0
017ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
05cooooo00?o0000ooooooooool06_ooool000gooooo1?ooo`000ol0003oool0oooo000Loooo0003
o`000?ooo`3o000005Ooool000?o0000oooo0?ooo`001Oooo`000ol0003o06@0o`1T001;o`1T0003
o`000?l0I03o06@0017o06@000?o0000oooo0?ooo`005?ooo`000ol0003oool0oooo001Woooo0003
o`000?ooo`3oool002?oool000?o0000oooo0?ooo`00G?ooo`000ol0003oool0oooo000=oooo00go
oooo000=ooooo`Coool000?o0000oooo0?ooo`007?ooo`000ol0003oool0o`00001Goooo0003o`00
0?ooo`3oool000Goool000?o0000oooo0?ooo`00Boooo`000ol0003o0?l0o`3o000Ao`3o0003o`00
0?l0o`3o0?l001Co0?l000?o0000o`3o0?l0o`00Iol0o`000ol0003oool0oooo000Soooo0003o`00
0?ooo`3oool005coool000?o0000oooo0?ooo`003Oooo`0=ooooo`004Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooo000005Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003ooooooooo
o`0Jooooo`003Oooool4oooo0003o`000?ooo`3oool001coool000?o0000oooo0?l00000Eoooo`00
0ol0003oool0oooo0005oooo0003o`000?ooo`3oool004_oool000?o0000ool0oooo0?l04Ooo0?l0
0ol0003oo`3oool0o`0Dool0o`03o`000?oo0?ooo`3o06Ooo`3o00?o0000oooo0?ooo`008oooo`00
0ol0003oool0oooo001Loooo0003o`000?ooo`3oool000goool03Oooool000gooooo1?ooo`000ol0
003oool0oooo000Loooo0003o`000?ooo`3o000005Ooool000?o0000oooo0?ooo`001Oooo`000ol0
003o0?ooo`3oo`1;o`3oo`03o`000?l0oooo0?oo017o0?oo00?o0000o`3oool0ool05?l0ool00ol0
003o0?ooo`3oo`1Wo`3oo`03o`000?l0oooo0?oo02?o0?oo00?o0000o`3oool0ool0G?l0ool00ol0
003o0?ooo`3oo`0=o`3oo`gooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool0
0000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000=ooooohGoool0
oon`<61iok0`H0gooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooo
oooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01co
oooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[o
oooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o
0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000A
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1L
ooooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03
o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03
o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000
Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo
01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo
01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo
00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo
000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000
ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Loooo
o`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool0
0000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooo
oooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01co
oooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[o
oooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o
0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000A
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1L
ooooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03
o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03
o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000
Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo
01cooooo00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo
01[ooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000Eoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000Aooooo`03o`000?oooooooooo01cooooo
00?o0000ooooool00000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo
000=ooooo`Coool000?o0000oooo0?ooo`007?ooo`000ol0003oool0o`00001Goooo0003o`000?oo
o`3oool000Goool000?o0000oooo0?ooo`00Boooo`000ol0003oool0oooo000Aoooo0003o`000?oo
o`3oool001Coool000?o0000oooo0?ooo`00Ioooo`000ol0003oool0oooo000Soooo0003o`000?oo
o`3oool005coool000?o0000oooo0?ooo`003Oooo`0=ooooo`004Oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooo000005Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1W
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0J
ooooo`003Oooool4oooo0003o`000?ooo`3oool001coool000?o0000oooo0?l00000Eoooo`000ol0
003oool0oooo0005oooo0003o`000?ooo`3oool004_oool000?o0000oooo0?ooo`004Oooo`000ol0
003oool0oooo000Doooo0003o`000?ooo`3oool006Ooool000?o0000oooo0?ooo`008oooo`000ol0
003oool0oooo001Loooo0003o`000?ooo`3oool000goool03Oooool000gooooo1?ooo`000ol0003o
ool0oooo000Loooo0003o`000?ooo`3o000005Ooool000?o0000oooo0?ooo`001Oooo`000ol0003o
ool0oooo001;oooo0003o`000?ooo`3oool0017oool000?o0000oooo0?ooo`005?ooo`000ol0003o
ool0oooo001Woooo0003o`000?ooo`3oool002?oool000?o0000oooo0?ooo`00G?ooo`000ol0003o
ool0oooo000=oooo00gooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000
Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000=ooooo`Coool000?o
0000oooo0?ooo`007?ooo`000ol0003oool0o`00001Goooo0003o`000?ooo`3oool000Goool000?o
0000oooo0?ooo`00Boooo`000ol0003oool0oooo000Aoooo0003o`000?ooo`3oool001Coool000?o
0000oooo0?ooo`00Ioooo`000ol0003oool0oooo000Soooo0003o`000?ooo`3oool005coool000?o
0000oooo0?ooo`003Oooo`0=ooooo`003Oooool4oooo0003o`000?ooo`3oool001coool000?o0000
oooo0?l00000Eoooo`000ol0003oool0oooo0005oooo0003o`000?ooo`3oool004_oool000?o0000
oooo0?ooo`004Oooo`000ol0003oool0oooo000Doooo0003o`000?ooo`3oool006Ooool000?o0000
oooo0?ooo`008oooo`000ol0003oool0oooo001Loooo0003o`000?ooo`3oool000goool03Oooool0
017ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00001Gooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
05cooooo00?o0000ooooooooool06_ooool000gooooo1?ooo`000ol0003oool0oooo000Loooo0003
o`000?ooo`3o000005Ooool000?o0000oooo0?ooo`001Oooo`000ol0003oool0oooo001;oooo0003
o`000?ooo`3oool0017oool000?o0000oooo0?ooo`005?ooo`000ol0003oool0oooo001Woooo0003
o`000?ooo`3oool002?oool000?o0000oooo0?ooo`00G?ooo`000ol0003oool0oooo000=oooo00go
oooo000=ooooo`Coool000?o0000oooo0?ooo`007?ooo`000ol0003oool0o`00001Goooo0003o`00
0?ooo`3oool000Goool000?o0000oooo0?ooo`00Boooo`000ol0003oool0oooo000Aoooo0003o`00
0?ooo`3oool001Coool000?o0000oooo0?ooo`00Ioooo`000ol0003oool0oooo000Soooo0003o`00
0?ooo`3oool005coool000?o0000oooo0?ooo`003Oooo`0=ooooo`004Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooo000005Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`1Wooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0G?ooool00ol0003ooooooooo
o`0Jooooo`003Oooool4oooo0003o`000?ooo`3oool001coool000?o0000oooo0?l00000Eoooo`00
0ol0003oool0oooo0005oooo0003o`000?ooo`3oool004_oool000?o0000oooo0?ooo`004Oooo`00
0ol0003oool0oooo000Doooo0003o`000?ooo`3oool006Ooool000?o0000oooo0?ooo`008oooo`00
0ol0003oool0oooo001Loooo0003o`000?ooo`3oool000goool03Oooool000gooooo1?ooo`000ol0
003oool0oooo000Loooo0003o`000?ooo`3o000005Ooool000?o0000oooo0?ooo`001Oooo`000ol0
003oool0oooo001;oooo0003o`000?ooo`3oool0017oool000?o0000oooo0?ooo`005?ooo`000ol0
003oool0oooo001Woooo0003o`000?ooo`3oool002?oool000?o0000oooo0?ooo`00G?ooo`000ol0
003oool0oooo000=oooo00gooooo000Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooool0
0000Eoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06Oooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01[ooooo000=ooooooooool0
o_ooo`0=ooooo`00oooooooooooooaWooooo003ooooooooooooo6Oooool00?oooooooooooolIoooo
o`00oooooooooooooaWooooo003ooooooooooooo6Oooool00?oooooooooooolIooooo`00oooooooo
oooooaWooooo0000\
\>"],
  ImageRangeCache->{{{0, 534.938}, {330, 0}} -> {-0.103886, -0.0262555, \
0.0098324, 0.00417615}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["The number of lineages extant", "SubsubsectionIcon"],

Cell["\<\
This gives the mean number of lineages present as a function of \
time.  Note the wide fluctuations.in the numbers of lineages\
\>", "Text"],

Cell[BoxData[{
    \(\(tt = 
        Table[{t, Length[LineagesPresent[ag, t]]}, {t, 0, 10, 
            0.1}];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[tt, PlotJoined \[Rule] True];\)\), "\[IndentingNewLine]", 
    \({Mean[Last /@ tt], Variance[Last /@ tt]} // N\)}], "Input",
  CellLabel->"In[61]:="],

Cell["\<\
This shows the mean number of lineages that actually carry some \
ancestral material\
\>", "Text"],

Cell[BoxData[{
    \(\(agNonNull = DeleteNullLineages[ag];\)\), "\[IndentingNewLine]", 
    \(\(tt = 
        Table[{t, Length[LineagesPresent[agNonNull, t]]}, {t, 0, 10, 
            0.1}];\)\), "\n", 
    \(\(ListPlot[tt, PlotJoined \[Rule] True];\)\), "\n", 
    \({Mean[Last /@ tt], Variance[Last /@ tt]} // N\)}], "Input",
  CellLabel->"In[65]:="],

Cell[TextData[{
  StyleBox["Q7: ",
    FontColor->RGBColor[0, 0, 1]],
  "How does the number of ancestral lineages depend on the length of the \
genome? (You can look at both the total number, and the number that actually \
carry material)"
}], "Text"],

Cell[TextData[{
  StyleBox["Hint: ",
    FontWeight->"Bold"],
  "Generate graphs for a range of R; the algorithm gets very slow above about \
R=5 or 10, though."
}], "Text"],

Cell[TextData[{
  StyleBox["Q8: ",
    FontColor->RGBColor[0, 0, 1]],
  "What is expected in theory?  Recall that the rate of coalescence of ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " lineages is ~ ",
  Cell[BoxData[
      \(TraditionalForm\`\(k \((k - 1)\)\)\/2, \ \(\(and\)\(\ \)\(the\)\(\ \)\
\(rate\)\(\ \)\)\)]],
  "of recombination is ~ ",
  Cell[BoxData[
      \(TraditionalForm\`k\[VeryThinSpace]R\)]],
  " (scaling time to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(2  N\_e\)\()\)\)\)]]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Number & sizes of blocks",
  FontColor->RGBColor[0, 0, 1]]], "SubsubsectionIcon"],

Cell["This lists the non-null lineages present at t=5", "Text"],

Cell[BoxData[
    \(agt = 
      DeleteNullLineages[\(ExtractLineage[ag, #] &\) /@ 
          LineagesPresent[ag, 5]]\)], "Input",
  CellLabel->"In[16]:="],

Cell[TextData[{
  "Note:  ",
  StyleBox["A somewhat clumsy construction is used to extract the subset of \
lineages present at time t=5:\n",
    FontWeight->"Plain"],
  "ExtractLineage[ag,#]&/@LineagesPresent[ag,5]"
}], "Text",
  FontWeight->"Bold"],

Cell["\<\
This list the number of blocks present in the lineages present at \
t=5:\
\>", "Text"],

Cell[BoxData[
    \(Length /@ BlockSizes[agt]\)], "Input",
  CellLabel->"In[24]:="],

Cell["This tabulates the mean number of blocks over time:", "Text"],

Cell[BoxData[
    \(jt = 
      Table[\[IndentingNewLine]N[
          Mean[Length /@ \((BlockSizes /@ 
                  DeleteNullLineages[\(ExtractLineage[ag, #] &\) /@ 
                      LineagesPresent[ag, t]])\)]], {t, 0, 10, 
          0.1}]\)], "Input",
  CellLabel->"In[31]:="],

Cell["This is the overall mean:", "Text"],

Cell[BoxData[
    \(Mean[jt]\)], "Input",
  CellLabel->"In[33]:="],

Cell[TextData[{
  StyleBox["Q9: ",
    FontColor->RGBColor[0, 0, 1]],
  "How does the mean block size depend on the map length, R?  What is the \
distribution of block sizes?"
}], "Text"]
}, Closed]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1276}, {0, 832}},
AutoGeneratedPackage->None,
WindowToolbars->{},
WindowSize->{1140, 805},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\"\[Placeholder]\"", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowCellBracket->True,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "SlideShow"],
    PageWidth->WindowWidth,
    ScrollingOptions->{"PagewiseDisplay"->True},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}],
  
  Cell[StyleData[All, "EnhancedPrintout"],
    PageWidth->PaperWidth,
    ShowCellBracket->False,
    ScriptMinSize->5,
    FontFamily->"Palatino",
    PrivateFontOptions->{"FontType"->"Outline"}],
  
  Cell[StyleData[All, "EnhancedPrintoutNonGray"],
    PageWidth->PaperWidth,
    ShowCellBracket->False,
    ScriptMinSize->5,
    FontFamily->"Palatino",
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1988-2002 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1988-2002 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None],
  
  Cell[StyleData["Notebook", "Printout"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1988-2002 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1988-2002 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True}],
  
  Cell[StyleData["Notebook", "EnhancedPrintout"],
    PageFooters->{{None, None, None}, {None, None, None}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"PrintingMargins"->{{62, 62}, {62, 72}},
    "PageSize"->{602, 672},
    "PrintRegistrationMarks"->True,
    "FirstPageHeader"->False,
    "FacingPages"->True}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{12, Inherited}, {10, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Plain"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 10}, {6, 30}},
    FontSize->14],
  
  Cell[StyleData["Chapter", "EnhancedPrintout"],
    CellMargins->{{2, 10}, {6, 30}},
    FontFamily->"Futura",
    FontSize->14],
  
  Cell[StyleData["Chapter", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 10}, {6, 30}},
    FontFamily->"Futura",
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    CellGroupingRules->{"SectionGrouping", 30},
    ConversionRules:>{"HTML" -> {
      "<font size=\"+2\" face=\"Helvetica, Arial\"><p><b>", 
      "</b></p></font>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "SlideShow"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {5, 0}},
    PageBreakBelow->False,
    CellFrameMargins->{{36, 36}, {Inherited, 15}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.408011, 0.440726, 0.8]],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18],
  
  Cell[StyleData["Section", "EnhancedPrintout"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{2, Inherited}, {5, 30}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Futura",
    FontSize->16],
  
  Cell[StyleData["Section", "EnhancedPrintoutNonGray"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{2, Inherited}, {5, 30}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Futura",
    FontSize->16]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 40},
    ConversionRules:>{"HTML" -> {
      "<li type=\"square\"><font size=\"+1\" face=\"Helvetica, \
Arial\"><p><b>", "</b></p></font></li>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "SlideShow"],
    CellDingbat->None,
    CellMargins->{{70, 0}, {4, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {5, 24}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "EnhancedPrintout"],
    CellMargins->{{9, 0}, {5, 20}},
    FontFamily->"Futura",
    FontSize->12],
  
  Cell[StyleData["Subsection", "EnhancedPrintoutNonGray"],
    CellMargins->{{9, 0}, {5, 20}},
    FontFamily->"Futura",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {"<font face=\"Helvetica, Arial\"><p><b>", 
      "</b></p></font>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {3, 8}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {3, 8}},
    FontFamily->"Futura",
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {3, 8}},
    FontFamily->"Futura",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<font face=\"Helvetica, Arial\" color=\"660099\"><p><b>", 
      "</b></p></font>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 40},
    ConversionRules:>{"HTML" -> {
      "<li type=\"square\"><font face=\"Helvetica, Arial\"><p><b>", 
      "</b></p></font>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<li type=\"square\"><font face=\"Helvetica, Arial\"><p><b>", 
      "</b></p></font>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<p>", "</p>"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    FontSize->12],
  
  Cell[StyleData["Text", "SlideShow"],
    CellMargins->{{36, 24}, {4, 4}},
    Hyphenation->False,
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontSize->10],
  
  Cell[StyleData["Text", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["Text", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<font size=\"-1\">", "</font>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8],
  
  Cell[StyleData["CompactText", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8],
  
  Cell[StyleData["CompactText", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<p>", "</p>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["Compact12Text", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["Compact12Text", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<font size=\"-1\" face=\"Helvetica, Arial\">", "</font>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8],
  
  Cell[StyleData["TextSans", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8],
  
  Cell[StyleData["TextSans", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{19, 4}, {4, 4}},
    ConversionRules:>{"HTML" -> {"<blockquote>", "</blockquote>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->-22,
    CounterIncrements->"ItemizedText",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    FontSize->10],
  
  Cell[StyleData["ItemizedText", "EnhancedPrintout"],
    CellMargins->{{16, 4}, {2, 4}},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedText", "EnhancedPrintoutNonGray"],
    ParagraphIndent->-18,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{41, 4}, {4, 0}},
    ConversionRules:>{"HTML" -> {"<blockquote>", "</blockquote>"}},
    Hyphenation->True,
    LineSpacing->{1, 2},
    CounterIncrements->"Text",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{34, 4}, {4, 1}},
    FontSize->10],
  
  Cell[StyleData["ItemizedTextNote", "EnhancedPrintout"],
    CellMargins->{{39, 4}, {4, 1}},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedTextNote", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 4}, {4, 1}},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<blockquote>", "</blockquote>"}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "SlideShow"],
    CellMargins->{{80, 24}, {5, 5}},
    Hyphenation->False,
    FontSize->13],
  
  Cell[StyleData["IndentedText", "Printout"],
    FontSize->11],
  
  Cell[StyleData["IndentedText", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["IndentedText", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<li type=\"square\"><p><font color=\"000066\">", "</font></p></li>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "SlideShow"],
    ShowCellBracket->False,
    CellMargins->{{36, 36}, {6, 6}}],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["MathCaption", "EnhancedPrintout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["MathCaption", "EnhancedPrintoutNonGray"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->1,
    FontSize->7],
  
  Cell[StyleData["SmallText", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->7],
  
  Cell[StyleData["SmallText", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "SlideShow"],
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {0, 6}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellFrameMargins->{{8, 8}, {4, 8}},
    Background->RGBColor[1, 1, 0.8]],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9],
  
  Cell[StyleData["Input", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9],
  
  Cell[StyleData["Input", "EnhancedPrintoutNonGray"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "SlideShow"],
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {6, 0}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellFrameMargins->{{8, 8}, {8, 4}},
    Background->RGBColor[1, 1, 0.8]],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9],
  
  Cell[StyleData["Output", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9],
  
  Cell[StyleData["Output", "EnhancedPrintoutNonGray"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputOnly"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["InputOnly", "SlideShow"],
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {6, 6}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    Background->RGBColor[1, 1, 0.8]],
  
  Cell[StyleData["InputOnly", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9],
  
  Cell[StyleData["InputOnly", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9],
  
  Cell[StyleData["InputOnly", "EnhancedPrintoutNonGray"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->None,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "SlideShow"],
    CellMargins->{{100, 50}, {6, 6}},
    FontSize->10,
    FontColor->RGBColor[0.699992, 0.4, 0]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->9,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontFamily->"Courier",
    FontSize->9,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "EnhancedPrintoutNonGray"],
    ShowCellBracket->False,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontFamily->"Courier",
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "SlideShow"],
    CellMargins->{{100, 50}, {6, 6}}],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{57, Inherited}, {Inherited, Inherited}},
    FontSize->9],
  
  Cell[StyleData["Print", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{57, Inherited}, {Inherited, Inherited}},
    FontFamily->"Courier",
    FontSize->9],
  
  Cell[StyleData["Print", "EnhancedPrintoutNonGray"],
    ShowCellBracket->False,
    CellMargins->{{57, Inherited}, {Inherited, Inherited}},
    FontFamily->"Courier",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->Utilities`Notation`Private`DefaultFormatTypeForOutput,
    LanguageCategory->None,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "SlideShow"],
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {6, 0}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellFrameMargins->{{8, 8}, {4, 4}},
    Background->RGBColor[1, 1, 0.8]],
  
  Cell[StyleData["Graphics", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250},
    FontSize->9],
  
  Cell[StyleData["Graphics", "EnhancedPrintout"],
    ShowCellBracket->False,
    CellMargins->{{32, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250},
    FontFamily->"Courier",
    FontSize->9],
  
  Cell[StyleData["Graphics", "EnhancedPrintoutNonGray"],
    ShowCellBracket->False,
    CellMargins->{{32, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250},
    FontFamily->"Courier",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "SlideShow"],
    FontColor->RGBColor[0.699992, 0.4, 0]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "EnhancedPrintout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "EnhancedPrintoutNonGray"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Name", "EnhancedPrintout"],
    FontSize->7,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Name", "EnhancedPrintoutNonGray"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLinkMR", "EnhancedPrintout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLinkMR", "EnhancedPrintoutNonGray"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "EnhancedPrintout"],
    FontFamily->"WRICourier",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "EnhancedPrintoutNonGray"],
    FontFamily->"WRICourier",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLinkText"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLinkText", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLinkText", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLinkText", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "EnhancedPrintout"],
    FontFamily->"WRICourier",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "EnhancedPrintoutNonGray"],
    FontFamily->"WRICourier",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLinkMR", "EnhancedPrintout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLinkMR", "EnhancedPrintoutNonGray"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JT", "Printout"]],
  
  Cell[StyleData["JT", "EnhancedPrintout"]],
  
  Cell[StyleData["JT", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JS", "Printout"]],
  
  Cell[StyleData["JS", "EnhancedPrintout"]],
  
  Cell[StyleData["JS", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["JSB", "Printout"]],
  
  Cell[StyleData["JSB", "EnhancedPrintout"]],
  
  Cell[StyleData["JSB", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["RM", "Printout"]],
  
  Cell[StyleData["RM", "EnhancedPrintout"]],
  
  Cell[StyleData["RM", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BF"],
    ConversionRules:>{"HTML" -> {"<b>", "</b>"}},
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["BF", "Printout"]],
  
  Cell[StyleData["BF", "EnhancedPrintout"]],
  
  Cell[StyleData["BF", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IT"],
    ConversionRules:>{"HTML" -> {"<i>", "</i>"}},
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["IT", "Printout"]],
  
  Cell[StyleData["IT", "EnhancedPrintout"]],
  
  Cell[StyleData["IT", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TR", "Printout"]],
  
  Cell[StyleData["TR", "EnhancedPrintout"]],
  
  Cell[StyleData["TR", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TI"],
    ConversionRules:>{"HTML" -> {"<i>", "</i>"}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSlant->"Italic"],
  
  Cell[StyleData["TI", "Printout"]],
  
  Cell[StyleData["TI", "EnhancedPrintout"]],
  
  Cell[StyleData["TI", "EnhancedPrintoutNonGray"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TB"],
    ConversionRules:>{"HTML" -> {"<b>", "</b>"}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TB", "Printout"]],
  
  Cell[StyleData["TB", "EnhancedPrintout"],
    FontFamily->"Palatino"],
  
  Cell[StyleData["TB", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TBI"],
    ConversionRules:>{"HTML" -> {"<b><i>", "</i></b>"}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["TBI", "Printout"]],
  
  Cell[StyleData["TBI", "EnhancedPrintout"],
    FontFamily->"Palatino"],
  
  Cell[StyleData["TBI", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MR"],
    ConversionRules:>{"HTML" -> {"<tt>", "</tt>"}},
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MR", "Printout"]],
  
  Cell[StyleData["MR", "EnhancedPrintout"],
    FontFamily->"WriCourier"],
  
  Cell[StyleData["MR", "EnhancedPrintoutNonGray"],
    FontFamily->"WriCourier"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MO"],
    ConversionRules:>{"HTML" -> {"<tt><i>", "</i></tt>"}},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MO", "Printout"]],
  
  Cell[StyleData["MO", "EnhancedPrintout"],
    FontFamily->"WriCourier"],
  
  Cell[StyleData["MO", "EnhancedPrintoutNonGray"],
    FontFamily->"WriCourier"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MB"],
    ConversionRules:>{"HTML" -> {"<tt><b>", "</b></tt>"}},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MB", "Printout"]],
  
  Cell[StyleData["MB", "EnhancedPrintout"],
    FontFamily->"WriCourier"],
  
  Cell[StyleData["MB", "EnhancedPrintoutNonGray"],
    FontFamily->"WriCourier"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MBO"],
    ConversionRules:>{"HTML" -> {"<tt><i><b>", "</b></i></tt>"}},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MBO", "Printout"]],
  
  Cell[StyleData["MBO", "EnhancedPrintout"],
    FontFamily->"WriCourier"],
  
  Cell[StyleData["MBO", "EnhancedPrintoutNonGray"],
    FontFamily->"WriCourier"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SR"],
    ConversionRules:>{"HTML" -> {"<font=\"Helvetica, Arial\">", "</font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SR", "Printout"]],
  
  Cell[StyleData["SR", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["SR", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO"],
    ConversionRules:>{"HTML" -> {"<font=\"Futura\"><i>", "</i></font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO", "Printout"],
    ConversionRules:>{"HTML" -> {"<I><Font=Futura>", "</I></Font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["SO", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SB"],
    ConversionRules:>{"HTML" -> {"<font=\"Futura\"><b>", "</b></font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SB", "Printout"],
    ConversionRules:>{"HTML" -> {"<B><Font=Futura>", "</B></Font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SB", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["SB", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SBO"],
    ConversionRules:>{"HTML" -> {"<font=\"Futura\"><b><i>", 
      "</i></b></font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SBO", "Printout"],
    ConversionRules:>{"HTML" -> {"<B><I><Font=Futura>", "</B></I></Font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SBO", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["SBO", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[StyleData["M4", "Printout"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[StyleData["M4", "EnhancedPrintout"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[StyleData["M4", "EnhancedPrintoutNonGray"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    ConversionRules:>{"HTML" -> {"<font=\"Helvetica, Arial\"><i>", 
      "</i></font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "EnhancedPrintout"],
    StyleMenuListing->None,
    FontFamily->"Futura",
    FontSize->8,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "EnhancedPrintoutNonGray"],
    StyleMenuListing->None,
    FontFamily->"Futura",
    FontSize->8,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["C1", "EnhancedPrintout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["C1", "EnhancedPrintoutNonGray"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["C1MR", "EnhancedPrintout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["C1MR", "EnhancedPrintoutNonGray"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CapSmallCaps"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["CapSmallCaps", "Printout"]],
  
  Cell[StyleData["CapSmallCaps", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["CapSmallCaps", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["KeyboardChars"],
    StyleMenuListing->None,
    FontSize->12],
  
  Cell[StyleData["KeyboardChars", "Printout"],
    FontSize->10],
  
  Cell[StyleData["KeyboardChars", "EnhancedPrintout"],
    FontSize->10],
  
  Cell[StyleData["KeyboardChars", "EnhancedPrintoutNonGray"],
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Box", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Box", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DoubleBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DoubleBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["1ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["1ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.31, 0.67}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnEvenBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnEvenBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnSmallBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnSmallBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.32}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["3ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["3ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["3ColumnSmallBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["3ColumnSmallBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.13, 0.35, 0.13, 0.35}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["4ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["4ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.202}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["5ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["5ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["6ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["6ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FramedBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["FramedBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["FramedBox", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["FramedBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox3Col", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox3Col", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox4Col", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox4Col", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox5Col", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox5Col", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox6Col", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox6Col", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[1]],
  
  Cell[StyleData["TopBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontFamily->"Palatino",
    Background->GrayLevel[1]],
  
  Cell[StyleData["TopBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontFamily->"Palatino",
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 2}},
    Background->GrayLevel[1]],
  
  Cell[StyleData["MiddleBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontFamily->"Palatino",
    Background->GrayLevel[1]],
  
  Cell[StyleData["MiddleBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 4}},
    FontFamily->"Palatino",
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 0}, {0, -5}},
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->2.2}],
  
  Cell[StyleData["BottomBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, -5}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->2.2}],
  
  Cell[StyleData["BottomBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, -5}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->2.2}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {-2, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-2, 8}},
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["TopSpanBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {-4, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["TopSpanBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {-4, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-5, 0}},
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}],
  
  Cell[StyleData["MiddleSpanBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {-7, 0}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}],
  
  Cell[StyleData["MiddleSpanBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {-7, 0}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.65],
  
  Cell[StyleData["Picture", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.65],
  
  Cell[StyleData["Picture", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.65]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OpenCloseItemizedPicture"],
    CellMargins->{{41, 4}, {4, 4}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["OpenCloseItemizedPicture", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False],
  
  Cell[StyleData["OpenCloseItemizedPicture", "EnhancedPrintout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False],
  
  Cell[StyleData["OpenCloseItemizedPicture", "EnhancedPrintoutNonGray"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{41, 4}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{77, 2}, {4, -4}},
    Magnification->0.5],
  
  Cell[StyleData["ItemizedPicture", "EnhancedPrintout"],
    CellMargins->{{78, 2}, {12, -6}},
    Magnification->0.5],
  
  Cell[StyleData["ItemizedPicture", "EnhancedPrintoutNonGray"],
    CellMargins->{{75, 2}, {4, -6}},
    Magnification->0.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{41, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False],
  
  Cell[StyleData["PictureGroup", "EnhancedPrintout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False],
  
  Cell[StyleData["PictureGroup", "EnhancedPrintoutNonGray"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["Sound", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["Sound", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 4}, {2, 0}},
    FontSize->7],
  
  Cell[StyleData["Caption", "EnhancedPrintout"],
    CellMargins->{{5, 4}, {2, -2}},
    FontFamily->"Futura",
    FontSize->7],
  
  Cell[StyleData["Caption", "EnhancedPrintoutNonGray"],
    CellMargins->{{5, 4}, {2, -2}},
    FontFamily->"Futura",
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9],
  
  Cell[StyleData["2ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9],
  
  Cell[StyleData["2ColumnTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9],
  
  Cell[StyleData["2ColumnEvenTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9],
  
  Cell[StyleData["2ColumnEvenTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9],
  
  Cell[StyleData["3ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9],
  
  Cell[StyleData["3ColumnTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["InlineFormula", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["InlineFormula", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5],
  
  Cell[StyleData["InlineOutput", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5],
  
  Cell[StyleData["InlineOutput", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"]],
  
  Cell[StyleData["DisplayFormula", "EnhancedPrintout"],
    FontFamily->"Palatino"],
  
  Cell[StyleData["DisplayFormula", "EnhancedPrintoutNonGray"],
    FontFamily->"Palatino"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9],
  
  Cell[StyleData["DisplayMath", "EnhancedPrintout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontFamily->"WRICourier",
    FontSize->9],
  
  Cell[StyleData["DisplayMath", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 0}, {4, 6}},
    FontFamily->"WRICourier",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{45, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{39, 55}, {0, 10}},
    FontSize->10],
  
  Cell[StyleData["NumberedEquation", "EnhancedPrintout"],
    CellMargins->{{39, 55}, {0, 10}},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["NumberedEquation", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 55}, {0, 10}},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0}],
  
  Cell[StyleData["EquationNumber", "EnhancedPrintout"],
    LineSpacing->{1.7, 0},
    FontFamily->"Palatino"],
  
  Cell[StyleData["EquationNumber", "EnhancedPrintoutNonGray"],
    LineSpacing->{1.7, 0},
    FontFamily->"Palatino"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    ShowSpecialCharacters->Automatic,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{42, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "EnhancedPrintout"],
    CellMargins->{{42, 30}, {Inherited, 4}},
    FontFamily->"WRICourier",
    FontSize->9.5],
  
  Cell[StyleData["Program", "EnhancedPrintoutNonGray"],
    CellMargins->{{42, 30}, {Inherited, 4}},
    FontFamily->"WRICourier",
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell["\<\
Standard Styles
\
\>", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-38,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"],
    HyphenationOptions->{"HyphenationCharacter"->"-"}],
  
  Cell[StyleData["InspectorLevel1", "SlideShow"],
    HyphenationOptions->{"HyphenationCharacter"->"-"}],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "SlideShow"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 50},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "SlideShow"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "SlideShow"],
    CellMargins->{{72, 4}, {1, 14}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "SlideShow"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "SlideShow"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "SlideShow"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "SlideShow"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "SlideShow"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "SlideShow"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "SlideShow"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "SlideShow"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "SlideShow"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 8}},
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 8}},
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.4, 0.6, 0.550011]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 8}},
    Hyphenation->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.300008, 0.600015, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    LineSpacing->{1, 3},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{36, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10],
  
  Cell[StyleData["Commentary", "EnhancedPrintout"],
    CellMargins->{{36, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["Commentary", "EnhancedPrintoutNonGray"],
    CellMargins->{{36, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CopyrightHead"],
    CellMargins->{{10, 4}, {0, 8}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CopyrightHead", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    CellMargins->{{10, 4}, {0, 8}},
    PageBreakAbove->False,
    StyleMenuListing->None],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Manual.nb Merge", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell["Function List", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionName"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 10}, {10, 12}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold",
    CellTags->"FunctionName"],
  
  Cell[StyleData["FunctionName", "Printout"],
    CellMargins->{{9, 0}, {10, 10}},
    FontSize->12],
  
  Cell[StyleData["FunctionName", "EnhancedPrintout"],
    CellMargins->{{9, 0}, {10, 10}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["FunctionName", "EnhancedPrintoutNonGray"],
    CellMargins->{{9, 0}, {10, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 10}, {0, 30}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    StyleMenuListing->None,
    FontSize->14,
    FontWeight->"Bold",
    CellTags->"FunctionSection"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellMargins->{{20, 0}, {0, 20}},
    FontSize->13],
  
  Cell[StyleData["SubsectionIcon", "EnhancedPrintout"],
    CellMargins->{{20, 0}, {0, 20}},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["SubsectionIcon", "EnhancedPrintoutNonGray"],
    CellMargins->{{20, 0}, {0, 20}},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionSubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{36, 10}, {0, 6}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    StyleMenuListing->None,
    FontWeight->"Bold",
    CellTags->"FunctionSubsection"],
  
  Cell[StyleData["FunctionSubsection", "Printout"],
    CellMargins->{{30, 0}, {0, 6}}],
  
  Cell[StyleData["FunctionSubsection", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {0, 6}},
    FontFamily->"Palatino",
    FontSize->11],
  
  Cell[StyleData["FunctionSubsection", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {0, 6}},
    FontFamily->"Palatino",
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{36, 10}, {0, 6}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    StyleMenuListing->None,
    FontWeight->"Bold",
    CellTags->"SubsubsectionIcon"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    CellMargins->{{30, 0}, {0, 6}},
    FontSize->11],
  
  Cell[StyleData["SubsubsectionIcon", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {0, 6}},
    FontFamily->"Palatino",
    FontSize->9],
  
  Cell[StyleData["SubsubsectionIcon", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {0, 6}},
    FontFamily->"Palatino",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionDescription"],
    CellMargins->{{36, 10}, {4, 0}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"Text",
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["FunctionDescription", "Printout"],
    CellMargins->{{30, 0}, {4, 0}},
    FontSize->11],
  
  Cell[StyleData["FunctionDescription", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["FunctionDescription", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionDescriptionRuled"],
    CellFrame->{{0, 0}, {0.25, 0.25}},
    CellMargins->{{36, 10}, {4, 0}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"Text",
    StyleMenuListing->None],
  
  Cell[StyleData["FunctionDescriptionRuled", "Printout"],
    CellMargins->{{30, 0}, {4, 0}},
    FontSize->11],
  
  Cell[StyleData["FunctionDescriptionRuled", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["FunctionDescriptionRuled", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionDescriptionRuleTop"],
    CellFrame->{{0, 0}, {0, 0.25}},
    CellMargins->{{36, 10}, {4, 0}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"Text",
    StyleMenuListing->None],
  
  Cell[StyleData["FunctionDescriptionRuleTop", "Printout"],
    CellMargins->{{30, 0}, {4, 0}},
    FontSize->11],
  
  Cell[StyleData["FunctionDescriptionRuleTop", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["FunctionDescriptionRuleTop", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionDescriptionRuleBottom"],
    CellFrame->{{0, 0}, {0.25, 0}},
    CellMargins->{{36, 10}, {4, 0}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"Text",
    StyleMenuListing->None],
  
  Cell[StyleData["FunctionDescriptionRuleBottom", "Printout"],
    CellMargins->{{30, 0}, {4, 0}},
    FontSize->11],
  
  Cell[StyleData["FunctionDescriptionRuleBottom", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["FunctionDescriptionRuleBottom", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {4, 0}},
    TextJustification->0,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionExample"],
    CellMargins->{{36, 10}, {4, 0}},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["FunctionExample", "Printout"],
    CellMargins->{{30, 0}, {4, 0}},
    FontSize->9],
  
  Cell[StyleData["FunctionExample", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {4, 0}},
    FontFamily->"Palatino",
    FontSize->9],
  
  Cell[StyleData["FunctionExample", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {4, 0}},
    FontFamily->"Palatino",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FunctionTextNote"],
    CellMargins->{{36, 4}, {0, 4}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 4},
    LineIndent->0,
    StyleMenuListing->None],
  
  Cell[StyleData["FunctionTextNote", "Printout"],
    CellMargins->{{36, 4}, {0, 4}},
    FontSize->9],
  
  Cell[StyleData["FunctionTextNote", "EnhancedPrintout"],
    CellMargins->{{36, 4}, {0, 4}},
    FontFamily->"Palatino",
    FontSize->8],
  
  Cell[StyleData["FunctionTextNote", "EnhancedPrintoutNonGray"],
    CellMargins->{{36, 4}, {0, 4}},
    FontFamily->"Palatino",
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnFunctionTable"],
    CellMargins->{{36, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnFunctionTable", "Printout"],
    CellMargins->{{30, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["3ColumnFunctionTable", "EnhancedPrintout"],
    CellMargins->{{30, 0}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["3ColumnFunctionTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{30, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Browser Emulation", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextNormal"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["TextNormal", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BrowserEmulation"],
    CellMargins->{{12, 1}, {7, 24}},
    CellGroupingRules->{"SectionGrouping", 70},
    LineSpacing->{1, 3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    GridBoxOptions->{ColumnWidths->0.25,
    ColumnAlignments->{Left},
    GridFrame->True,
    GridFrameMargins->0.5,
    ColumnLines->True}],
  
  Cell[StyleData["BrowserEmulation", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CategoryDefs"],
    CellMargins->{{300, 10}, {7, 7}},
    LineSpacing->{1, 3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    Background->RGBColor[1, 0.8, 0.6],
    GridBoxOptions->{ColumnAlignments->{Left},
    GridFrame->False,
    RowLines->True,
    ColumnLines->True}],
  
  Cell[StyleData["CategoryDefs", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Category1"],
    ShowCellBracket->False,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    StyleMenuListing->None,
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Category1", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Category2"],
    ShowCellBracket->False,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{85, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    StyleMenuListing->None,
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Category2", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Category3"],
    ShowCellBracket->False,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{157, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.2, 0, 0.4]],
  
  Cell[StyleData["Category3", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Category4"],
    ShowCellBracket->False,
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{230, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.300008, 0.4]],
  
  Cell[StyleData["Category4", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Misc", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.25,
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["4ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["4ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["4ColumnTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.2,
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["5ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["5ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["5ColumnTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.16,
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["6ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["6ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["6ColumnTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["7ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.14,
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["7ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["7ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["7ColumnTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["8ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnWidths->0.12,
    ColumnAlignments->{Left, Center}}],
  
  Cell[StyleData["8ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["8ColumnTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["8ColumnTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ABItemizedText"],
    CellMargins->{{20, 4}, {0, 5}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->-21,
    CounterIncrements->"ItemizedText",
    StyleMenuListing->None],
  
  Cell[StyleData["ABItemizedText", "Printout"],
    ParagraphIndent->-21,
    FontSize->11],
  
  Cell[StyleData["ABItemizedText", "EnhancedPrintout"],
    ParagraphIndent->-21,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ABItemizedText", "EnhancedPrintoutNonGray"],
    ParagraphIndent->-21,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChapNumber"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->42,
    FontWeight->"Plain"],
  
  Cell[StyleData["ChapNumber", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->36],
  
  Cell[StyleData["ChapNumber", "EnhancedPrintout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontFamily->"Futura",
    FontSize->36],
  
  Cell[StyleData["ChapNumber", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 10}, {15, 30}},
    FontFamily->"Futura",
    FontSize->36]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChapTitle"],
    CellMargins->{{12, Inherited}, {80, 10}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["ChapTitle", "Printout"],
    CellMargins->{{2, 10}, {80, 6}},
    FontSize->30],
  
  Cell[StyleData["ChapTitle", "EnhancedPrintout"],
    CellMargins->{{2, 10}, {80, 6}},
    FontFamily->"Futura",
    FontSize->30],
  
  Cell[StyleData["ChapTitle", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 10}, {80, 6}},
    FontFamily->"Futura",
    FontSize->30]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemDingbat"],
    CellSize->{22, 14},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["ItemDingbat", "Printout"],
    CellSize->{22, 13.125}],
  
  Cell[StyleData["ItemDingbat", "EnhancedPrintout"],
    CellSize->{22, 11}],
  
  Cell[StyleData["ItemDingbat", "EnhancedPrintoutNonGray"],
    CellSize->{22, 11}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item1"],
    CellMargins->{{19, 4}, {4, 4}},
    ParagraphIndent->-22,
    CounterIncrements->"Item1",
    StyleMenuListing->None],
  
  Cell[StyleData["Item1", "Printout"],
    CellMargins->{{12, 0}, {2, 4}},
    FontSize->10],
  
  Cell[StyleData["Item1", "EnhancedPrintout"],
    CellMargins->{{16, 0}, {2, 4}},
    FontSize->10],
  
  Cell[StyleData["Item1", "EnhancedPrintoutNonGray"],
    CellMargins->{{16, 0}, {2, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item1Continued"],
    CellMargins->{{41, 4}, {4, 1}},
    CounterIncrements->"Item1Continued",
    StyleMenuListing->None],
  
  Cell[StyleData["Item1Continued", "Printout"],
    CellMargins->{{34, 0}, {4, 1}},
    FontSize->10],
  
  Cell[StyleData["Item1Continued", "EnhancedPrintout"],
    CellMargins->{{39, 0}, {4, 1}},
    FontSize->10],
  
  Cell[StyleData["Item1Continued", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 0}, {4, 1}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item2"],
    CellMargins->{{32, 4}, {4, 4}},
    ParagraphIndent->-22,
    CounterIncrements->"Item2",
    StyleMenuListing->None],
  
  Cell[StyleData["Item2", "Printout"],
    CellMargins->{{26, 0}, {4, 4}},
    ParagraphIndent->-22,
    FontSize->10],
  
  Cell[StyleData["Item2", "EnhancedPrintout"],
    CellMargins->{{29, 0}, {2, 4}},
    ParagraphIndent->-22,
    FontSize->10],
  
  Cell[StyleData["Item2", "EnhancedPrintoutNonGray"],
    CellMargins->{{29, 0}, {2, 4}},
    ParagraphIndent->-22,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item2Continued"],
    CellMargins->{{54, 4}, {4, 1}},
    CounterIncrements->"Item2Continued",
    StyleMenuListing->None],
  
  Cell[StyleData["Item2Continued", "Printout"],
    CellMargins->{{27, 0}, {4, 1}}],
  
  Cell[StyleData["Item2Continued", "EnhancedPrintout"],
    CellMargins->{{52, 0}, {4, 1}},
    FontSize->10],
  
  Cell[StyleData["Item2Continued", "EnhancedPrintoutNonGray"],
    CellMargins->{{52, 0}, {4, 1}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item3"],
    CellMargins->{{45, 4}, {4, 4}},
    ParagraphIndent->-23,
    CounterIncrements->"Item3",
    StyleMenuListing->None],
  
  Cell[StyleData["Item3", "Printout"],
    CellMargins->{{27, 0}, {2, 4}}],
  
  Cell[StyleData["Item3", "EnhancedPrintout"],
    CellMargins->{{42, 0}, {2, 4}},
    FontSize->10],
  
  Cell[StyleData["Item3", "EnhancedPrintoutNonGray"],
    CellMargins->{{42, 0}, {2, 4}},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Item3Continued"],
    CellMargins->{{67, 4}, {4, 1}},
    CounterIncrements->"Item3Continued",
    StyleMenuListing->None],
  
  Cell[StyleData["Item3Continued", "Printout"],
    CellMargins->{{27, 0}, {4, 1}}],
  
  Cell[StyleData["Item3Continued", "EnhancedPrintout"],
    CellMargins->{{65, 0}, {4, 1}},
    FontSize->10],
  
  Cell[StyleData["Item3Continued", "EnhancedPrintoutNonGray"],
    CellMargins->{{65, 0}, {4, 1}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedBulletText"],
    CellMargins->{{19, 4}, {0, 5}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->-22,
    CounterIncrements->"ItemizedBulletText",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedBulletText", "Printout"],
    ParagraphIndent->-20,
    FontSize->11],
  
  Cell[StyleData["ItemizedBulletText", "EnhancedPrintout"],
    ParagraphIndent->-19,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedBulletText", "EnhancedPrintoutNonGray"],
    ParagraphIndent->-19,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NoteBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {8, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["NoteBox", "Printout"],
    CellMargins->{{2, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["NoteBox", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["NoteBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{41, 4}, {8, 2}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    CellMargins->{{39, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ItemizedNoteBox", "EnhancedPrintout"],
    CellMargins->{{39, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ItemizedNoteBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameMargins->{{8, 8}, {0, 8}},
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["ItemizedTopBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ItemizedTopBox", "EnhancedPrintout"],
    CellMargins->{{39, 4}, {0, 6}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ItemizedTopBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 4}, {0, 6}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedBottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{37, 4}, {4, 0}},
    CellHorizontalScrolling->True,
    CellFrameMargins->{{8, 8}, {8, 0}},
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["ItemizedBottomBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ItemizedBottomBox", "EnhancedPrintout"],
    CellMargins->{{39, 4}, {6, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ItemizedBottomBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{39, 4}, {6, 0}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpacedBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpacedBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}],
  
  Cell[StyleData["MiddleSpacedBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontFamily->"Palatino",
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}],
  
  Cell[StyleData["MiddleSpacedBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 0}},
    FontFamily->"Palatino",
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNote"],
    CellMargins->{{41, 4}, {0, 12}},
    Hyphenation->True,
    LineSpacing->{1, 2},
    CounterIncrements->"Text",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedNote", "Printout"],
    CellMargins->{{38, 4}, {0, 9}},
    FontSize->11],
  
  Cell[StyleData["ItemizedNote", "EnhancedPrintout"],
    CellMargins->{{38, 4}, {0, 0}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedNote", "EnhancedPrintoutNonGray"],
    CellMargins->{{38, 4}, {0, 0}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBelow"],
    CellMargins->{{41, 4}, {0, 8}},
    Hyphenation->True,
    LineSpacing->{1, 2},
    CounterIncrements->"Text",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedNoteBelow", "Printout"],
    CellMargins->{{38, 4}, {0, 12}},
    FontSize->11],
  
  Cell[StyleData["ItemizedNoteBelow", "EnhancedPrintout"],
    CellMargins->{{38, 4}, {0, 8}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedNoteBelow", "EnhancedPrintoutNonGray"],
    CellMargins->{{38, 4}, {0, 8}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextBelowPic"],
    CellMargins->{{19, 4}, {0, 8}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->-22,
    CounterIncrements->"ItemizedText",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextBelowPic", "Printout"],
    CellMargins->{{20, 4}, {2, 12}},
    ParagraphIndent->-18,
    FontSize->11],
  
  Cell[StyleData["ItemizedTextBelowPic", "EnhancedPrintout"],
    CellMargins->{{20, 4}, {2, 12}},
    ParagraphIndent->-17,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedTextBelowPic", "EnhancedPrintoutNonGray"],
    CellMargins->{{20, 4}, {2, 12}},
    ParagraphIndent->-17,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote2"],
    CellMargins->{{41, 4}, {0, 4}},
    Hyphenation->True,
    LineSpacing->{1, 2},
    CounterIncrements->"Text",
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote2", "Printout"],
    CellMargins->{{38, 4}, {0, 2}},
    FontSize->11],
  
  Cell[StyleData["ItemizedTextNote2", "EnhancedPrintout"],
    CellMargins->{{38, 4}, {0, 2}},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["ItemizedTextNote2", "EnhancedPrintoutNonGray"],
    CellMargins->{{38, 4}, {0, 2}},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedItem1"],
    CellMargins->{{48, 4}, {4, 4}},
    CellGroupingRules->{"SectionGrouping", 15},
    ParagraphIndent->-23,
    CounterIncrements->"NumberedItem1",
    StyleMenuListing->None],
  
  Cell[StyleData["NumberedItem1", "Printout"],
    CellMargins->{{12, 0}, {0, 8}}],
  
  Cell[StyleData["NumberedItem1", "EnhancedPrintout"],
    CellMargins->{{12, 0}, {0, 8}}],
  
  Cell[StyleData["NumberedItem1", "EnhancedPrintoutNonGray"],
    CellMargins->{{12, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedItem2"],
    CellMargins->{{71, 4}, {3, 3}},
    CellGroupingRules->{"SectionGrouping", 15},
    ParagraphIndent->-21,
    CounterIncrements->"NumberedItem2",
    StyleMenuListing->None],
  
  Cell[StyleData["NumberedItem2", "Printout"],
    CellMargins->{{27, 0}, {0, 4}}],
  
  Cell[StyleData["NumberedItem2", "EnhancedPrintout"],
    CellMargins->{{27, 0}, {0, 4}}],
  
  Cell[StyleData["NumberedItem2", "EnhancedPrintoutNonGray"],
    CellMargins->{{27, 0}, {0, 4}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedItem3"],
    CellMargins->{{94, 4}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 15},
    ParagraphIndent->-23,
    CounterIncrements->"NumberedItem3",
    StyleMenuListing->None],
  
  Cell[StyleData["NumberedItem3", "Printout"],
    CellMargins->{{27, 0}, {0, 4}}],
  
  Cell[StyleData["NumberedItem3", "EnhancedPrintout"],
    CellMargins->{{27, 0}, {0, 4}}],
  
  Cell[StyleData["NumberedItem3", "EnhancedPrintoutNonGray"],
    CellMargins->{{27, 0}, {0, 4}},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageHeaderBold"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["PageHeaderBold", "Printout"]],
  
  Cell[StyleData["PageHeaderBold", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["PageHeaderBold", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["S9"],
    ConversionRules:>{"HTML" -> {"<font=\"Helvetica, Arial\">", "</font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain"],
  
  Cell[StyleData["S9", "Printout"],
    FontSize->9,
    FontWeight->"Plain"],
  
  Cell[StyleData["S9", "EnhancedPrintout"],
    FontFamily->"Futura",
    FontSize->9,
    FontWeight->"Plain"],
  
  Cell[StyleData["S9", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura",
    FontSize->9,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["S10"],
    ConversionRules:>{"HTML" -> {"<font=\"Helvetica, Arial\">", "</font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain"],
  
  Cell[StyleData["S10", "Printout"],
    FontSize->10,
    FontWeight->"Plain"],
  
  Cell[StyleData["S10", "EnhancedPrintout"],
    FontFamily->"Futura",
    FontSize->10,
    FontWeight->"Plain"],
  
  Cell[StyleData["S10", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura",
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SB9"],
    ConversionRules:>{"HTML" -> {"<font=\"Helvetica, Arial\">", "</font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold",
    PrivateFontOptions->{"OperatorSubstitution"->False}],
  
  Cell[StyleData["SB9", "Printout"],
    FontSize->7],
  
  Cell[StyleData["SB9", "EnhancedPrintout"],
    FontFamily->"Futura",
    FontSize->7],
  
  Cell[StyleData["SB9", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura",
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SB10"],
    ConversionRules:>{"HTML" -> {"<font=\"Helvetica, Arial\">", "</font>"}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["SB10", "Printout"],
    FontSize->7],
  
  Cell[StyleData["SB10", "EnhancedPrintout"],
    FontFamily->"Futura",
    FontSize->7],
  
  Cell[StyleData["SB10", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura",
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SingleRowTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["SingleRowTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["SingleRowTable", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["SingleRowTable", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsubsection", "Printout"],
    CellMargins->{{2, 0}, {3, 8}},
    FontSize->10],
  
  Cell[StyleData["Subsubsubsection", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {3, 8}},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["Subsubsubsection", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {3, 8}},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "EnhancedPrintout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontFamily->"Futura",
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 10}, {8, 10}},
    FontFamily->"Futura",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->24],
  
  Cell[StyleData["Subtitle", "EnhancedPrintout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontFamily->"Futura",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 10}, {10, 15}},
    FontFamily->"Futura",
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextBelow"],
    CellMargins->{{10, 4}, {0, 14}},
    ConversionRules:>{"HTML" -> {"<p>", "</p>"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontSize->12],
  
  Cell[StyleData["TextBelow", "Printout"],
    CellMargins->{{2, 2}, {6, 12}},
    TextJustification->1,
    FontSize->10],
  
  Cell[StyleData["TextBelow", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {6, 12}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["TextBelow", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 2}, {6, 12}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->30],
  
  Cell[StyleData["Title", "EnhancedPrintout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontFamily->"Futura",
    FontSize->30.5],
  
  Cell[StyleData["Title", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 10}, {15, 30}},
    FontFamily->"Futura",
    FontSize->30.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Undersubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<p><font face=\"Helvetica, Arial\"><b>", 
      "</b></font></p>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm]},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Undersubsection", "Printout"],
    CellMargins->{{2, 0}, {7, 10}},
    FontSize->10],
  
  Cell[StyleData["Undersubsection", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {7, 8}},
    FontFamily->"Futura",
    FontSize->10],
  
  Cell[StyleData["Undersubsection", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {7, 8}},
    FontFamily->"Futura",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellMargins->{{10, 4}, {12, 18}},
    CellGroupingRules->{"SectionGrouping", 30},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Printout"],
    CellMargins->{{2, 0}, {0, 6}},
    PageBreakBelow->False,
    FontSize->18],
  
  Cell[StyleData["SectionFirst", "EnhancedPrintout"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{2, Inherited}, {5, 6}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Futura",
    FontSize->16],
  
  Cell[StyleData["SectionFirst", "EnhancedPrintoutNonGray"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{2, Inherited}, {5, 6}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Futura",
    FontSize->16]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionFirst"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 40},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionFirst", "SlideShow"],
    CellDingbat->None,
    CellMargins->{{70, 0}, {4, 6}},
    FontSize->12],
  
  Cell[StyleData["SubsectionFirst", "Printout"],
    CellMargins->{{9, 0}, {5, 6}},
    CellBracketOptions->{"Color"->RGBColor[1, 0, 0]},
    FontSize->12],
  
  Cell[StyleData["SubsectionFirst", "EnhancedPrintout"],
    CellMargins->{{9, 0}, {5, 6}},
    CellBracketOptions->{"Color"->RGBColor[1, 0, 0]},
    FontFamily->"Futura",
    FontSize->12],
  
  Cell[StyleData["SubsectionFirst", "EnhancedPrintoutNonGray"],
    CellMargins->{{9, 0}, {5, 6}},
    CellBracketOptions->{"Color"->RGBColor[1, 0, 0]},
    FontFamily->"Futura",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionFirst"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 50},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionFirst", "Printout"],
    CellMargins->{{2, 0}, {3, 3}},
    CellBracketOptions->{"Color"->RGBColor[1, 0, 0]},
    FontSize->10],
  
  Cell[StyleData["SubsubsectionFirst", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {3, 3}},
    CellBracketOptions->{"Color"->RGBColor[1, 0, 0]},
    FontFamily->"Futura",
    FontSize->10],
  
  Cell[StyleData["SubsubsectionFirst", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {3, 3}},
    CellBracketOptions->{"Color"->RGBColor[1, 0, 0]},
    FontFamily->"Futura",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsubsectionFirst"],
    CellMargins->{{10, 4}, {0, 12}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsubsectionFirst", "Printout"],
    CellMargins->{{2, 0}, {3, 3}},
    FontSize->10],
  
  Cell[StyleData["SubsubsubsectionFirst", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {3, 3}},
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["SubsubsubsectionFirst", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {3, 3}},
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell["Spacer Cell", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Spacer"],
    CellMargins->{{10, 10}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->2,
    "ClosedCellHeight"->1},
    CellOpen->False,
    StyleMenuListing->None],
  
  Cell[StyleData["Spacer", "Printout"],
    CellOpen->True,
    FontSize->3]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DiscretionaryHyphen"],
    StyleMenuListing->None,
    FontSize->0.0625,
    FontColor->GrayLevel[1]],
  
  Cell[StyleData["DiscretionaryHyphen", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["DiscretionaryHyphen", "EnhancedPrintout"],
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["DiscretionaryHyphen", "EnhancedPrintoutNonGray"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureSmaller1"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureSmaller1", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.63],
  
  Cell[StyleData["PictureSmaller1", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.63],
  
  Cell[StyleData["PictureSmaller1", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.63]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureSmaller2"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureSmaller2", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.61],
  
  Cell[StyleData["PictureSmaller2", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.61],
  
  Cell[StyleData["PictureSmaller2", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.61]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureSmaller3"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureSmaller3", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.59],
  
  Cell[StyleData["PictureSmaller3", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.59],
  
  Cell[StyleData["PictureSmaller3", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.59]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureSmaller4"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureSmaller4", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.57],
  
  Cell[StyleData["PictureSmaller4", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.57],
  
  Cell[StyleData["PictureSmaller4", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.57]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureSmaller5"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureSmaller5", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.55],
  
  Cell[StyleData["PictureSmaller5", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.55],
  
  Cell[StyleData["PictureSmaller5", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.55]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureSmaller6"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureSmaller6", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.53],
  
  Cell[StyleData["PictureSmaller6", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.53],
  
  Cell[StyleData["PictureSmaller6", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.53]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPicture"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPicture", "Printout"],
    CellMargins->{{55, Inherited}, {8, -4}},
    Magnification->0.65],
  
  Cell[StyleData["ItemPicture", "EnhancedPrintout"],
    CellMargins->{{60, Inherited}, {10, -3}},
    Magnification->0.65],
  
  Cell[StyleData["ItemPicture", "EnhancedPrintoutNonGray"],
    CellMargins->{{60, Inherited}, {10, -3}},
    Magnification->0.65]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureSmaller1"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureSmaller1", "Printout"],
    CellMargins->{{56, Inherited}, {9, -3}},
    Magnification->0.63],
  
  Cell[StyleData["ItemPictureSmaller1", "EnhancedPrintout"],
    CellMargins->{{63, Inherited}, {10, -3}},
    Magnification->0.63],
  
  Cell[StyleData["ItemPictureSmaller1", "EnhancedPrintoutNonGray"],
    CellMargins->{{63, Inherited}, {10, -3}},
    Magnification->0.63]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureSmaller2"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureSmaller2", "Printout"],
    CellMargins->{{58, Inherited}, {8, -4}},
    Magnification->0.61],
  
  Cell[StyleData["ItemPictureSmaller2", "EnhancedPrintout"],
    CellMargins->{{65, Inherited}, {11, -3}},
    Magnification->0.61],
  
  Cell[StyleData["ItemPictureSmaller2", "EnhancedPrintoutNonGray"],
    CellMargins->{{65, Inherited}, {11, -3}},
    Magnification->0.61]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureSmaller3"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureSmaller3", "Printout"],
    CellMargins->{{61, Inherited}, {10, -2}},
    Magnification->0.59],
  
  Cell[StyleData["ItemPictureSmaller3", "EnhancedPrintout"],
    CellMargins->{{67, Inherited}, {11, -3}},
    Magnification->0.59],
  
  Cell[StyleData["ItemPictureSmaller3", "EnhancedPrintoutNonGray"],
    CellMargins->{{67, Inherited}, {11, -3}},
    Magnification->0.59]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureSmaller4"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureSmaller4", "Printout"],
    CellMargins->{{63, Inherited}, {10, -2}},
    Magnification->0.57],
  
  Cell[StyleData["ItemPictureSmaller4", "EnhancedPrintout"],
    CellMargins->{{69, Inherited}, {12, -4}},
    Magnification->0.57],
  
  Cell[StyleData["ItemPictureSmaller4", "EnhancedPrintoutNonGray"],
    CellMargins->{{69, Inherited}, {12, -4}},
    Magnification->0.57]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureSmaller5"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureSmaller5", "Printout"],
    CellMargins->{{65, Inherited}, {11, -2}},
    Magnification->0.55],
  
  Cell[StyleData["ItemPictureSmaller5", "EnhancedPrintout"],
    CellMargins->{{71, Inherited}, {13, -2}},
    Magnification->0.55],
  
  Cell[StyleData["ItemPictureSmaller5", "EnhancedPrintoutNonGray"],
    CellMargins->{{71, Inherited}, {13, -2}},
    Magnification->0.55]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureSmaller6"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureSmaller6", "Printout"],
    CellMargins->{{67, Inherited}, {12, -2}},
    Magnification->0.53],
  
  Cell[StyleData["ItemPictureSmaller6", "EnhancedPrintout"],
    CellMargins->{{74, Inherited}, {13, -3}},
    Magnification->0.53],
  
  Cell[StyleData["ItemPictureSmaller6", "EnhancedPrintoutNonGray"],
    CellMargins->{{74, Inherited}, {13, -3}},
    Magnification->0.53]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureBigger1"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureBigger1", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.68],
  
  Cell[StyleData["PictureBigger1", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.68],
  
  Cell[StyleData["PictureBigger1", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.68]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureBigger2"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureBigger2", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.71],
  
  Cell[StyleData["PictureBigger2", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.71],
  
  Cell[StyleData["PictureBigger2", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.71]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureBigger3"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureBigger3", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.74],
  
  Cell[StyleData["PictureBigger3", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.74],
  
  Cell[StyleData["PictureBigger3", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.74]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureBigger4"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureBigger4", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.77],
  
  Cell[StyleData["PictureBigger4", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.77],
  
  Cell[StyleData["PictureBigger4", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.77]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureBigger5"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureBigger5", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.8],
  
  Cell[StyleData["PictureBigger5", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.8],
  
  Cell[StyleData["PictureBigger5", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureBigger6"],
    CellMargins->{{10, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureBigger6", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.83],
  
  Cell[StyleData["PictureBigger6", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.83],
  
  Cell[StyleData["PictureBigger6", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {4, 2}},
    Magnification->0.83]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureBigger1"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureBigger1", "Printout"],
    CellMargins->{{50, Inherited}, {9, -3}},
    Magnification->0.68],
  
  Cell[StyleData["ItemPictureBigger1", "EnhancedPrintout"],
    CellMargins->{{57, Inherited}, {10, -3}},
    Magnification->0.68],
  
  Cell[StyleData["ItemPictureBigger1", "EnhancedPrintoutNonGray"],
    CellMargins->{{57, Inherited}, {10, -3}},
    Magnification->0.68]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureBigger2"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureBigger2", "Printout"],
    CellMargins->{{48, Inherited}, {8, -4}},
    Magnification->0.71],
  
  Cell[StyleData["ItemPictureBigger2", "EnhancedPrintout"],
    CellMargins->{{54, Inherited}, {10, -3}},
    Magnification->0.71],
  
  Cell[StyleData["ItemPictureBigger2", "EnhancedPrintoutNonGray"],
    CellMargins->{{54, Inherited}, {10, -3}},
    Magnification->0.71]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureBigger3"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureBigger3", "Printout"],
    CellMargins->{{46, Inherited}, {10, -2}},
    Magnification->0.74],
  
  Cell[StyleData["ItemPictureBigger3", "EnhancedPrintout"],
    CellMargins->{{52, Inherited}, {10, -3}},
    Magnification->0.74],
  
  Cell[StyleData["ItemPictureBigger3", "EnhancedPrintoutNonGray"],
    CellMargins->{{52, Inherited}, {10, -3}},
    Magnification->0.74]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureBigger4"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureBigger4", "Printout"],
    CellMargins->{{45, Inherited}, {10, -2}},
    Magnification->0.77],
  
  Cell[StyleData["ItemPictureBigger4", "EnhancedPrintout"],
    CellMargins->{{50, Inherited}, {10, -3}},
    Magnification->0.77],
  
  Cell[StyleData["ItemPictureBigger4", "EnhancedPrintoutNonGray"],
    CellMargins->{{50, Inherited}, {10, -3}},
    Magnification->0.77]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureBigger5"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureBigger5", "Printout"],
    CellMargins->{{43, Inherited}, {11, -2}},
    Magnification->0.8],
  
  Cell[StyleData["ItemPictureBigger5", "EnhancedPrintout"],
    CellMargins->{{49, Inherited}, {10, -3}},
    Magnification->0.8],
  
  Cell[StyleData["ItemPictureBigger5", "EnhancedPrintoutNonGray"],
    CellMargins->{{49, Inherited}, {10, -3}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemPictureBigger6"],
    CellMargins->{{41, Inherited}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemPictureBigger6", "Printout"],
    CellMargins->{{43, Inherited}, {12, -2}},
    Magnification->0.83],
  
  Cell[StyleData["ItemPictureBigger6", "EnhancedPrintout"],
    CellMargins->{{46, Inherited}, {8, -2}},
    Magnification->0.83],
  
  Cell[StyleData["ItemPictureBigger6", "EnhancedPrintoutNonGray"],
    CellMargins->{{46, Inherited}, {8, -2}},
    Magnification->0.83]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ScreenGraphic"],
    CellMargins->{{12, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ScreenGraphic", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}}],
  
  Cell[StyleData["ScreenGraphic", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {0, 8}},
    CellElementSpacings->{"CellMinHeight"->2,
    "ClosedCellHeight"->2},
    CellOpen->False],
  
  Cell[StyleData["ScreenGraphic", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {0, 8}},
    CellElementSpacings->{"CellMinHeight"->2,
    "ClosedCellHeight"->2},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrintGraphic"],
    CellMargins->{{12, Inherited}, {0, 8}},
    CellElementSpacings->{"CellMinHeight"->2,
    "ClosedCellHeight"->2},
    CellOpen->False,
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PrintGraphic", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}},
    CellElementSpacings->{"CellMinHeight"->2,
    "ClosedCellHeight"->2},
    CellOpen->False],
  
  Cell[StyleData["PrintGraphic", "EnhancedPrintout"],
    CellMargins->{{2, Inherited}, {0, 8}},
    CellElementSpacings->{"CellMinHeight"->12},
    CellOpen->True],
  
  Cell[StyleData["PrintGraphic", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, Inherited}, {0, 8}},
    CellElementSpacings->{"CellMinHeight"->12},
    CellOpen->True]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallTextSans"],
    CellMargins->{{10, 4}, {8, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 2},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallTextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->7],
  
  Cell[StyleData["SmallTextSans", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, -2},
    FontFamily->"Futura",
    FontSize->7]
  }, Closed]]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["AuthorTools", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BilateralCell"],
    CellMargins->{{10, 4}, {0, 8}},
    StyleMenuListing->None,
    FontSize->12,
    GridBoxOptions->{ColumnWidths->{0.33, 0.6},
    RowAlignments->Top,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BilateralCell", "SlideShow"],
    CellMargins->{{36, 24}, {4, 4}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["BilateralCell", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontSize->10],
  
  Cell[StyleData["BilateralCell", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10],
  
  Cell[StyleData["BilateralCell", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RuledPageBreak"],
    CellFrame->{{0, 0}, {0.25, 0}},
    CellMargins->{{10, 4}, {12, 0}},
    CellFrameMargins->{{0, 0}, {1, 0}},
    FontSize->8],
  
  Cell[StyleData["RuledPageBreak", "SlideShow"],
    CellMargins->{{36, 24}, {4, 4}}],
  
  Cell[StyleData["RuledPageBreak", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    PageBreakBelow->True,
    FontSize->1],
  
  Cell[StyleData["RuledPageBreak", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    PageBreakBelow->True],
  
  Cell[StyleData["RuledPageBreak", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 2}, {6, 6}},
    PageBreakBelow->True]
  }, Closed]],
  
  Cell[StyleData["PaletteTitle"],
    CellFrame->{{0, 0}, {1, 0}},
    CellMargins->{{4, 20}, {Inherited, 0}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.32549, 0.537255],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #2]}]&),
    ButtonEvaluator->None,
    ButtonStyle->"PaletteButton",
    ButtonMargins->3}],
  
  Cell[StyleData["PaletteButton"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    ButtonBoxOptions->{ButtonEvaluator->"Local",
    Active->True,
    ButtonMargins->6,
    Background->RGBColor[0.329412, 0.584314, 0.694118]}],
  
  Cell[StyleData["PaletteButton2"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    ButtonBoxOptions->{ButtonEvaluator->"Local",
    Active->True,
    ButtonMargins->4,
    Background->RGBColor[0.537255, 0.72549, 0.843137]}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Outline Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline1"],
    CellMargins->{{12, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    ParagraphIndent->-38,
    CounterIncrements->"Outline1",
    FontSize->18,
    FontWeight->"Bold",
    CounterBoxOptions->{
    CounterFunction:>Utilities`Notation`Private`CapitalRomanNumeral}],
  
  Cell[StyleData["Outline1", "Printout"],
    CounterBoxOptions->{
    CounterFunction:>Utilities`Notation`Private`CapitalRomanNumeral}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline2"],
    CellMargins->{{48, 10}, {6, 6}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontSize->15,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}],
  
  Cell[StyleData["Outline2", "Printout"],
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline3"],
    CellMargins->{{84, 10}, {5, 5}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-21,
    CounterIncrements->"Outline3",
    FontSize->12,
    CounterBoxOptions->{CounterFunction:>Identity}],
  
  Cell[StyleData["Outline3", "Printout"],
    CounterBoxOptions->{CounterFunction:>Identity}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline4"],
    CellMargins->{{120, 10}, {4, 4}},
    CellGroupingRules->{"SectionGrouping", 80},
    ParagraphIndent->-18,
    CounterIncrements->"Outline4",
    FontSize->10,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["Outline4", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Slide Show Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowNavigationBar"],
    Editable->False,
    CellFrame->True,
    CellMargins->{{0, 0}, {3, 3}},
    CellElementSpacings->{"CellMinHeight"->0.8125},
    CellGroupingRules->{"SectionGrouping", 30},
    CellFrameMargins->False,
    CellFrameColor->GrayLevel[1],
    CellFrameLabelMargins->False,
    TextAlignment->Center,
    CounterIncrements->"SlideShowNavigationBar",
    StyleMenuListing->None,
    FontSize->10,
    Background->GrayLevel[0.8],
    Magnification->1,
    GridBoxOptions->{GridBaseline->Center,
    RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->{3.5, 3.5, 3.5, 3.5, 13, 5, 4},
    RowAlignments->Baseline,
    ColumnAlignments->{
      Center, Center, Center, Center, Center, Center, Right, Center}}],
  
  Cell[StyleData["SlideShowNavigationBar", "SlideShow"],
    Deletable->False,
    ShowCellBracket->False,
    CellMargins->{{-1, -1}, {-1, -1}},
    PageBreakAbove->True,
    CellFrameMargins->{{1, 1}, {0, 0}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{0, 0}, {10, 0}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 4}, {6, 12}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Plain",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.408011, 0.440726, 0.8]],
  
  Cell[StyleData["SlideShowSection", "SlideShow"],
    ShowCellBracket->False,
    PageBreakAbove->True],
  
  Cell[StyleData["SlideShowSection", "Printout"],
    CellMargins->{{18, 30}, {0, 30}},
    CellFrameMargins->5,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->26,
    FontColor->GrayLevel[0.400015],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMinHeight->0.85,
    ButtonMargins->0.5,
    ButtonNote->None}],
  
  Cell[StyleData["SlideHyperlink", "SlideShow"]],
  
  Cell[StyleData["SlideHyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOCLink"],
    CellMargins->{{24, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Helvetica",
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMargins->1.5,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SlideTOCLink", "SlideShow"]],
  
  Cell[StyleData["SlideTOCLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOC"],
    CellDingbat->"\[Bullet]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["SlideTOC", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["SlideTOC", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["1ColumnBox", "SlideShow"],
    CellMargins->{{36, 36}, {3, 6}},
    Background->RGBColor[0.700008, 0.849989, 0.949996]],
  
  Cell[StyleData["1ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["1ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {3, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.31, 0.67}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnBox", "SlideShow"],
    CellMargins->{{36, 36}, {6, 6}},
    Background->RGBColor[0.700008, 0.849989, 0.949996]],
  
  Cell[StyleData["2ColumnBox", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox", "SlideShow"],
    CellMargins->{{36, 36}, {6, 6}},
    Background->RGBColor[0.700008, 0.849989, 0.949996]],
  
  Cell[StyleData["DefinitionBox", "EnhancedPrintout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["DefinitionBox", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 4}, {0, 8}},
    FontFamily->"Palatino",
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{21, 4}, {12, 24}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{12, 0}, {102, 89}},
    PageBreakBelow->False,
    FontSize->30.5],
  
  Cell[StyleData["ContentsTitle", "EnhancedPrintout"],
    CellMargins->{{24, 0}, {102, 89}},
    PageBreakBelow->False,
    FontFamily->"Futura",
    FontSize->30.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{35, 4}, {3, 18}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{20, 0}, {3, 18}},
    PageBreakBelow->False,
    FontSize->11],
  
  Cell[StyleData["ContentsSection", "EnhancedPrintout"],
    CellMargins->{{20, 0}, {3, 18}},
    PageBreakBelow->False,
    FontFamily->"Futura",
    FontSize->11],
  
  Cell[StyleData["ContentsSection", "EnhancedPrintoutNonGray"],
    CellMargins->{{20, 0}, {3, 18}},
    PageBreakBelow->False,
    FontFamily->"Futura",
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{50, 4}, {0, 5}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{40, 4}, {0, 5}},
    FontSize->11],
  
  Cell[StyleData["Contents", "EnhancedPrintout"],
    CellMargins->{{40, 5}, {0, 5}},
    FontFamily->"Palatino",
    FontSize->11],
  
  Cell[StyleData["Contents", "EnhancedPrintoutNonGray"],
    CellMargins->{{40, 5}, {0, 5}},
    FontFamily->"Palatino",
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9],
  
  Cell[StyleData["Index", "EnhancedPrintout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontFamily->"Palatino",
    FontSize->9],
  
  Cell[StyleData["Index", "EnhancedPrintoutNonGray"],
    CellMargins->{{13, 0}, {0, 0}},
    FontFamily->"Palatino",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9],
  
  Cell[StyleData["IndexSubentry", "EnhancedPrintout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontFamily->"Palatino",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index2Column"],
    CellMargins->{{21, 4}, {0, 8}},
    ParagraphIndent->-20,
    TabSpacings->1,
    StyleMenuListing->None,
    FontSize->10,
    GridBoxOptions->{ColumnWidths->0.5,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["Index2Column", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontSize->8],
  
  Cell[StyleData["Index2Column", "EnhancedPrintout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontFamily->"Palatino",
    FontSize->8],
  
  Cell[StyleData["Index2Column", "EnhancedPrintoutNonGray"],
    CellMargins->{{2, 2}, {6, 6}},
    FontFamily->"Palatino",
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Leader"],
    TabFilling->".",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain"],
  
  Cell[StyleData["Leader", "Printout"],
    FontSize->10],
  
  Cell[StyleData["Leader", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LeaderNoDots"],
    TabFilling->" ",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain"],
  
  Cell[StyleData["LeaderNoDots", "Printout"],
    FontSize->10],
  
  Cell[StyleData["LeaderNoDots", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["PageLink", "Printout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["PageLink", "EnhancedPrintout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCPage"],
    CellSize->{22, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Plain"],
  
  Cell[StyleData["TOCPage", "Printout"],
    FontSize->10],
  
  Cell[StyleData["TOCPage", "EnhancedPrintout"],
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCTitle"],
    CellMargins->{{20, 0}, {1, 8}},
    CellGroupingRules->{"SectionGrouping", 70},
    TabSpacings->46,
    CounterIncrements->"TOCTitle",
    CounterAssignments->{{"TOCSection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["TOCTitle", "Printout"],
    CellMargins->{{12, 0}, {1, 8}},
    PageBreakBelow->False,
    TabSpacings->47.4,
    FontSize->11],
  
  Cell[StyleData["TOCTitle", "EnhancedPrintout"],
    CellMargins->{{2, 0}, {2, 10}},
    PageBreakBelow->False,
    TabSpacings->49.3,
    FontFamily->"Futura",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSection"],
    CellMargins->{{48, 0}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 75},
    TabSpacings->42.9,
    CounterIncrements->"TOCSection",
    CounterAssignments->{{"TOCSubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["TOCSection", "Printout"],
    CellMargins->{{30, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->12],
  
  Cell[StyleData["TOCSection", "EnhancedPrintout"],
    CellMargins->{{26, 0}, {1, 3}},
    PageBreakBelow->False,
    TabSpacings->46.45,
    FontFamily->"Futura",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsection"],
    CellMargins->{{76, 0}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 80},
    TabSpacings->39.8,
    CounterIncrements->"TOCSubsection",
    CounterAssignments->{{"TOCSubsubsection", 0}},
    FontSize->12],
  
  Cell[StyleData["TOCSubsection", "Printout"],
    CellMargins->{{70, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->10],
  
  Cell[StyleData["TOCSubsection", "EnhancedPrintout"],
    CellMargins->{{38, 0}, {1, 1}},
    PageBreakBelow->False,
    TabSpacings->45.15,
    FontFamily->"Palatino",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsubsection"],
    CellMargins->{{104, 0}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 85},
    TabSpacings->36.7,
    CounterIncrements->"TOCSubsubsection",
    FontSize->12],
  
  Cell[StyleData["TOCSubsubsection", "Printout"],
    CellMargins->{{96, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->9],
  
  Cell[StyleData["TOCSubsubsection", "EnhancedPrintout"],
    CellMargins->{{96, 0}, {1, 1}},
    PageBreakBelow->False,
    FontFamily->"Palatino",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCTitleDingbat"],
    CellSize->{34, Inherited},
    TextAlignment->Right],
  
  Cell[StyleData["TOCTitleDingbat", "EnhancedPrintout"],
    FontFamily->"Futura",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSectionDingbat"],
    CellSize->{38, Inherited},
    TextAlignment->Right],
  
  Cell[StyleData["TOCSectionDingbat", "EnhancedPrintout"],
    FontFamily->"Futura",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsectionDingbat"],
    CellSize->{54, Inherited},
    TextAlignment->Right],
  
  Cell[StyleData["TOCSubsectionDingbat", "EnhancedPrintout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCTitleCondensed"],
    CellMargins->{{20, 0}, {1, 8}},
    CellGroupingRules->{"SectionGrouping", 70},
    TabSpacings->50.4,
    CounterIncrements->"TOCTitleCondensed",
    CounterAssignments->{{"TOCSectionCondensed", 0}, {
        "TOCSubsectionCondensed", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["TOCTitleCondensed", "Printout"],
    CellMargins->{{12, 0}, {1, 8}},
    PageBreakBelow->False,
    FontSize->11],
  
  Cell[StyleData["TOCTitleCondensed", "EnhancedPrintout"],
    CellMargins->{{12, 0}, {1, 8}},
    PageBreakBelow->False,
    FontFamily->"Futura",
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSectionCondensed"],
    CellMargins->{{48, 0}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 75},
    TabSpacings->47.4,
    CounterIncrements->"TOCSectionCondensed",
    CounterAssignments->{{"TOCSubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold",
    FontColor->GrayLevel[0.2]],
  
  Cell[StyleData["TOCSectionCondensed", "Printout"],
    CellMargins->{{36, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->11],
  
  Cell[StyleData["TOCSectionCondensed", "EnhancedPrintout"],
    CellMargins->{{36, 0}, {1, 1}},
    PageBreakBelow->False,
    FontFamily->"Palatino",
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsectionCondensed"],
    PageWidth->470,
    CellMargins->{{76, 0}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 80},
    TextJustification->1,
    Hyphenation->True,
    FontSize->12],
  
  Cell[StyleData["TOCSubsectionCondensed", "Printout"],
    CellMargins->{{72, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->10],
  
  Cell[StyleData["TOCSubsectionCondensed", "EnhancedPrintout"],
    CellMargins->{{72, 0}, {1, 1}},
    PageBreakBelow->False,
    FontFamily->"Palatino",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsubsectionCondensed"],
    CellMargins->{{104, 0}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 85},
    TabSpacings->39.3,
    CounterIncrements->"TOCSubsubsectionCondensed",
    FontSize->12],
  
  Cell[StyleData["TOCSubsubsectionCondensed", "Printout"],
    CellMargins->{{96, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->9],
  
  Cell[StyleData["TOCSubsubsectionCondensed", "EnhancedPrintout"],
    CellMargins->{{96, 0}, {1, 1}},
    PageBreakBelow->False,
    FontFamily->"Palatino",
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageHeader", "Printout"]],
  
  Cell[StyleData["PageHeader", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["PageHeader", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageNumber", "Printout"]],
  
  Cell[StyleData["PageNumber", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["PageNumber", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageFooter", "Printout"]],
  
  Cell[StyleData["PageFooter", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["PageFooter", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["For compatibility", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["Header", "Printout"]],
  
  Cell[StyleData["Header", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["Header", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Footer"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["Footer", "Printout"]],
  
  Cell[StyleData["Footer", "EnhancedPrintout"],
    FontFamily->"Futura"],
  
  Cell[StyleData["Footer", "EnhancedPrintoutNonGray"],
    FontFamily->"Futura"]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 37, 0, 39, "Subsubsection"],

Cell[CellGroupData[{
Cell[1816, 55, 40, 0, 27, "SubsubsectionIcon"],
Cell[1859, 57, 315, 8, 30, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2211, 70, 33, 0, 21, "SubsubsectionIcon"],
Cell[2247, 72, 495, 15, 27, "Text"],
Cell[2745, 89, 144, 3, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2926, 97, 94, 1, 21, "SubsubsectionIcon"],
Cell[3023, 100, 88, 3, 27, "Text"],
Cell[3114, 105, 116, 2, 31, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3267, 112, 45, 0, 21, "SubsubsectionIcon"],
Cell[3315, 114, 211, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[3551, 124, 154, 3, 50, "Input"],
Cell[3708, 129, 877, 16, 101, "Output"]
}, Open  ]],
Cell[4600, 148, 285, 6, 44, "Text"],
Cell[4888, 156, 237, 9, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5162, 170, 49, 0, 21, "SubsubsectionIcon"],
Cell[5214, 172, 41, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[5280, 176, 86, 2, 31, "Input"],
Cell[5369, 180, 31781, 713, 230, 10609, 446, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[37165, 896, 55, 0, 27, "Text"],
Cell[37223, 898, 181, 4, 27, "Text"],

Cell[CellGroupData[{
Cell[37429, 906, 282, 7, 31, "Input"],
Cell[37714, 915, 24933, 628, 230, 10606, 446, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[62662, 1546, 160, 5, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[62859, 1556, 51, 0, 21, "SubsubsectionIcon"],
Cell[62913, 1558, 59, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[62997, 1562, 90, 2, 31, "Input"],
Cell[63090, 1566, 280, 5, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[63407, 1576, 140, 3, 31, "Input"],
Cell[63550, 1581, 128, 3, 25, "Output"]
}, Open  ]]
}, Closed]],
Cell[63705, 1588, 61, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[63791, 1592, 96, 1, 27, "SubsubsectionIcon"],
Cell[63890, 1595, 119, 3, 27, "Text"],
Cell[64012, 1600, 176, 3, 50, "Input"],
Cell[64191, 1605, 106, 3, 27, "Text"],
Cell[64300, 1610, 96, 2, 31, "Input"],
Cell[64399, 1614, 72, 0, 27, "Text"],
Cell[64474, 1616, 98, 2, 31, "Input"],
Cell[64575, 1620, 133, 3, 27, "Text"],
Cell[64711, 1625, 99, 2, 31, "Input"],
Cell[64813, 1629, 200, 6, 27, "Text"],
Cell[65016, 1637, 67, 0, 27, "Text"],
Cell[65086, 1639, 70, 2, 31, "Input"],
Cell[65159, 1643, 100, 3, 27, "Text"],
Cell[65262, 1648, 138, 3, 31, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[65437, 1656, 116, 1, 21, "SubsubsectionIcon"],
Cell[65556, 1659, 176, 5, 27, "Text"],
Cell[65735, 1666, 205, 5, 27, "Text"],
Cell[65943, 1673, 146, 5, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[66126, 1683, 60, 0, 21, "SubsubsectionIcon"],
Cell[66189, 1685, 142, 3, 30, "Text"],
Cell[66334, 1690, 91, 1, 56, "DisplayMath"],
Cell[66428, 1693, 407, 13, 30, "Text"],
Cell[66838, 1708, 306, 5, 61, "DisplayMath"],
Cell[67147, 1715, 103, 3, 30, "Text"],
Cell[67253, 1720, 234, 4, 57, "DisplayMath"],
Cell[67490, 1726, 463, 10, 50, "Text"],
Cell[67956, 1738, 378, 11, 30, "Text"],

Cell[CellGroupData[{
Cell[68359, 1753, 155, 3, 51, "Input"],
Cell[68517, 1758, 17241, 454, 230, 3978, 285, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[85807, 2218, 115, 1, 21, "SubsubsectionIcon"],
Cell[85925, 2221, 204, 6, 27, "Text"],
Cell[86132, 2229, 149, 3, 55, "Input"],
Cell[86284, 2234, 136, 3, 31, "Input"],
Cell[86423, 2239, 292, 5, 44, "Text"],
Cell[86718, 2246, 348, 8, 31, "Input"],
Cell[87069, 2256, 100, 3, 27, "Text"],
Cell[87172, 2261, 197, 4, 31, "Input"],
Cell[87372, 2267, 122, 3, 27, "Text"],
Cell[87497, 2272, 146, 3, 31, "Input"],
Cell[87646, 2277, 236, 5, 27, "Text"]
}, Closed]],
Cell[87897, 2285, 48, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[87970, 2289, 50, 0, 27, "SubsubsectionIcon"],
Cell[88023, 2291, 205, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[88253, 2301, 108, 2, 31, "Input"],
Cell[88364, 2305, 2002, 34, 215, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[90403, 2344, 86, 2, 31, "Input"],
Cell[90492, 2348, 37816, 787, 230, 10621, 446, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[128323, 3138, 140, 3, 27, "Text"],
Cell[128466, 3143, 71, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[128562, 3147, 76, 2, 31, "Input"],
Cell[128641, 3151, 193, 3, 25, "Output"]
}, Open  ]],
Cell[128849, 3157, 47, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[128921, 3161, 68, 2, 31, "Input"],
Cell[128992, 3165, 61, 2, 25, "Output"]
}, Open  ]],
Cell[129068, 3170, 98, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[129191, 3177, 85, 2, 31, "Input"],
Cell[129279, 3181, 224, 4, 44, "Output"]
}, Open  ]],
Cell[129518, 3188, 185, 4, 27, "Text"],

Cell[CellGroupData[{
Cell[129728, 3196, 71, 2, 31, "Input"],
Cell[129802, 3200, 78, 2, 25, "Output"]
}, Open  ]],
Cell[129895, 3205, 103, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[130023, 3212, 132, 3, 31, "Input"],
Cell[130158, 3217, 41539, 753, 230, 4042, 285, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[171746, 3976, 107, 1, 21, "SubsubsectionIcon"],
Cell[171856, 3979, 150, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[172031, 3986, 132, 3, 31, "Input"],
Cell[172166, 3991, 2356, 36, 217, "Output"]
}, Open  ]],
Cell[174537, 4030, 247, 6, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[174821, 4041, 96, 1, 21, "SubsubsectionIcon"],
Cell[174920, 4044, 87, 3, 27, "Text"],
Cell[175010, 4049, 232, 5, 50, "Input"],
Cell[175245, 4056, 126, 3, 27, "Text"],
Cell[175374, 4061, 135, 3, 31, "Input"],
Cell[175512, 4066, 281, 6, 44, "Text"],
Cell[175796, 4074, 72, 0, 27, "Text"],
Cell[175871, 4076, 120, 3, 31, "Input"],
Cell[175994, 4081, 76, 0, 27, "Text"],
Cell[176073, 4083, 144, 3, 31, "Input"],
Cell[176220, 4088, 57, 0, 27, "Text"],
Cell[176280, 4090, 68, 2, 31, "Input"],
Cell[176351, 4094, 258, 6, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[176646, 4105, 46, 0, 21, "SubsubsectionIcon"],
Cell[176695, 4107, 90, 3, 27, "Text"],
Cell[176788, 4112, 164, 4, 27, "Text"],
Cell[176955, 4118, 179, 4, 27, "Text"]
}, Closed]],
Cell[177149, 4125, 38, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[177212, 4129, 56, 0, 27, "SubsubsectionIcon"],
Cell[177271, 4131, 527, 12, 46, "Text"],
Cell[177801, 4145, 197, 4, 52, "Input"],
Cell[178001, 4151, 426, 9, 152, "Text"],
Cell[178430, 4162, 113, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[178568, 4169, 103, 2, 31, "Input"],
Cell[178674, 4173, 223, 5, 25, "Output"]
}, Open  ]],
Cell[178912, 4181, 50, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[178987, 4185, 116, 2, 31, "Input"],
Cell[179106, 4189, 128, 3, 25, "Output"]
}, Open  ]],
Cell[179249, 4195, 133, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[179407, 4202, 151, 4, 31, "Input"],
Cell[179561, 4208, 69, 2, 25, "Output"]
}, Open  ]],
Cell[179645, 4213, 50, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[179720, 4217, 81, 2, 31, "Input"],
Cell[179804, 4221, 89, 2, 25, "Output"]
}, Open  ]],
Cell[179908, 4226, 50, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[179983, 4230, 129, 3, 31, "Input"],
Cell[180115, 4235, 2725, 51, 215, "Output"]
}, Closed]],
Cell[182855, 4289, 156, 3, 21, "Text"],

Cell[CellGroupData[{
Cell[183036, 4296, 76, 2, 31, "Input"],
Cell[183115, 4300, 559, 10, 44, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[183723, 4316, 48, 0, 21, "SubsubsectionIcon"],
Cell[183774, 4318, 481, 9, 61, "Text"],

Cell[CellGroupData[{
Cell[184280, 4331, 464, 9, 69, "Input"],
Cell[184747, 4342, 72780, 1632, 230, 9638, 847, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[257564, 5979, 129, 3, 31, "Input"],
Cell[257696, 5984, 2725, 51, 215, "Output"]
}, Closed]],
Cell[260436, 6038, 481, 9, 55, "Text"],
Cell[260920, 6049, 103, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[261048, 6056, 512, 9, 88, "Input"],
Cell[261563, 6067, 93663, 1794, 338, 8400, 736, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[355275, 7867, 58, 0, 21, "SubsubsectionIcon"],
Cell[355336, 7869, 150, 3, 27, "Text"],
Cell[355489, 7874, 306, 6, 69, "Input"],
Cell[355798, 7882, 108, 3, 27, "Text"],
Cell[355909, 7887, 352, 7, 88, "Input"],
Cell[356264, 7896, 252, 6, 27, "Text"],
Cell[356519, 7904, 173, 5, 27, "Text"],
Cell[356695, 7911, 524, 16, 35, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[357256, 7932, 105, 1, 21, "SubsubsectionIcon"],
Cell[357364, 7935, 63, 0, 27, "Text"],
Cell[357430, 7937, 155, 4, 31, "Input"],
Cell[357588, 7943, 249, 7, 52, "Text"],
Cell[357840, 7952, 96, 3, 27, "Text"],
Cell[357939, 7957, 83, 2, 31, "Input"],
Cell[358025, 7961, 67, 0, 27, "Text"],
Cell[358095, 7963, 289, 7, 69, "Input"],
Cell[358387, 7972, 41, 0, 27, "Text"],
Cell[358431, 7974, 66, 2, 31, "Input"],
Cell[358500, 7978, 187, 5, 27, "Text"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

