(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    173475,       9836]*)
(*NotebookOutlinePosition[    175298,       9889]*)
(*  CellTagsIndexPosition[    175065,       9879]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["The distribution of coalescence times", "SubsectionIcon"],

Cell[TextData[{
  "The ",
  StyleBox["times",
    FontSlant->"Italic"],
  " of the coalescence events are independent of the structure of the \
families they produce."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(RandomCoalescenceTimes[
              k]\), \(\(\ \)\(gives\ a\ list\ of\ random\ coalescence\ \
\(\(times\)\(.\)\)\)\)},
          {\(NumberOfCoalescences[k, 
              T]\), \(gives\ a\ randomly\ sampled\ number\ of\ coalescence\ \
events\ that\ occur\ in\ T\ \((scaled\ to\ 2  
                    N)\) . \ \ k\ is\ the\ #\ of\ \(\(lineages\)\(.\)\)\)},
          {\(\(NumberOfCoalescences[{t1, t2 .. }, 
              T]\)\(\ \)\), \(gives\ the\ number\ of\ coalescence\ events\ \
that\ occurs\ by\ T, \ 
            for\ a\ specified\ list\ of\ coalescence\ \(\(times\)\(.\)\)\)},
          {\(\(TotalLength[{t1, 
                t2,  .. }]\)\(\ \)\), \(is\ the\ total\ length\ of\ the\ tree\
\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"RandomCoalescenceTimes", "NumberOfCoalescences", "TotalLength"}],\


Cell["\<\
Here is a list of the times of the 9 coalescence events that unite \
10 lineages\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rt = RandomCoalescenceTimes[10]\)], "Input",
  CellLabel->"In[168]:="],

Cell[BoxData[
    \({0.00877174088266424689`, 0.0261851336731639694`, 
      0.0310030482121928319`, 0.0322149892004613125`, 0.117436467009096245`, 
      0.16230672727884734`, 0.174043263794671831`, 0.328225095464784821`, 
      0.427203594365092786`}\)], "Output",
  CellLabel->"Out[168]="]
}, Closed]],

Cell["\<\
The total length of any genealogy with these coalescence times is \
1.73s:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TotalLength[rt]\)], "Input",
  CellLabel->"In[169]:="],

Cell[BoxData[
    \(1.73459365424606808`\)], "Output",
  CellLabel->"Out[169]="]
}, Closed]],

Cell["\<\
Only one coalescence event has occurred by time 0.1 (scaled to \
2N)\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NumberOfCoalescences[rt, 0.1]\)], "Input",
  CellLabel->"In[170]:="],

Cell[BoxData[
    \(4\)], "Output",
  CellLabel->"Out[170]="]
}, Closed]],

Cell[TextData[{
  "This gives a randomly sampled # of coalescences among 10 lineages that \
have occurred by ",
  Cell[BoxData[
      \(TraditionalForm\`t = \(\(0.1\)\(:\)\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tt = Table[NumberOfCoalescences[10, 0.1], {100}]\)], "Input",
  CellLabel->"In[171]:="],

Cell[BoxData[
    \({3, 5, 4, 1, 4, 3, 2, 3, 1, 3, 2, 4, 2, 4, 4, 3, 2, 4, 5, 1, 3, 2, 3, 
      3, 2, 3, 1, 5, 2, 3, 3, 3, 1, 3, 5, 5, 2, 4, 1, 3, 4, 1, 1, 4, 6, 4, 3, 
      1, 3, 2, 2, 1, 4, 3, 5, 3, 1, 5, 1, 3, 3, 4, 2, 3, 3, 3, 3, 3, 5, 4, 4, 
      3, 2, 2, 0, 2, 2, 4, 3, 5, 2, 5, 6, 0, 2, 3, 4, 2, 5, 4, 2, 3, 3, 5, 3, 
      4, 2, 4, 3, 5}\)], "Output",
  CellLabel->"Out[171]="]
}, Closed]],

Cell[BoxData[
    \(<< Statistics`DataManipulation`; << Graphics`Graphics`; \)], "Input",
  CellLabel->"In[172]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BarChart[Frequencies[tt]]; \)\)], "Input",
  CellLabel->"In[173]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0555556 0.138889 0.0147151 0.0183939 [
[.08333 .00222 -3 -9 ]
[.08333 .00222 3 0 ]
[.22222 .00222 -3 -9 ]
[.22222 .00222 3 0 ]
[.36111 .00222 -3 -9 ]
[.36111 .00222 3 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.63889 .00222 -3 -9 ]
[.63889 .00222 3 0 ]
[.77778 .00222 -3 -9 ]
[.77778 .00222 3 0 ]
[.91667 .00222 -3 -9 ]
[.91667 .00222 3 0 ]
[-0.0125 .10668 -6 -4.5 ]
[-0.0125 .10668 0 4.5 ]
[-0.0125 .19865 -12 -4.5 ]
[-0.0125 .19865 0 4.5 ]
[-0.0125 .29062 -12 -4.5 ]
[-0.0125 .29062 0 4.5 ]
[-0.0125 .38259 -12 -4.5 ]
[-0.0125 .38259 0 4.5 ]
[-0.0125 .47456 -12 -4.5 ]
[-0.0125 .47456 0 4.5 ]
[-0.0125 .56653 -12 -4.5 ]
[-0.0125 .56653 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 .01472 m
.08333 .02097 L
s
[(0)] .08333 .00222 0 1 Mshowa
.22222 .01472 m
.22222 .02097 L
s
[(1)] .22222 .00222 0 1 Mshowa
.36111 .01472 m
.36111 .02097 L
s
[(2)] .36111 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(3)] .5 .00222 0 1 Mshowa
.63889 .01472 m
.63889 .02097 L
s
[(4)] .63889 .00222 0 1 Mshowa
.77778 .01472 m
.77778 .02097 L
s
[(5)] .77778 .00222 0 1 Mshowa
.91667 .01472 m
.91667 .02097 L
s
[(6)] .91667 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
0 .10668 m
.00625 .10668 L
s
[(5)] -0.0125 .10668 1 0 Mshowa
0 .19865 m
.00625 .19865 L
s
[(10)] -0.0125 .19865 1 0 Mshowa
0 .29062 m
.00625 .29062 L
s
[(15)] -0.0125 .29062 1 0 Mshowa
0 .38259 m
.00625 .38259 L
s
[(20)] -0.0125 .38259 1 0 Mshowa
0 .47456 m
.00625 .47456 L
s
[(25)] -0.0125 .47456 1 0 Mshowa
0 .56653 m
.00625 .56653 L
s
[(30)] -0.0125 .56653 1 0 Mshowa
.125 Mabswid
0 .03311 m
.00375 .03311 L
s
0 .0515 m
.00375 .0515 L
s
0 .0699 m
.00375 .0699 L
s
0 .08829 m
.00375 .08829 L
s
0 .12508 m
.00375 .12508 L
s
0 .14347 m
.00375 .14347 L
s
0 .16187 m
.00375 .16187 L
s
0 .18026 m
.00375 .18026 L
s
0 .21705 m
.00375 .21705 L
s
0 .23544 m
.00375 .23544 L
s
0 .25384 m
.00375 .25384 L
s
0 .27223 m
.00375 .27223 L
s
0 .30902 m
.00375 .30902 L
s
0 .32741 m
.00375 .32741 L
s
0 .3458 m
.00375 .3458 L
s
0 .3642 m
.00375 .3642 L
s
0 .40099 m
.00375 .40099 L
s
0 .41938 m
.00375 .41938 L
s
0 .43777 m
.00375 .43777 L
s
0 .45617 m
.00375 .45617 L
s
0 .49296 m
.00375 .49296 L
s
0 .51135 m
.00375 .51135 L
s
0 .52974 m
.00375 .52974 L
s
0 .54814 m
.00375 .54814 L
s
0 .58493 m
.00375 .58493 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.02778 .01472 m
.02778 .0515 L
.13889 .0515 L
.13889 .01472 L
F
0 g
.5 Mabswid
.02778 .01472 m
.02778 .0515 L
.13889 .0515 L
.13889 .01472 L
.02778 .01472 L
s
1 0 0 r
.16667 .01472 m
.16667 .23544 L
.27778 .23544 L
.27778 .01472 L
F
0 g
.16667 .01472 m
.16667 .23544 L
.27778 .23544 L
.27778 .01472 L
.16667 .01472 L
s
1 0 0 r
.30556 .01472 m
.30556 .38259 L
.41667 .38259 L
.41667 .01472 L
F
0 g
.30556 .01472 m
.30556 .38259 L
.41667 .38259 L
.41667 .01472 L
.30556 .01472 L
s
1 0 0 r
.44444 .01472 m
.44444 .60332 L
.55556 .60332 L
.55556 .01472 L
F
0 g
.44444 .01472 m
.44444 .60332 L
.55556 .60332 L
.55556 .01472 L
.44444 .01472 L
s
1 0 0 r
.58333 .01472 m
.58333 .3642 L
.69444 .3642 L
.69444 .01472 L
F
0 g
.58333 .01472 m
.58333 .3642 L
.69444 .3642 L
.69444 .01472 L
.58333 .01472 L
s
1 0 0 r
.72222 .01472 m
.72222 .25384 L
.83333 .25384 L
.83333 .01472 L
F
0 g
.72222 .01472 m
.72222 .25384 L
.83333 .25384 L
.83333 .01472 L
.72222 .01472 L
s
1 0 0 r
.86111 .01472 m
.86111 .0515 L
.97222 .0515 L
.97222 .01472 L
F
0 g
.86111 .01472 m
.86111 .0515 L
.97222 .0515 L
.97222 .01472 L
.86111 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[173]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool002Eoo`80029oo`<002=oo`@0029oo`<002=oo`<0029oo`<002Aoo`8001Moo`0097oo00@007oo
Ool0029oo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oogoo02Aoo`03001o
ogoo021oo`04001oogoo000FOol002Aoo`04001oogoo000ROol00`00Oomoo`0TOol00`00Oomoo`0T
Ool00`00Oomoo`0OOol4000UOol00`00Oomoo`0POol01000Oomoo`005Woo000TOol01000Oomoo`00
8Woo00<007ooOol09Goo00<007ooOol08Goo0P008Woo00<007oo00008goo0`008goo0`005goo000T
Ool01000Oomoo`008Woo00<007ooOol08Woo00@007ooOol002Eoo`03001oogoo01moo`03001oo`00
02=oo`03001oogoo02=oo`03001oogoo01Moo`009Goo0P008Woo0P009Goo0P008goo0`008goo0P00
8goo10008goo0`005Woo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo
00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moool0018000003goo00<007ooOol0
17oo00<007`0O00077`000<007ooOol017oo00<007`0O0006g`000<007ooOol01Goo00<007`0O000
6g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol017oo00<007`0O00077`000<007ooOol0
17oo00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol01Woo000?Ool00`00
Oomoo`04Ool00`00O01l000LO0000`00Oomoo`04Ool00`00O01l000KO0000`00Oomoo`05Ool00`00
O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00O01l000LO0000`00
Oomoo`04Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`06Ool000mo
o`03001oogoo00Aoo`03001l07`001al0003001oogoo00Aoo`03001l07`001]l0003001oogoo00Eo
o`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Aoo`03001l07`001al
0003001oogoo00Aoo`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Io
o`003goo00<007ooOol017oo00<007`0O00077`000<007ooOol017oo00<007`0O0006g`000<007oo
Ool01Goo00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol017oo00<007`0
O00077`000<007ooOol017oo00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007oo
Ool01Woo000?Ool20005Ool00`00O01l000LO0000`00Oomoo`04Ool00`00O01l000KO0000`00Oomo
o`05Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00O01l
000LO0000`00Oomoo`04Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomo
o`06Ool000moo`03001oogoo00Aoo`03001l07`001al0003001oogoo00Aoo`03001l07`001]l0003
001oogoo00Eoo`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Aoo`03
001l07`001al0003001oogoo00Aoo`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003
001oogoo00Ioo`003goo00<007ooOol017oo00<007`0O00077`000<007ooOol017oo00<007`0O000
6g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol0
17oo00<007`0O00077`000<007ooOol017oo00<007`0O0006g`000<007ooOol01Goo00<007`0O000
6g`000<007ooOol01Woo000?Ool00`00Oomoo`04Ool00`00O01l000LO0000`00Oomoo`04Ool00`00
O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00
Oomoo`04Ool00`00O01l000LO0000`00Oomoo`04Ool00`00O01l000KO0000`00Oomoo`05Ool00`00
O01l000KO0000`00Oomoo`06Ool000moo`03001oogoo00Aoo`03001l07`001al0003001oogoo00Ao
o`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l
0003001oogoo00Aoo`03001l07`001al0003001oogoo00Aoo`03001l07`001]l0003001oogoo00Eo
o`03001l07`001]l0003001oogoo00Ioo`003goo0P001Goo80001Woo00<007`0O0006g`000<007oo
Ool01Goo00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol017oo00<007`0
O00077`000<007ooOol017oo00<007`0O0006g`000<007ooOol01Goo7`0027oo000?Ool00`00Oomo
o`0ZOol00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l
000KO0000`00Oomoo`04Ool00`00O01l000LO0000`00Oomoo`04Ool00`00O01l000KO0000`00Oomo
o`0/Ool000moo`03001oogoo02Yoo`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003
001oogoo00Eoo`03001l07`001]l0003001oogoo00Aoo`03001l07`001al0003001oogoo00Aoo`03
001l07`001]l0003001oogoo02aoo`003goo00<007ooOol0:Woo00<007`0O0006g`000<007ooOol0
1Goo00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol017oo00<007`0O000
77`000<007ooOol017oo00<007`0O0006g`000<007ooOol0;7oo000?Ool00`00Oomoo`0ZOol00`00
O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00
Oomoo`04Ool00`00O01l000LO0000`00Oomoo`04Ool00`00O01l000KO0000`00Oomoo`0/Ool000mo
o`8002]oo`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Eoo`03001l
07`001]l0003001oogoo00Aoo`03001l07`001al0003001oogoo00Aoo`03001l07`001]l0003001o
ogoo02aoo`003goo00<007ooOol0:Woo00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`0
00<007ooOol01Goo00<007`0O0006g`000<007ooOol017oo00<007`0O00077`000<007ooOol017oo
00<007`0O0006g`000<007ooOol0;7oo000?Ool00`00Oomoo`0ZOol00`00O01l000KO0000`00Oomo
o`05Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00O01l
000LO0000`00Oomoo`04Ool00`00O01l000KO0000`00Oomoo`0/Ool000moo`03001oogoo02Yoo`03
001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003
001oogoo00Aoo`03001l07`001al0003001oogoo00Aoo`03001l07`001]l0003001oogoo02aoo`00
3goo00<007ooOol0:Woo00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol0
1Goo00<007`0O0006g`000<007ooOol017oo00<007`0O00077`000<007ooOol017oo00<007`0O000
6g`000<007ooOol0;7oo000?Ool2000[Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000K
O0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00O01l000LO0000`00Oomoo`04
Ool00`00O01l000KO0000`00Oomoo`0/Ool000moo`03001oogoo02Yoo`03001l07`001]l0003001o
ogoo00Eoo`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Aoo`03001l
07`001al0003001oogoo00Aoo`03001l07`001]l0003001oogoo02aoo`003goo00<007ooOol0:Woo
00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`0
00<007ooOol017oo00<007`0O00077`000<007ooOol017oo00<007`0O0006g`000<007ooOol0;7oo
0007Ool30005Ool00`00Oomoo`0ZOol00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO000
0`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00O01l000LO0000`00Oomoo`04Ool0
0`00O01l000KO0000`00Oomoo`0/Ool000Yoo`03001oogoo009oo`03001oogoo02Yoo`03001l07`0
01]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo
00Aoo`03001l07`001al0003001oogoo00Aoo`03001l07`001]l0003001oogoo02aoo`002Woo00<0
07ooOol00Woo0`00:Woo00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol0
1Goo00<007`0O0006g`000<007ooOol017oo00<007`0O00077`000<007ooOol017oo00<007`0O000
6g`000<007ooOol0;7oo0007Ool30005Ool00`00Oomoo`0ZOol00`00O01l000KO0000`00Oomoo`05
Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00O01l000L
O0000`00Oomoo`04Ool00`00O01l000KO0000`00Oomoo`0/Ool000Moo`03001oogoo00Eoo`03001o
ogoo02Yoo`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Eoo`03001l
07`001]l0003001oogoo00Aoo`03001l07`001al0003001oogoo00Aoo`03001l07`001]l0003001o
ogoo02aoo`001goo100017oo00<007ooOol0:Woo00<007`0O0006g`000<007ooOol01Goo00<007`0
O0006g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol017oo00<007`0O00077`000<007oo
Ool017oo00<007`0O0006g`000<007ooOol0;7oo000?Ool00`00Oomoo`0ZOol00`00O01l000KO000
0`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`04Ool0
0`00O01l000LO0000`00Oomoo`04Ool00`00O01l000KO0000`00Oomoo`0/Ool000moo`8002]oo`03
001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003
001oogoo00Aoo`03001l07`001al0003001oogoo00Aoo`03001l07`001]l0003001oogoo02aoo`00
3goo00<007ooOol0:Woo00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol0
1Goo00<007`0O0006g`000<007ooOol017oo00<007`0O00077`000<007ooOol017oo00<007`0O000
6g`000<007ooOol0;7oo000?Ool00`00Oomoo`0ZOol00`00O01l000KO0000`00Oomoo`05Ool00`00
O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00O01l000LO0000`00
Oomoo`04Ool00`00O01l000KO0000`00Oomoo`0/Ool000moo`03001oogoo02Yoo`03001l07`001]l
0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Ao
o`03001l07`001al0003001oogoo00Aoo`03001l07`001]l0003001oogoo02aoo`003goo00<007oo
Ool0:Woo00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol01Goo00<007`0
O0006g`000<007ooOol017oo00<007`0O00077`000<007ooOol017oo00<007`0O0006g`000<007oo
Ool0;7oo000?Ool2000[Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomo
o`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00O01l000LO0000`00Oomoo`04Ool00`00O01l
000KO0000`00Oomoo`0/Ool000moo`03001oogoo02Yoo`03001l07`001]l0003001oogoo00Eoo`03
001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Aoo`03001l07`001al0003
001oogoo00Aoo`03001l07`001]l0003001oogoo02aoo`003goo00<007ooOol0:Woo00<007`0O000
6g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol0
17oo00<007`0O00077`000<007ooOol017oo00<007`0O0006g`000<007ooOol0;7oo000?Ool00`00
Oomoo`0ZOol00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`05Ool00`00
O01l000KO0000`00Oomoo`04Ool00`00O01l000LO0000`00Oomoo`04Ool00`00O01l000KO0000`00
Oomoo`0/Ool000moo`03001oogoo02Yoo`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l
0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Aoo`03001l07`001al0003001oogoo00Ao
o`03001l07`001]l0003001oogoo02aoo`003goo0P00:goo00<007`0O0006g`000<007ooOol01Goo
00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol017oo00<007`0O00077`0
00<007ooOol017oo00<007`0O0006g`000<007ooOol0;7oo000?Ool00`00Oomoo`0ZOol00`00O01l
000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomo
o`04Ool00`00O01l000LO0000`00Oomoo`04Ool00`00O01l000KO0000`00Oomoo`0/Ool000moo`03
001oogoo02Yoo`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Eoo`03
001l07`001]l0003001oogoo00Aoo`03001l07`001al0003001oogoo00Aoo`03001l07`001]l0003
001oogoo02aoo`003goo00<007ooOol0:Woo00<007`0O0006g`000<007ooOol01Goo00<007`0O000
6g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol017oo00<007`0O00077`000<007ooOol0
17oo00<007`0O0006g`000<007ooOol0;7oo000?Ool00`00Oomoo`0ZOol00`00O01l000KO0000`00
Oomoo`05Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00
O01l000LO0000`00Oomoo`04Ool00`00O01l000KO0000`00Oomoo`0/Ool000moo`8002]oo`03001l
07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003001o
ogoo00Aoo`03001l07`001al0003001oogoo00Aoo`03001l07`001]l0003001oogoo02aoo`003goo
00<007ooOol0:Woo00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol01Goo
00<007`0O0006g`000<007ooOol017oo00<007`0O00077`000<007ooOol017oo00<007`0O0006g`0
00<007ooOol0;7oo000?Ool00`00Oomoo`0ZOol00`00O01l000KO0000`00Oomoo`05Ool00`00O01l
000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00O01l000LO0000`00Oomo
o`04Ool00`00O01l000KO0000`00Oomoo`0/Ool00004Ool000000004Ool20005Ool00`00Oomoo`0Z
Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000K
O0000`00Oomoo`04Ool00`00O01l000LO0000`00Oomoo`04Ool00`00O01l000KO0000`00Oomoo`0/
Ool0009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`0ZOol00`00O01l000KO0000`00
Oomoo`05Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00
O01l000LO0000`00Oomoo`04Ool00`00O01l000KO0000`00Oomoo`0/Ool0009oo`03001oogoo009o
o`04001oogoo0004Ool3000ZOol00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00
Oomoo`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00O01l000LO0000`00Oomoo`04Ool00`00
O01l000KO0000`00Oomoo`0/Ool0009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`0Z
Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000K
O0000`00Oomoo`04Ool00`00O01l000LO0000`00Oomoo`04Ool00`00O01l000KO0000`00Oomoo`0/
Ool0009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`0ZOol00`00O01l000KO0000`00
Oomoo`05Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00
O01l000LO0000`00Oomoo`04Ool00`00O01l000KO0000`00Oomoo`0/Ool00003Ool0000000Eoo`80
00Eoo`03001oogoo02Yoo`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo
00Eoo`03001l07`001]l0003001oogoo00Aoo`03001l07`001al0003001oogoo00Aoo`03001l07`0
01]l0003001oogoo02aoo`003goo00<007ooOol0:Woo00<007`0O0006g`000<007ooOol01Goo00<0
07`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol017oo00<007`0O00077`000<0
07ooOol017oo00<007`0O0006g`000<007ooOol0;7oo000?Ool2000[Ool00`00O01l000KO0000`00
Oomoo`05Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00
O01l000LO0000`00Oomoo`04Ool00`00O01l000KO0000`00Oomoo`0/Ool000moo`03001oogoo02Yo
o`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l
0003001oogoo00Aoo`03001l07`001al0003001oogoo00Aoo`03001l07`001]l0003001oogoo02ao
o`003goo00<007ooOol0:Woo00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007oo
Ool01Goo00<007`0O0006g`000<007ooOol017oo00<007`0O00077`000<007ooOol017oo00<007`0
O0006g`000<007ooOol0;7oo000?Ool00`00Oomoo`0ZOol00`00O01l000KO0000`00Oomoo`05Ool0
0`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00O01l000LO000
0`00Oomoo`04Ool00`00O01l000KO0000`00Oomoo`0/Ool000moo`03001oogoo02Yoo`03001l07`0
01]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo
00Aoo`03001l07`001al0003001oogoo00Aoo`03001l07`001]l0003001oogoo02aoo`003goo0P00
:goo7`001goo00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol017oo00<0
07`0O00077`000<007ooOol017oo00<007`0O0006g`000<007ooOol0;7oo000?Ool00`00Oomoo`1@
Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00O01l000L
O0000`00Oomoo`04Ool00`00O01l000KO0000`00Oomoo`0/Ool000moo`03001oogoo051oo`03001l
07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Aoo`03001l07`001al0003001o
ogoo00Aoo`03001l07`001]l0003001oogoo02aoo`003goo00<007ooOol0D7oo00<007`0O0006g`0
00<007ooOol01Goo00<007`0O0006g`000<007ooOol017oo00<007`0O00077`000<007ooOol017oo
00<007`0O0006g`000<007ooOol0;7oo000?Ool00`00Oomoo`1@Ool00`00O01l000KO0000`00Oomo
o`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00O01l000LO0000`00Oomoo`04Ool00`00O01l
000KO0000`00Oomoo`0/Ool000moo`80055oo`03001l07`001]l0003001oogoo00Eoo`03001l07`0
01]l0003001oogoo00Aoo`03001l07`001al0003001oogoo00Aooal002ioo`003goo00<007ooOol0
D7oo00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol017oo00<007`0O000
77`000<007ooOol0DGoo000?Ool00`00Oomoo`1@Ool00`00O01l000KO0000`00Oomoo`05Ool00`00
O01l000KO0000`00Oomoo`04Ool00`00O01l000LO0000`00Oomoo`1AOol000moo`03001oogoo051o
o`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Aoo`03001l07`001al
0003001oogoo055oo`003goo00<007ooOol0D7oo00<007`0O0006g`000<007ooOol01Goo00<007`0
O0006g`000<007ooOol017oo00<007`0O00077`000<007ooOol0DGoo000?Ool2001AOol00`00O01l
000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00O01l000LO0000`00Oomo
o`1AOol000moo`03001oogoo051oo`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003
001oogoo00Aoo`03001l07`001al0003001oogoo055oo`003goo00<007ooOol0D7oo00<007`0O000
6g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol017oo00<007`0O00077`000<007ooOol0
DGoo000017oo000000000goo0`001Goo00<007ooOol0D7oo00<007`0O0006g`000<007ooOol01Goo
00<007`0O0006g`000<007ooOol017oo00<007`0O00077`000<007ooOol0DGoo0002Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool00`00Oomoo`1@Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l
000KO0000`00Oomoo`04Ool00`00O01l000LO0000`00Oomoo`1AOol0009oo`03001oogoo00Eoo`03
001oogoo009oo`<0051oo`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo
00Aoo`03001l07`001al0003001oogoo055oo`000Woo00<007ooOol00Woo0`001Goo00<007ooOol0
D7oo00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol017oo00<007`0O000
77`000<007ooOol0DGoo0002Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`1@Ool00`00
O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00O01l000LO0000`00
Oomoo`1AOol00003Ool0000000Aoo`@000Aoo`03001oogoo051oo`03001l07`001]l0003001oogoo
00Eoo`03001l07`001]l0003001oogoo00Aoo`03001l07`001al0003001oogoo055oo`003goo00<0
07ooOol0D7oo00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol017oo00<0
07`0O00077`000<007ooOol0DGoo000?Ool2001AOol00`00O01l000KO0000`00Oomoo`05Ool00`00
O01l000KO0000`00Oomoo`04Ool00`00O01l000LO0000`00Oomoo`1AOol000moo`03001oogoo051o
o`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Aoo`03001l07`001al
0003001oogoo055oo`003goo00<007ooOol0D7oo00<007`0O0006g`000<007ooOol01Goo00<007`0
O0006g`000<007ooOol017oo00<007`0O00077`000<007ooOol0DGoo000?Ool00`00Oomoo`1@Ool0
0`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00O01l000LO000
0`00Oomoo`1AOol000moo`03001oogoo051oo`03001l07`001]l0003001oogoo00Eoo`03001l07`0
01]l0003001oogoo00Aoo`03001l07`001al0003001oogoo055oo`003goo0P00DGoo00<007`0O000
6g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol017oo00<007`0O00077`000<007ooOol0
DGoo000?Ool00`00Oomoo`1@Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00
Oomoo`04Ool00`00O01l000LO0000`00Oomoo`1AOol000moo`03001oogoo051oo`03001l07`001]l
0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Aoo`03001l07`001al0003001oogoo055o
o`003goo00<007ooOol0D7oo00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007oo
Ool017oo00<007`0O00077`000<007ooOol0DGoo000?Ool00`00Oomoo`1@Ool00`00O01l000KO000
0`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00O01l000LO0000`00Oomoo`1AOol0
00moo`80055oo`03001l07`001]l0003001oogoo00Eoo`03001l07`001]l0003001oogoo00Aoo`03
001l07`001al0003001oogoo055oo`003goo00<007ooOol0D7oo00<007`0O0006g`000<007ooOol0
1Goo00<007`0O0006g`000<007ooOol017oo00<007`0O00077`000<007ooOol0DGoo000?Ool00`00
Oomoo`1@Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`04Ool00`00
O01l000LO0000`00Oomoo`1AOol000moo`03001oogoo051oo`03001l07`001]l0003001oogoo00Eo
o`03001l07`001]l0003001oogoo00Aoo`03001l07`001al0003001oogoo055oo`003goo00<007oo
Ool0D7oo00<007`0O0006g`000<007ooOol01Goo00<007`0O0006g`000<007ooOol017oo00<007`0
O00077`000<007ooOol0DGoo000?Ool2001AOol00`00O01l000KO0000`00Oomoo`05Ool00`00O01l
000KO0000`00Oomoo`04OolP001COol000moo`03001oogoo051oo`03001l07`001]l0003001oogoo
00Eoo`03001l07`001]l0003001oogoo07Moo`003goo00<007ooOol0D7oo00<007`0O0006g`000<0
07ooOol01Goo00<007`0O0006g`000<007ooOol0Mgoo00000goo000000020003Ool20005Ool00`00
Oomoo`1@Ool00`00O01l000KO0000`00Oomoo`05Ool00`00O01l000KO0000`00Oomoo`1gOol0009o
o`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`1@Ool00`00O01l000KO0000`00Oomoo`05
Ool00`00O01l000KO0000`00Oomoo`1gOol000=oo`05001oogooOol00002Ool00`00Oomoo`02Ool3
001@OolO0007Ool00`00O01l000KO0000`00Oomoo`1gOol000Aoo`04001oogoo0002Ool00`00Oomo
o`02Ool00`00Oomoo`1fOol00`00O01l000KO0000`00Oomoo`1gOol00005Ool007ooOol00002Ool0
1000Oomoo`0017oo00<007ooOol0MWoo00<007`0O0006g`000<007ooOol0Mgoo0002Ool20004Ool2
0005Ool00`00Oomoo`1fOol00`00O01l000KO0000`00Oomoo`1gOol000moo`03001oogoo07Ioo`03
001l07`001]l0003001oogoo07Moo`003goo0P00Mgoo00<007`0O0006g`000<007ooOol0Mgoo000?
Ool00`00Oomoo`1fOol00`00O01l000KO0000`00Oomoo`1gOol000moo`03001oogoo07Ioo`03001l
07`001]l0003001oogoo07Moo`003goo00<007ooOol0MWoo00<007`0O0006g`000<007ooOol0Mgoo
000?Ool00`00Oomoo`1fOol00`00O01l000KO0000`00Oomoo`1gOol000moo`8007Moo`03001l07`0
01]l0003001oogoo07Moo`003goo00<007ooOol0MWoo00<007`0O0006g`000<007ooOol0Mgoo000?
Ool00`00Oomoo`1fOol00`00O01l000KO0000`00Oomoo`1gOol000moo`03001oogoo07Ioo`03001l
07`001]l0003001oogoo07Moo`003goo00<007ooOol0MWoo00<007`0O0006g`000<007ooOol0Mgoo
000?Ool2001gOol00`00O01l000KO0000`00Oomoo`1gOol000moo`03001oogoo07Ioo`03001l07`0
01]l0003001oogoo07Moo`003goo00<007ooOol0MWoo00<007`0O0006g`000<007ooOol0Mgoo000?
Ool00`00Oomoo`1fOol00`00O01l000KO0000`00Oomoo`1gOol000moo`03001oogoo07Ioo`03001l
07`001]l0003001oogoo07Moo`003goo0P00Mgoo00<007`0O0006g`000<007ooOol0Mgoo000?Ool0
0`00Oomoo`1fOol00`00O01l000KO0000`00Oomoo`1gOol000moo`03001oogoo07Ioo`03001l07`0
01]l0003001oogoo07Moo`0000=oo`0000000P000Woo0`001Goo00<007ooOol0MWoo00<007`0O000
6g`000<007ooOol0Mgoo0002Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`1fOol00`00
O01l000KO0000`00Oomoo`1gOol000=oo`03001oogoo00Aoo`03001oogoo009oo`<007Ioo`03001l
07`001]l0003001oogoo07Moo`0017oo00<007ooOol00`001Goo00<007ooOol0MWoo00<007`0O000
6g`000<007ooOol0Mgoo00001Goo001oogoo00000Woo00<007ooOol01Goo00<007ooOol0MWoo00<0
07`0O0006g`000<007ooOol0Mgoo0002Ool20003Ool40004Ool00`00Oomoo`1fOol00`00O01l000K
O0000`00Oomoo`1gOol000moo`03001oogoo07Ioo`03001l07`001]l0003001oogoo07Moo`003goo
0P00Mgoo00<007`0O0006g`000<007ooOol0Mgoo000?Ool00`00Oomoo`1fOol00`00O01l000KO000
0`00Oomoo`1gOol000moo`03001oogoo07Ioo`03001l07`001]l0003001oogoo07Moo`003goo00<0
07ooOol0MWoo00<007`0O0006g`000<007ooOol0Mgoo000?Ool00`00Oomoo`1fOol00`00O01l000K
O0000`00Oomoo`1gOol000moo`8007Moo`03001l07`001]l0003001oogoo07Moo`003goo00<007oo
Ool0MWoo00<007`0O0006g`000<007ooOol0Mgoo000?Ool00`00Oomoo`1fOol00`00O01l000KO000
0`00Oomoo`1gOol000moo`03001oogoo07Ioo`03001l07`001]l0003001oogoo07Moo`003goo00<0
07ooOol0MWoo00<007`0O0006g`000<007ooOol0Mgoo000?Ool2001gOol00`00O01l000KO0000`00
Oomoo`1gOol000moo`03001oogoo07Ioo`03001l07`001]l0003001oogoo07Moo`003goo00<007oo
Ool0MWoo00<007`0O0006g`000<007ooOol0Mgoo000?Ool00`00Oomoo`1fOol00`00O01l000KO000
0`00Oomoo`1gOol000moo`03001oogoo07Ioo`03001l07`001]l0003001oogoo07Moo`003goo0P00
Mgoo00<007`0O0006g`000<007ooOol0Mgoo000?Ool00`00Oomoo`1fOol00`00O01l000KO0000`00
Oomoo`1gOol000moo`03001oogoo07Ioo`03001l07`001]l0003001oogoo07Moo`0000Aoo`000000
00Aoo`8000Eoo`03001oogoo07Ioo`03001l07`001]l0003001oogoo07Moo`0017oo00@007ooOol0
009oo`03001oogoo009oo`03001oogoo07Ioo`03001l07`001]l0003001oogoo07Moo`0017oo00@0
07ooOol0009oo`03001oogoo009oo`<007Ioo`03001l07`001]l0003001oogoo07Moo`000Woo0P00
0goo00@007ooOol000Aoo`03001oogoo07Ioo`03001l07`001]l0003001oogoo07Moo`0017oo00@0
07ooOol0009oo`03001oogoo009oo`03001oogoo07Ioo`03001l07`001]l0003001oogoo07Moo`00
00Aoo`00000000Aoo`8000Eoo`03001oogoo07Ioo`03001l07`001]l0003001oogoo07Moo`003goo
00<007ooOol0MWoo00<007`0O0006g`000<007ooOol0Mgoo000?Ool2001gOol00`00O01l000KO000
0`00Oomoo`1gOol000moo`03001oogoo07Ioo`03001l07`001]l0003001oogoo07Moo`003goo00<0
07ooOol0MWoo00<007`0O0006g`000<007ooOol0Mgoo000?Ool00`00Oomoo`1fOol00`00O01l000K
O0000`00Oomoo`1gOol000moo`03001oogoo07Ioo`03001l07`001]l0003001oogoo07Moo`003goo
0P00Mgoo7`00NGoo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<0
07ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.00814839, -2.54908, 
  0.0265093, 0.200167}}]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(CoalescenceDistribution[j, k, 
              t]\), \(is\ the\ probability\ of\ j\ lineages\ surviving\ from\ \
among\ k\ lineages\ over\ t\ generations\ \((scaled\ relative\ to\ 2  
                  N)\)\)},
          {\(B[j, i, 
              k]\), \(is\ the\ coefficient\ of\ Exp[\(-\[Lambda]\_i\) t/2  
                  N]\ in\ the\ expression\ for\ P\_j, \ 
            the\ probability\ of\ j\ coalescences\ having\ \
\(\(occurred\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"CoalescenceDistribution", "B"}],

Cell["\<\
This is the probability that 2 lineages survive among 10 lineages, \
tracing back for (scaled) time t.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoalescenceDistribution[2, 10, t]\)], "Input",
  CellLabel->"In[174]:="],

Cell[BoxData[
    \(\(45\ E\^\(\(-45\)\ t\)\)\/4862 - \(18\ E\^\(\(-36\)\ t\)\)\/143 + 
      \(1890\ E\^\(\(-28\)\ t\)\)\/2431 - \(63\ E\^\(\(-21\)\ t\)\)\/22 + 
      \(90\ E\^\(\(-15\)\ t\)\)\/13 - \(1620\ E\^\(\(-10\)\ t\)\)\/143 + 
      \(1764\ E\^\(\(-6\)\ t\)\)\/143 - \(90\ E\^\(\(-3\)\ t\)\)\/11 + 
      \(27\ E\^\(-t\)\)\/11\)], "Output",
  CellLabel->"Out[174]="]
}, Closed]],

Cell[TextData[{
  "The number of families, ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ", from which a set ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " of genes descend, can be found from the recursion:\n",
  Cell[BoxData[
      \(\[PartialD]\_t P\_j = \ 
        \(\(\[Lambda]\_\(j + 1\)\) P\_\(j + 1\) - 
            \(\[Lambda]\_j\) P\_j\ \ with\ P\_j[0] = 
          \(\[Delta]\_jk\ \ \[Lambda]\_j = \ 
            \(\((j - 1)\) j\)\/\(4  N\)\)\)\)], "DisplayFormula"],
  "\nThis has the solution:\n",
  Cell[BoxData[
      \(P\_j = \ 
        \(\(\[Sum]\+\(i = j\)\)\&k\( B\_\(j, i\)\) Exp[\(-\[Lambda]\_i\) t]\ 
              \n\t\t\t\t\ with\ B\_\(j, i\) = \ 
          \(\[Lambda]\_\(j + 1\)\/\(\[Lambda]\_j - \[Lambda]\_i\) = \ 
            \(j \((j + 1)\)\)\/\(j \((j - 1)\) - i \((i - 1)\)\)\ 
              \((i > j)\)\)\), \ 
      B\_\(j, j\) = \(-\(\(\[Sum]\+\(i = j + 1\)\)\&k B\_\(j, i\)\)\), \ 
      B\_\(k, k\) = 1\)], "DisplayFormula"],
  "\nThe expected pairwise identity is 1-Exp[-t/2N], and so the above could \
be rewritten as a function of this expected identity. "
}], "Text"],

Cell["The distribution does add up to 1", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[CoalescenceDistribution[j, 10, t], {j, 1, 10}]\)], "Input",
  CellLabel->"In[175]:="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[175]="]
}, Closed]],

Cell["It also satisfies the differential equations:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[PartialD]\_t CoalescenceDistribution[2, 4, t] - 
        \((3  CoalescenceDistribution[3, 4, t] - 
            CoalescenceDistribution[2, 4, t])\) // Expand\)], "Input",
  CellLabel->"In[176]:="],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[176]="]
}, Closed]],

Cell[TextData[{
  "This shows the distribution of the probabilities that 1, 2, \[Ellipsis]10 \
lineages remain ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " generations back; note the logarithmic timescale.  For small ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " (left of plot) it is almost certain that all 10 survive; for large ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(t, \)\ \)\)]],
  "it is likely that only one does."
}], "Text"],

Cell[BoxData[
    \(\(<< Graphics`Graphics`; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(LogLinearPlot[
      Table[CoalescenceDistribution[j, 10, t], {j, 1, 10}] // Evaluate, {t, 
        0, 10}, PlotRange -> {{0.001, 10}, {0, 1}}, PlotPoints -> 400]; 
    \)\)], "Input",
  CellLabel->"In[177]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.75 0.25 0 0.618034 [
[.25 -0.0125 -14 -12 ]
[.25 -0.0125 14 0 ]
[.5 -0.0125 -11 -12 ]
[.5 -0.0125 11 0 ]
[.75 -0.0125 -5 -12 ]
[.75 -0.0125 5 0 ]
[1 -0.0125 -8 -12 ]
[1 -0.0125 8 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25 0 m
.25 .00625 L
s
gsave
.25 -0.0125 -75 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
87.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -72 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.75 0 m
.75 .00625 L
s
gsave
.75 -0.0125 -66 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -69 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
.07526 0 m
.07526 .00375 L
s
.11928 0 m
.11928 .00375 L
s
.15051 0 m
.15051 .00375 L
s
.17474 0 m
.17474 .00375 L
s
.19454 0 m
.19454 .00375 L
s
.21127 0 m
.21127 .00375 L
s
.22577 0 m
.22577 .00375 L
s
.23856 0 m
.23856 .00375 L
s
.32526 0 m
.32526 .00375 L
s
.36928 0 m
.36928 .00375 L
s
.40051 0 m
.40051 .00375 L
s
.42474 0 m
.42474 .00375 L
s
.44454 0 m
.44454 .00375 L
s
.46127 0 m
.46127 .00375 L
s
.47577 0 m
.47577 .00375 L
s
.48856 0 m
.48856 .00375 L
s
.57526 0 m
.57526 .00375 L
s
.61928 0 m
.61928 .00375 L
s
.65051 0 m
.65051 .00375 L
s
.67474 0 m
.67474 .00375 L
s
.69454 0 m
.69454 .00375 L
s
.71127 0 m
.71127 .00375 L
s
.72577 0 m
.72577 .00375 L
s
.73856 0 m
.73856 .00375 L
s
.82526 0 m
.82526 .00375 L
s
.86928 0 m
.86928 .00375 L
s
.90051 0 m
.90051 .00375 L
s
.92474 0 m
.92474 .00375 L
s
.94454 0 m
.94454 .00375 L
s
.96127 0 m
.96127 .00375 L
s
.97577 0 m
.97577 .00375 L
s
.98856 0 m
.98856 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03792 0 m
.0855 0 L
.1169 0 L
.13958 0 L
.157 0 L
.17336 0 L
s
.20161 0 m
.21425 0 L
.22497 0 L
.23393 0 L
.24353 0 L
.24862 0 L
.25313 0 L
.26094 0 L
.26869 0 L
.27239 0 L
.27616 0 L
.28261 0 L
.28604 0 L
.28914 0 L
.29245 0 L
.29589 0 L
.29877 0 L
.30182 0 L
.30714 0 L
.31209 0 L
.31648 0 L
.32057 0 L
.32427 0 L
.32819 0 L
.33227 0 L
.33616 0 L
.34012 0 L
.34339 0 L
.34685 0 L
.35062 0 L
.35456 0 L
.35816 0 L
.36138 0 L
.36419 0 L
.36721 0 L
.37028 0 L
.37307 0 L
.37624 0 L
.37917 0 L
.38445 0 L
.3873 0 L
.38987 0 L
.3926 0 L
.39548 0 L
.40015 0 L
.40437 0 L
.40833 0 L
.41184 0 L
.41553 0 L
.41944 0 L
Mistroke
.42338 0 L
.42692 0 L
.43037 0 L
.43347 0 L
.43677 0 L
.44016 0 L
.44563 0 L
.44863 0 L
.45136 0 L
.45626 0 L
.46056 0 L
.46509 0 L
.46966 0 L
.47412 0 L
.47801 0 L
.48233 0 L
.48626 0 L
.48978 0 L
.49292 0 L
.4997 0 L
.50287 0 L
.50618 0 L
.51191 0 L
.51527 0 L
.51835 0 L
.52391 0 L
.52909 1e-05 L
.53434 1e-05 L
.53862 1e-05 L
.54317 2e-05 L
.54772 2e-05 L
.55173 3e-05 L
.55597 4e-05 L
.56026 5e-05 L
.56395 6e-05 L
.56776 8e-05 L
.5743 .00011 L
.57778 .00014 L
.58144 .00017 L
.58777 .00024 L
.59368 .00034 L
.5996 .00047 L
.60483 .00062 L
.6095 .0008 L
.6188 .00128 L
.62355 .00163 L
.62788 .00201 L
.63566 .00292 L
.64337 .00416 L
.65031 .00566 L
Mistroke
.65723 .00761 L
.66351 .00986 L
.66922 .01238 L
.67499 .01547 L
.68026 .01884 L
.6851 .02245 L
.69003 .02668 L
.69457 .03113 L
.6992 .03625 L
.70348 .04155 L
.70744 .04697 L
.71151 .05307 L
.71528 .05924 L
.71879 .06543 L
.72241 .07228 L
.72578 .0791 L
.72925 .08657 L
.73249 .09397 L
.73552 .10124 L
.73865 .10913 L
.74159 .11686 L
.74462 .12518 L
.74747 .13329 L
.75013 .14116 L
.7529 .14959 L
.7555 .15775 L
.75795 .16561 L
.76049 .17399 L
.76288 .18205 L
.76537 .1906 L
.76771 .19881 L
.76992 .20667 L
.77221 .21498 L
.77438 .22292 L
.77664 .2313 L
.77877 .23929 L
.78079 .24691 L
.78289 .25492 L
.78487 .26254 L
.78675 .26978 L
.78871 .27739 L
.79057 .28461 L
.7925 .29218 L
.79434 .29936 L
.79608 .30615 L
.79789 .31327 L
.79962 .32001 L
.80125 .32639 L
.80295 .33306 L
.80457 .33936 L
Mistroke
.80627 .34594 L
.80788 .35217 L
.80941 .35804 L
.81101 .36417 L
.81252 .36996 L
.81412 .37599 L
.81563 .38167 L
.81706 .38704 L
.81857 .39263 L
.82 .39789 L
.82135 .40286 L
.82278 .40803 L
.82414 .4129 L
.82556 .41797 L
.82691 .42275 L
.8282 .42724 L
.82955 .43192 L
.83084 .43632 L
.83206 .44046 L
.83335 .44478 L
.83457 .44884 L
.83586 .45305 L
.83708 .45702 L
.83825 .46076 L
.83947 .46464 L
.84064 .46829 L
.84187 .47208 L
.84304 .47564 L
.84415 .47899 L
.84532 .48247 L
.84644 .48575 L
.8475 .48882 L
.84862 .49202 L
.84969 .49502 L
.85082 .49814 L
.85189 .50107 L
.85291 .50383 L
.85398 .50669 L
.85501 .50938 L
.85609 .51217 L
.85712 .51479 L
.8581 .51725 L
.85914 .5198 L
.86012 .5222 L
.86107 .52446 L
.86206 .5268 L
.86301 .529 L
.864 .53128 L
.86496 .53342 L
.86587 .53543 L
Mistroke
.86682 .53752 L
.86774 .53948 L
.86861 .54133 L
.86953 .54324 L
.87041 .54504 L
.87134 .5469 L
.87223 .54865 L
.87307 .5503 L
.87397 .55201 L
.87482 .55361 L
.87572 .55527 L
.87657 .55683 L
.87739 .5583 L
.87826 .55982 L
.87909 .56124 L
.87988 .56259 L
.88071 .56398 L
.88151 .56528 L
.88235 .56664 L
.88315 .56791 L
.88392 .56911 L
.88473 .57035 L
.8855 .57151 L
.88624 .5726 L
.88703 .57374 L
.88777 .57481 L
.88856 .57591 L
.88932 .57695 L
.89004 .57792 L
.8908 .57894 L
.89153 .57989 L
.8923 .58087 L
.89303 .58179 L
.89374 .58266 L
.89448 .58356 L
.89519 .58441 L
.89587 .5852 L
.89659 .58603 L
.89728 .5868 L
.898 .5876 L
.8987 .58835 L
.89936 .58906 L
.90006 .5898 L
.90074 .59048 L
.90144 .5912 L
.90212 .59187 L
.90277 .5925 L
.90346 .59315 L
.90412 .59376 L
.90474 .59434 L
Mistroke
.90541 .59493 L
.90604 .5955 L
.90672 .59608 L
.90736 .59662 L
.90798 .59713 L
.90863 .59767 L
.90925 .59816 L
.90984 .59863 L
.91048 .59912 L
.91108 .59957 L
.91172 .60005 L
.91233 .60049 L
.91291 .60091 L
.91353 .60134 L
.91412 .60175 L
.91475 .60217 L
.91535 .60257 L
.91592 .60294 L
.91653 .60332 L
.91711 .60368 L
.91767 .60402 L
.91826 .60438 L
.91882 .60471 L
.91942 .60505 L
.91999 .60537 L
.92053 .60567 L
.92111 .60599 L
.92167 .60628 L
.92225 .60659 L
.92282 .60687 L
.92335 .60714 L
.92392 .60742 L
.92447 .60768 L
.92499 .60793 L
.92554 .60818 L
.92607 .60842 L
.92663 .60867 L
.92717 .6089 L
.92768 .60912 L
.92822 .60935 L
.92875 .60956 L
.92924 .60976 L
.92977 .60997 L
.93028 .61017 L
.93081 .61037 L
.93133 .61056 L
.93182 .61074 L
.93234 .61092 L
.93284 .61109 L
.93337 .61127 L
Mistroke
.93387 .61144 L
.93436 .6116 L
.93487 .61177 L
.93536 .61192 L
.93583 .61206 L
.93633 .61221 L
.93681 .61236 L
.93732 .6125 L
.9378 .61264 L
.93827 .61277 L
.93876 .6129 L
.93923 .61303 L
.93968 .61315 L
.94016 .61327 L
.94062 .61338 L
.94111 .6135 L
.94157 .61361 L
.94202 .61372 L
.94249 .61383 L
.94295 .61393 L
.94343 .61404 L
.94389 .61414 L
.94433 .61423 L
.9448 .61433 L
.94524 .61442 L
.94567 .6145 L
.94613 .61459 L
.94656 .61468 L
.94703 .61476 L
.94747 .61484 L
.94789 .61492 L
.94834 .615 L
.94877 .61507 L
.94923 .61515 L
.94967 .61522 L
.95009 .61529 L
.95053 .61536 L
.95096 .61543 L
.95137 .61549 L
.9518 .61555 L
.95222 .61561 L
.95266 .61567 L
.95308 .61573 L
.95348 .61579 L
.95391 .61584 L
.95432 .6159 L
.95472 .61595 L
.95513 .616 L
.95553 .61605 L
.95596 .6161 L
Mistroke
.95637 .61615 L
.95676 .61619 L
.95717 .61624 L
.95757 .61628 L
.95799 .61633 L
.95839 .61637 L
.95878 .61641 L
.95919 .61645 L
.95958 .61649 L
.95996 .61653 L
.96036 .61657 L
.96074 .6166 L
.96114 .61664 L
.96153 .61667 L
.96191 .61671 L
.9623 .61674 L
.96268 .61677 L
.96309 .6168 L
.96347 .61684 L
.96384 .61686 L
.96423 .61689 L
.96461 .61692 L
.96497 .61695 L
.96535 .61698 L
.96572 .617 L
.96611 .61703 L
.96648 .61705 L
.96684 .61708 L
.96722 .6171 L
.96759 .61712 L
.96793 .61715 L
.96831 .61717 L
.96866 .61719 L
.96904 .61721 L
.9694 .61723 L
.96975 .61725 L
.97011 .61727 L
.97047 .61729 L
.97084 .61731 L
.9712 .61733 L
.97154 .61734 L
.97191 .61736 L
.97226 .61738 L
.97259 .61739 L
.97295 .61741 L
.97329 .61742 L
.97365 .61744 L
.974 .61745 L
.97433 .61747 L
.97469 .61748 L
Mistroke
.97503 .6175 L
.97535 .61751 L
.9757 .61752 L
.97603 .61753 L
.97638 .61755 L
.97672 .61756 L
.97704 .61757 L
.97738 .61758 L
.97771 .61759 L
.97806 .6176 L
.9784 .61762 L
.97872 .61763 L
.97906 .61764 L
.97939 .61765 L
.9797 .61765 L
.98003 .61766 L
.98035 .61767 L
.98069 .61768 L
.98102 .61769 L
.98133 .6177 L
.98166 .61771 L
.98198 .61772 L
.98231 .61772 L
.98264 .61773 L
.98295 .61774 L
.98327 .61775 L
.98359 .61775 L
.98389 .61776 L
.98421 .61777 L
.98452 .61777 L
.98485 .61778 L
.98516 .61779 L
.98547 .61779 L
.98579 .6178 L
.98609 .6178 L
.98639 .61781 L
.9867 .61782 L
.987 .61782 L
.98732 .61783 L
.98762 .61783 L
.98791 .61784 L
.98823 .61784 L
.98852 .61785 L
.98884 .61785 L
.98914 .61786 L
.98944 .61786 L
.98974 .61786 L
.99004 .61787 L
.99033 .61787 L
.99063 .61788 L
Mistroke
.99092 .61788 L
.99123 .61788 L
.99152 .61789 L
.99181 .61789 L
.99211 .6179 L
.99239 .6179 L
.99267 .6179 L
.99297 .61791 L
.99325 .61791 L
.99355 .61791 L
.99384 .61791 L
.99411 .61792 L
.9944 .61792 L
.99469 .61792 L
.99498 .61793 L
.99527 .61793 L
.99555 .61793 L
.99584 .61793 L
.99612 .61794 L
.99639 .61794 L
.99667 .61794 L
.99695 .61794 L
.99724 .61795 L
.99751 .61795 L
.99778 .61795 L
.99807 .61795 L
.99834 .61795 L
.99863 .61796 L
.99891 .61796 L
.99917 .61796 L
.99946 .61796 L
.99973 .61796 L
.99999 .61797 L
1 .61797 L
Mfstroke
.03792 0 m
.08288 0 L
.1169 0 L
.14104 0 L
.15938 0 L
.17443 0 L
.18838 0 L
.20161 0 L
.21425 0 L
.22497 0 L
.23393 0 L
.24353 0 L
.24862 0 L
.25313 0 L
.26094 0 L
.26869 0 L
.27239 0 L
.27616 0 L
.28261 0 L
.28604 0 L
.28914 0 L
.29245 0 L
.29589 0 L
.29877 0 L
.30182 0 L
.30714 0 L
.31209 0 L
.31648 0 L
.32057 0 L
.32427 0 L
.32819 0 L
.33227 0 L
.33616 0 L
.34012 0 L
.34339 0 L
.34685 0 L
.35062 0 L
.35456 0 L
.35816 0 L
.36138 0 L
.36721 0 L
.37004 0 L
.37307 0 L
.3791 0 L
.38234 0 L
.38522 0 L
.39061 0 L
.39548 0 L
.39978 0 L
.40417 0 L
Mistroke
.40817 0 L
.41166 0 L
.41564 0 L
.41979 0 L
.42356 0 L
.42692 0 L
.43308 0 L
.43638 0 L
.43931 0 L
.44478 0 L
.44971 0 L
.45518 0 L
.46 1e-05 L
.46506 1e-05 L
.47018 1e-05 L
.47452 2e-05 L
.47835 2e-05 L
.4824 2e-05 L
.4865 3e-05 L
.49308 5e-05 L
.49664 6e-05 L
.49985 7e-05 L
.50327 8e-05 L
.50686 .0001 L
.51308 .00015 L
.51882 .00021 L
.52384 .00027 L
.52906 .00036 L
.53373 .00047 L
.53862 .00061 L
.54364 .00079 L
.5482 .001 L
.55296 .00128 L
.55691 .00156 L
.56112 .00192 L
.56857 .00276 L
.57597 .00391 L
.58236 .00524 L
.58885 .00699 L
.59475 .00902 L
.60063 .01154 L
.6105 .01716 L
.62011 .0247 L
.62861 .03348 L
.63698 .04438 L
.64447 .05627 L
.65123 .06884 L
.65797 .08322 L
.6641 .09783 L
.66968 .11238 L
Mistroke
.67532 .1282 L
.68049 .14354 L
.68573 .15978 L
.69054 .17518 L
.69498 .18961 L
.69951 .20444 L
.70371 .2181 L
.70799 .23185 L
.71196 .24428 L
.71565 .25544 L
.71945 .26642 L
.72298 .27609 L
.72627 .28456 L
.72967 .29269 L
.73284 .29964 L
.73611 .30614 L
.73918 .31154 L
.74204 .31596 L
.74501 .31989 L
.7478 .32293 L
.75041 .32522 L
.75183 .32623 L
.75312 .32699 L
.75445 .32764 L
.75567 .3281 L
.7569 .32844 L
.75754 .32857 L
.7579 .32862 L
.75822 .32866 L
.75854 .32869 L
.75887 .32872 L
.75904 .32873 L
.75921 .32873 L
.7593 .32874 L
.75938 .32874 L
.75943 .32874 L
.75948 .32874 L
.75953 .32874 L
.75957 .32874 L
.75965 .32874 L
.7597 .32874 L
.75974 .32874 L
.75981 .32874 L
.75989 .32873 L
.76003 .32873 L
.76018 .32872 L
.76034 .32871 L
.76052 .3287 L
.76083 .32867 L
.76116 .32863 L
Mistroke
.76146 .32859 L
.76214 .32846 L
.76274 .32832 L
.76337 .32813 L
.76564 .3272 L
.76679 .32656 L
.76801 .32577 L
.77037 .32389 L
.77261 .32172 L
.77471 .31931 L
.77691 .31645 L
.77898 .31343 L
.78114 .30996 L
.78319 .30639 L
.78512 .30277 L
.78713 .29875 L
.78904 .29472 L
.79084 .29072 L
.79272 .28636 L
.79451 .28207 L
.79638 .27742 L
.79814 .27287 L
.79982 .26845 L
.80157 .26371 L
.80323 .25911 L
.8048 .25468 L
.80645 .24994 L
.80802 .24539 L
.80966 .24056 L
.81122 .23592 L
.81269 .23148 L
.81424 .22678 L
.81571 .22229 L
.81726 .21756 L
.81872 .21305 L
.82011 .20875 L
.82157 .20423 L
.82296 .19992 L
.82428 .19584 L
.82567 .19155 L
.82698 .18748 L
.82837 .18321 L
.82968 .17917 L
.83094 .17534 L
.83225 .17133 L
.8335 .16754 L
.83482 .16358 L
.83607 .15984 L
.83726 .1563 L
.83851 .1526 L
Mistroke
.83971 .14911 L
.84084 .14582 L
.84204 .14238 L
.84318 .13913 L
.84437 .13575 L
.84551 .13257 L
.8466 .12956 L
.84774 .12643 L
.84883 .12348 L
.84987 .1207 L
.85097 .1178 L
.85201 .11507 L
.85311 .11223 L
.85415 .10956 L
.85515 .10704 L
.8562 .10442 L
.85721 .10196 L
.85826 .0994 L
.85927 .09699 L
.86023 .09472 L
.86124 .09237 L
.86221 .09015 L
.86313 .08807 L
.8641 .0859 L
.86503 .08386 L
.86601 .08174 L
.86694 .07975 L
.86783 .07788 L
.86877 .07594 L
.86967 .07411 L
.87053 .0724 L
.87143 .07061 L
.87229 .06893 L
.8732 .06719 L
.87407 .06555 L
.8749 .06401 L
.87578 .06242 L
.87661 .06091 L
.87749 .05936 L
.87834 .05789 L
.87914 .05652 L
.87999 .05509 L
.8808 .05375 L
.88158 .05249 L
.8824 .05118 L
.88318 .04995 L
.88401 .04868 L
.8848 .04748 L
.88555 .04636 L
.88635 .04519 L
Mistroke
.88711 .04409 L
.88791 .04295 L
.88868 .04189 L
.88942 .04088 L
.89019 .03984 L
.89094 .03887 L
.89164 .03795 L
.89239 .03699 L
.89311 .0361 L
.89387 .03517 L
.89459 .0343 L
.89528 .03348 L
.89601 .03263 L
.89671 .03184 L
.89738 .03109 L
.89809 .03031 L
.89877 .02958 L
.89948 .02882 L
.90016 .02811 L
.90082 .02745 L
.90151 .02675 L
.90217 .0261 L
.90287 .02543 L
.90354 .0248 L
.90418 .0242 L
.90485 .02359 L
.9055 .02301 L
.90612 .02246 L
.90677 .0219 L
.9074 .02137 L
.90806 .02082 L
.9087 .0203 L
.9093 .01982 L
.90994 .01932 L
.91056 .01885 L
.91121 .01836 L
.91183 .0179 L
.91242 .01747 L
.91305 .01702 L
.91366 .0166 L
.91423 .01621 L
.91484 .0158 L
.91543 .01541 L
.91604 .01502 L
.91663 .01464 L
.9172 .01429 L
.9178 .01393 L
.91837 .01359 L
.91892 .01327 L
.9195 .01293 L
Mistroke
.92006 .01262 L
.92065 .0123 L
.92121 .01199 L
.92175 .01171 L
.92232 .01141 L
.92287 .01113 L
.92345 .01084 L
.924 .01057 L
.92453 .01032 L
.92509 .01006 L
.92563 .00981 L
.92615 .00958 L
.92669 .00934 L
.92721 .00911 L
.92777 .00887 L
.9283 .00865 L
.9288 .00845 L
.92934 .00823 L
.92986 .00803 L
.93035 .00784 L
.93087 .00765 L
.93137 .00746 L
.9319 .00727 L
.93241 .00709 L
.93289 .00692 L
.93341 .00675 L
.9339 .00658 L
.93442 .00641 L
.93492 .00625 L
.9354 .0061 L
.93591 .00595 L
.93639 .0058 L
.93686 .00566 L
.93735 .00552 L
.93783 .00539 L
.93833 .00525 L
.93881 .00512 L
.93926 .005 L
.93975 .00487 L
.94022 .00475 L
.94071 .00463 L
.94119 .00451 L
.94164 .0044 L
.94212 .00429 L
.94258 .00419 L
.94302 .00409 L
.94349 .00398 L
.94394 .00389 L
.94441 .00379 L
.94487 .00369 L
Mistroke
.9453 .0036 L
.94577 .00351 L
.94621 .00343 L
.94663 .00335 L
.94708 .00326 L
.94752 .00318 L
.94797 .0031 L
.94841 .00302 L
.94883 .00295 L
.94928 .00288 L
.9497 .00281 L
.95015 .00273 L
.95059 .00267 L
.951 .0026 L
.95144 .00254 L
.95186 .00247 L
.95227 .00241 L
.9527 .00235 L
.95311 .0023 L
.95354 .00224 L
.95396 .00218 L
.95436 .00213 L
.95479 .00208 L
.95519 .00203 L
.95562 .00197 L
.95604 .00192 L
.95643 .00188 L
.95685 .00183 L
.95726 .00178 L
.95764 .00174 L
.95805 .0017 L
.95844 .00166 L
.95886 .00161 L
.95926 .00157 L
.95964 .00154 L
.96005 .0015 L
.96044 .00146 L
.96081 .00143 L
.96121 .00139 L
.96159 .00136 L
.96199 .00132 L
.96237 .00129 L
.96274 .00126 L
.96313 .00123 L
.96351 .0012 L
.96391 .00116 L
.96429 .00114 L
.96466 .00111 L
.96505 .00108 L
.96542 .00105 L
Mistroke
.96578 .00103 L
.96616 .001 L
.96652 .00098 L
.96691 .00095 L
.96728 .00093 L
.96763 .00091 L
.96801 .00088 L
.96837 .00086 L
.96871 .00084 L
.96908 .00082 L
.96943 .0008 L
.9698 .00078 L
.97016 .00076 L
.97051 .00074 L
.97087 .00072 L
.97122 .00071 L
.97159 .00069 L
.97195 .00067 L
.97229 .00066 L
.97265 .00064 L
.973 .00062 L
.97333 .00061 L
.97368 .00059 L
.97402 .00058 L
.97438 .00056 L
.97472 .00055 L
.97505 .00054 L
.9754 .00052 L
.97574 .00051 L
.9761 .0005 L
.97644 .00048 L
.97677 .00047 L
.97712 .00046 L
.97745 .00045 L
.97777 .00044 L
.97811 .00043 L
.97844 .00042 L
.97878 .00041 L
.97911 .0004 L
.97943 .00039 L
.97977 .00038 L
.9801 .00037 L
.98041 .00036 L
.98074 .00035 L
.98105 .00034 L
.98139 .00033 L
.98171 .00032 L
.98202 .00032 L
.98235 .00031 L
.98266 .0003 L
Mistroke
.983 .00029 L
.98332 .00029 L
.98363 .00028 L
.98395 .00027 L
.98426 .00027 L
.98457 .00026 L
.98488 .00025 L
.98519 .00025 L
.98551 .00024 L
.98583 .00023 L
.98612 .00023 L
.98644 .00022 L
.98675 .00022 L
.98704 .00021 L
.98735 .00021 L
.98764 .0002 L
.98796 .0002 L
.98826 .00019 L
.98855 .00019 L
.98886 .00018 L
.98916 .00018 L
.98947 .00017 L
.98977 .00017 L
.99006 .00017 L
.99037 .00016 L
.99066 .00016 L
.99095 .00015 L
.99125 .00015 L
.99153 .00015 L
.99184 .00014 L
.99213 .00014 L
.99241 .00014 L
.99271 .00013 L
.993 .00013 L
.9933 .00013 L
.99359 .00012 L
.99387 .00012 L
.99417 .00012 L
.99446 .00011 L
.99473 .00011 L
.99502 .00011 L
.9953 .00011 L
.9956 .0001 L
.99588 .0001 L
.99615 .0001 L
.99644 .0001 L
.99672 9e-05 L
.99699 9e-05 L
.99727 9e-05 L
.99754 9e-05 L
Mistroke
.99783 8e-05 L
.99811 8e-05 L
.99837 8e-05 L
.99866 8e-05 L
.99893 8e-05 L
.99921 7e-05 L
.99949 7e-05 L
.99975 7e-05 L
1 7e-05 L
Mfstroke
0 0 m
.03792 0 L
.0855 0 L
.1169 0 L
.13958 0 L
.157 0 L
.17336 0 L
.18838 0 L
.20161 0 L
.21425 0 L
.22497 0 L
.23393 0 L
.24353 0 L
.24862 0 L
.25313 0 L
.26094 0 L
.26869 0 L
.27239 0 L
.27616 0 L
.28261 0 L
.28604 0 L
.28914 0 L
.29266 0 L
.29589 0 L
.30147 0 L
.30631 0 L
.3113 0 L
.31648 0 L
.32059 0 L
.32496 0 L
.32935 0 L
.33331 0 L
.34004 0 L
.34365 0 L
.34685 0 L
.35354 0 L
.35711 0 L
.36026 0 L
.36613 0 L
.3714 0 L
.37724 0 L
.38236 0 L
.38772 0 L
.39312 1e-05 L
.39772 1e-05 L
.40246 1e-05 L
.40675 1e-05 L
.41053 1e-05 L
.41478 2e-05 L
.41924 2e-05 L
Mistroke
.423 3e-05 L
.42692 3e-05 L
.43386 5e-05 L
.44 7e-05 L
.44567 9e-05 L
.45063 .00012 L
.45577 .00016 L
.46114 .00022 L
.46647 .00028 L
.47122 .00036 L
.47562 .00045 L
.48021 .00057 L
.48807 .00084 L
.49522 .00119 L
.50143 .00161 L
.50777 .00216 L
.5134 .0028 L
.51926 .00364 L
.52523 .00474 L
.53563 .00739 L
.5405 .00903 L
.54558 .01109 L
.5541 .01547 L
.5625 .02118 L
.57045 .02811 L
.57744 .03565 L
.58967 .05254 L
.60132 .07348 L
.61147 .09562 L
.62041 .11781 L
.62919 .14143 L
.63701 .16333 L
.64475 .18495 L
.65172 .2036 L
.65803 .21918 L
.66436 .23301 L
.67012 .24357 L
.67539 .25121 L
.67821 .25442 L
.68073 .25675 L
.68315 .25848 L
.68434 .25915 L
.68564 .25973 L
.68629 .25997 L
.6869 .26016 L
.68746 .2603 L
.68804 .26042 L
.68834 .26047 L
.68867 .26051 L
.68897 .26055 L
Mistroke
.68925 .26057 L
.68942 .26058 L
.68958 .26059 L
.68966 .26059 L
.68974 .2606 L
.68983 .2606 L
.68992 .2606 L
.69001 .2606 L
.69009 .2606 L
.69018 .2606 L
.69025 .2606 L
.6904 .26059 L
.69055 .26059 L
.6907 .26058 L
.69085 .26057 L
.69114 .26055 L
.69141 .26052 L
.69167 .26048 L
.69225 .26038 L
.69286 .26024 L
.69386 .25994 L
.69496 .25951 L
.69715 .25833 L
.69945 .25663 L
.70386 .2521 L
.70794 .24646 L
.71172 .24007 L
.71561 .23244 L
.71923 .22445 L
.72294 .21548 L
.7264 .20649 L
.72964 .19767 L
.73297 .1882 L
.73609 .17909 L
.739 .17041 L
.74202 .16132 L
.74485 .15277 L
.74778 .14393 L
.75053 .1357 L
.75311 .12807 L
.75579 .12027 L
.75831 .11309 L
.76092 .10581 L
.76339 .09915 L
.7657 .09305 L
.76811 .08691 L
.77038 .08132 L
.77253 .07624 L
.77476 .07114 L
.77687 .06651 L
Mistroke
.77906 .06189 L
.78114 .05771 L
.7831 .05393 L
.78514 .05017 L
.78708 .04677 L
.7889 .04371 L
.79082 .04066 L
.79263 .03791 L
.79452 .03519 L
.79631 .03274 L
.79801 .03054 L
.79978 .02835 L
.80146 .02639 L
.80322 .02445 L
.80489 .02271 L
.80648 .02115 L
.80813 .0196 L
.80971 .01822 L
.8112 .01698 L
.81277 .01575 L
.81425 .01465 L
.81581 .01357 L
.81729 .01259 L
.81869 .01172 L
.82017 .01086 L
.82157 .01009 L
.8229 .0094 L
.8243 .00872 L
.82563 .00811 L
.82703 .00751 L
.82835 .00697 L
.82962 .00649 L
.83094 .00601 L
.83221 .00559 L
.83353 .00517 L
.83479 .00479 L
.836 .00446 L
.83726 .00413 L
.83846 .00383 L
.8396 .00357 L
.84081 .0033 L
.84196 .00307 L
.84316 .00284 L
.84431 .00264 L
.84541 .00245 L
.84656 .00227 L
.84766 .00211 L
.84881 .00195 L
.84991 .00181 L
.85096 .00168 L
Mistroke
.85207 .00155 L
.85312 .00144 L
.85412 .00134 L
.85518 .00124 L
.85619 .00115 L
.85725 .00107 L
.85827 .00099 L
.85923 .00092 L
.86025 .00085 L
.86123 .00079 L
.86215 .00074 L
.86313 .00068 L
.86406 .00063 L
.86505 .00059 L
.86598 .00054 L
.86688 .00051 L
.86782 .00047 L
.86873 .00044 L
.86968 .0004 L
.87058 .00037 L
.87145 .00035 L
.87236 .00032 L
.87324 .0003 L
.87407 .00028 L
.87495 .00026 L
.87579 .00024 L
.87667 .00022 L
.87752 .0002 L
.87833 .00019 L
.87918 .00018 L
.88 .00016 L
.88078 .00015 L
.8816 .00014 L
.88238 .00013 L
.88321 .00012 L
.88401 .00011 L
.88476 .0001 L
.88556 .0001 L
.88633 9e-05 L
.88713 8e-05 L
.88791 8e-05 L
.88864 7e-05 L
.88942 7e-05 L
.89017 6e-05 L
.89088 6e-05 L
.89163 5e-05 L
.89235 5e-05 L
.89311 5e-05 L
.89384 4e-05 L
.89453 4e-05 L
Mistroke
.89526 4e-05 L
.89597 3e-05 L
.89671 3e-05 L
.89742 3e-05 L
.89809 3e-05 L
.89881 2e-05 L
.8995 2e-05 L
.90015 2e-05 L
.90084 2e-05 L
.90151 2e-05 L
.90221 2e-05 L
.90288 2e-05 L
.90352 1e-05 L
.9042 1e-05 L
.90485 1e-05 L
.90547 1e-05 L
.90612 1e-05 L
.90675 1e-05 L
.90742 1e-05 L
.90805 1e-05 L
.90866 1e-05 L
.9093 1e-05 L
.90992 1e-05 L
.91057 1e-05 L
.91119 1e-05 L
.91179 1e-05 L
.91242 1e-05 L
.91302 0 L
.9136 0 L
.91421 0 L
.9148 0 L
.91542 0 L
.91601 0 L
.91658 0 L
.91718 0 L
.91775 0 L
.91836 0 L
.91894 0 L
.9195 0 L
.92009 0 L
.92065 0 L
.92119 0 L
.92176 0 L
.92231 0 L
.92289 0 L
.92345 0 L
.92398 0 L
.92454 0 L
.92508 0 L
.92559 0 L
Mistroke
.92614 0 L
.92666 0 L
.92722 0 L
.92775 0 L
.92826 0 L
.9288 0 L
.92931 0 L
.92986 0 L
.93038 0 L
.93088 0 L
.93141 0 L
.93192 0 L
.9324 0 L
.93292 0 L
.93341 0 L
.93393 0 L
.93443 0 L
.93491 0 L
.93542 0 L
.93591 0 L
.93637 0 L
.93687 0 L
.93734 0 L
.93784 0 L
.93832 0 L
.93878 0 L
.93927 0 L
.93974 0 L
.94023 0 L
.9407 0 L
.94116 0 L
.94164 0 L
.9421 0 L
.94254 0 L
.94301 0 L
.94346 0 L
.94394 0 L
.94439 0 L
.94483 0 L
.94529 0 L
.94573 0 L
.9462 0 L
.94665 0 L
.94708 0 L
.94754 0 L
.94798 0 L
.9484 0 L
.94885 0 L
.94927 0 L
.94972 0 L
Mistroke
.95016 0 L
.95057 0 L
.95101 0 L
.95144 0 L
.95184 0 L
.95227 0 L
.95268 0 L
.95312 0 L
.95353 0 L
.95393 0 L
.95436 0 L
.95477 0 L
.9552 0 L
.95561 0 L
.95601 0 L
.95643 0 L
.95683 0 L
.95722 0 L
.95763 0 L
.95802 0 L
.95844 0 L
.95884 0 L
.95922 0 L
.95962 0 L
.96001 0 L
.96043 0 L
.96082 0 L
.9612 0 L
.9616 0 L
.96199 0 L
.96236 0 L
.96275 0 L
.96313 0 L
.96352 0 L
.96391 0 L
.96427 0 L
.96466 0 L
.96503 0 L
.96539 0 L
.96577 0 L
.96614 0 L
.96652 0 L
.96689 0 L
.96725 0 L
.96762 0 L
.96798 0 L
.96836 0 L
.96873 0 L
.96908 0 L
.96946 0 L
Mistroke
.96981 0 L
.97016 0 L
.97052 0 L
.97087 0 L
.97124 0 L
.9716 0 L
.97194 0 L
.9723 0 L
.97265 0 L
.97298 0 L
.97333 0 L
.97367 0 L
.97403 0 L
.97437 0 L
.9747 0 L
.97506 0 L
.97539 0 L
.97575 0 L
.97609 0 L
.97642 0 L
.97677 0 L
.9771 0 L
.97742 0 L
.97776 0 L
.97809 0 L
.97843 0 L
.97876 0 L
.97908 0 L
.97942 0 L
.97975 0 L
.98009 0 L
.98042 0 L
.98073 0 L
.98107 0 L
.98139 0 L
.9817 0 L
.98203 0 L
.98234 0 L
.98268 0 L
.983 0 L
.98331 0 L
.98363 0 L
.98394 0 L
.98425 0 L
.98456 0 L
.98487 0 L
.98519 0 L
.9855 0 L
.9858 0 L
.98612 0 L
Mistroke
.98642 0 L
.98675 0 L
.98706 0 L
.98735 0 L
.98767 0 L
.98797 0 L
.98826 0 L
.98857 0 L
.98887 0 L
.98918 0 L
.98948 0 L
.98977 0 L
.99008 0 L
.99037 0 L
.99065 0 L
.99095 0 L
.99124 0 L
.99155 0 L
.99184 0 L
.99212 0 L
.99242 0 L
.9927 0 L
.99301 0 L
.9933 0 L
.99358 0 L
.99388 0 L
.99416 0 L
.99444 0 L
.99473 0 L
.995 0 L
.9953 0 L
.99558 0 L
.99586 0 L
.99615 0 L
.99642 0 L
.99672 0 L
.997 0 L
.99727 0 L
.99756 0 L
.99784 0 L
.9981 0 L
.99838 0 L
.99866 0 L
.99894 0 L
.99922 0 L
.99948 0 L
.99976 0 L
1 0 L
Mfstroke
0 0 m
.03792 0 L
.0855 0 L
.1169 0 L
.13958 0 L
.157 0 L
.17336 0 L
.18838 0 L
.20161 0 L
.21425 0 L
.22497 0 L
.23393 0 L
.24353 0 L
.24862 0 L
.25313 0 L
.26094 0 L
.26869 0 L
.27239 0 L
.27616 0 L
.28261 0 L
.28914 0 L
.29589 0 L
.30141 0 L
.30702 0 L
.31207 0 L
.31648 0 L
.32477 0 L
.32919 1e-05 L
.33313 1e-05 L
.34 1e-05 L
.34685 1e-05 L
.35391 2e-05 L
.35999 3e-05 L
.36631 4e-05 L
.37258 5e-05 L
.37777 7e-05 L
.38239 9e-05 L
.3922 .00014 L
.3974 .00018 L
.4021 .00022 L
.41037 .00032 L
.41474 .00039 L
.41863 .00047 L
.42692 .00069 L
.43303 .0009 L
.43923 .00119 L
.4496 .00186 L
.45547 .00238 L
.46077 .00297 L
.47006 .00435 L
Mistroke
.47841 .00606 L
.48665 .00833 L
.49389 .01092 L
.50006 .01367 L
.51253 .02113 L
.52457 .03133 L
.53498 .04306 L
.54498 .05723 L
.56097 .08608 L
.57575 .11868 L
.58829 .14885 L
.6002 .17695 L
.61057 .19846 L
.61968 .21326 L
.6241 .21861 L
.62629 .22075 L
.6286 .22262 L
.63072 .22397 L
.63163 .22445 L
.63262 .22489 L
.63349 .22521 L
.63441 .22548 L
.63491 .2256 L
.63537 .22569 L
.63583 .22577 L
.63626 .22582 L
.63647 .22584 L
.63671 .22586 L
.63684 .22587 L
.63697 .22587 L
.6372 .22588 L
.63745 .22589 L
.63768 .22588 L
.63793 .22588 L
.63805 .22587 L
.63819 .22587 L
.63842 .22585 L
.63863 .22583 L
.6391 .22578 L
.63952 .22572 L
.63995 .22564 L
.64092 .2254 L
.64181 .22511 L
.64381 .22422 L
.64571 .22306 L
.64748 .22171 L
.6507 .21859 L
.65709 .20998 L
.66349 .19839 L
.66932 .18565 L
Mistroke
.67465 .17256 L
.68004 .15826 L
.685 .14454 L
.69002 .13036 L
.69466 .11733 L
.69893 .10552 L
.70331 .09384 L
.70736 .08349 L
.7115 .07347 L
.71535 .06475 L
.71893 .0572 L
.72261 .05 L
.72605 .04384 L
.72925 .03856 L
.73255 .03358 L
.73564 .02935 L
.73884 .0254 L
.74182 .02207 L
.74462 .01927 L
.74752 .01665 L
.75025 .01446 L
.7528 .01262 L
.75545 .0109 L
.75795 .00947 L
.76054 .00814 L
.76298 .00704 L
.76528 .00612 L
.76767 .00527 L
.76992 .00456 L
.77226 .00391 L
.77448 .00337 L
.77656 .00292 L
.77874 .0025 L
.78079 .00216 L
.78273 .00187 L
.78476 .00161 L
.78668 .00139 L
.78868 .00119 L
.79057 .00103 L
.79237 .00089 L
.79424 .00076 L
.79601 .00066 L
.79787 .00056 L
.79962 .00048 L
.80129 .00042 L
.80303 .00036 L
.80468 .00031 L
.80625 .00027 L
.80789 .00023 L
.80945 .0002 L
Mistroke
.81108 .00017 L
.81263 .00015 L
.81409 .00013 L
.81564 .00011 L
.8171 9e-05 L
.81849 8e-05 L
.81995 7e-05 L
.82134 6e-05 L
.82279 5e-05 L
.82417 4e-05 L
.82549 4e-05 L
.82687 3e-05 L
.82818 3e-05 L
.82956 2e-05 L
.83087 2e-05 L
.83212 2e-05 L
.83343 2e-05 L
.83468 1e-05 L
.83587 1e-05 L
.83712 1e-05 L
.83831 1e-05 L
.83956 1e-05 L
.84075 1e-05 L
.84188 1e-05 L
.84307 0 L
.84421 0 L
.84529 0 L
.84643 0 L
.84752 0 L
.84866 0 L
.84975 0 L
.85078 0 L
.85188 0 L
.85292 0 L
.85402 0 L
.85506 0 L
.85606 0 L
.85711 0 L
.85811 0 L
.85907 0 L
.86008 0 L
.86104 0 L
.86205 0 L
.86302 0 L
.86394 0 L
.86491 0 L
.86584 0 L
.86682 0 L
.86775 0 L
.86864 0 L
Mistroke
.86958 0 L
.87048 0 L
.87134 0 L
.87224 0 L
.8731 0 L
.87401 0 L
.87488 0 L
.87571 0 L
.87659 0 L
.87742 0 L
.87822 0 L
.87907 0 L
.87987 0 L
.88072 0 L
.88154 0 L
.88231 0 L
.88313 0 L
.88392 0 L
.88474 0 L
.88553 0 L
.88629 0 L
.88709 0 L
.88785 0 L
.88858 0 L
.88935 0 L
.89008 0 L
.89086 0 L
.8916 0 L
.89231 0 L
.89306 0 L
.89378 0 L
.89447 0 L
.89519 0 L
.89589 0 L
.89662 0 L
.89732 0 L
.89799 0 L
.8987 0 L
.89938 0 L
.90009 0 L
.90078 0 L
.90143 0 L
.90212 0 L
.90279 0 L
.90342 0 L
.90409 0 L
.90473 0 L
.90541 0 L
.90606 0 L
.90668 0 L
Mistroke
.90734 0 L
.90796 0 L
.90863 0 L
.90926 0 L
.90987 0 L
.91051 0 L
.91113 0 L
.91172 0 L
.91234 0 L
.91294 0 L
.91357 0 L
.91417 0 L
.91475 0 L
.91536 0 L
.91595 0 L
.91651 0 L
.9171 0 L
.91767 0 L
.91827 0 L
.91885 0 L
.9194 0 L
.91998 0 L
.92054 0 L
.92113 0 L
.92169 0 L
.92224 0 L
.92281 0 L
.92336 0 L
.92388 0 L
.92444 0 L
.92497 0 L
.92553 0 L
.92607 0 L
.92659 0 L
.92714 0 L
.92766 0 L
.92822 0 L
.92875 0 L
.92926 0 L
.9298 0 L
.93031 0 L
.93081 0 L
.93133 0 L
.93183 0 L
.93237 0 L
.93287 0 L
.93336 0 L
.93388 0 L
.93437 0 L
.93485 0 L
Mistroke
.93535 0 L
.93583 0 L
.93634 0 L
.93683 0 L
.93729 0 L
.93779 0 L
.93826 0 L
.93876 0 L
.93925 0 L
.93971 0 L
.9402 0 L
.94066 0 L
.94111 0 L
.94159 0 L
.94204 0 L
.94253 0 L
.94299 0 L
.94343 0 L
.9439 0 L
.94435 0 L
.94478 0 L
.94524 0 L
.94568 0 L
.94614 0 L
.94659 0 L
.94701 0 L
.94747 0 L
.9479 0 L
.94836 0 L
.9488 0 L
.94922 0 L
.94967 0 L
.95009 0 L
.9505 0 L
.95094 0 L
.95136 0 L
.9518 0 L
.95222 0 L
.95263 0 L
.95306 0 L
.95347 0 L
.95391 0 L
.95433 0 L
.95473 0 L
.95516 0 L
.95557 0 L
.95596 0 L
.95637 0 L
.95677 0 L
.95719 0 L
Mistroke
.9576 0 L
.95799 0 L
.9584 0 L
.95879 0 L
.95917 0 L
.95957 0 L
.95996 0 L
.96036 0 L
.96075 0 L
.96113 0 L
.96153 0 L
.96191 0 L
.96231 0 L
.9627 0 L
.96307 0 L
.96346 0 L
.96384 0 L
.9642 0 L
.96459 0 L
.96496 0 L
.96535 0 L
.96572 0 L
.96608 0 L
.96646 0 L
.96683 0 L
.96721 0 L
.96759 0 L
.96794 0 L
.96832 0 L
.96868 0 L
.96903 0 L
.9694 0 L
.96975 0 L
.97013 0 L
.97049 0 L
.97083 0 L
.9712 0 L
.97155 0 L
.97189 0 L
.97224 0 L
.97259 0 L
.97295 0 L
.9733 0 L
.97363 0 L
.97399 0 L
.97433 0 L
.97469 0 L
.97504 0 L
.97537 0 L
.97572 0 L
Mistroke
.97606 0 L
.97638 0 L
.97673 0 L
.97706 0 L
.97741 0 L
.97774 0 L
.97806 0 L
.97841 0 L
.97873 0 L
.97905 0 L
.97938 0 L
.9797 0 L
.98004 0 L
.98037 0 L
.98068 0 L
.98101 0 L
.98133 0 L
.98167 0 L
.98199 0 L
.9823 0 L
.98263 0 L
.98295 0 L
.98325 0 L
.98357 0 L
.98388 0 L
.98421 0 L
.98453 0 L
.98483 0 L
.98515 0 L
.98546 0 L
.98578 0 L
.9861 0 L
.9864 0 L
.98671 0 L
.98702 0 L
.98731 0 L
.98763 0 L
.98792 0 L
.98824 0 L
.98855 0 L
.98884 0 L
.98915 0 L
.98945 0 L
.98973 0 L
.99003 0 L
.99032 0 L
.99063 0 L
.99093 0 L
.99121 0 L
.99151 0 L
Mistroke
.9918 0 L
.99211 0 L
.99241 0 L
.99269 0 L
.99299 0 L
.99328 0 L
.99355 0 L
.99385 0 L
.99413 0 L
.99443 0 L
.99471 0 L
.99499 0 L
.99528 0 L
.99556 0 L
.99583 0 L
.99612 0 L
.99639 0 L
.99668 0 L
.99696 0 L
.99723 0 L
.99751 0 L
.99779 0 L
.99808 0 L
.99836 0 L
.99862 0 L
.99891 0 L
.99918 0 L
.99944 0 L
.99972 0 L
.99998 0 L
1 0 L
Mfstroke
0 0 m
.03792 0 L
.0855 0 L
.1169 0 L
.13958 0 L
.157 0 L
.17336 0 L
.18838 0 L
.20161 0 L
.21425 0 L
.22497 0 L
.23393 0 L
.24353 0 L
.24862 1e-05 L
.25313 1e-05 L
.26094 1e-05 L
.26869 1e-05 L
.27616 2e-05 L
.28261 2e-05 L
.28927 3e-05 L
.29589 4e-05 L
.30134 5e-05 L
.30619 6e-05 L
.3116 8e-05 L
.31648 .0001 L
.32498 .00014 L
.3322 .00019 L
.33946 .00025 L
.34685 .00034 L
.35393 .00045 L
.36018 .00058 L
.36664 .00075 L
.3732 .00097 L
.37934 .00123 L
.38545 .00155 L
.39558 .00227 L
.40422 .00312 L
.41168 .00409 L
.41931 .00536 L
.42692 .00699 L
.43988 .01082 L
.44656 .01345 L
.45238 .01619 L
.46292 .02239 L
.47194 .02919 L
.48744 .04475 L
.50226 .06484 L
.52563 .10663 L
.54596 .14872 L
.56249 .18008 L
Mistroke
.56997 .19134 L
.57632 .19875 L
.57971 .20176 L
.58281 .20386 L
.58448 .20473 L
.58599 .20536 L
.58763 .20585 L
.58844 .20603 L
.5889 .20611 L
.58933 .20617 L
.58969 .20621 L
.59008 .20624 L
.59047 .20626 L
.59069 .20627 L
.5909 .20627 L
.59127 .20627 L
.59161 .20626 L
.59198 .20624 L
.59236 .20621 L
.59269 .20617 L
.59304 .20613 L
.59366 .20602 L
.5944 .20586 L
.59506 .20568 L
.59653 .20516 L
.59809 .20444 L
.60088 .2027 L
.60342 .20061 L
.60614 .19786 L
.61144 .19102 L
.62094 .17436 L
.62936 .15578 L
.63764 .13522 L
.64507 .11595 L
.65176 .09868 L
.65845 .08211 L
.66453 .06812 L
.67007 .05648 L
.67568 .04593 L
.68081 .03742 L
.68601 .02993 L
.6908 .02402 L
.69521 .01937 L
.69972 .01536 L
.70389 .01224 L
.70815 .0096 L
.71211 .00757 L
.71578 .00602 L
.71956 .00471 L
.72307 .00371 L
Mistroke
.72635 .00295 L
.72973 .0023 L
.73289 .00181 L
.73616 .00141 L
.73921 .0011 L
.74206 .00087 L
.74502 .00068 L
.7478 .00053 L
.75067 .00041 L
.75337 .00032 L
.7559 .00025 L
.75853 .00019 L
.76101 .00015 L
.76334 .00012 L
.76576 9e-05 L
.76805 7e-05 L
.77043 6e-05 L
.77267 4e-05 L
.77478 3e-05 L
.77699 3e-05 L
.77907 2e-05 L
.78103 2e-05 L
.78308 1e-05 L
.78502 1e-05 L
.78705 1e-05 L
.78896 1e-05 L
.79078 0 L
.79267 0 L
.79446 0 L
.79634 0 L
.79811 0 L
.79979 0 L
.80155 0 L
.80322 0 L
.8048 0 L
.80646 0 L
.80803 0 L
.80968 0 L
.81124 0 L
.81273 0 L
.81428 0 L
.81576 0 L
.81731 0 L
.81878 0 L
.82017 0 L
.82164 0 L
.82303 0 L
.82436 0 L
.82575 0 L
.82707 0 L
Mistroke
.82846 0 L
.82978 0 L
.83103 0 L
.83235 0 L
.83361 0 L
.8348 0 L
.83606 0 L
.83726 0 L
.83852 0 L
.83971 0 L
.84085 0 L
.84205 0 L
.8432 0 L
.8444 0 L
.84554 0 L
.84663 0 L
.84778 0 L
.84888 0 L
.84992 0 L
.85102 0 L
.85206 0 L
.85317 0 L
.85422 0 L
.85522 0 L
.85627 0 L
.85728 0 L
.85824 0 L
.85925 0 L
.86022 0 L
.86124 0 L
.86221 0 L
.86313 0 L
.86411 0 L
.86504 0 L
.86602 0 L
.86696 0 L
.86785 0 L
.8688 0 L
.8697 0 L
.87056 0 L
.87146 0 L
.87233 0 L
.87324 0 L
.87411 0 L
.87495 0 L
.87583 0 L
.87667 0 L
.87755 0 L
.8784 0 L
.87921 0 L
Mistroke
.88006 0 L
.88087 0 L
.88165 0 L
.88247 0 L
.88326 0 L
.88409 0 L
.88488 0 L
.88564 0 L
.88644 0 L
.8872 0 L
.88793 0 L
.8887 0 L
.88944 0 L
.89022 0 L
.89097 0 L
.89168 0 L
.89243 0 L
.89315 0 L
.89391 0 L
.89464 0 L
.89533 0 L
.89606 0 L
.89677 0 L
.89744 0 L
.89815 0 L
.89883 0 L
.89954 0 L
.90023 0 L
.90088 0 L
.90158 0 L
.90224 0 L
.90288 0 L
.90355 0 L
.90419 0 L
.90487 0 L
.90552 0 L
.90614 0 L
.9068 0 L
.90743 0 L
.90809 0 L
.90873 0 L
.90934 0 L
.90998 0 L
.9106 0 L
.91119 0 L
.91181 0 L
.91241 0 L
.91304 0 L
.91365 0 L
.91423 0 L
Mistroke
.91484 0 L
.91542 0 L
.91604 0 L
.91664 0 L
.91721 0 L
.91781 0 L
.91838 0 L
.91893 0 L
.91952 0 L
.92008 0 L
.92067 0 L
.92123 0 L
.92177 0 L
.92235 0 L
.9229 0 L
.92342 0 L
.92398 0 L
.92451 0 L
.92508 0 L
.92562 0 L
.92613 0 L
.92668 0 L
.92721 0 L
.92776 0 L
.92829 0 L
.9288 0 L
.92934 0 L
.92986 0 L
.93035 0 L
.93088 0 L
.93138 0 L
.93191 0 L
.93242 0 L
.93291 0 L
.93343 0 L
.93392 0 L
.93444 0 L
.93495 0 L
.93543 0 L
.93594 0 L
.93642 0 L
.93689 0 L
.93739 0 L
.93786 0 L
.93836 0 L
.93885 0 L
.93931 0 L
.9398 0 L
.94026 0 L
.94071 0 L
Mistroke
.94119 0 L
.94164 0 L
.94213 0 L
.94259 0 L
.94303 0 L
.9435 0 L
.94395 0 L
.94443 0 L
.94489 0 L
.94532 0 L
.94579 0 L
.94623 0 L
.94666 0 L
.94711 0 L
.94754 0 L
.948 0 L
.94844 0 L
.94886 0 L
.94931 0 L
.94974 0 L
.95015 0 L
.95058 0 L
.951 0 L
.95144 0 L
.95187 0 L
.95227 0 L
.9527 0 L
.95312 0 L
.95355 0 L
.95397 0 L
.95438 0 L
.9548 0 L
.95521 0 L
.9556 0 L
.95602 0 L
.95642 0 L
.95684 0 L
.95724 0 L
.95763 0 L
.95804 0 L
.95844 0 L
.95885 0 L
.95925 0 L
.95964 0 L
.96005 0 L
.96044 0 L
.96081 0 L
.96121 0 L
.96159 0 L
.96199 0 L
Mistroke
.96238 0 L
.96275 0 L
.96315 0 L
.96352 0 L
.96388 0 L
.96427 0 L
.96464 0 L
.96503 0 L
.9654 0 L
.96576 0 L
.96614 0 L
.96651 0 L
.96689 0 L
.96727 0 L
.96762 0 L
.968 0 L
.96836 0 L
.96871 0 L
.96908 0 L
.96943 0 L
.96981 0 L
.97017 0 L
.97051 0 L
.97088 0 L
.97123 0 L
.9716 0 L
.97196 0 L
.9723 0 L
.97266 0 L
.97301 0 L
.97334 0 L
.9737 0 L
.97404 0 L
.9744 0 L
.97475 0 L
.97508 0 L
.97543 0 L
.97577 0 L
.97609 0 L
.97643 0 L
.97676 0 L
.97711 0 L
.97745 0 L
.97777 0 L
.97811 0 L
.97844 0 L
.97879 0 L
.97912 0 L
.97944 0 L
.97978 0 L
Mistroke
.98011 0 L
.98042 0 L
.98075 0 L
.98107 0 L
.9814 0 L
.98173 0 L
.98204 0 L
.98237 0 L
.98268 0 L
.98299 0 L
.98331 0 L
.98362 0 L
.98395 0 L
.98426 0 L
.98456 0 L
.98488 0 L
.98519 0 L
.98552 0 L
.98583 0 L
.98613 0 L
.98645 0 L
.98675 0 L
.98705 0 L
.98736 0 L
.98766 0 L
.98797 0 L
.98828 0 L
.98857 0 L
.98888 0 L
.98917 0 L
.98949 0 L
.98979 0 L
.99008 0 L
.99039 0 L
.99069 0 L
.99097 0 L
.99127 0 L
.99156 0 L
.99187 0 L
.99216 0 L
.99244 0 L
.99274 0 L
.99303 0 L
.99331 0 L
.9936 0 L
.99388 0 L
.99418 0 L
.99447 0 L
.99474 0 L
.99503 0 L
Mistroke
.99531 0 L
.99561 0 L
.9959 0 L
.99617 0 L
.99646 0 L
.99674 0 L
.99701 0 L
.99729 0 L
.99757 0 L
.99785 0 L
.99813 0 L
.9984 0 L
.99868 0 L
.99895 0 L
.99922 0 L
.99949 0 L
.99976 0 L
1 0 L
Mfstroke
0 0 m
.03792 0 L
.0855 0 L
.1169 0 L
.13958 0 L
.157 1e-05 L
.17336 1e-05 L
.18838 2e-05 L
.20161 3e-05 L
.21425 5e-05 L
.22497 8e-05 L
.23393 .00011 L
.24353 .00015 L
.25313 .0002 L
.26148 .00027 L
.26869 .00035 L
.27565 .00044 L
.28271 .00055 L
.29444 .00082 L
.30476 .00114 L
.31345 .00151 L
.32216 .002 L
.33098 .00264 L
.33948 .00344 L
.34685 .00431 L
.35397 .00534 L
.36121 .00663 L
.37326 .00941 L
.38383 .0127 L
.39277 .01624 L
.41067 .026 L
.4187 .03179 L
.42692 .03877 L
.45023 .06504 L
.47078 .09625 L
.50256 .15242 L
.51551 .17297 L
.5213 .18067 L
.5263 .18631 L
.53096 .19058 L
.53579 .19388 L
.53836 .19513 L
.53947 .19556 L
.54067 .19594 L
.5418 .19623 L
.54284 .19642 L
.54341 .1965 L
.54393 .19656 L
.54453 .1966 L
.54509 .19663 L
Mistroke
.54565 .19663 L
.54597 .19662 L
.54626 .19661 L
.54679 .19658 L
.54735 .19653 L
.54785 .19646 L
.54831 .19639 L
.54936 .19617 L
.55048 .19587 L
.55149 .19553 L
.55372 .19455 L
.5556 .19348 L
.5576 .19211 L
.56115 .18906 L
.56863 .1802 L
.57603 .16843 L
.58819 .14392 L
.5998 .11692 L
.60991 .09286 L
.61972 .07083 L
.62839 .05349 L
.63613 .04022 L
.6438 .0293 L
.65071 .02138 L
.6576 .01515 L
.66384 .01079 L
.66953 .00774 L
.67527 .00541 L
.68053 .00381 L
.68535 .00271 L
.69026 .00188 L
.69479 .00132 L
.6994 .00091 L
.70367 .00063 L
.70762 .00044 L
.71167 .0003 L
.71543 .00021 L
.71893 .00015 L
.72254 .0001 L
.7259 7e-05 L
.72936 5e-05 L
.7326 3e-05 L
.73562 2e-05 L
.73875 2e-05 L
.74168 1e-05 L
.74314 1e-05 L
.7447 1e-05 L
.74754 1e-05 L
.74893 0 L
.75037 0 L
Mistroke
.75293 0 L
.75559 0 L
.75809 0 L
.75942 0 L
.76068 0 L
.76303 0 L
.76432 0 L
.76547 0 L
.76778 0 L
.76889 0 L
.77009 0 L
.7712 0 L
.7724 0 L
.77458 0 L
.77564 0 L
.77677 0 L
.77783 0 L
.77897 0 L
.78104 0 L
.78205 0 L
.78312 0 L
.78501 0 L
.78605 0 L
.78699 0 L
.78887 0 L
.78977 0 L
.79075 0 L
.79175 0 L
.79264 0 L
.79444 0 L
.79531 0 L
.79625 0 L
.79712 0 L
.79806 0 L
.79979 0 L
.80063 0 L
.80152 0 L
.80236 0 L
.80327 0 L
.80493 0 L
.80574 0 L
.8066 0 L
.80741 0 L
.80828 0 L
.80988 0 L
.81066 0 L
.81149 0 L
.81296 0 L
.81371 0 L
.8145 0 L
Mistroke
.81525 0 L
.81606 0 L
.81754 0 L
.81827 0 L
.81903 0 L
.8204 0 L
.82109 0 L
.82183 0 L
.82253 0 L
.82328 0 L
.82466 0 L
.82533 0 L
.82605 0 L
.82673 0 L
.82746 0 L
.82879 0 L
.82945 0 L
.83015 0 L
.83138 0 L
.83201 0 L
.83268 0 L
.83332 0 L
.834 0 L
.83525 0 L
.83587 0 L
.83652 0 L
.83768 0 L
.83827 0 L
.8389 0 L
.8395 0 L
.84014 0 L
.84132 0 L
.8419 0 L
.84251 0 L
.84309 0 L
.84372 0 L
.84487 0 L
.84543 0 L
.84603 0 L
.8471 0 L
.84764 0 L
.84822 0 L
.84877 0 L
.84936 0 L
.85045 0 L
.85098 0 L
.85155 0 L
.85209 0 L
.85266 0 L
.85373 0 L
Mistroke
.85425 0 L
.8548 0 L
.85579 0 L
.8563 0 L
.85683 0 L
.85734 0 L
.85789 0 L
.8589 0 L
.8594 0 L
.85992 0 L
.86086 0 L
.86134 0 L
.86185 0 L
.86233 0 L
.86285 0 L
.86381 0 L
.86428 0 L
.86478 0 L
.86525 0 L
.86577 0 L
.86671 0 L
.86717 0 L
.86766 0 L
.86854 0 L
.86898 0 L
.86946 0 L
.86991 0 L
.8704 0 L
.8713 0 L
.87174 0 L
.87221 0 L
.87304 0 L
.87347 0 L
.87393 0 L
.87436 0 L
.87482 0 L
.87568 0 L
.8761 0 L
.87655 0 L
.87697 0 L
.87743 0 L
.87827 0 L
.87869 0 L
.87913 0 L
.87992 0 L
.88032 0 L
.88075 0 L
.88116 0 L
.8816 0 L
.8824 0 L
Mistroke
.8828 0 L
.88322 0 L
.88362 0 L
.88406 0 L
.88485 0 L
.88525 0 L
.88566 0 L
.88641 0 L
.88679 0 L
.88719 0 L
.88758 0 L
.88799 0 L
.88875 0 L
.88913 0 L
.88953 0 L
.89025 0 L
.89061 0 L
.891 0 L
.89137 0 L
.89177 0 L
.8925 0 L
.89286 0 L
.89325 0 L
.89361 0 L
.89401 0 L
.89473 0 L
.89509 0 L
.89547 0 L
.89615 0 L
.89649 0 L
.89686 0 L
.89721 0 L
.89759 0 L
.89829 0 L
.89864 0 L
.899 0 L
.89935 0 L
.89972 0 L
.90041 0 L
.90076 0 L
.90112 0 L
.90176 0 L
.90209 0 L
.90245 0 L
.90278 0 L
.90314 0 L
.90381 0 L
.90414 0 L
.90449 0 L
.90511 0 L
Mistroke
.90543 0 L
.90577 0 L
.90609 0 L
.90644 0 L
.90708 0 L
.9074 0 L
.90773 0 L
.90805 0 L
.9084 0 L
.90904 0 L
.90935 0 L
.90968 0 L
.91028 0 L
.91058 0 L
.91091 0 L
.91122 0 L
.91155 0 L
.91217 0 L
.91247 0 L
.91279 0 L
.91337 0 L
.91366 0 L
.91398 0 L
.91428 0 L
.9146 0 L
.9152 0 L
.91549 0 L
.9158 0 L
.9161 0 L
.91642 0 L
.91701 0 L
.9173 0 L
.91761 0 L
.91816 0 L
.91844 0 L
.91875 0 L
.91903 0 L
.91934 0 L
.91991 0 L
.9202 0 L
.9205 0 L
.92078 0 L
.92109 0 L
.92165 0 L
.92194 0 L
.92223 0 L
.92276 0 L
.92304 0 L
.92333 0 L
.9236 0 L
Mistroke
.9239 0 L
.92445 0 L
.92472 0 L
.92501 0 L
.92553 0 L
.92579 0 L
.92607 0 L
.92634 0 L
.92663 0 L
.92716 0 L
.92742 0 L
.9277 0 L
.92797 0 L
.92826 0 L
.92879 0 L
.92905 0 L
.92933 0 L
.92982 0 L
.93008 0 L
.93035 0 L
.93061 0 L
.93089 0 L
.9314 0 L
.93166 0 L
.93193 0 L
.93218 0 L
.93246 0 L
.93297 0 L
.93323 0 L
.93349 0 L
.93397 0 L
.93422 0 L
.93448 0 L
.93473 0 L
.935 0 L
.9355 0 L
.93574 0 L
.936 0 L
.93647 0 L
.93671 0 L
.93697 0 L
.93721 0 L
.93747 0 L
.93795 0 L
.93819 0 L
.93844 0 L
.93869 0 L
.93895 0 L
.93943 0 L
.93967 0 L
Mistroke
.93992 0 L
.94037 0 L
.9406 0 L
.94085 0 L
.94108 0 L
.94134 0 L
.9418 0 L
.94204 0 L
.94228 0 L
.94272 0 L
.94295 0 L
.94319 0 L
.94341 0 L
.94366 0 L
.94412 0 L
.94434 0 L
.94458 0 L
.94481 0 L
.94505 0 L
.94551 0 L
.94573 0 L
.94597 0 L
.9464 0 L
.94662 0 L
.94685 0 L
.94707 0 L
.94731 0 L
.94775 0 L
.94797 0 L
.9482 0 L
.94842 0 L
.94866 0 L
.9491 0 L
.94932 0 L
.94955 0 L
.94997 0 L
.95018 0 L
.9504 0 L
.95062 0 L
.95085 0 L
.95128 0 L
.95149 0 L
.95172 0 L
.95212 0 L
.95233 0 L
.95255 0 L
.95276 0 L
.95299 0 L
.95341 0 L
.95361 0 L
Mistroke
.95383 0 L
.95404 0 L
.95427 0 L
.95468 0 L
.95489 0 L
.95511 0 L
.9555 0 L
.9557 0 L
.95592 0 L
.95612 0 L
.95634 0 L
.95675 0 L
.95695 0 L
.95717 0 L
.95755 0 L
.95775 0 L
.95796 0 L
.95815 0 L
.95837 0 L
.95877 0 L
.95896 0 L
.95917 0 L
.95937 0 L
.95959 0 L
.95998 0 L
.96018 0 L
.96039 0 L
.96076 0 L
.96095 0 L
.96116 0 L
.96135 0 L
.96156 0 L
.96195 0 L
.96214 0 L
.96234 0 L
.96254 0 L
.96275 0 L
.96313 0 L
.96332 0 L
.96353 0 L
.96389 0 L
.96408 0 L
.96428 0 L
.96447 0 L
.96467 0 L
.96505 0 L
.96524 0 L
.96543 0 L
.96579 0 L
.96597 0 L
Mistroke
.96617 0 L
.96635 0 L
.96655 0 L
.96692 0 L
.9671 0 L
.9673 0 L
.96748 0 L
.96768 0 L
.96805 0 L
.96823 0 L
.96843 0 L
.96877 0 L
.96895 0 L
.96914 0 L
.96932 0 L
.96952 0 L
.96988 0 L
.97006 0 L
.97025 0 L
.97043 0 L
.97062 0 L
.97098 0 L
.97116 0 L
.97135 0 L
.97169 0 L
.97186 0 L
.97205 0 L
.97222 0 L
.97241 0 L
.97277 0 L
.97294 0 L
.97313 0 L
.97346 0 L
.97363 0 L
.97381 0 L
.97398 0 L
.97417 0 L
.97451 0 L
.97468 0 L
.97486 0 L
.97504 0 L
.97522 0 L
.97557 0 L
.97574 0 L
.97592 0 L
.97624 0 L
.97641 0 L
.97659 0 L
.97676 0 L
.97694 0 L
Mistroke
.97728 0 L
.97744 0 L
.97762 0 L
.97794 0 L
.9781 0 L
.97827 0 L
.97844 0 L
.97862 0 L
.97895 0 L
.97911 0 L
.97929 0 L
.97945 0 L
.97963 0 L
.97996 0 L
.98012 0 L
.9803 0 L
.98061 0 L
.98077 0 L
.98094 0 L
.9811 0 L
.98127 0 L
.9816 0 L
.98176 0 L
.98193 0 L
.98209 0 L
.98226 0 L
.98259 0 L
.98275 0 L
.98292 0 L
.98322 0 L
.98338 0 L
.98355 0 L
.9837 0 L
.98387 0 L
.98419 0 L
.98435 0 L
.98452 0 L
.98481 0 L
.98497 0 L
.98513 0 L
.98528 0 L
.98545 0 L
.98576 0 L
.98592 0 L
.98608 0 L
.98624 0 L
.9864 0 L
.98671 0 L
.98687 0 L
.98703 0 L
Mistroke
.98732 0 L
.98747 0 L
.98764 0 L
.98779 0 L
.98795 0 L
.98826 0 L
.98841 0 L
.98857 0 L
.98885 0 L
.989 0 L
.98916 0 L
.98931 0 L
.98947 0 L
.98977 0 L
.98992 0 L
.99007 0 L
.99022 0 L
.99038 0 L
.99068 0 L
.99083 0 L
.99099 0 L
.99127 0 L
.99141 0 L
.99157 0 L
.99171 0 L
.99187 0 L
.99217 0 L
.99231 0 L
.99247 0 L
.99261 0 L
.99277 0 L
.99306 0 L
.99321 0 L
.99336 0 L
.99364 0 L
.99378 0 L
.99393 0 L
.99408 0 L
.99423 0 L
.99452 0 L
.99466 0 L
.99481 0 L
.99509 0 L
.99522 0 L
.99537 0 L
.99551 0 L
.99567 0 L
.99595 0 L
.99609 0 L
.99624 0 L
Mistroke
.99638 0 L
.99653 0 L
.99682 0 L
.99696 0 L
.9971 0 L
.99737 0 L
.99751 0 L
.99765 0 L
.99779 0 L
.99794 0 L
.99822 0 L
.99836 0 L
.9985 0 L
.99864 0 L
.99879 0 L
.99907 0 L
.99921 0 L
.99935 0 L
.99962 0 L
.99975 0 L
.99989 0 L
1 0 L
Mfstroke
0 1e-05 m
.03792 1e-05 L
.0855 5e-05 L
.1169 .00011 L
.13958 .0002 L
.157 .00031 L
.17336 .00048 L
.18838 .00071 L
.20161 .001 L
.21425 .00138 L
.22497 .00181 L
.23393 .00227 L
.24353 .00288 L
.25313 .00365 L
.26869 .00533 L
.2828 .00746 L
.29418 .00974 L
.30598 .01276 L
.31604 .01599 L
.33193 .0226 L
.34685 .03086 L
.37333 .05168 L
.39569 .07636 L
.42692 .12065 L
.45079 .15699 L
.46876 .18008 L
.47306 .18445 L
.47755 .18839 L
.48129 .19112 L
.48527 .19344 L
.48725 .19435 L
.48933 .19513 L
.49047 .19547 L
.4915 .19574 L
.49253 .19595 L
.49349 .19611 L
.49431 .19621 L
.49518 .19628 L
.49567 .1963 L
.49613 .19631 L
.497 .19631 L
.4979 .19627 L
.49873 .19619 L
.49963 .19608 L
.50057 .19591 L
.50228 .1955 L
.50388 .19499 L
.50682 .19371 L
.5099 .19191 L
.51316 .18949 L
Mistroke
.51879 .18409 L
.52375 .17809 L
.54344 .1446 L
.56107 .1068 L
.57571 .07544 L
.58815 .052 L
.59998 .03396 L
.61027 .02203 L
.61933 .01429 L
.62406 .01117 L
.6282 .00889 L
.63611 .00557 L
.63979 .00441 L
.64365 .00342 L
.64714 .00269 L
.65087 .00206 L
.65738 .00126 L
.66046 .00098 L
.66368 .00075 L
.66663 .00059 L
.66976 .00045 L
.67531 .00027 L
.67796 .00021 L
.68071 .00016 L
.68346 .00012 L
.68598 9e-05 L
.68823 7e-05 L
.69064 6e-05 L
.69297 4e-05 L
.69539 3e-05 L
.69758 3e-05 L
.69988 2e-05 L
.70216 1e-05 L
.70428 1e-05 L
.70617 1e-05 L
.70821 1e-05 L
.71018 1e-05 L
.71224 0 L
.7141 0 L
.71607 0 L
.71793 0 L
.71986 0 L
.72163 0 L
.72325 0 L
.72488 0 L
.72662 0 L
.72842 0 L
.73009 0 L
.73172 0 L
.73341 0 L
Mistroke
.73496 0 L
.73639 0 L
.73782 0 L
.73937 0 L
.74095 0 L
.74244 0 L
.74388 0 L
.74539 0 L
.74691 0 L
.74833 0 L
.74972 0 L
.75098 0 L
.75225 0 L
.75363 0 L
.75492 0 L
.75628 0 L
.75765 0 L
.75893 0 L
.76018 0 L
.76132 0 L
.76247 0 L
.76372 0 L
.76489 0 L
.76613 0 L
.76731 0 L
.76853 0 L
.76967 0 L
.77072 0 L
.77187 0 L
.77291 0 L
.77397 0 L
.77511 0 L
.77618 0 L
.77731 0 L
.77835 0 L
.77931 0 L
.78037 0 L
.78133 0 L
.7823 0 L
.78335 0 L
.78434 0 L
.78539 0 L
.78645 0 L
.78743 0 L
.7884 0 L
.78929 0 L
.79019 0 L
.79116 0 L
.79208 0 L
.79305 0 L
Mistroke
.79403 0 L
.79494 0 L
.79584 0 L
.79667 0 L
.7975 0 L
.79841 0 L
.79926 0 L
.80016 0 L
.80107 0 L
.80193 0 L
.80277 0 L
.80354 0 L
.8044 0 L
.80517 0 L
.80596 0 L
.80681 0 L
.80761 0 L
.80846 0 L
.80924 0 L
.80997 0 L
.81077 0 L
.81149 0 L
.81223 0 L
.81303 0 L
.81379 0 L
.81459 0 L
.81532 0 L
.816 0 L
.81675 0 L
.81744 0 L
.81813 0 L
.81889 0 L
.8196 0 L
.82035 0 L
.82112 0 L
.82183 0 L
.82254 0 L
.82318 0 L
.82384 0 L
.82455 0 L
.82522 0 L
.82593 0 L
.82665 0 L
.82733 0 L
.828 0 L
.82861 0 L
.82929 0 L
.8299 0 L
.83054 0 L
.83121 0 L
Mistroke
.83186 0 L
.83254 0 L
.83317 0 L
.83375 0 L
.83439 0 L
.83498 0 L
.83557 0 L
.83622 0 L
.83683 0 L
.83748 0 L
.83807 0 L
.83863 0 L
.83924 0 L
.8398 0 L
.84036 0 L
.84098 0 L
.84156 0 L
.84218 0 L
.8428 0 L
.84339 0 L
.84397 0 L
.8445 0 L
.84504 0 L
.84563 0 L
.84618 0 L
.84677 0 L
.84736 0 L
.84793 0 L
.84848 0 L
.84899 0 L
.8495 0 L
.85006 0 L
.85059 0 L
.85115 0 L
.85169 0 L
.85226 0 L
.85278 0 L
.85327 0 L
.85381 0 L
.8543 0 L
.8548 0 L
.85534 0 L
.85585 0 L
.8564 0 L
.8569 0 L
.85737 0 L
.85788 0 L
.85835 0 L
.85883 0 L
.85935 0 L
Mistroke
.85984 0 L
.86036 0 L
.86089 0 L
.86139 0 L
.86188 0 L
.86234 0 L
.86279 0 L
.86329 0 L
.86376 0 L
.86427 0 L
.86477 0 L
.86525 0 L
.86572 0 L
.86616 0 L
.8666 0 L
.86708 0 L
.86753 0 L
.86801 0 L
.86847 0 L
.86896 0 L
.86941 0 L
.86983 0 L
.87029 0 L
.87071 0 L
.87115 0 L
.87161 0 L
.87206 0 L
.87252 0 L
.87296 0 L
.87336 0 L
.87381 0 L
.87421 0 L
.87463 0 L
.87508 0 L
.8755 0 L
.87596 0 L
.87642 0 L
.87685 0 L
.87728 0 L
.87767 0 L
.87807 0 L
.8785 0 L
.87891 0 L
.87935 0 L
.87979 0 L
.88021 0 L
.88062 0 L
.881 0 L
.88138 0 L
.8818 0 L
Mistroke
.8822 0 L
.88262 0 L
.88304 0 L
.88345 0 L
.88384 0 L
.88421 0 L
.88462 0 L
.88499 0 L
.88537 0 L
.88578 0 L
.88617 0 L
.88658 0 L
.88696 0 L
.88732 0 L
.88771 0 L
.88807 0 L
.88843 0 L
.88883 0 L
.88921 0 L
.8896 0 L
.88997 0 L
.89032 0 L
.8907 0 L
.89104 0 L
.8914 0 L
.89178 0 L
.89214 0 L
.89253 0 L
.89292 0 L
.89329 0 L
.89366 0 L
.894 0 L
.89434 0 L
.89471 0 L
.89506 0 L
.89544 0 L
.89582 0 L
.89618 0 L
.89653 0 L
.89686 0 L
.89722 0 L
.89755 0 L
.89789 0 L
.89825 0 L
.8986 0 L
.89897 0 L
.89931 0 L
.89963 0 L
.89998 0 L
.9003 0 L
Mistroke
.90062 0 L
.90098 0 L
.90132 0 L
.90167 0 L
.902 0 L
.90231 0 L
.90265 0 L
.90296 0 L
.90328 0 L
.90363 0 L
.90395 0 L
.9043 0 L
.90465 0 L
.90499 0 L
.90532 0 L
.90562 0 L
.90592 0 L
.90626 0 L
.90658 0 L
.90691 0 L
.90726 0 L
.90758 0 L
.9079 0 L
.90819 0 L
.90852 0 L
.90882 0 L
.90912 0 L
.90945 0 L
.90977 0 L
.9101 0 L
.91041 0 L
.9107 0 L
.91101 0 L
.9113 0 L
.9116 0 L
.91192 0 L
.91223 0 L
.91255 0 L
.91285 0 L
.91313 0 L
.91344 0 L
.91372 0 L
.91401 0 L
.91432 0 L
.91462 0 L
.91493 0 L
.91525 0 L
.91555 0 L
.91585 0 L
.91613 0 L
Mistroke
.91641 0 L
.91671 0 L
.917 0 L
.91731 0 L
.91762 0 L
.91791 0 L
.9182 0 L
.91847 0 L
.91874 0 L
.91904 0 L
.91932 0 L
.91962 0 L
.91991 0 L
.92021 0 L
.92049 0 L
.92075 0 L
.92104 0 L
.92131 0 L
.92158 0 L
.92187 0 L
.92215 0 L
.92245 0 L
.92272 0 L
.92298 0 L
.92326 0 L
.92352 0 L
.92378 0 L
.92407 0 L
.92434 0 L
.92463 0 L
.92492 0 L
.9252 0 L
.92547 0 L
.92572 0 L
.92598 0 L
.92626 0 L
.92652 0 L
.9268 0 L
.92709 0 L
.92736 0 L
.92763 0 L
.92787 0 L
.92812 0 L
.92839 0 L
.92865 0 L
.92893 0 L
.92919 0 L
.92947 0 L
.92973 0 L
.92997 0 L
Mistroke
.93024 0 L
.93048 0 L
.93073 0 L
.931 0 L
.93126 0 L
.93153 0 L
.93178 0 L
.93201 0 L
.93228 0 L
.93251 0 L
.93276 0 L
.93302 0 L
.93327 0 L
.93354 0 L
.93378 0 L
.93401 0 L
.93427 0 L
.9345 0 L
.93473 0 L
.93499 0 L
.93524 0 L
.9355 0 L
.93576 0 L
.93601 0 L
.93626 0 L
.93648 0 L
.93672 0 L
.93697 0 L
.93721 0 L
.93746 0 L
.93772 0 L
.93796 0 L
.9382 0 L
.93843 0 L
.93867 0 L
.9389 0 L
.93913 0 L
.93938 0 L
.93962 0 L
.93987 0 L
.9401 0 L
.94032 0 L
.94056 0 L
.94078 0 L
.94101 0 L
.94125 0 L
.94149 0 L
.94173 0 L
.94196 0 L
.94218 0 L
Mistroke
.94241 0 L
.94263 0 L
.94285 0 L
.94309 0 L
.94331 0 L
.94356 0 L
.9438 0 L
.94403 0 L
.94426 0 L
.94447 0 L
.94469 0 L
.94492 0 L
.94515 0 L
.94538 0 L
.94562 0 L
.94585 0 L
.94607 0 L
.94628 0 L
.94651 0 L
.94672 0 L
.94694 0 L
.94717 0 L
.94739 0 L
.94763 0 L
.94785 0 L
.94805 0 L
.94827 0 L
.94848 0 L
.94869 0 L
.94892 0 L
.94914 0 L
.94937 0 L
.94958 0 L
.94978 0 L
.95 0 L
.9502 0 L
.95041 0 L
.95063 0 L
.95084 0 L
.95107 0 L
.9513 0 L
.95151 0 L
.95173 0 L
.95193 0 L
.95213 0 L
.95235 0 L
.95255 0 L
.95278 0 L
.953 0 L
.95321 0 L
Mistroke
.95342 0 L
.95362 0 L
.95381 0 L
.95403 0 L
.95423 0 L
.95445 0 L
.95466 0 L
.95488 0 L
.95508 0 L
.95527 0 L
.95548 0 L
.95567 0 L
.95587 0 L
.95609 0 L
.95629 0 L
.95651 0 L
.95671 0 L
.95689 0 L
.9571 0 L
.95729 0 L
.95748 0 L
.95769 0 L
.95789 0 L
.9581 0 L
.95832 0 L
.95852 0 L
.95872 0 L
.95891 0 L
.9591 0 L
.9593 0 L
.9595 0 L
.95971 0 L
.95992 0 L
.96012 0 L
.96031 0 L
.9605 0 L
.96068 0 L
.96088 0 L
.96107 0 L
.96128 0 L
.96147 0 L
.96168 0 L
.96187 0 L
.96205 0 L
.96225 0 L
.96243 0 L
.96262 0 L
.96282 0 L
.96301 0 L
.96321 0 L
Mistroke
.9634 0 L
.96358 0 L
.96377 0 L
.96395 0 L
.96413 0 L
.96433 0 L
.96452 0 L
.96472 0 L
.9649 0 L
.96507 0 L
.96526 0 L
.96544 0 L
.96562 0 L
.96581 0 L
.96599 0 L
.96619 0 L
.96639 0 L
.96658 0 L
.96676 0 L
.96694 0 L
.96711 0 L
.9673 0 L
.96748 0 L
.96767 0 L
.96787 0 L
.96805 0 L
.96824 0 L
.96841 0 L
.96859 0 L
.96876 0 L
.96894 0 L
.96913 0 L
.96931 0 L
.9695 0 L
.96968 0 L
.96985 0 L
.97003 0 L
.9702 0 L
.97037 0 L
.97056 0 L
.97074 0 L
.97092 0 L
.9711 0 L
.97126 0 L
.97144 0 L
.97161 0 L
.97178 0 L
.97196 0 L
.97213 0 L
.97232 0 L
Mistroke
.97251 0 L
.97269 0 L
.97286 0 L
.97302 0 L
.97319 0 L
.97337 0 L
.97354 0 L
.97372 0 L
.97391 0 L
.97408 0 L
.97426 0 L
.97442 0 L
.97459 0 L
.97475 0 L
.97492 0 L
.9751 0 L
.97527 0 L
.97545 0 L
.97562 0 L
.97578 0 L
.97596 0 L
.97611 0 L
.97628 0 L
.97646 0 L
.97662 0 L
.9768 0 L
.97697 0 L
.97712 0 L
.97729 0 L
.97745 0 L
.97761 0 L
.97778 0 L
.97795 0 L
.97813 0 L
.97831 0 L
.97847 0 L
.97864 0 L
.9788 0 L
.97895 0 L
.97912 0 L
.97929 0 L
.97946 0 L
.97963 0 L
.9798 0 L
.97997 0 L
.98012 0 L
.98027 0 L
.98044 0 L
.9806 0 L
.98077 0 L
Mistroke
.98093 0 L
.98111 0 L
.98127 0 L
.98142 0 L
.98158 0 L
.98173 0 L
.98189 0 L
.98206 0 L
.98222 0 L
.98239 0 L
.98254 0 L
.98269 0 L
.98285 0 L
.983 0 L
.98316 0 L
.98332 0 L
.98348 0 L
.98365 0 L
.98382 0 L
.98398 0 L
.98414 0 L
.98428 0 L
.98443 0 L
.9846 0 L
.98475 0 L
.98491 0 L
.98508 0 L
.98524 0 L
.9854 0 L
.98554 0 L
.98569 0 L
.98585 0 L
.986 0 L
.98616 0 L
.98632 0 L
.98648 0 L
.98664 0 L
.98678 0 L
.98694 0 L
.98708 0 L
.98723 0 L
.98739 0 L
.98754 0 L
.9877 0 L
.98785 0 L
.98799 0 L
.98815 0 L
.98829 0 L
.98844 0 L
.9886 0 L
Mistroke
.98875 0 L
.9889 0 L
.98907 0 L
.98922 0 L
.98937 0 L
.98951 0 L
.98966 0 L
.98981 0 L
.98996 0 L
.99012 0 L
.99028 0 L
.99043 0 L
.99058 0 L
.99071 0 L
.99085 0 L
.99101 0 L
.99115 0 L
.99131 0 L
.99146 0 L
.99161 0 L
.99176 0 L
.9919 0 L
.99205 0 L
.99218 0 L
.99233 0 L
.99248 0 L
.99263 0 L
.99278 0 L
.99292 0 L
.99306 0 L
.99321 0 L
.99334 0 L
.99348 0 L
.99363 0 L
.99378 0 L
.99393 0 L
.99407 0 L
.9942 0 L
.99435 0 L
.99448 0 L
.99462 0 L
.99477 0 L
.99491 0 L
.99506 0 L
.99521 0 L
.99535 0 L
.9955 0 L
.99563 0 L
.99576 0 L
.99591 0 L
Mistroke
.99605 0 L
.9962 0 L
.99635 0 L
.99649 0 L
.99663 0 L
.99676 0 L
.99691 0 L
.99704 0 L
.99717 0 L
.99732 0 L
.99746 0 L
.99761 0 L
.99774 0 L
.99787 0 L
.99802 0 L
.99815 0 L
.99828 0 L
.99842 0 L
.99856 0 L
.99871 0 L
.99884 0 L
.99897 0 L
.99911 0 L
.99924 0 L
.99937 0 L
.99951 0 L
.99965 0 L
.99979 0 L
1 0 L
Mfstroke
0 .00058 m
.03792 .00096 L
.0855 .00223 L
.1169 .00388 L
.13958 .00574 L
.157 .00774 L
.17336 .0102 L
.18838 .0131 L
.21425 .01996 L
.23393 .02723 L
.25206 .03593 L
.26869 .04592 L
.29568 .06687 L
.31631 .08715 L
.34685 .12327 L
.37312 .15724 L
.39552 .18394 L
.40493 .19324 L
.41311 .19991 L
.41996 .20426 L
.42364 .20607 L
.42692 .20734 L
.42985 .2082 L
.43146 .20856 L
.43291 .2088 L
.43424 .20897 L
.43566 .20908 L
.437 .20912 L
.43821 .2091 L
.4396 .20902 L
.44089 .20888 L
.44229 .20866 L
.44378 .20835 L
.44674 .2075 L
.44939 .20645 L
.45427 .20385 L
.45936 .20018 L
.46896 .19066 L
.47795 .17883 L
.48553 .16693 L
.50081 .13882 L
.5251 .08971 L
.54424 .0549 L
.55278 .04202 L
.56147 .03095 L
.57581 .01722 L
.58225 .01277 L
.58877 .00921 L
.595 .00658 L
.6006 .00476 L
Mistroke
.60586 .00344 L
.61051 .00255 L
.61549 .00181 L
.61981 .00133 L
.62411 .00096 L
.62858 .00068 L
.63269 .00048 L
.63686 .00034 L
.64062 .00024 L
.64402 .00018 L
.64767 .00012 L
.65089 9e-05 L
.6541 6e-05 L
.6575 4e-05 L
.66064 3e-05 L
.66387 2e-05 L
.66679 2e-05 L
.66945 1e-05 L
.67233 1e-05 L
.67489 1e-05 L
.67746 0 L
.6802 0 L
.68273 0 L
.68537 0 L
.688 0 L
.69042 0 L
.69277 0 L
.69489 0 L
.69702 0 L
.6993 0 L
.70141 0 L
.70363 0 L
.70584 0 L
.70789 0 L
.70988 0 L
.71169 0 L
.7135 0 L
.71545 0 L
.71726 0 L
.71918 0 L
.72098 0 L
.72286 0 L
.72458 0 L
.72616 0 L
.72789 0 L
.72944 0 L
.73102 0 L
.7327 0 L
.73429 0 L
.73594 0 L
Mistroke
.73746 0 L
.73886 0 L
.74039 0 L
.74177 0 L
.74316 0 L
.74467 0 L
.74607 0 L
.74756 0 L
.74827 0 L
.74905 0 L
.75043 0 L
.75179 0 L
.7532 0 L
.7545 0 L
.7557 0 L
.75702 0 L
.75821 0 L
.75941 0 L
.76071 0 L
.76193 0 L
.76322 0 L
.76439 0 L
.76549 0 L
.76668 0 L
.76776 0 L
.76886 0 L
.77005 0 L
.77116 0 L
.77234 0 L
.77291 0 L
.77352 0 L
.77463 0 L
.77571 0 L
.77625 0 L
.77684 0 L
.77788 0 L
.77898 0 L
.77952 0 L
.78009 0 L
.78113 0 L
.78214 0 L
.78321 0 L
.78373 0 L
.78429 0 L
.78529 0 L
.78628 0 L
.78677 0 L
.78731 0 L
.78825 0 L
.78926 0 L
Mistroke
.78975 0 L
.79027 0 L
.79122 0 L
.79215 0 L
.79261 0 L
.79312 0 L
.79401 0 L
.79496 0 L
.79542 0 L
.79591 0 L
.79681 0 L
.79769 0 L
.79861 0 L
.79906 0 L
.79954 0 L
.80042 0 L
.80127 0 L
.8017 0 L
.80217 0 L
.80299 0 L
.80387 0 L
.80429 0 L
.80475 0 L
.80558 0 L
.80639 0 L
.8068 0 L
.80724 0 L
.80802 0 L
.80842 0 L
.80886 0 L
.80965 0 L
.81009 0 L
.81049 0 L
.81129 0 L
.81201 0 L
.81275 0 L
.81313 0 L
.81355 0 L
.8143 0 L
.81471 0 L
.8151 0 L
.81586 0 L
.81655 0 L
.81725 0 L
.81765 0 L
.81802 0 L
.81874 0 L
.81913 0 L
.8195 0 L
.82022 0 L
Mistroke
.82088 0 L
.82155 0 L
.82228 0 L
.82297 0 L
.8237 0 L
.82406 0 L
.82444 0 L
.82513 0 L
.82581 0 L
.82615 0 L
.82652 0 L
.82718 0 L
.82751 0 L
.82788 0 L
.82855 0 L
.82891 0 L
.82925 0 L
.82992 0 L
.83053 0 L
.83116 0 L
.83148 0 L
.83183 0 L
.83247 0 L
.83282 0 L
.83315 0 L
.83379 0 L
.83438 0 L
.83498 0 L
.83529 0 L
.83563 0 L
.83624 0 L
.83657 0 L
.83689 0 L
.83751 0 L
.83807 0 L
.83865 0 L
.83897 0 L
.83927 0 L
.83986 0 L
.84018 0 L
.84049 0 L
.84108 0 L
.84162 0 L
.84218 0 L
.84278 0 L
.84334 0 L
.84395 0 L
.84424 0 L
.84456 0 L
.84513 0 L
Mistroke
.84569 0 L
.846 0 L
.84629 0 L
.84683 0 L
.84711 0 L
.84741 0 L
.84797 0 L
.84827 0 L
.84855 0 L
.84911 0 L
.84962 0 L
.85015 0 L
.85041 0 L
.85071 0 L
.85125 0 L
.85154 0 L
.85181 0 L
.85235 0 L
.85285 0 L
.85335 0 L
.85363 0 L
.85389 0 L
.85441 0 L
.85469 0 L
.85496 0 L
.85548 0 L
.85596 0 L
.85644 0 L
.85697 0 L
.85747 0 L
.85774 0 L
.858 0 L
.85848 0 L
.85875 0 L
.859 0 L
.8595 0 L
.85977 0 L
.86002 0 L
.86052 0 L
.86098 0 L
.86144 0 L
.86171 0 L
.86195 0 L
.86243 0 L
.86269 0 L
.86293 0 L
.86342 0 L
.86386 0 L
.86431 0 L
.8648 0 L
Mistroke
.86526 0 L
.86576 0 L
.86599 0 L
.86625 0 L
.86672 0 L
.86718 0 L
.86744 0 L
.86767 0 L
.86812 0 L
.86834 0 L
.8686 0 L
.86905 0 L
.8693 0 L
.86953 0 L
.87 0 L
.87042 0 L
.87085 0 L
.87107 0 L
.87131 0 L
.87176 0 L
.872 0 L
.87222 0 L
.87267 0 L
.87308 0 L
.8735 0 L
.87374 0 L
.87395 0 L
.87438 0 L
.87461 0 L
.87484 0 L
.87527 0 L
.87567 0 L
.87607 0 L
.87651 0 L
.87693 0 L
.87716 0 L
.87737 0 L
.87777 0 L
.878 0 L
.87821 0 L
.87863 0 L
.87885 0 L
.87906 0 L
.87948 0 L
.87987 0 L
.88026 0 L
.88048 0 L
.88068 0 L
.88108 0 L
.8813 0 L
Mistroke
.88151 0 L
.88192 0 L
.88229 0 L
.88267 0 L
.88309 0 L
.88348 0 L
.88369 0 L
.88389 0 L
.88427 0 L
.88449 0 L
.88468 0 L
.88507 0 L
.88528 0 L
.88549 0 L
.88588 0 L
.88624 0 L
.88661 0 L
.88682 0 L
.88701 0 L
.88739 0 L
.88759 0 L
.88779 0 L
.88817 0 L
.88852 0 L
.88892 0 L
.88927 0 L
.88964 0 L
.88983 0 L
.89003 0 L
.89041 0 L
.89062 0 L
.89081 0 L
.89119 0 L
.89154 0 L
.89189 0 L
.89207 0 L
.89228 0 L
.89264 0 L
.89284 0 L
.89303 0 L
.8934 0 L
.89374 0 L
.89408 0 L
.89428 0 L
.89446 0 L
.89482 0 L
.89501 0 L
.8952 0 L
.89556 0 L
.89589 0 L
Mistroke
.89622 0 L
.89642 0 L
.89659 0 L
.89694 0 L
.89713 0 L
.89731 0 L
.89766 0 L
.89798 0 L
.89831 0 L
.89867 0 L
.89901 0 L
.89919 0 L
.89937 0 L
.89969 0 L
.89988 0 L
.90005 0 L
.90039 0 L
.90057 0 L
.90075 0 L
.90109 0 L
.9014 0 L
.90172 0 L
.9019 0 L
.90207 0 L
.9024 0 L
.90258 0 L
.90275 0 L
.90308 0 L
.90339 0 L
.90373 0 L
.90404 0 L
.90436 0 L
.90453 0 L
.90471 0 L
.90504 0 L
.90521 0 L
.90538 0 L
.90572 0 L
.90602 0 L
.90633 0 L
.90649 0 L
.90667 0 L
.90699 0 L
.90716 0 L
.90733 0 L
.90765 0 L
.90795 0 L
.90825 0 L
.90842 0 L
.90858 0 L
Mistroke
.90889 0 L
.90906 0 L
.90923 0 L
.90954 0 L
.90983 0 L
.91013 0 L
.9103 0 L
.91045 0 L
.91076 0 L
.91092 0 L
.91108 0 L
.91139 0 L
.91168 0 L
.91196 0 L
.91228 0 L
.91258 0 L
.91274 0 L
.9129 0 L
.91319 0 L
.91335 0 L
.9135 0 L
.9138 0 L
.91396 0 L
.91412 0 L
.91442 0 L
.9147 0 L
.91498 0 L
.91514 0 L
.91529 0 L
.91558 0 L
.91574 0 L
.91589 0 L
.91618 0 L
.91645 0 L
.91676 0 L
.91703 0 L
.91732 0 L
.91747 0 L
.91762 0 L
.9179 0 L
.91805 0 L
.9182 0 L
.91848 0 L
.91864 0 L
.91879 0 L
.91907 0 L
.91934 0 L
.91961 0 L
.91976 0 L
.9199 0 L
Mistroke
.92018 0 L
.92033 0 L
.92048 0 L
.92076 0 L
.92102 0 L
.92131 0 L
.92157 0 L
.92185 0 L
.92198 0 L
.92214 0 L
.92242 0 L
.92257 0 L
.92271 0 L
.92299 0 L
.92325 0 L
.92352 0 L
.92367 0 L
.9238 0 L
.92408 0 L
.92423 0 L
.92437 0 L
.92464 0 L
.9249 0 L
.92515 0 L
.9253 0 L
.92544 0 L
.9257 0 L
.92585 0 L
.92599 0 L
.92626 0 L
.92651 0 L
.92676 0 L
.9269 0 L
.92704 0 L
.9273 0 L
.92744 0 L
.92758 0 L
.92784 0 L
.92808 0 L
.92836 0 L
.9286 0 L
.92886 0 L
.92899 0 L
.92913 0 L
.92939 0 L
.92954 0 L
.92967 0 L
.92994 0 L
.93018 0 L
.93043 0 L
Mistroke
.93056 0 L
.9307 0 L
.93095 0 L
.93109 0 L
.93123 0 L
.93149 0 L
.93172 0 L
.93197 0 L
.93211 0 L
.93223 0 L
.93248 0 L
.93262 0 L
.93275 0 L
.933 0 L
.93324 0 L
.93348 0 L
.93361 0 L
.93374 0 L
.93398 0 L
.93412 0 L
.93424 0 L
.93449 0 L
.93472 0 L
.93498 0 L
.93521 0 L
.93545 0 L
.93559 0 L
.93571 0 L
.93594 0 L
.93608 0 L
.9362 0 L
.93644 0 L
.93657 0 L
.9367 0 L
.93694 0 L
.93717 0 L
.9374 0 L
.93753 0 L
.93765 0 L
.93788 0 L
.93801 0 L
.93814 0 L
.93838 0 L
.9386 0 L
.93885 0 L
.93907 0 L
.9393 0 L
.93942 0 L
.93955 0 L
.93979 0 L
Mistroke
.93992 0 L
.94004 0 L
.94028 0 L
.9405 0 L
.94073 0 L
.94084 0 L
.94097 0 L
.9412 0 L
.94133 0 L
.94145 0 L
.94169 0 L
.9419 0 L
.94213 0 L
.94225 0 L
.94237 0 L
.94259 0 L
.94272 0 L
.94284 0 L
.94307 0 L
.94328 0 L
.9435 0 L
.94362 0 L
.94374 0 L
.94396 0 L
.94408 0 L
.9442 0 L
.94443 0 L
.94464 0 L
.94487 0 L
.94508 0 L
.9453 0 L
.94542 0 L
.94554 0 L
.94575 0 L
.94587 0 L
.94598 0 L
.9462 0 L
.94632 0 L
.94644 0 L
.94666 0 L
.94687 0 L
.94708 0 L
.9472 0 L
.94731 0 L
.94752 0 L
.94764 0 L
.94775 0 L
.94797 0 L
.94818 0 L
.9484 0 L
Mistroke
.94861 0 L
.94882 0 L
.94893 0 L
.94905 0 L
.94926 0 L
.94938 0 L
.94949 0 L
.94971 0 L
.94992 0 L
.95012 0 L
.95024 0 L
.95035 0 L
.95056 0 L
.95068 0 L
.95079 0 L
.95101 0 L
.9512 0 L
.95141 0 L
.95152 0 L
.95163 0 L
.95184 0 L
.95195 0 L
.95206 0 L
.95227 0 L
.95247 0 L
.95267 0 L
.95278 0 L
.95289 0 L
.95309 0 L
.9532 0 L
.95331 0 L
.95352 0 L
.95371 0 L
.95393 0 L
.95412 0 L
.95432 0 L
.95444 0 L
.95454 0 L
.95474 0 L
.95485 0 L
.95495 0 L
.95515 0 L
.95526 0 L
.95537 0 L
.95558 0 L
.95577 0 L
.95596 0 L
.95607 0 L
.95617 0 L
.95637 0 L
Mistroke
.95647 0 L
.95658 0 L
.95678 0 L
.95697 0 L
.95718 0 L
.95737 0 L
.95756 0 L
.95766 0 L
.95777 0 L
.95797 0 L
.95808 0 L
.95818 0 L
.95839 0 L
.95857 0 L
.95877 0 L
.95887 0 L
.95897 0 L
.95917 0 L
.95928 0 L
.95938 0 L
.95958 0 L
.95976 0 L
.95995 0 L
.96006 0 L
.96016 0 L
.96035 0 L
.96045 0 L
.96055 0 L
.96075 0 L
.96093 0 L
.96112 0 L
.96122 0 L
.96132 0 L
.96151 0 L
.96161 0 L
.96171 0 L
.9619 0 L
.96208 0 L
.96228 0 L
.96246 0 L
.96265 0 L
.96275 0 L
.96285 0 L
.96303 0 L
.96313 0 L
.96323 0 L
.96342 0 L
.96352 0 L
.96362 0 L
.96381 0 L
Mistroke
.96398 0 L
.96418 0 L
.96436 0 L
.96454 0 L
.96464 0 L
.96474 0 L
.96492 0 L
.96502 0 L
.96511 0 L
.9653 0 L
.9654 0 L
.96549 0 L
.96568 0 L
.96586 0 L
.96603 0 L
.96613 0 L
.96622 0 L
.96641 0 L
.96651 0 L
.9666 0 L
.96679 0 L
.96696 0 L
.96715 0 L
.96732 0 L
.9675 0 L
.9676 0 L
.96769 0 L
.96786 0 L
.96796 0 L
.96805 0 L
.96823 0 L
.96833 0 L
.96843 0 L
.96861 0 L
.96878 0 L
.96895 0 L
.96904 0 L
.96913 0 L
.96931 0 L
.9694 0 L
.9695 0 L
.96968 0 L
.96985 0 L
.97003 0 L
.9702 0 L
.97037 0 L
.97047 0 L
.97056 0 L
.97073 0 L
.97082 0 L
Mistroke
.97091 0 L
.97109 0 L
.97118 0 L
.97127 0 L
.97145 0 L
.97161 0 L
.9718 0 L
.97196 0 L
.97213 0 L
.97223 0 L
.97232 0 L
.97248 0 L
.97258 0 L
.97267 0 L
.97284 0 L
.97293 0 L
.97302 0 L
.9732 0 L
.97336 0 L
.97352 0 L
.97362 0 L
.9737 0 L
.97387 0 L
.97396 0 L
.97406 0 L
.97423 0 L
.97439 0 L
.97457 0 L
.97473 0 L
.97489 0 L
.97499 0 L
.97507 0 L
.97523 0 L
.97533 0 L
.97541 0 L
.97558 0 L
.97567 0 L
.97576 0 L
.97593 0 L
.97609 0 L
.97625 0 L
.97634 0 L
.97642 0 L
.97659 0 L
.97667 0 L
.97676 0 L
.97693 0 L
.97709 0 L
.97726 0 L
.97742 0 L
Mistroke
.97758 0 L
.97766 0 L
.97775 0 L
.97792 0 L
.97801 0 L
.9781 0 L
.97827 0 L
.97842 0 L
.97858 0 L
.97867 0 L
.97875 0 L
.97892 0 L
.97901 0 L
.97909 0 L
.97926 0 L
.97941 0 L
.97957 0 L
.97966 0 L
.97974 0 L
.9799 0 L
.97999 0 L
.98007 0 L
.98024 0 L
.98039 0 L
.98054 0 L
.98063 0 L
.98071 0 L
.98087 0 L
.98095 0 L
.98104 0 L
.9812 0 L
.98135 0 L
.98152 0 L
.98167 0 L
.98182 0 L
.98191 0 L
.98199 0 L
.98214 0 L
.98223 0 L
.98231 0 L
.98247 0 L
.98255 0 L
.98263 0 L
.98279 0 L
.98294 0 L
.98311 0 L
.98326 0 L
.98341 0 L
.9835 0 L
.98358 0 L
Mistroke
.98373 0 L
.98381 0 L
.98389 0 L
.98405 0 L
.98413 0 L
.98421 0 L
.98437 0 L
.98452 0 L
.98466 0 L
.98475 0 L
.98483 0 L
.98498 0 L
.98506 0 L
.98514 0 L
.9853 0 L
.98544 0 L
.9856 0 L
.98575 0 L
.9859 0 L
.98599 0 L
.98606 0 L
.98621 0 L
.98629 0 L
.98637 0 L
.98652 0 L
.98661 0 L
.98668 0 L
.98684 0 L
.98698 0 L
.98712 0 L
.98721 0 L
.98728 0 L
.98743 0 L
.98751 0 L
.98759 0 L
.98774 0 L
.98789 0 L
.98804 0 L
.98818 0 L
.98833 0 L
.98841 0 L
.98849 0 L
.98863 0 L
.98871 0 L
.98879 0 L
.98894 0 L
.98902 0 L
.9891 0 L
.98925 0 L
.98938 0 L
Mistroke
.98954 0 L
.98968 0 L
.98983 0 L
.98991 0 L
.98998 0 L
.99012 0 L
.9902 0 L
.99028 0 L
.99043 0 L
.99051 0 L
.99058 0 L
.99073 0 L
.99087 0 L
.99101 0 L
.99109 0 L
.99116 0 L
.99131 0 L
.99138 0 L
.99146 0 L
.99161 0 L
.99174 0 L
.99189 0 L
.99203 0 L
.99217 0 L
.99225 0 L
.99233 0 L
.99246 0 L
.99254 0 L
.99262 0 L
.99276 0 L
.99284 0 L
.99291 0 L
.99306 0 L
.99319 0 L
.99334 0 L
.99348 0 L
.99362 0 L
.9937 0 L
.99377 0 L
.99391 0 L
.99399 0 L
.99406 0 L
.9942 0 L
.99428 0 L
.99435 0 L
.99449 0 L
.99463 0 L
.99476 0 L
.99484 0 L
.99491 0 L
Mistroke
.99505 0 L
.99513 0 L
.9952 0 L
.99534 0 L
.99547 0 L
.99562 0 L
.99575 0 L
.99589 0 L
.99597 0 L
.99604 0 L
.99617 0 L
.99625 0 L
.99632 0 L
.99646 0 L
.99653 0 L
.9966 0 L
.99674 0 L
.99687 0 L
.99701 0 L
.99708 0 L
.99715 0 L
.99729 0 L
.99736 0 L
.99743 0 L
.99757 0 L
.9977 0 L
.99784 0 L
.99797 0 L
.99811 0 L
.99818 0 L
.99825 0 L
.99838 0 L
.99846 0 L
.99853 0 L
.99866 0 L
.99874 0 L
.99881 0 L
.99895 0 L
.99907 0 L
.99921 0 L
.99934 0 L
.99948 0 L
.99955 0 L
.99962 0 L
.99975 0 L
.99989 0 L
1 0 L
Mfstroke
0 .02795 m
.03792 .03724 L
.0855 .05592 L
.1169 .07248 L
.18838 .12534 L
.26869 .2043 L
.29252 .22616 L
.31311 .24132 L
.32249 .2465 L
.32715 .24858 L
.33195 .25035 L
.33618 .25157 L
.3399 .25236 L
.34352 .25288 L
.34685 .25311 L
.34868 .25315 L
.35062 .2531 L
.35406 .25282 L
.3573 .25231 L
.36021 .25165 L
.36327 .25075 L
.36653 .24953 L
.37284 .24646 L
.37806 .24316 L
.3834 .2391 L
.39242 .23063 L
.41182 .20589 L
.42692 .18132 L
.47046 .09877 L
.50042 .04953 L
.51315 .03388 L
.52522 .02236 L
.53532 .01507 L
.54401 .01034 L
.55287 .00678 L
.5604 .00459 L
.5676 .00306 L
.57151 .00243 L
.57496 .00196 L
.5815 .00128 L
.58493 .00101 L
.58808 .00081 L
.591 .00066 L
.59401 .00052 L
.59921 .00035 L
.60177 .00028 L
.60446 .00023 L
.60915 .00015 L
.61167 .00012 L
.61434 9e-05 L
Mistroke
.61684 7e-05 L
.61905 6e-05 L
.62347 4e-05 L
.62582 3e-05 L
.62799 2e-05 L
.63004 2e-05 L
.63215 2e-05 L
.63584 1e-05 L
.63769 1e-05 L
.63964 1e-05 L
.64306 0 L
.64492 0 L
.6469 0 L
.64858 0 L
.65041 0 L
.65376 0 L
.65555 0 L
.6572 0 L
.65878 0 L
.66041 0 L
.66327 0 L
.66472 0 L
.66625 0 L
.66894 0 L
.67041 0 L
.67199 0 L
.67333 0 L
.67479 0 L
.67748 0 L
.67893 0 L
.68026 0 L
.68162 0 L
.68288 0 L
.68522 0 L
.68641 0 L
.68767 0 L
.68988 0 L
.691 0 L
.69218 0 L
.69429 0 L
.69538 0 L
.69656 0 L
.69779 0 L
.6989 0 L
.70103 0 L
.70219 0 L
.70326 0 L
.70428 0 L
.70535 0 L
.70724 0 L
Mistroke
.7082 0 L
.70921 0 L
.71103 0 L
.71201 0 L
.71308 0 L
.71409 0 L
.715 0 L
.71685 0 L
.71785 0 L
.71878 0 L
.71967 0 L
.72061 0 L
.72225 0 L
.72309 0 L
.72398 0 L
.72557 0 L
.72644 0 L
.72738 0 L
.72818 0 L
.72906 0 L
.7307 0 L
.73158 0 L
.7324 0 L
.73319 0 L
.73402 0 L
.73548 0 L
.73623 0 L
.73702 0 L
.73843 0 L
.73921 0 L
.74005 0 L
.74077 0 L
.74155 0 L
.74302 0 L
.74381 0 L
.74454 0 L
.74529 0 L
.746 0 L
.74731 0 L
.74798 0 L
.7487 0 L
.74997 0 L
.75067 0 L
.75143 0 L
.75208 0 L
.75279 0 L
.75411 0 L
.75483 0 L
.7555 0 L
.75618 0 L
Mistroke
.75682 0 L
.75801 0 L
.75863 0 L
.75927 0 L
.76043 0 L
.76101 0 L
.76164 0 L
.76276 0 L
.76337 0 L
.76404 0 L
.76467 0 L
.76524 0 L
.76641 0 L
.76704 0 L
.76764 0 L
.76821 0 L
.7688 0 L
.76986 0 L
.7704 0 L
.77098 0 L
.77201 0 L
.77258 0 L
.77319 0 L
.77372 0 L
.7743 0 L
.77538 0 L
.77596 0 L
.77651 0 L
.77704 0 L
.77759 0 L
.77857 0 L
.77907 0 L
.7796 0 L
.78056 0 L
.78109 0 L
.78166 0 L
.78215 0 L
.78268 0 L
.78369 0 L
.78423 0 L
.78474 0 L
.78526 0 L
.78575 0 L
.78666 0 L
.78713 0 L
.78762 0 L
.78851 0 L
.78901 0 L
.78954 0 L
.79 0 L
Mistroke
.7905 0 L
.79143 0 L
.79194 0 L
.79242 0 L
.7929 0 L
.79336 0 L
.79421 0 L
.79465 0 L
.79511 0 L
.79595 0 L
.79637 0 L
.79682 0 L
.79763 0 L
.79805 0 L
.79851 0 L
.799 0 L
.79944 0 L
.80029 0 L
.80075 0 L
.80119 0 L
.8016 0 L
.80204 0 L
.80282 0 L
.80322 0 L
.80365 0 L
.80441 0 L
.80483 0 L
.80529 0 L
.80568 0 L
.80611 0 L
.80692 0 L
.80736 0 L
.80777 0 L
.80816 0 L
.80858 0 L
.80931 0 L
.80969 0 L
.81009 0 L
.81081 0 L
.81121 0 L
.81164 0 L
.81202 0 L
.81242 0 L
.81319 0 L
.8136 0 L
.81399 0 L
.81438 0 L
.81476 0 L
.81546 0 L
.81581 0 L
Mistroke
.8162 0 L
.81688 0 L
.81726 0 L
.81767 0 L
.81802 0 L
.81841 0 L
.81914 0 L
.81953 0 L
.8199 0 L
.82027 0 L
.82063 0 L
.82129 0 L
.82163 0 L
.822 0 L
.82264 0 L
.82297 0 L
.82333 0 L
.82396 0 L
.82429 0 L
.82466 0 L
.82504 0 L
.82538 0 L
.82605 0 L
.82642 0 L
.82676 0 L
.82709 0 L
.82744 0 L
.82805 0 L
.82837 0 L
.82871 0 L
.82931 0 L
.82965 0 L
.83001 0 L
.83036 0 L
.83067 0 L
.83131 0 L
.83166 0 L
.83199 0 L
.8323 0 L
.83263 0 L
.83323 0 L
.83353 0 L
.83385 0 L
.83443 0 L
.83475 0 L
.8351 0 L
.8354 0 L
.83573 0 L
.83634 0 L
.83668 0 L
Mistroke
.83699 0 L
.83731 0 L
.83761 0 L
.83818 0 L
.83847 0 L
.83878 0 L
.83933 0 L
.83964 0 L
.83998 0 L
.84026 0 L
.84058 0 L
.84086 0 L
.84117 0 L
.84149 0 L
.84179 0 L
.84209 0 L
.84241 0 L
.84269 0 L
.843 0 L
.84358 0 L
.84389 0 L
.84418 0 L
.84446 0 L
.84476 0 L
.84529 0 L
.84556 0 L
.84585 0 L
.84637 0 L
.84666 0 L
.84697 0 L
.84724 0 L
.84753 0 L
.84809 0 L
.84839 0 L
.84867 0 L
.84896 0 L
.84923 0 L
.84974 0 L
.85 0 L
.85028 0 L
.85078 0 L
.85106 0 L
.85136 0 L
.85162 0 L
.8519 0 L
.85216 0 L
.85243 0 L
.85273 0 L
.853 0 L
.85327 0 L
Mistroke
.85356 0 L
.85381 0 L
.85409 0 L
.85461 0 L
.85489 0 L
.85516 0 L
.85541 0 L
.85568 0 L
.85616 0 L
.85641 0 L
.85667 0 L
.85714 0 L
.8574 0 L
.85768 0 L
.85793 0 L
.8582 0 L
.85844 0 L
.8587 0 L
.85897 0 L
.85923 0 L
.85948 0 L
.85976 0 L
.86002 0 L
.86026 0 L
.86075 0 L
.86101 0 L
.86126 0 L
.86151 0 L
.86176 0 L
.86221 0 L
.86244 0 L
.86269 0 L
.86314 0 L
.86338 0 L
.86365 0 L
.86388 0 L
.86413 0 L
.86461 0 L
.86487 0 L
.86511 0 L
.86535 0 L
.86559 0 L
.86603 0 L
.86625 0 L
.86649 0 L
.86692 0 L
.86716 0 L
.86742 0 L
.86764 0 L
.86789 0 L
Mistroke
.86811 0 L
.86835 0 L
.8686 0 L
.86883 0 L
.86907 0 L
.86932 0 L
.86954 0 L
.86978 0 L
.87023 0 L
.87047 0 L
.8707 0 L
.87092 0 L
.87116 0 L
.87157 0 L
.87178 0 L
.87201 0 L
.87242 0 L
.87265 0 L
.87289 0 L
.87311 0 L
.87334 0 L
.87355 0 L
.87378 0 L
.87401 0 L
.87424 0 L
.87446 0 L
.8747 0 L
.87493 0 L
.87513 0 L
.87556 0 L
.87579 0 L
.87601 0 L
.87622 0 L
.87644 0 L
.87684 0 L
.87704 0 L
.87726 0 L
.87764 0 L
.87786 0 L
.87809 0 L
.8783 0 L
.87852 0 L
.87893 0 L
.87916 0 L
.87937 0 L
.87958 0 L
.87979 0 L
.88017 0 L
.88037 0 L
.88058 0 L
Mistroke
.88096 0 L
.88117 0 L
.8814 0 L
.8816 0 L
.88181 0 L
.88201 0 L
.88222 0 L
.88244 0 L
.88264 0 L
.88285 0 L
.88307 0 L
.88326 0 L
.88347 0 L
.88387 0 L
.88409 0 L
.88429 0 L
.88448 0 L
.88469 0 L
.88505 0 L
.88524 0 L
.88544 0 L
.8858 0 L
.886 0 L
.88622 0 L
.88641 0 L
.88662 0 L
.8868 0 L
.887 0 L
.88721 0 L
.88741 0 L
.8876 0 L
.88782 0 L
.88802 0 L
.8882 0 L
.88858 0 L
.88879 0 L
.88898 0 L
.88917 0 L
.88936 0 L
.88971 0 L
.88989 0 L
.89009 0 L
.89043 0 L
.89062 0 L
.89083 0 L
.89101 0 L
.89121 0 L
.89158 0 L
.89178 0 L
.89197 0 L
Mistroke
.89215 0 L
.89234 0 L
.89268 0 L
.89286 0 L
.89305 0 L
.89338 0 L
.89357 0 L
.89377 0 L
.89395 0 L
.89414 0 L
.89431 0 L
.8945 0 L
.8947 0 L
.89488 0 L
.89506 0 L
.89526 0 L
.89545 0 L
.89562 0 L
.89598 0 L
.89617 0 L
.89635 0 L
.89653 0 L
.89671 0 L
.89704 0 L
.89721 0 L
.89739 0 L
.89771 0 L
.89789 0 L
.89808 0 L
.89825 0 L
.89844 0 L
.8986 0 L
.89878 0 L
.89897 0 L
.89915 0 L
.89932 0 L
.89951 0 L
.89969 0 L
.89986 0 L
.9002 0 L
.90038 0 L
.90056 0 L
.90073 0 L
.9009 0 L
.90122 0 L
.90138 0 L
.90155 0 L
.90186 0 L
.90203 0 L
.90222 0 L
Mistroke
.90238 0 L
.90256 0 L
.90289 0 L
.90307 0 L
.90324 0 L
.90341 0 L
.90358 0 L
.90389 0 L
.90405 0 L
.90421 0 L
.90452 0 L
.90469 0 L
.90487 0 L
.90503 0 L
.9052 0 L
.90536 0 L
.90553 0 L
.9057 0 L
.90587 0 L
.90604 0 L
.90622 0 L
.90639 0 L
.90654 0 L
.90686 0 L
.90704 0 L
.9072 0 L
.90736 0 L
.90752 0 L
.90782 0 L
.90797 0 L
.90813 0 L
.90843 0 L
.90859 0 L
.90877 0 L
.90892 0 L
.90909 0 L
.90924 0 L
.9094 0 L
.90957 0 L
.90973 0 L
.91005 0 L
.9102 0 L
.91038 0 L
.91053 0 L
.91068 0 L
.91085 0 L
.91101 0 L
.91116 0 L
.91132 0 L
.91161 0 L
Mistroke
.91175 0 L
.91191 0 L
.91219 0 L
.91235 0 L
.91252 0 L
.91267 0 L
.91283 0 L
.91313 0 L
.91329 0 L
.91345 0 L
.9136 0 L
.91376 0 L
.91404 0 L
.91418 0 L
.91433 0 L
.91461 0 L
.91476 0 L
.91493 0 L
.91507 0 L
.91523 0 L
.91538 0 L
.91553 0 L
.91569 0 L
.91584 0 L
.91599 0 L
.91616 0 L
.91631 0 L
.91645 0 L
.91675 0 L
.9169 0 L
.91705 0 L
.9172 0 L
.91735 0 L
.91762 0 L
.91776 0 L
.91791 0 L
.91817 0 L
.91832 0 L
.91848 0 L
.91862 0 L
.91878 0 L
.91891 0 L
.91906 0 L
.91922 0 L
.91937 0 L
.91965 0 L
.9198 0 L
.91996 0 L
.92024 0 L
.92039 0 L
Mistroke
.92054 0 L
.92081 0 L
.92096 0 L
.9211 0 L
.92137 0 L
.92152 0 L
.92166 0 L
.92181 0 L
.92195 0 L
.92221 0 L
.92234 0 L
.92249 0 L
.92274 0 L
.92289 0 L
.92304 0 L
.92318 0 L
.92332 0 L
.92346 0 L
.9236 0 L
.92375 0 L
.92389 0 L
.92403 0 L
.92419 0 L
.92432 0 L
.92446 0 L
.9246 0 L
.92474 0 L
.92489 0 L
.92502 0 L
.9253 0 L
.92544 0 L
.92559 0 L
.92572 0 L
.92585 0 L
.926 0 L
.92614 0 L
.92627 0 L
.92641 0 L
.92666 0 L
.92679 0 L
.92692 0 L
.92717 0 L
.9273 0 L
.92745 0 L
.92758 0 L
.92772 0 L
.92785 0 L
.92798 0 L
.92813 0 L
.92826 0 L
Mistroke
.92853 0 L
.92866 0 L
.92881 0 L
.92907 0 L
.92921 0 L
.92934 0 L
.92959 0 L
.92974 0 L
.92987 0 L
.93011 0 L
.93025 0 L
.93038 0 L
.93052 0 L
.93064 0 L
.93088 0 L
.93101 0 L
.93114 0 L
.93138 0 L
.93151 0 L
.93165 0 L
.93178 0 L
.93191 0 L
.93204 0 L
.93217 0 L
.93231 0 L
.93244 0 L
.93257 0 L
.93271 0 L
.93283 0 L
.93297 0 L
.93309 0 L
.93322 0 L
.93336 0 L
.93348 0 L
.93374 0 L
.93386 0 L
.934 0 L
.93413 0 L
.93425 0 L
.93439 0 L
.93451 0 L
.93464 0 L
.93476 0 L
.93499 0 L
.93511 0 L
.93524 0 L
.93547 0 L
.93559 0 L
.93573 0 L
.93586 0 L
Mistroke
.93598 0 L
.93622 0 L
.93636 0 L
.93648 0 L
.9366 0 L
.93673 0 L
.93696 0 L
.93707 0 L
.9372 0 L
.93742 0 L
.93755 0 L
.93768 0 L
.9378 0 L
.93793 0 L
.93804 0 L
.93817 0 L
.9383 0 L
.93842 0 L
.93854 0 L
.93868 0 L
.9388 0 L
.93892 0 L
.93915 0 L
.93928 0 L
.93941 0 L
.93952 0 L
.93965 0 L
.93987 0 L
.93998 0 L
.9401 0 L
.94032 0 L
.94044 0 L
.94057 0 L
.94068 0 L
.94081 0 L
.94092 0 L
.94104 0 L
.94117 0 L
.94129 0 L
.94153 0 L
.94164 0 L
.94177 0 L
.94189 0 L
.942 0 L
.94213 0 L
.94225 0 L
.94236 0 L
.94248 0 L
.9427 0 L
.94281 0 L
Mistroke
.94292 0 L
.94314 0 L
.94325 0 L
.94338 0 L
.9435 0 L
.94361 0 L
.94384 0 L
.94396 0 L
.94408 0 L
.94419 0 L
.94431 0 L
.94452 0 L
.94463 0 L
.94475 0 L
.94496 0 L
.94507 0 L
.9452 0 L
.94531 0 L
.94543 0 L
.94553 0 L
.94565 0 L
.94577 0 L
.94589 0 L
.94611 0 L
.94623 0 L
.94635 0 L
.94646 0 L
.94657 0 L
.9467 0 L
.94681 0 L
.94692 0 L
.94703 0 L
.94724 0 L
.94734 0 L
.94746 0 L
.94766 0 L
.94777 0 L
.94789 0 L
.948 0 L
.94812 0 L
.94822 0 L
.94834 0 L
.94845 0 L
.94857 0 L
.94879 0 L
.9489 0 L
.94902 0 L
.94923 0 L
.94935 0 L
.94946 0 L
Mistroke
.94967 0 L
.94979 0 L
.9499 0 L
.9501 0 L
.95022 0 L
.95032 0 L
.95044 0 L
.95054 0 L
.95074 0 L
.95085 0 L
.95096 0 L
.95116 0 L
.95127 0 L
.95139 0 L
.95149 0 L
.9516 0 L
.9517 0 L
.95182 0 L
.95193 0 L
.95204 0 L
.95215 0 L
.95227 0 L
.95237 0 L
.95248 0 L
.95258 0 L
.95269 0 L
.95281 0 L
.95291 0 L
.95312 0 L
.95323 0 L
.95335 0 L
.95345 0 L
.95355 0 L
.95367 0 L
.95377 0 L
.95388 0 L
.95398 0 L
.95418 0 L
.95428 0 L
.95438 0 L
.95457 0 L
.95468 0 L
.95479 0 L
.9549 0 L
.955 0 L
.95521 0 L
.95532 0 L
.95542 0 L
.95553 0 L
.95563 0 L
Mistroke
.95582 0 L
.95592 0 L
.95602 0 L
.95621 0 L
.95632 0 L
.95643 0 L
.95653 0 L
.95664 0 L
.95674 0 L
.95684 0 L
.95695 0 L
.95705 0 L
.95716 0 L
.95727 0 L
.95738 0 L
.95747 0 L
.95767 0 L
.95778 0 L
.95788 0 L
.95798 0 L
.95809 0 L
.95827 0 L
.95837 0 L
.95847 0 L
.95865 0 L
.95876 0 L
.95887 0 L
.95896 0 L
.95907 0 L
.95916 0 L
.95927 0 L
.95937 0 L
.95948 0 L
.95967 0 L
.95977 0 L
.95988 0 L
.95998 0 L
.96008 0 L
.96019 0 L
.96029 0 L
.96038 0 L
.96048 0 L
.96067 0 L
.96076 0 L
.96086 0 L
.96104 0 L
.96114 0 L
.96125 0 L
.96135 0 L
.96144 0 L
Mistroke
.96163 0 L
.96174 0 L
.96184 0 L
.96193 0 L
.96203 0 L
.96221 0 L
.96231 0 L
.96241 0 L
.96258 0 L
.96268 0 L
.96279 0 L
.96288 0 L
.96298 0 L
.96307 0 L
.96317 0 L
.96328 0 L
.96338 0 L
.96357 0 L
.96366 0 L
.96377 0 L
.96387 0 L
.96396 0 L
.96406 0 L
.96416 0 L
.96425 0 L
.96435 0 L
.96452 0 L
.96461 0 L
.96471 0 L
.96488 0 L
.96498 0 L
.96509 0 L
.96519 0 L
.96528 0 L
.96537 0 L
.96546 0 L
.96556 0 L
.96566 0 L
.96585 0 L
.96594 0 L
.96605 0 L
.96623 0 L
.96633 0 L
.96642 0 L
.9666 0 L
.9667 0 L
.9668 0 L
.96697 0 L
.96707 0 L
.96716 0 L
Mistroke
.96726 0 L
.96735 0 L
.96752 0 L
.96761 0 L
.9677 0 L
.96787 0 L
.96797 0 L
.96807 0 L
.96816 0 L
.96826 0 L
.96835 0 L
.96844 0 L
.96854 0 L
.96863 0 L
.96873 0 L
.96883 0 L
.96891 0 L
.96901 0 L
.9691 0 L
.96919 0 L
.96929 0 L
.96938 0 L
.96956 0 L
.96966 0 L
.96976 0 L
.96985 0 L
.96993 0 L
.97003 0 L
.97012 0 L
.97021 0 L
.9703 0 L
.97047 0 L
.97055 0 L
.97065 0 L
.97081 0 L
.9709 0 L
.971 0 L
.97109 0 L
.97118 0 L
.97136 0 L
.97145 0 L
.97154 0 L
.97163 0 L
.97172 0 L
.97189 0 L
.97197 0 L
.97206 0 L
.97222 0 L
.97231 0 L
.97241 0 L
Mistroke
.9725 0 L
.97259 0 L
.97267 0 L
.97276 0 L
.97286 0 L
.97295 0 L
.97313 0 L
.97321 0 L
.97331 0 L
.9734 0 L
.97348 0 L
.97358 0 L
.97367 0 L
.97375 0 L
.97384 0 L
.974 0 L
.97409 0 L
.97417 0 L
.97433 0 L
.97442 0 L
.97452 0 L
.9746 0 L
.97469 0 L
.97477 0 L
.97486 0 L
.97496 0 L
.97504 0 L
.97522 0 L
.9753 0 L
.9754 0 L
.97548 0 L
.97557 0 L
.97566 0 L
.97575 0 L
.97583 0 L
.97592 0 L
.97607 0 L
.97615 0 L
.97624 0 L
.9764 0 L
.97648 0 L
.97658 0 L
.97667 0 L
.97675 0 L
.97692 0 L
.97701 0 L
.97709 0 L
.97718 0 L
.97726 0 L
.97742 0 L
Mistroke
.9775 0 L
.97759 0 L
.97774 0 L
.97783 0 L
.97792 0 L
.978 0 L
.97809 0 L
.97817 0 L
.97825 0 L
.97834 0 L
.97843 0 L
.9786 0 L
.97868 0 L
.97877 0 L
.97886 0 L
.97894 0 L
.97903 0 L
.97911 0 L
.97919 0 L
.97928 0 L
.97943 0 L
.97951 0 L
.97959 0 L
.97974 0 L
.97983 0 L
.97992 0 L
.98001 0 L
.98008 0 L
.98016 0 L
.98025 0 L
.98034 0 L
.98042 0 L
.98058 0 L
.98067 0 L
.98076 0 L
.98092 0 L
.98101 0 L
.98109 0 L
.98124 0 L
.98133 0 L
.98141 0 L
.98156 0 L
.98165 0 L
.98173 0 L
.98182 0 L
.9819 0 L
.98205 0 L
.98212 0 L
.98221 0 L
.98235 0 L
Mistroke
.98244 0 L
.98253 0 L
.9826 0 L
.98269 0 L
.98277 0 L
.98285 0 L
.98294 0 L
.98302 0 L
.9831 0 L
.98319 0 L
.98327 0 L
.98335 0 L
.98343 0 L
.98351 0 L
.98359 0 L
.98368 0 L
.98383 0 L
.98391 0 L
.984 0 L
.98408 0 L
.98416 0 L
.98425 0 L
.98432 0 L
.9844 0 L
.98448 0 L
.98463 0 L
.9847 0 L
.98478 0 L
.98493 0 L
.98501 0 L
.98509 0 L
.98518 0 L
.98525 0 L
.98533 0 L
.98541 0 L
.98549 0 L
.98557 0 L
.98573 0 L
.98581 0 L
.98589 0 L
.98604 0 L
.98613 0 L
.98621 0 L
.98636 0 L
.98644 0 L
.98652 0 L
.98666 0 L
.98674 0 L
.98682 0 L
.9869 0 L
Mistroke
.98698 0 L
.98712 0 L
.9872 0 L
.98727 0 L
.98742 0 L
.98749 0 L
.98758 0 L
.98765 0 L
.98774 0 L
.98781 0 L
.98789 0 L
.98797 0 L
.98805 0 L
.98813 0 L
.98821 0 L
.98828 0 L
.98836 0 L
.98844 0 L
.98852 0 L
.9886 0 L
.98868 0 L
.98883 0 L
.9889 0 L
.98899 0 L
.98906 0 L
.98914 0 L
.98922 0 L
.98929 0 L
.98937 0 L
.98945 0 L
.98959 0 L
.98966 0 L
.98973 0 L
.98987 0 L
.98995 0 L
.99003 0 L
.99011 0 L
.99018 0 L
.99033 0 L
.99041 0 L
.99048 0 L
.99056 0 L
.99064 0 L
.99077 0 L
.99084 0 L
.99092 0 L
.99106 0 L
.99113 0 L
.99121 0 L
.99129 0 L
Mistroke
.99136 0 L
.99143 0 L
.99151 0 L
.99159 0 L
.99167 0 L
.99181 0 L
.99189 0 L
.99197 0 L
.99205 0 L
.99212 0 L
.9922 0 L
.99227 0 L
.99234 0 L
.99242 0 L
.99255 0 L
.99262 0 L
.9927 0 L
.99283 0 L
.9929 0 L
.99299 0 L
.99306 0 L
.99313 0 L
.9932 0 L
.99328 0 L
.99336 0 L
.99343 0 L
.99357 0 L
.99365 0 L
.99373 0 L
.99387 0 L
.99395 0 L
.99402 0 L
.99416 0 L
.99424 0 L
.99431 0 L
.99445 0 L
.99452 0 L
.99459 0 L
.99467 0 L
.99474 0 L
.99487 0 L
.99494 0 L
.99502 0 L
.99515 0 L
.99522 0 L
.9953 0 L
.99537 0 L
.99544 0 L
.99551 0 L
.99559 0 L
Mistroke
.99566 0 L
.99574 0 L
.99581 0 L
.99589 0 L
.99596 0 L
.99603 0 L
.9961 0 L
.99617 0 L
.99625 0 L
.99632 0 L
.99646 0 L
.99653 0 L
.99661 0 L
.99668 0 L
.99675 0 L
.99683 0 L
.9969 0 L
.99697 0 L
.99704 0 L
.99717 0 L
.99724 0 L
.99731 0 L
.99744 0 L
.99751 0 L
.99758 0 L
.99766 0 L
.99773 0 L
.99786 0 L
.99794 0 L
.99801 0 L
.99808 0 L
.99815 0 L
.99828 0 L
.99834 0 L
.99842 0 L
.99854 0 L
.99861 0 L
.99869 0 L
.99876 0 L
.99883 0 L
.9989 0 L
.99897 0 L
.99904 0 L
.99911 0 L
.99925 0 L
.99932 0 L
.9994 0 L
.99947 0 L
.99953 0 L
.99961 0 L
Mistroke
.99968 0 L
.99974 0 L
.99981 0 L
.99994 0 L
1 0 L
Mfstroke
0 .58949 m
.03792 .57983 L
.0855 .55983 L
.1169 .54157 L
.157 .51054 L
.18838 .47887 L
.23732 .41411 L
.26869 .36213 L
.34685 .20613 L
.39224 .11659 L
.42692 .06224 L
.43934 .04712 L
.45128 .03494 L
.47001 .02034 L
.47878 .01526 L
.48761 .01116 L
.49542 .00827 L
.50205 .0063 L
.50823 .00482 L
.51454 .0036 L
.52083 .00265 L
.52644 .00199 L
.53185 .00148 L
.53666 .00113 L
.54147 .00085 L
.54651 .00062 L
.55108 .00046 L
.55524 .00035 L
.55882 .00027 L
.56263 .0002 L
.56629 .00016 L
.57004 .00012 L
.57341 9e-05 L
.57647 7e-05 L
.57976 5e-05 L
.58311 4e-05 L
.58589 3e-05 L
.58886 2e-05 L
.59192 2e-05 L
.59463 1e-05 L
.59768 1e-05 L
.60048 1e-05 L
.60309 1e-05 L
.60579 0 L
.60804 0 L
.61046 0 L
.61295 0 L
.61518 0 L
.61769 0 L
.62003 0 L
Mistroke
.62219 0 L
.62444 0 L
.62653 0 L
.62838 0 L
.63047 0 L
.63236 0 L
.6344 0 L
.6365 0 L
.63834 0 L
.64027 0 L
.64207 0 L
.64368 0 L
.64548 0 L
.64711 0 L
.64888 0 L
.65073 0 L
.65232 0 L
.65402 0 L
.65559 0 L
.65701 0 L
.65859 0 L
.66003 0 L
.66159 0 L
.66323 0 L
.66479 0 L
.66645 0 L
.66799 0 L
.66939 0 L
.67078 0 L
.67207 0 L
.67346 0 L
.67493 0 L
.67631 0 L
.6778 0 L
.67918 0 L
.68045 0 L
.68169 0 L
.68285 0 L
.6841 0 L
.68544 0 L
.68662 0 L
.6879 0 L
.68922 0 L
.69043 0 L
.69167 0 L
.69283 0 L
.69386 0 L
.69496 0 L
.69603 0 L
.6972 0 L
Mistroke
.69841 0 L
.69952 0 L
.70065 0 L
.70171 0 L
.70266 0 L
.70368 0 L
.70476 0 L
.70572 0 L
.70683 0 L
.70787 0 L
.70885 0 L
.70988 0 L
.71075 0 L
.7117 0 L
.71269 0 L
.71359 0 L
.71461 0 L
.71557 0 L
.71648 0 L
.71743 0 L
.71824 0 L
.71913 0 L
.72004 0 L
.72088 0 L
.72178 0 L
.72273 0 L
.72357 0 L
.72446 0 L
.72529 0 L
.72604 0 L
.72689 0 L
.72767 0 L
.72852 0 L
.72941 0 L
.73019 0 L
.73102 0 L
.7318 0 L
.73251 0 L
.7333 0 L
.73403 0 L
.73482 0 L
.73566 0 L
.73647 0 L
.73733 0 L
.73814 0 L
.73888 0 L
.73962 0 L
.7403 0 L
.74105 0 L
.74184 0 L
Mistroke
.74259 0 L
.7434 0 L
.74416 0 L
.74486 0 L
.74555 0 L
.7462 0 L
.7469 0 L
.74765 0 L
.74836 0 L
.74912 0 L
.74984 0 L
.7505 0 L
.75122 0 L
.75189 0 L
.75249 0 L
.75314 0 L
.75377 0 L
.75446 0 L
.75517 0 L
.75584 0 L
.75651 0 L
.75715 0 L
.75772 0 L
.75834 0 L
.75893 0 L
.75958 0 L
.76026 0 L
.7609 0 L
.7615 0 L
.76214 0 L
.76268 0 L
.76327 0 L
.76389 0 L
.76445 0 L
.7651 0 L
.7657 0 L
.76628 0 L
.76688 0 L
.7674 0 L
.76796 0 L
.76855 0 L
.76908 0 L
.7697 0 L
.77028 0 L
.77082 0 L
.7714 0 L
.77194 0 L
.77243 0 L
.77299 0 L
.7735 0 L
Mistroke
.77406 0 L
.77465 0 L
.77516 0 L
.77572 0 L
.77623 0 L
.7767 0 L
.77723 0 L
.77772 0 L
.77826 0 L
.77882 0 L
.77931 0 L
.77984 0 L
.78034 0 L
.78079 0 L
.7813 0 L
.78176 0 L
.78228 0 L
.78282 0 L
.78334 0 L
.7839 0 L
.78442 0 L
.7849 0 L
.78539 0 L
.78584 0 L
.78633 0 L
.78685 0 L
.78734 0 L
.78788 0 L
.78838 0 L
.78885 0 L
.78931 0 L
.78974 0 L
.79021 0 L
.79071 0 L
.79116 0 L
.79165 0 L
.79216 0 L
.79263 0 L
.79312 0 L
.79357 0 L
.79398 0 L
.79442 0 L
.79485 0 L
.79532 0 L
.79581 0 L
.79627 0 L
.79673 0 L
.79717 0 L
.79756 0 L
.79799 0 L
Mistroke
.79845 0 L
.79886 0 L
.79933 0 L
.79977 0 L
.80019 0 L
.80064 0 L
.80101 0 L
.80143 0 L
.80186 0 L
.80226 0 L
.80271 0 L
.80314 0 L
.80355 0 L
.80397 0 L
.80434 0 L
.80474 0 L
.80516 0 L
.80554 0 L
.80596 0 L
.80639 0 L
.80678 0 L
.8072 0 L
.80758 0 L
.80794 0 L
.80834 0 L
.80871 0 L
.80911 0 L
.80953 0 L
.80991 0 L
.81031 0 L
.81068 0 L
.81103 0 L
.81141 0 L
.81177 0 L
.81216 0 L
.81257 0 L
.81297 0 L
.81339 0 L
.81379 0 L
.81416 0 L
.81453 0 L
.81488 0 L
.81525 0 L
.81565 0 L
.81603 0 L
.81645 0 L
.81684 0 L
.81719 0 L
.81755 0 L
.81788 0 L
Mistroke
.81825 0 L
.81864 0 L
.819 0 L
.8194 0 L
.81978 0 L
.82013 0 L
.82051 0 L
.82086 0 L
.82118 0 L
.82152 0 L
.82186 0 L
.82223 0 L
.82261 0 L
.82297 0 L
.82333 0 L
.82368 0 L
.82399 0 L
.82432 0 L
.82465 0 L
.825 0 L
.82537 0 L
.82572 0 L
.82606 0 L
.82641 0 L
.82671 0 L
.82703 0 L
.82738 0 L
.82769 0 L
.82805 0 L
.82839 0 L
.82872 0 L
.82906 0 L
.82935 0 L
.82967 0 L
.83 0 L
.8303 0 L
.83065 0 L
.83099 0 L
.8313 0 L
.83163 0 L
.83194 0 L
.83222 0 L
.83254 0 L
.83284 0 L
.83316 0 L
.8335 0 L
.8338 0 L
.83413 0 L
.83443 0 L
.8347 0 L
Mistroke
.83502 0 L
.8353 0 L
.83562 0 L
.83595 0 L
.83624 0 L
.83655 0 L
.83685 0 L
.83712 0 L
.83742 0 L
.8377 0 L
.838 0 L
.83833 0 L
.83864 0 L
.83898 0 L
.83929 0 L
.83958 0 L
.83988 0 L
.84015 0 L
.84044 0 L
.84076 0 L
.84106 0 L
.84139 0 L
.8417 0 L
.84198 0 L
.84229 0 L
.84259 0 L
.84285 0 L
.84313 0 L
.84341 0 L
.84371 0 L
.84403 0 L
.84432 0 L
.84462 0 L
.8449 0 L
.84516 0 L
.84543 0 L
.8457 0 L
.846 0 L
.8463 0 L
.84659 0 L
.84688 0 L
.84716 0 L
.84741 0 L
.84768 0 L
.84797 0 L
.84822 0 L
.84852 0 L
.84881 0 L
.84907 0 L
.84936 0 L
Mistroke
.8496 0 L
.84986 0 L
.85014 0 L
.8504 0 L
.85069 0 L
.85096 0 L
.85122 0 L
.8515 0 L
.85174 0 L
.852 0 L
.85227 0 L
.85251 0 L
.85278 0 L
.85307 0 L
.85332 0 L
.85359 0 L
.85384 0 L
.85407 0 L
.85434 0 L
.85458 0 L
.85484 0 L
.85512 0 L
.85537 0 L
.85563 0 L
.85588 0 L
.8561 0 L
.85636 0 L
.85659 0 L
.85685 0 L
.85712 0 L
.85739 0 L
.85767 0 L
.85794 0 L
.85818 0 L
.85843 0 L
.85866 0 L
.85891 0 L
.85918 0 L
.85943 0 L
.85971 0 L
.85997 0 L
.86021 0 L
.86045 0 L
.86068 0 L
.86092 0 L
.86119 0 L
.86142 0 L
.86168 0 L
.86195 0 L
.86219 0 L
Mistroke
.86245 0 L
.86269 0 L
.86291 0 L
.86314 0 L
.86337 0 L
.86362 0 L
.86389 0 L
.86413 0 L
.86438 0 L
.86462 0 L
.86483 0 L
.86506 0 L
.86528 0 L
.86553 0 L
.86578 0 L
.86602 0 L
.86625 0 L
.8665 0 L
.8667 0 L
.86693 0 L
.86717 0 L
.86739 0 L
.86764 0 L
.86787 0 L
.8681 0 L
.86833 0 L
.86854 0 L
.86876 0 L
.86899 0 L
.8692 0 L
.86945 0 L
.86968 0 L
.8699 0 L
.87013 0 L
.87035 0 L
.87055 0 L
.87077 0 L
.87098 0 L
.87121 0 L
.87145 0 L
.87166 0 L
.87189 0 L
.8721 0 L
.8723 0 L
.87252 0 L
.87272 0 L
.87294 0 L
.87318 0 L
.87338 0 L
.87361 0 L
Mistroke
.87382 0 L
.87401 0 L
.87422 0 L
.87442 0 L
.87464 0 L
.87487 0 L
.87509 0 L
.87533 0 L
.87556 0 L
.87577 0 L
.87598 0 L
.87617 0 L
.87639 0 L
.87661 0 L
.87683 0 L
.87707 0 L
.87729 0 L
.87749 0 L
.87772 0 L
.87793 0 L
.87812 0 L
.87832 0 L
.87852 0 L
.87874 0 L
.87897 0 L
.87918 0 L
.8794 0 L
.87961 0 L
.87979 0 L
.87999 0 L
.88019 0 L
.8804 0 L
.88063 0 L
.88083 0 L
.88105 0 L
.88125 0 L
.88143 0 L
.88163 0 L
.88184 0 L
.88203 0 L
.88225 0 L
.88245 0 L
.88265 0 L
.88286 0 L
.88304 0 L
.88323 0 L
.88344 0 L
.88362 0 L
.88384 0 L
.88404 0 L
Mistroke
.88423 0 L
.88444 0 L
.88461 0 L
.8848 0 L
.885 0 L
.88518 0 L
.88538 0 L
.8856 0 L
.88578 0 L
.88598 0 L
.88617 0 L
.88634 0 L
.88654 0 L
.88672 0 L
.88691 0 L
.88712 0 L
.8873 0 L
.8875 0 L
.88768 0 L
.88785 0 L
.88804 0 L
.88822 0 L
.88841 0 L
.88861 0 L
.88881 0 L
.88902 0 L
.88922 0 L
.88941 0 L
.88959 0 L
.88977 0 L
.88995 0 L
.89016 0 L
.89035 0 L
.89056 0 L
.89075 0 L
.89093 0 L
.89111 0 L
.89128 0 L
.89147 0 L
.89167 0 L
.89185 0 L
.89204 0 L
.89224 0 L
.89243 0 L
.89262 0 L
.89281 0 L
.89297 0 L
.89315 0 L
.89332 0 L
.89351 0 L
Mistroke
.89371 0 L
.8939 0 L
.89409 0 L
.89427 0 L
.89443 0 L
.8946 0 L
.89477 0 L
.89496 0 L
.89516 0 L
.89534 0 L
.89552 0 L
.8957 0 L
.89586 0 L
.89603 0 L
.89621 0 L
.89638 0 L
.89657 0 L
.89675 0 L
.89692 0 L
.89711 0 L
.89726 0 L
.89743 0 L
.89761 0 L
.89777 0 L
.89796 0 L
.89814 0 L
.89831 0 L
.89849 0 L
.89866 0 L
.89881 0 L
.89898 0 L
.89914 0 L
.89932 0 L
.8995 0 L
.89967 0 L
.89984 0 L
.90001 0 L
.90016 0 L
.90033 0 L
.90049 0 L
.90066 0 L
.90084 0 L
.901 0 L
.90117 0 L
.90134 0 L
.90149 0 L
.90165 0 L
.90181 0 L
.90198 0 L
.90216 0 L
Mistroke
.90233 0 L
.90252 0 L
.90269 0 L
.90286 0 L
.90302 0 L
.90317 0 L
.90334 0 L
.90351 0 L
.90368 0 L
.90387 0 L
.90404 0 L
.9042 0 L
.90438 0 L
.90454 0 L
.90469 0 L
.90485 0 L
.905 0 L
.90518 0 L
.90536 0 L
.90552 0 L
.90569 0 L
.90586 0 L
.906 0 L
.90616 0 L
.90631 0 L
.90648 0 L
.90666 0 L
.90682 0 L
.90698 0 L
.90715 0 L
.90729 0 L
.90745 0 L
.90761 0 L
.90776 0 L
.90793 0 L
.9081 0 L
.90825 0 L
.90842 0 L
.90856 0 L
.90871 0 L
.90887 0 L
.90902 0 L
.90919 0 L
.90935 0 L
.9095 0 L
.90966 0 L
.9098 0 L
.90995 0 L
.91011 0 L
.91026 0 L
Mistroke
.91042 0 L
.91058 0 L
.91073 0 L
.91089 0 L
.91104 0 L
.91118 0 L
.91133 0 L
.91147 0 L
.91163 0 L
.9118 0 L
.91194 0 L
.9121 0 L
.91225 0 L
.91238 0 L
.91253 0 L
.91267 0 L
.91283 0 L
.91299 0 L
.91315 0 L
.91332 0 L
.91348 0 L
.91362 0 L
.91377 0 L
.91391 0 L
.91406 0 L
.91422 0 L
.91438 0 L
.91454 0 L
.9147 0 L
.91485 0 L
.91499 0 L
.91513 0 L
.91527 0 L
.91543 0 L
.91558 0 L
.91573 0 L
.9159 0 L
.91605 0 L
.9162 0 L
.91635 0 L
.91648 0 L
.91663 0 L
.91677 0 L
.91692 0 L
.91708 0 L
.91723 0 L
.91738 0 L
.91753 0 L
.91766 0 L
.9178 0 L
Mistroke
.91795 0 L
.91809 0 L
.91824 0 L
.91839 0 L
.91853 0 L
.91868 0 L
.91881 0 L
.91895 0 L
.9191 0 L
.91924 0 L
.91939 0 L
.91954 0 L
.91968 0 L
.91982 0 L
.91995 0 L
.92009 0 L
.92023 0 L
.92037 0 L
.92052 0 L
.92066 0 L
.9208 0 L
.92094 0 L
.92108 0 L
.92121 0 L
.92135 0 L
.92148 0 L
.92162 0 L
.92177 0 L
.92191 0 L
.92205 0 L
.92218 0 L
.92231 0 L
.92244 0 L
.92257 0 L
.92271 0 L
.92286 0 L
.92299 0 L
.92313 0 L
.92327 0 L
.92339 0 L
.92352 0 L
.92365 0 L
.92379 0 L
.92394 0 L
.92408 0 L
.92423 0 L
.92438 0 L
.92451 0 L
.92464 0 L
.92477 0 L
Mistroke
.9249 0 L
.92505 0 L
.92519 0 L
.92534 0 L
.92548 0 L
.92561 0 L
.92576 0 L
.92589 0 L
.92601 0 L
.92614 0 L
.92627 0 L
.92641 0 L
.92656 0 L
.9267 0 L
.92684 0 L
.92697 0 L
.92709 0 L
.92722 0 L
.92735 0 L
.92749 0 L
.92763 0 L
.92777 0 L
.9279 0 L
.92804 0 L
.92815 0 L
.92828 0 L
.92842 0 L
.92854 0 L
.92869 0 L
.92882 0 L
.92895 0 L
.92908 0 L
.9292 0 L
.92933 0 L
.92946 0 L
.92958 0 L
.92972 0 L
.92986 0 L
.92998 0 L
.93012 0 L
.93023 0 L
.93036 0 L
.93049 0 L
.93061 0 L
.93074 0 L
.93088 0 L
.931 0 L
.93113 0 L
.93126 0 L
.93137 0 L
Mistroke
.9315 0 L
.93162 0 L
.93175 0 L
.93188 0 L
.93201 0 L
.93214 0 L
.93226 0 L
.93237 0 L
.9325 0 L
.93261 0 L
.93274 0 L
.93288 0 L
.93301 0 L
.93315 0 L
.93328 0 L
.9334 0 L
.93353 0 L
.93364 0 L
.93377 0 L
.9339 0 L
.93403 0 L
.93417 0 L
.9343 0 L
.93442 0 L
.93454 0 L
.93466 0 L
.93478 0 L
.93492 0 L
.93503 0 L
.93517 0 L
.9353 0 L
.93543 0 L
.93556 0 L
.93568 0 L
.93579 0 L
.93591 0 L
.93603 0 L
.93616 0 L
.93629 0 L
.93642 0 L
.93655 0 L
.93667 0 L
.93678 0 L
.93689 0 L
.93702 0 L
.93714 0 L
.93727 0 L
.93739 0 L
.93751 0 L
.93764 0 L
Mistroke
.93775 0 L
.93786 0 L
.93799 0 L
.9381 0 L
.93823 0 L
.93835 0 L
.93847 0 L
.9386 0 L
.9387 0 L
.93882 0 L
.93894 0 L
.93905 0 L
.93918 0 L
.9393 0 L
.93942 0 L
.93954 0 L
.93965 0 L
.93976 0 L
.93988 0 L
.93999 0 L
.94011 0 L
.94024 0 L
.94035 0 L
.94047 0 L
.94058 0 L
.94069 0 L
.9408 0 L
.94091 0 L
.94103 0 L
.94116 0 L
.94127 0 L
.94139 0 L
.9415 0 L
.9416 0 L
.94172 0 L
.94182 0 L
.94194 0 L
.94206 0 L
.94218 0 L
.94231 0 L
.94244 0 L
.94255 0 L
.94266 0 L
.94277 0 L
.94288 0 L
.94301 0 L
.94312 0 L
.94325 0 L
.94337 0 L
.94348 0 L
Mistroke
.9436 0 L
.94372 0 L
.94382 0 L
.94393 0 L
.94404 0 L
.94416 0 L
.94429 0 L
.9444 0 L
.94452 0 L
.94464 0 L
.94474 0 L
.94485 0 L
.94496 0 L
.94507 0 L
.9452 0 L
.94531 0 L
.94542 0 L
.94554 0 L
.94564 0 L
.94575 0 L
.94587 0 L
.94597 0 L
.94609 0 L
.94621 0 L
.94632 0 L
.94643 0 L
.94653 0 L
.94664 0 L
.94676 0 L
.94686 0 L
.94698 0 L
.94709 0 L
.9472 0 L
.94731 0 L
.94742 0 L
.94752 0 L
.94763 0 L
.94773 0 L
.94785 0 L
.94797 0 L
.94807 0 L
.94818 0 L
.94829 0 L
.94839 0 L
.9485 0 L
.9486 0 L
.94871 0 L
.94883 0 L
.94893 0 L
.94904 0 L
Mistroke
.94914 0 L
.94924 0 L
.94935 0 L
.94945 0 L
.94956 0 L
.94967 0 L
.94979 0 L
.94991 0 L
.95002 0 L
.95013 0 L
.95023 0 L
.95033 0 L
.95044 0 L
.95055 0 L
.95066 0 L
.95078 0 L
.9509 0 L
.951 0 L
.9511 0 L
.9512 0 L
.95131 0 L
.95142 0 L
.95153 0 L
.95164 0 L
.95175 0 L
.95186 0 L
.95198 0 L
.95208 0 L
.95218 0 L
.95228 0 L
.95238 0 L
.95249 0 L
.95261 0 L
.95271 0 L
.95282 0 L
.95293 0 L
.95302 0 L
.95312 0 L
.95323 0 L
.95333 0 L
.95345 0 L
.95355 0 L
.95366 0 L
.95376 0 L
.95386 0 L
.95396 0 L
.95407 0 L
.95416 0 L
.95428 0 L
.95438 0 L
Mistroke
.95448 0 L
.95459 0 L
.95468 0 L
.95478 0 L
.95489 0 L
.95498 0 L
.95509 0 L
.9552 0 L
.9553 0 L
.9554 0 L
.9555 0 L
.95559 0 L
.9557 0 L
.95579 0 L
.9559 0 L
.95601 0 L
.9561 0 L
.95621 0 L
.95631 0 L
.9564 0 L
.9565 0 L
.95659 0 L
.95669 0 L
.9568 0 L
.9569 0 L
.957 0 L
.9571 0 L
.95719 0 L
.95729 0 L
.95738 0 L
.95748 0 L
.95759 0 L
.95769 0 L
.95781 0 L
.95791 0 L
.95801 0 L
.95811 0 L
.9582 0 L
.9583 0 L
.95841 0 L
.95851 0 L
.95862 0 L
.95872 0 L
.95882 0 L
.95893 0 L
.95903 0 L
.95911 0 L
.95921 0 L
.95931 0 L
.95941 0 L
Mistroke
.95952 0 L
.95962 0 L
.95972 0 L
.95982 0 L
.95991 0 L
.96001 0 L
.9601 0 L
.9602 0 L
.96031 0 L
.96041 0 L
.96051 0 L
.96061 0 L
.9607 0 L
.96079 0 L
.96089 0 L
.96098 0 L
.96109 0 L
.96119 0 L
.96129 0 L
.96139 0 L
.96147 0 L
.96157 0 L
.96167 0 L
.96176 0 L
.96186 0 L
.96196 0 L
.96205 0 L
.96215 0 L
.96225 0 L
.96233 0 L
.96243 0 L
.96252 0 L
.96262 0 L
.96272 0 L
.96281 0 L
.96291 0 L
.963 0 L
.96309 0 L
.96318 0 L
.96327 0 L
.96337 0 L
.96347 0 L
.96356 0 L
.96366 0 L
.96375 0 L
.96383 0 L
.96393 0 L
.96402 0 L
.96411 0 L
.96421 0 L
Mistroke
.96431 0 L
.96442 0 L
.96452 0 L
.96461 0 L
.9647 0 L
.96479 0 L
.96488 0 L
.96498 0 L
.96508 0 L
.96518 0 L
.96528 0 L
.96537 0 L
.96546 0 L
.96555 0 L
.96564 0 L
.96574 0 L
.96583 0 L
.96593 0 L
.96603 0 L
.96613 0 L
.96623 0 L
.96632 0 L
.9664 0 L
.96649 0 L
.96658 0 L
.96668 0 L
.96678 0 L
.96688 0 L
.96697 0 L
.96706 0 L
.96715 0 L
.96724 0 L
.96733 0 L
.96742 0 L
.96752 0 L
.96761 0 L
.9677 0 L
.9678 0 L
.96788 0 L
.96797 0 L
.96806 0 L
.96815 0 L
.96825 0 L
.96834 0 L
.96843 0 L
.96852 0 L
.9686 0 L
.96869 0 L
.96879 0 L
.96887 0 L
Mistroke
.96896 0 L
.96906 0 L
.96915 0 L
.96924 0 L
.96933 0 L
.96941 0 L
.9695 0 L
.96958 0 L
.96967 0 L
.96977 0 L
.96986 0 L
.96995 0 L
.97003 0 L
.97011 0 L
.9702 0 L
.97029 0 L
.97038 0 L
.97047 0 L
.97056 0 L
.97065 0 L
.97073 0 L
.97081 0 L
.9709 0 L
.97098 0 L
.97107 0 L
.97117 0 L
.97126 0 L
.97136 0 L
.97145 0 L
.97154 0 L
.97162 0 L
.9717 0 L
.97179 0 L
.97189 0 L
.97198 0 L
.97207 0 L
.97217 0 L
.97225 0 L
.97235 0 L
.97243 0 L
.97251 0 L
.9726 0 L
.97268 0 L
.97277 0 L
.97287 0 L
.97296 0 L
.97305 0 L
.97314 0 L
.97322 0 L
.9733 0 L
Mistroke
.97338 0 L
.97347 0 L
.97357 0 L
.97366 0 L
.97374 0 L
.97383 0 L
.97391 0 L
.974 0 L
.97409 0 L
.97417 0 L
.97426 0 L
.97435 0 L
.97443 0 L
.97452 0 L
.9746 0 L
.97468 0 L
.97477 0 L
.97485 0 L
.97494 0 L
.97503 0 L
.97511 0 L
.9752 0 L
.97529 0 L
.97536 0 L
.97545 0 L
.97553 0 L
.97561 0 L
.97571 0 L
.97579 0 L
.97587 0 L
.97596 0 L
.97603 0 L
.97612 0 L
.97619 0 L
.97628 0 L
.97637 0 L
.97645 0 L
.97654 0 L
.97662 0 L
.97669 0 L
.97678 0 L
.97685 0 L
.97694 0 L
.97703 0 L
.97712 0 L
.97721 0 L
.9773 0 L
.97738 0 L
.97746 0 L
.97754 0 L
Mistroke
.97762 0 L
.97771 0 L
.9778 0 L
.97789 0 L
.97798 0 L
.97806 0 L
.97814 0 L
.97822 0 L
.9783 0 L
.97839 0 L
.97847 0 L
.97856 0 L
.97865 0 L
.97873 0 L
.97882 0 L
.9789 0 L
.97898 0 L
.97906 0 L
.97914 0 L
.97922 0 L
.97931 0 L
.9794 0 L
.97948 0 L
.97957 0 L
.97964 0 L
.97972 0 L
.97981 0 L
.97988 0 L
.97997 0 L
.98006 0 L
.98014 0 L
.98022 0 L
.98029 0 L
.98037 0 L
.98046 0 L
.98053 0 L
.98062 0 L
.9807 0 L
.98078 0 L
.98087 0 L
.98094 0 L
.98102 0 L
.9811 0 L
.98118 0 L
.98126 0 L
.98135 0 L
.98142 0 L
.98151 0 L
.98159 0 L
.98166 0 L
Mistroke
.98174 0 L
.98181 0 L
.98189 0 L
.98198 0 L
.98206 0 L
.98214 0 L
.98222 0 L
.98229 0 L
.98237 0 L
.98244 0 L
.98252 0 L
.98261 0 L
.98269 0 L
.98278 0 L
.98287 0 L
.98294 0 L
.98302 0 L
.98309 0 L
.98317 0 L
.98326 0 L
.98334 0 L
.98343 0 L
.98351 0 L
.98359 0 L
.98367 0 L
.98374 0 L
.98382 0 L
.9839 0 L
.98398 0 L
.98407 0 L
.98415 0 L
.98423 0 L
.98432 0 L
.98439 0 L
.98446 0 L
.98454 0 L
.98462 0 L
.9847 0 L
.98478 0 L
.98486 0 L
.98495 0 L
.98503 0 L
.9851 0 L
.98517 0 L
.98525 0 L
.98533 0 L
.98541 0 L
.98549 0 L
.98557 0 L
.98565 0 L
Mistroke
.98572 0 L
.98579 0 L
.98587 0 L
.98595 0 L
.98603 0 L
.98611 0 L
.98619 0 L
.98627 0 L
.98633 0 L
.98641 0 L
.98649 0 L
.98656 0 L
.98664 0 L
.98672 0 L
.9868 0 L
.98688 0 L
.98695 0 L
.98702 0 L
.9871 0 L
.98717 0 L
.98725 0 L
.98733 0 L
.9874 0 L
.98748 0 L
.98755 0 L
.98762 0 L
.9877 0 L
.98777 0 L
.98785 0 L
.98793 0 L
.988 0 L
.98808 0 L
.98815 0 L
.98822 0 L
.98829 0 L
.98836 0 L
.98844 0 L
.98852 0 L
.9886 0 L
.98868 0 L
.98876 0 L
.98884 0 L
.98891 0 L
.98898 0 L
.98905 0 L
.98913 0 L
.98921 0 L
.9893 0 L
.98937 0 L
.98945 0 L
Mistroke
.98952 0 L
.98959 0 L
.98966 0 L
.98974 0 L
.98982 0 L
.98989 0 L
.98998 0 L
.99005 0 L
.99013 0 L
.99021 0 L
.99027 0 L
.99035 0 L
.99042 0 L
.99049 0 L
.99058 0 L
.99065 0 L
.99073 0 L
.9908 0 L
.99087 0 L
.99094 0 L
.99102 0 L
.99109 0 L
.99117 0 L
.99124 0 L
.99132 0 L
.99139 0 L
.99146 0 L
.99153 0 L
.99161 0 L
.99167 0 L
.99175 0 L
.99183 0 L
.9919 0 L
.99198 0 L
.99204 0 L
.99211 0 L
.99219 0 L
.99226 0 L
.99233 0 L
.99241 0 L
.99248 0 L
.99255 0 L
.99262 0 L
.99269 0 L
.99276 0 L
.99283 0 L
.9929 0 L
.99298 0 L
.99305 0 L
.99312 0 L
Mistroke
.99319 0 L
.99326 0 L
.99333 0 L
.9934 0 L
.99347 0 L
.99355 0 L
.99362 0 L
.9937 0 L
.99378 0 L
.99385 0 L
.99392 0 L
.99399 0 L
.99406 0 L
.99414 0 L
.99421 0 L
.99429 0 L
.99437 0 L
.99444 0 L
.99451 0 L
.99457 0 L
.99464 0 L
.99472 0 L
.99479 0 L
.99487 0 L
.99495 0 L
.99502 0 L
.99509 0 L
.99516 0 L
.99523 0 L
.9953 0 L
.99537 0 L
.99544 0 L
.99552 0 L
.99559 0 L
.99566 0 L
.99574 0 L
.9958 0 L
.99587 0 L
.99593 0 L
.99601 0 L
.99609 0 L
.99616 0 L
.99623 0 L
.9963 0 L
.99636 0 L
.99643 0 L
.9965 0 L
.99657 0 L
.99665 0 L
.99672 0 L
Mistroke
.99679 0 L
.99686 0 L
.99692 0 L
.99699 0 L
.99706 0 L
.99713 0 L
.9972 0 L
.99727 0 L
.99734 0 L
.99741 0 L
.99748 0 L
.99754 0 L
.99761 0 L
.99768 0 L
.99775 0 L
.99782 0 L
.99789 0 L
.99796 0 L
.99803 0 L
.99809 0 L
.99816 0 L
.99822 0 L
.99829 0 L
.99837 0 L
.99843 0 L
.9985 0 L
.99857 0 L
.99863 0 L
.9987 0 L
.99876 0 L
.99883 0 L
.9989 0 L
.99898 0 L
.99905 0 L
.99913 0 L
.99919 0 L
.99926 0 L
.99932 0 L
.99939 0 L
.99946 0 L
.99953 0 L
.99961 0 L
.99968 0 L
.99975 0 L
.99981 0 L
.99987 0 L
.99993 0 L
1 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[177]:=",
  ImageSize->{452, 279.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007400015a000`40O003h00OogooaGoo003oOoo5
Ool00?moolEoo`00ogooaGoo001gOol20004Ool20004Ool20003Ool3001GOol20004Ool20003Ool3
001NOol3001ROol30004Ool20008Ool007Ioo`04001oogoo0003Ool20003Ool01000Oomoo`000goo
00<007ooOol0EGoo00@007ooOol000=oo`8000Aoo`03001oogoo05ioo`03001oogoo069oo`03001o
ogoo009oo`04001oogoo0007Ool007Ioo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0
EGoo00@007ooOol000Uoo`03001oogoo05ioo`03001oogoo069oo`03001oogoo009oo`04001oogoo
0007Ool007Ioo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0EGoo00@007ooOol000Uo
o`03001oogoo05ioo`03001oogoo069oo`03001oogoo009oo`04001oogoo0007Ool007Ioo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol0EGoo00@007ooOol000Uoo`03001oogoo05ioo`03
001oogoo069oo`03001oogoo009oo`04001oogoo0007Ool007Moo`8000Yoo`8000=oo`8005Qoo`80
00Uoo`8005moo`8006=oo`8000Eoo`8000Qoo`00ogooaGoo003oOoo5Ool00?moolEoo`00ogooaGoo
003oOoo5Ool00?moolEoo`00ogooaGoo000IOooo002Q000;Ool001Uoob`000Ioo`03001oogoo009o
oe800003Ool0000006000003Ool0000001d0009oo`h0009oo`d0009oo`03001oo`0000d000Ioo`l0
00Eoo`03001oogoo00Eooa0000Moo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo0180009o
o`03001oogoo00Uoo`006Goo00<007ooOol077oo00<007ooOol02Woo2`0027oo00<007ooOol01goo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo2`006Goo00<007oo
00002@001Woo00<007ooOol02Woo20000Woo00<007ooOol01Woo00<007ooOol00goo200017oo00<0
07ooOol00Woo00<007oo00002@0037oo2P001Woo1@0017oo00<007ooOol017oo1`002Goo00<007oo
00000`000Woo00<007ooOol017oo00<007ooOol01@0017oo00D007ooOomoo`0000Qoo`<001Aoo`04
001oogooOol50009Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`03Ool60003Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`09Ool001Uoo`03001oogoo03Ao
o`P002Uoo`03001oogoo00=oo`H001moo`L001Aoo`H0019oo`@000Eoo`<000Yoo`8000Moo`<000Yo
o`H000moo`8000Eoo`<000Ioo`<000moo`03001oogoo00]oo`03001oogoo00=oo`<001Qoo`<002Qo
o`@001Qoo`03001oogoo00Uoo`006Goo00<007ooOol0?7oo1`00;Woo20007Woo0`005goo0`004goo
1@003goo1`003goo0P0000=oo`0000002goo0`002Woo0P000Woo0P003goo0`004Woo0P006Goo0P00
:Goo0`009goo000IOol00`00Oomoo`13Ool6000`Ool3000NOol2000HOol2000@Ool3000017oo0000
00004Goo10003Woo00<007ooOol00goo0P001goo0P003goo0`003goo00<007ooOol04Woo00<007oo
Ool05goo0P00:7oo0`00:Woo000IOol00`00Oomoo`19Ool5000^Ool3000MOol3000GOol3000<Ool0
0`00Oomoo`05Ool2000=Ool20004Ool00`00Oomoo`09Ool20008Ool00`00Oomoo`03Ool00`00Oomo
o`0>Ool01000Oomoogoo0P0037oo00<007ooOol047oo0`006Goo00<007ooOol09goo0P00;7oo000I
Ool00`00Oomoo`1>Ool4000]Ool3000MOol3000GOol20008Ool2000:Ool20009Ool20007Ool20008
Ool00`00Oomoo`09Ool01@00Oomoogoo00003goo0P001Woo0P0027oo0P004Woo00<007ooOol067oo
0P00:7oo0`00;Goo000IOol00`00Oomoo`1BOol3000]Ool3000MOol2000GOol00`00Oomoo`03Ool2
000>Ool00`00Oomoo`05Ool00`00Oomoo`09Ool20004Ool2000=Ool3000?Ool00`00Oomoo`08Ool0
0`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`0HOol00`00Oomoo`0WOol2000_Ool001Uoo`03
001oogoo05Eoo`<002eoo`8001eoo`8001Ioo`03001oogoo0080015oo`8000Aoo`03001oogoo00ao
o`04001oogoo000@Ool2000>Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0BOol00`00
Oomoo`0GOol2000XOol2000`Ool001Uoo`03001oogoo05Qoo`<002aoo`8001eoo`8001Eoo`8001Eo
o`04001oogoo000@Ool2000@Ool01000Oomoo`003Goo00<007ooOol02goo00@007ooOol001Aoo`03
001oogoo01Moo`03001oogoo02Ioo`80039oo`006Goo00<007ooOol0Fgoo0`00:goo0P007Goo00<0
07ooOol04Woo00<007oo00005Goo0P004Goo0P0047oo00@007ooOomoo`8000Yoo`03001oogoo00eo
o`03001oo`0001=oo`03001oogoo01Moo`03001oogoo02Moo`03001oogoo035oo`006Goo0`00GWoo
0P00:goo0P0077oo00<007ooOol03goo0P000goo00<007ooOol04Woo0P0047oo00@007ooOol000io
o`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00moo`80019oo`03001oogoo01Moo`03001o
ogoo02Ioo`8003Aoo`006Goo1`00G7oo0`00:Woo0P006goo00<007ooOol03Goo00<007ooOol017oo
00<007ooOol047oo00@007ooOol000ioo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Io
o`03001oogoo00Aoo`03001oogoo00moo`04001oogoo000@Ool00`00Oomoo`0GOol00`00Oomoo`0W
Ool00`00Oomoo`0cOol001Uoo`03001oogoo00Aoo`@005]oo`<002Uoo`03001oogoo01Uoo`03001o
ogoo00]oo`03001oogoo00Ioo`03001oogoo00ioo`05001oogooOol0000>Ool00`00Oomoo`03Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool01@00Oomoogoo0000
3Woo00<007ooOol067oo00<007ooOol09Woo00<007ooOol0=7oo000IOol00`00Oomoo`08Ool4001J
Ool2000XOol00`00Oomoo`0IOol00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00
Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00
Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`0GOol00`00
Oomoo`0VOol00`00Oomoo`0eOol001Uoo`03001oogoo00aoo`<005Uoo`03001oogoo02Ioo`03001o
ogoo01Uoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Aoo`03001o
ogoo00Qoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Yoo`04001oogoo000AOol00`00
Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0GOol00`00Oomoo`0VOol00`00Oomoo`0fOol001Uo
o`03001oogoo00moo`<005Moo`8002Moo`8001Yoo`03001oogoo00Eoo`03001oogoo00aoo`03001o
ogoo00Uoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`03001o
ogoo00aoo`80019oo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo01Ioo`03001oogoo02Io
o`8003Qoo`006Goo00<007ooOol04Woo0P00Egoo00<007ooOol09Woo00<007ooOol067oo00<007oo
Ool00goo00<007ooOol03Woo00<007ooOol01goo00<007ooOol027oo00<007ooOol01Goo00<007oo
Ool02Goo00<007ooOol00Woo00<007ooOol03Goo0P004Goo00<007ooOol01goo00<007ooOol01goo
00<007ooOol05goo00<007ooOol09Woo00<007ooOol0=goo000IOol00`00Oomoo`0DOol3001EOol0
0`00Oomoo`0VOol00`00Oomoo`0HOol01@00Oomoogoo00004Woo00<007ooOol01Goo00<007ooOol0
2Goo00<007ooOol01Goo00<007ooOol02Woo00@007ooOol0011oo`80015oo`03001oogoo00Qoo`03
001oogoo00Eoo`03001oogoo01Qoo`03001oogoo02Eoo`03001oogoo03Qoo`006Goo00<007ooOol0
5goo0P00E7oo0P009goo00<007ooOol067oo00<007oo00004goo00<007ooOol017oo00<007ooOol0
2goo00<007ooOol00goo00<007ooOol02goo00@007ooOol0011oo`80011oo`03001oogoo00Yoo`03
001oogoo00Aoo`03001oogoo01Moo`03001oogoo02Eoo`8003Yoo`006Goo00<007ooOol06Goo0`00
Dgoo00<007ooOol09Goo00<007ooOol067oo0P0057oo00<007ooOol00Woo00<007ooOol03Goo00D0
07ooOomoo`0000moo`80011oo`04001oogoo000?Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00
Oomoo`0GOol00`00Oomoo`0VOol00`00Oomoo`0iOol001Uoo`03001oogoo01aoo`80059oo`03001o
ogoo02Eoo`03001oogoo01Moo`8001Eoo`05001oogooOol0000?Ool01000Oomoo`0047oo0P0047oo
00D007ooOomoo`0000eoo`03001oogoo00aoo`03001oogoo009oo`03001oogoo01Moo`03001oogoo
02Eoo`03001oogoo03Yoo`006Goo00<007ooOol07Woo0`00D7oo0P009Goo00<007ooOol05Woo00@0
07ooOol001Eoo`03001oo`00015oo`80015oo`8000moo`03001oogoo00=oo`03001oogoo00Uoo`03
001oogoo00eoo`05001oogooOol0000IOol00`00Oomoo`0UOol2000lOol001Uoo`03001oogoo025o
o`80051oo`03001oogoo02=oo`03001oogoo01Aoo`03001oogoo009oo`03001oogoo01=oo`03001o
ogoo015oo`03001oogoo00ioo`04001oogoo000>Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00
Oomoo`0?Ool00`00Ool0000IOol00`00Oomoo`0VOol00`00Oomoo`0kOol001Uoo`03001oogoo02=o
o`8004moo`8002Aoo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo019oo`80015oo`80011o
o`04001oogoo000=Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool2000IOol00`00
Oomoo`0UOol00`00Oomoo`0lOol001Uoo`<002Eoo`8004moo`03001oogoo029oo`03001oogoo011o
o`03001oogoo00Ioo`03001oogoo011oo`04001oogoo000@Ool00`00Ool0000>Ool00`00Oomoo`02
Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`0AOol00`00Oomoo`0G
Ool00`00Oomoo`0VOol00`00Oomoo`0lOol001Uoo`03001oogoo02Moo`8004ioo`03001oogoo029o
o`03001oogoo00moo`03001oogoo00Moo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00ao
o`04001oogoo000>Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`05
Ool00`00Oomoo`0AOol2000HOol00`00Oomoo`0UOol00`00Oomoo`0mOol001Uoo`03001oogoo02Uo
o`03001oogoo04aoo`03001oogoo029oo`03001oogoo00eoo`03001oogoo00Qoo`03001oogoo00io
o`03001oogoo009oo`03001oogoo00aoo`05001oogooOol0000<Ool00`00Oomoo`04Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`0AOol2000HOol00`00Oomoo`0UOol0
0`00Oomoo`0mOol001Uoo`03001oogoo02Yoo`8004aoo`03001oogoo02=oo`03001oogoo00]oo`03
001oogoo00Yoo`03001oogoo00aoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00=oo`03
001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00=oo`03
001oogoo015oo`04001oogoo000GOol00`00Oomoo`0TOol00`00Oomoo`0nOol001Uoo`03001oogoo
02aoo`8004]oo`03001oogoo02=oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Yoo`03
001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00Ioo`03
001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo015oo`05001oogooOol0000E
Ool00`00Oomoo`0TOol20010Ool001Uoo`03001oogoo02ioo`8004Yoo`03001oogoo02=oo`03001o
ogoo00Qoo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00Qoo`03001o
ogoo00Eoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00]oo`05001o
ogooOol0000COol00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`0TOol00`00Oomoo`0oOol0
01Uoo`03001oogoo031oo`03001oogoo04Qoo`03001oogoo02=oo`03001oogoo00Moo`03001oogoo
00eoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo
00Ioo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo00aoo`05001oogooOol0000COol00`00
Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`0UOol00`00Oomoo`0oOol001Uoo`03001oogoo035o
o`03001oogoo04Qoo`03001oogoo029oo`03001oogoo00Ioo`03001oogoo00ioo`03001oogoo00Qo
o`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Uo
o`03001oogoo009oo`03001oogoo00eoo`03001oo`0001Aoo`03001oogoo00=oo`03001oogoo015o
o`03001oogoo02Aoo`03001oogoo041oo`006Goo00<007ooOol0<Woo0P00BGoo00<007ooOol08Woo
00<007ooOol017oo00<007ooOol047oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo
00<007ooOol02Goo00<007ooOol00goo00<007ooOol02Woo00D007ooOomoo`00011oo`03001oo`00
01=oo`03001oogoo00Aoo`03001oogoo011oo`03001oogoo02Eoo`03001oogoo041oo`006Goo00<0
07ooOol0=7oo00<007ooOol0Agoo00<007ooOol08Woo00<007ooOol00goo00<007ooOol04Goo00<0
07ooOol017oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Goo00<007ooOol00goo00<0
07ooOol02goo00@007ooOol0015oo`03001oogoo019oo`03001oogoo00Eoo`03001oogoo00moo`03
001oogoo02Aoo`03001oogoo045oo`006Goo00<007ooOol0=Goo0P00B7oo00<007ooOol08Goo00<0
07ooOol00Woo00<007ooOol04Woo00<007ooOol017oo00<007ooOol02goo00<007ooOol00goo00<0
07ooOol02goo00D007ooOomoo`0000ioo`04001oogoo000AOol00`00Oomoo`0BOol00`00Oomoo`06
Ool00`00Oomoo`0=Ool00`00Oomoo`0UOol00`00Oomoo`11Ool001Uoo`03001oogoo03Moo`03001o
ogoo04Ioo`03001oogoo025oo`05001oogooOol0000EOol00`00Oomoo`02Ool00`00Oomoo`0=Ool0
0`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomoogoo00003Woo00<007oo00004Goo00<007oo0000
4Woo00<007ooOol01goo00<007ooOol03Goo00<007ooOol097oo00<007ooOol0@Woo000IOol00`00
Oomoo`0hOol00`00Oomoo`15Ool00`00Oomoo`0ROol00`00Ool0000FOol01@00Oomoogoo000047oo
00D007ooOomoo`0000moo`03001oo`00011oo`80015oo`03001oo`00019oo`03001oogoo00Qoo`03
001oogoo00aoo`03001oogoo02Aoo`03001oogoo049oo`006Goo0`00>Goo0P00AWoo00<007ooOol0
8Goo0P0067oo00@007ooOol0015oo`04001oogoo000?Ool00`00Ool0000@Ool00`00Oomoo`0@Ool0
1000Oomoo`0047oo00<007ooOol02Goo00<007ooOol02goo00<007ooOol09Goo00<007ooOol0@Woo
000IOol00`00Oomoo`0kOol00`00Oomoo`14Ool00`00Oomoo`0QOol00`00Oomoo`0GOol2000BOol0
0`00Ool0000AOol2000@Ool2000@Ool01@00Oomoogoo000047oo00<007ooOol02Goo00<007ooOol0
2goo00<007ooOol097oo00<007ooOol0@goo000IOol00`00Oomoo`0lOol20015Ool00`00Oomoo`0O
Ool00`00Ool0000HOol00`00Oomoo`0BOol2000AOol00`00Oomoo`0>Ool00`00Ool0000@Ool00`00
Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`0UOol00`00
Oomoo`13Ool001Uoo`03001oogoo03ioo`03001oogoo04=oo`03001oogoo01ioo`04001oogoo000G
Ool2000COol00`00Oomoo`0@Ool00`00Oomoo`0>Ool01000Oomoo`003goo00<007ooOol00Woo00<0
07ooOol037oo00<007ooOol02goo00<007ooOol02Goo00<007ooOol097oo00<007ooOol0A7oo000I
Ool00`00Oomoo`0oOol00`00Oomoo`13Ool00`00Oomoo`0LOol01@00Oomoogoo00005Woo00<007oo
00004goo0P0047oo00<007oo00003goo00@007ooOol000ioo`03001oogoo00Aoo`03001oogoo00]o
o`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo02Aoo`03001oogoo04Aoo`006Goo00<007oo
Ool0@7oo0P00A7oo00<007ooOol06Woo00<007ooOol00goo00<007ooOol04goo00@007ooOol0015o
o`03001oo`00011oo`03001oo`0000ioo`03001oogoo009oo`03001oogoo00]oo`03001oogoo00Ao
o`03001oogoo00Yoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo02Aoo`03001oogoo04Eo
o`006Goo00<007ooOol0@Woo00<007ooOol0@Woo00<007ooOol06Goo00<007ooOol017oo00<007oo
Ool04Goo00<007ooOol00Woo00<007ooOol03Woo00@007ooOol000ioo`05001oogooOol0000=Ool0
0`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool0
0`00Oomoo`07Ool00`00Oomoo`0TOol00`00Oomoo`15Ool001Uoo`03001oogoo04=oo`03001oogoo
045oo`03001oogoo01Qoo`03001oogoo00Eoo`03001oogoo015oo`03001oogoo009oo`03001oogoo
00eoo`05001oogooOol0000>Ool01@00Oomoogoo000037oo00<007ooOol00goo00<007ooOol02Woo
00<007ooOol01Woo00<007ooOol027oo00<007ooOol03goo00<007ooOol01Goo00<007ooOol09Goo
00<007ooOol0AGoo000IOol00`00Oomoo`14Ool20012Ool00`00Oomoo`0GOol00`00Oomoo`06Ool0
0`00Oomoo`0?Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool0
0`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`06Ool0
0`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Oomoo`05Ool00`00Oomoo`0TOol00`00Oomoo`16Ool0
01Uoo`03001oogoo04Ioo`03001oogoo041oo`03001oogoo01Eoo`03001oogoo00Qoo`03001oogoo
00ioo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo
00=oo`03001oogoo00Uoo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo
00Qoo`03001oogoo011oo`03001oogoo00Aoo`03001oogoo02Aoo`03001oogoo04Ioo`006Goo00<0
07ooOol0Agoo0P00@Goo00<007ooOol04goo00<007ooOol02Goo00<007ooOol03Goo00<007ooOol0
1Woo00<007ooOol02Woo00<007ooOol017oo00<007ooOol027oo00<007ooOol017oo00<007ooOol0
27oo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
4Goo00<007ooOol00goo00<007ooOol097oo00<007ooOol0Agoo0004Ool20004Ool20003Ool40006
Ool00`00Oomoo`19Ool00`00Oomoo`0oOol00`00Oomoo`0BOol00`00Oomoo`0:Ool00`00Oomoo`0<
Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`05
Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`06
Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0TOol00`00Oomoo`17Ool000=oo`04001o
ogoo0003Ool20004Ool00`00Oomoo`06Ool00`00Oomoo`1:Ool00`00Oomoo`0oOol00`00Oomoo`0@
Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`06
Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06
Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0COol00`00Oomoo`02Ool00`00Oomoo`0T
Ool00`00Oomoo`17Ool000=oo`04001oogoo000:Ool00`00Oomoo`05Ool4001:Ool20010Ool00`00
Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00
Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00
Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0COol00`00Oomoo`02Ool00`00
Oomoo`0SOol00`00Oomoo`18Ool000=oo`04001oogoo000;Ool00`00Oomoo`04Ool00`00Oomoo`1=
Ool00`00Oomoo`0mOol00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`08Ool00`00Oomoo`0:
Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`04
Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0C
Ool01@00Oomoogoo00009Woo00<007ooOol0B7oo0003Ool01000Oomoo`0027oo00@007ooOol000Io
o`03001oogoo04ioo`03001oogoo03eoo`03001oogoo00eoo`03001oogoo00moo`03001oogoo00Mo
o`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo00Qo
o`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00=o
o`03001oogoo01Aoo`05001oogooOol0000UOol00`00Oomoo`19Ool000Aoo`8000Yoo`8000Moo`03
001oogoo04moo`03001oogoo03eoo`03001oogoo00]oo`03001oogoo011oo`03001oogoo00Ioo`03
001oogoo00aoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo00Uoo`03
001oogoo009oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03
001oogoo01Eoo`04001oogoo000UOol00`00Oomoo`19Ool001Uoo`03001oogoo051oo`03001oogoo
03eoo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo00Eoo`03001oogoo00eoo`03001oogoo
009oo`03001oogoo00aoo`05001oogooOol0000<Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00
Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0EOol00`00Ool0000VOol00`00
Oomoo`19Ool001Uoo`03001oogoo055oo`03001oogoo03eoo`03001oogoo00Qoo`03001oogoo01=o
o`03001oogoo00=oo`03001oogoo00moo`05001oogooOol0000>Ool01@00Oomoogoo00003Goo00D0
07ooOomoo`0000eoo`03001oogoo009oo`03001oogoo00eoo`05001oogooOol0000HOol00`00Ool0
000VOol00`00Oomoo`19Ool001Uoo`03001oogoo059oo`03001oogoo03aoo`03001oogoo00Qoo`03
001oogoo01=oo`03001oogoo00=oo`03001oogoo00moo`04001oogoo000@Ool00`00Ool0000>Ool0
1000Oomoo`003goo00D007ooOomoo`00011oo`04001oogoo000IOol2000UOol00`00Oomoo`1:Ool0
01Uoo`03001oogoo05=oo`03001oogoo03aoo`03001oogoo00Ioo`03001oogoo01Eoo`05001oogoo
Ool0000COol00`00Ool0000@Ool00`00Ool0000?Ool00`00Ool0000?Ool01000Oomoo`004Goo00@0
07ooOol001Uoo`03001oogoo02Aoo`03001oogoo04Yoo`006Goo00<007ooOol0E7oo00<007ooOol0
?7oo00<007ooOol01Goo00<007ooOol05Woo00<007oo000057oo0P004Woo00<007ooOol03Woo0P00
47oo00@007ooOol0019oo`8001Uoo`8002Ioo`03001oogoo04Yoo`006Goo00<007ooOol0EGoo00<0
07ooOol0?7oo00<007ooOol00goo00<007ooOol05goo00<007oo00005Goo00<007ooOol047oo00<0
07ooOol03Woo0P004Goo0P004goo0P006Goo00<007oo000097oo00<007ooOol0Bgoo000IOol00`00
Oomoo`1FOol00`00Oomoo`0kOol00`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`0COol00`00
Ool0000@Ool00`00Ool0000?Ool2000AOol2000COol00`00Oomoo`0HOol00`00Ool0000TOol00`00
Oomoo`1;Ool001Uoo`03001oogoo05Moo`03001oogoo03]oo`05001oogooOol0000KOol2000DOol0
0`00Ool0000?Ool01000Oomoo`003goo0P004Goo00<007ooOol04Woo0P0067oo00D007ooOomoo`00
02=oo`03001oogoo04]oo`006Goo00<007ooOol0F7oo00<007ooOol0>goo00@007ooOol001Yoo`03
001oo`0001=oo`05001oogooOol0000>Ool01@00Oomoogoo00003Goo00@007ooOol0011oo`8001=o
o`8001Qoo`05001oogooOol0000ROol00`00Oomoo`1<Ool001Uoo`<005Uoo`03001oogoo03]oo`80
01]oo`04001oogoo000BOol01@00Oomoogoo00003Goo00<007ooOol00Woo00<007ooOol02goo00@0
07ooOol000moo`03001oo`00019oo`03001oo`0001Qoo`03001oogoo009oo`03001oogoo01moo`03
001oogoo04aoo`006Goo00<007ooOol0FWoo00<007ooOol0>goo00<007ooOol067oo00<007ooOol0
0Woo00<007ooOol03Woo00<007ooOol00goo00<007ooOol02Goo00<007ooOol017oo00<007ooOol0
2Goo00D007ooOomoo`0000moo`03001oo`00019oo`04001oogoo000FOol00`00Oomoo`03Ool00`00
Oomoo`0OOol00`00Oomoo`1<Ool001Uoo`03001oogoo05]oo`03001oogoo03Uoo`8001Yoo`03001o
ogoo009oo`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo00Aoo`03001o
ogoo00Uoo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol0000AOol01000Oomoo`005Woo
00<007ooOol00goo00<007ooOol07Woo00<007ooOol0CGoo000IOol00`00Oomoo`1LOol00`00Oomo
o`0gOol01000Oomoo`0067oo00<007ooOol017oo00<007ooOol037oo00<007ooOol01Goo00<007oo
Ool01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol02goo00D007oo
Oomoo`00011oo`05001oogooOol0000FOol00`00Oomoo`04Ool00`00Oomoo`0MOol00`00Oomoo`1=
Ool001Uoo`03001oogoo05eoo`03001oogoo03Ioo`05001oogooOol0000GOol00`00Oomoo`05Ool0
0`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool0
0`00Oomoo`04Ool00`00Oomoo`0:Ool01@00Oomoogoo000047oo00<007ooOol00Woo00<007ooOol0
4goo00<007ooOol017oo00<007ooOol07Goo00<007ooOol0CGoo000IOol00`00Oomoo`1NOol00`00
Oomoo`0dOol00`00Oomoo`03Ool00`00Oomoo`0COol00`00Oomoo`07Ool00`00Oomoo`09Ool00`00
Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0BOol00`00
Oomoo`05Ool00`00Oomoo`0LOol00`00Oomoo`1>Ool001Uoo`03001oogoo05moo`03001oogoo03=o
o`03001oogoo00Aoo`03001oogoo019oo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qo
o`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Qo
o`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo019oo`03001oogoo00Eo
o`03001oogoo01aoo`03001oogoo04ioo`006Goo00<007ooOol0H7oo00<007ooOol0<Goo00<007oo
Ool01Woo00<007ooOol047oo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol02Woo00<007oo
Ool00Woo00<007ooOol02Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool017oo00<007ooOol02goo00<007ooOol017oo00<007ooOol04Goo00<007ooOol01Woo00<007oo
Ool06goo00<007ooOol0CWoo000IOol00`00Oomoo`1QOol00`00Oomoo`0`Ool00`00Oomoo`06Ool0
0`00Oomoo`0@Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool01@00Oomoogoo0000
3Woo00D007ooOomoo`0000Yoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00]oo`03001o
ogoo00Aoo`03001oogoo015oo`03001oogoo00Ioo`03001oogoo01Yoo`03001oogoo04moo`006Goo
00<007ooOol0HWoo00<007ooOol0;Woo00<007ooOol027oo00<007ooOol03Woo00<007ooOol03Goo
00<007ooOol00Woo00<007ooOol03Goo00<007oo00003goo00D007ooOomoo`0000]oo`03001oogoo
00Ioo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo011oo`03001oogoo
00Moo`03001oogoo01Yoo`03001oogoo04moo`006Goo00<007ooOol0Hgoo00<007ooOol0;Goo00<0
07ooOol02Goo00<007ooOol03Goo00<007ooOol03Woo00@007ooOol0015oo`80011oo`03001oo`00
00aoo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo
00moo`03001oogoo00Qoo`03001oogoo01Qoo`03001oogoo051oo`006Goo00<007ooOol0I7oo00<0
07ooOol0:goo00<007ooOol02goo00<007ooOol02goo00<007ooOol03goo00@007ooOol0015oo`80
011oo`03001oo`0000eoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo
00Ioo`03001oogoo00moo`03001oogoo00Qoo`03001oogoo01Qoo`03001oogoo051oo`006Goo0`00
IGoo00<007ooOol0:Woo00<007ooOol037oo00<007ooOol02Woo00<007ooOol047oo0P004Goo00@0
07ooOol0011oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00ioo`03001oogoo00Uoo`03001oogoo01Qoo`03001oogoo051oo`00
6Goo00<007ooOol0IWoo00<007ooOol0:7oo00<007ooOol03Woo00<007ooOol027oo00<007ooOol0
4Goo0P0047oo00<007ooOol00Woo00<007ooOol037oo00<007oo00003Woo00D007ooOomoo`0000ao
o`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00eoo`03001oogoo00Uoo`03001oogoo01Mo
o`03001oogoo055oo`006Goo00<007ooOol0Igoo00<007ooOol09goo00<007ooOol03goo00<007oo
Ool01Woo00<007ooOol04Woo00@007oo000000eoo`03001oogoo00=oo`03001oogoo00]oo`04001o
ogoo000>Ool01@00Oomoogoo00003Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol037oo
00<007ooOol02goo00<007ooOol05Woo00<007ooOol0DGoo000IOol00`00Oomoo`1XOol00`00Oomo
o`0UOol00`00Oomoo`0AOol00`00Oomoo`05Ool00`00Oomoo`0AOol00`00Oomoo`02Ool00`00Oomo
o`08Ool20007Ool2000:Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01000Oomoo`003Woo00<007oo
Ool01Goo00<007ooOol02Goo00<007ooOol037oo00<007ooOol02goo00<007ooOol05Woo00<007oo
Ool0DGoo000IOol00`00Oomoo`1YOol00`00Oomoo`0TOol00`00Oomoo`0BOol20004Ool00`00Oomo
o`0AOol00`00Oomoo`04Ool30005Ool2000;Ool30005Ool20005Ool00`00Oomoo`0<Ool00`00Ool0
000>Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomo
o`0FOol00`00Oomoo`1AOol001Uoo`03001oogoo06Yoo`03001oogoo029oo`03001oogoo01Eoo`80
009oo`03001oogoo011oo`03001oogoo00Qoo`H000ioo`H000Qoo`03001oogoo00]oo`80011oo`03
001oogoo00=oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00eoo`03001oogoo01Aoo`03
001oogoo059oo`006Goo00<007ooOol0Jgoo00<007ooOol08Goo00<007ooOol05goo0P004Woo00<0
07ooOol0;7oo0P002goo0P0047oo00<007ooOol00Woo00<007ooOol037oo00<007ooOol02Woo00<0
07ooOol03Goo00<007ooOol057oo00<007ooOol0DWoo000IOol00`00Oomoo`1/Ool00`00Oomoo`0O
Ool00`00Oomoo`0HOol2000@Ool2000aOol00`00Oomoo`06Ool200000goo001oo`0?Ool00`00Oomo
o`02Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool00`00Oomoo`0DOol00`00Oomo
o`1BOol001Uoo`03001oogoo06eoo`03001oogoo01ioo`03001oogoo01Qoo`04001oo`00000<Ool2
000dOol20004Ool20004Ool00`00Oomoo`0>Ool01000Oomoo`003goo00<007ooOol02Goo00<007oo
Ool03goo00<007ooOol04Woo00<007ooOol0Dgoo000IOol00`00Oomoo`1^Ool00`00Oomoo`0LOol0
0`00Oomoo`0HOol00`00Oomoo`02Ool00`00Oomoo`07Ool2000gOol60006Ool00`00Oomoo`0=Ool0
1000Oomoo`003goo00<007ooOol02Goo00<007ooOol03goo00<007ooOol04Woo00<007ooOol0Dgoo
000IOol00`00Oomoo`1_Ool00`00Oomoo`0KOol00`00Oomoo`0HOol00`00Oomoo`03Ool90015Ool0
0`00Oomoo`0>Ool00`00Ool0000@Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Oomoo`0AOol0
0`00Oomoo`1DOol001Uoo`03001oogoo071oo`03001oogoo01Uoo`03001oogoo01Qoo`03001oogoo
05=oo`03001oogoo00eoo`80015oo`03001oogoo00Moo`03001oogoo011oo`03001oogoo015oo`03
001oogoo05Aoo`006Goo00<007ooOol0LGoo00<007ooOol067oo00<007ooOol05goo00<007ooOol0
EGoo00<007ooOol037oo00<007ooOol047oo00<007ooOol01goo00<007ooOol04Goo00<007ooOol0
47oo00<007ooOol0E7oo000IOol3001bOol00`00Oomoo`0FOol00`00Oomoo`0GOol00`00Oomoo`1G
Ool00`00Oomoo`0:Ool00`00Ool0000BOol00`00Oomoo`05Ool00`00Oomoo`0BOol00`00Oomoo`0@
Ool00`00Oomoo`1DOol001Uoo`03001oogoo07=oo`03001oogoo01Eoo`03001oogoo01Ioo`03001o
ogoo05Uoo`03001oogoo00Qoo`04001oogoo000BOol00`00Oomoo`05Ool00`00Oomoo`0BOol00`00
Oomoo`0?Ool00`00Oomoo`1EOol001Uoo`03001oogoo07Aoo`03001oogoo01=oo`03001oogoo01Mo
o`03001oogoo05Yoo`03001oogoo00Ioo`05001oogooOol0000BOol00`00Oomoo`05Ool00`00Oomo
o`0BOol00`00Oomoo`0?Ool00`00Oomoo`1EOol001Uoo`03001oogoo07Eoo`03001oogoo019oo`03
001oogoo01Ioo`03001oogoo05aoo`8000Eoo`03001oogoo00=oo`03001oogoo011oo`03001oogoo
00=oo`03001oogoo01=oo`03001oogoo00moo`03001oogoo05Eoo`006Goo00<007ooOol0MWoo0P00
4Goo00<007ooOol05Woo00<007ooOol0GWoo1P001Woo00<007ooOol047oo00<007ooOol00goo00<0
07ooOol04goo00<007ooOol03goo00<007ooOol0EGoo000IOol00`00Oomoo`1hOol00`00Oomoo`0>
Ool00`00Oomoo`0EOol00`00Oomoo`1/Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`0D
Ool00`00Oomoo`0=Ool00`00Oomoo`1FOol001Uoo`03001oogoo07Uoo`03001oogoo00aoo`03001o
ogoo01Eoo`03001oogoo06eoo`03001oogoo011oo`05001oogooOol0000GOol00`00Oomoo`0=Ool0
0`00Oomoo`1FOol001Uoo`03001oogoo07Yoo`8000aoo`03001oogoo01Aoo`03001oogoo06moo`03
001oogoo00moo`04001oogoo000HOol00`00Oomoo`0<Ool00`00Oomoo`1GOol001Uoo`03001oogoo
07aoo`03001oogoo00Qoo`03001oogoo01Aoo`03001oogoo071oo`03001oogoo00moo`04001oogoo
000HOol00`00Oomoo`0<Ool00`00Oomoo`1GOol001Uoo`03001oogoo07eoo`03001oogoo00Moo`03
001oogoo01=oo`03001oogoo079oo`03001oogoo00moo`8001Yoo`03001oogoo00]oo`03001oogoo
05Moo`006Goo00<007ooOol0OWoo00<007ooOol01Goo00<007ooOol04Woo0P00MGoo00<007ooOol0
3goo00<007ooOol06Goo00<007ooOol02Woo00<007ooOol0F7oo0004Ool20004Ool20004Ool30006
Ool00`00Oomoo`1oOol20005Ool00`00Oomoo`0AOol00`00Oomoo`1eOol00`00Oomoo`0?Ool00`00
Oomoo`0IOol00`00Oomoo`0:Ool00`00Oomoo`1HOol000=oo`04001oogoo0003Ool20005Ool00`00
Oomoo`05Ool00`00Oomoo`21Ool20002Ool00`00Oomoo`0AOol00`00Oomoo`1gOol00`00Oomoo`0=
Ool00`00Ool0000KOol00`00Oomoo`08Ool00`00Oomoo`1IOol000=oo`04001oogoo0008Ool40006
Ool40022Ool3000AOol2001jOol00`00Oomoo`0=Ool00`00Ool0000KOol00`00Oomoo`08Ool00`00
Oomoo`1IOol000=oo`04001oogoo0008Ool00`00Ool00007Ool00`00Oomoo`24Ool5000<Ool2001m
Ool00`00Oomoo`0;Ool01000Oomoo`006goo00<007ooOol027oo00<007ooOol0FGoo0003Ool01000
Oomoo`0027oo00<007oo00001goo00<007ooOol0Q7oo00<007ooOol00Woo10000goo1@00P7oo0P00
2Woo00<007ooOol00Woo00<007ooOol06Goo00<007ooOol01goo00<007ooOol0FGoo0004Ool2000:
Ool20007Ool00`00Oomoo`23Ool00`00Oomoo`07Ool30027Ool00`00Oomoo`06Ool00`00Oomoo`03
Ool00`00Oomoo`0IOol00`00Oomoo`06Ool00`00Oomoo`1JOol001Uoo`03001oogoo08=oo`03001o
ogoo099oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo01Uoo`03001oogoo00Ioo`03001o
ogoo05Yoo`006Goo00<007ooOol0PWoo00<007ooOol0U7oo0P0000Aoo`00000000Qoo`03001oogoo
01Uoo`03001oogoo00Aoo`03001oogoo05]oo`006Goo00<007ooOol0PWoo00<007ooOol0UWoo0P00
2Woo00<007ooOol06Goo00<007ooOol017oo00<007ooOol0Fgoo000IOol00`00Oomoo`21Ool00`00
Oomoo`2SOol00`00Oomoo`0IOol00`00Oomoo`04Ool00`00Oomoo`1KOol001Uoo`03001oogoo085o
o`03001oogoo0:Aoo`03001oogoo01Uoo`03001oogoo00=oo`03001oogoo05]oo`006Goo00<007oo
Ool0P7oo00<007ooOol0YGoo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol0G7oo000IOol0
0`00Oomoo`20Ool00`00Oomoo`2UOol00`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomoo`1LOol0
01Uoo`03001oogoo07moo`03001oogoo0:Moo`03001oogoo01Qoo`05001oogooOol0001OOol001Uo
o`03001oogoo07moo`03001oogoo0:Moo`03001oogoo01Qoo`05001oogooOol0001OOol001Uoo`<0
07ioo`03001oogoo0:Qoo`03001oogoo01Qoo`05001oogooOol0001OOol001Uoo`03001oogoo07io
o`03001oogoo0:Uoo`03001oogoo01Moo`05001oogooOol0001OOol001Uoo`03001oogoo07eoo`03
001oogoo0:Yoo`03001oogoo01Qoo`03001oo`00061oo`006Goo00<007ooOol0OGoo00<007ooOol0
Zgoo00<007ooOol05goo0P00HGoo000IOol00`00Oomoo`1mOol00`00Oomoo`2[Ool00`00Oomoo`0G
Ool2001QOol001Uoo`03001oogoo07aoo`03001oogoo0:eoo`03001oogoo01Ioo`80065oo`006Goo
00<007ooOol0O7oo00<007ooOol0[Goo00<007ooOol05Woo0P00HGoo000IOol00`00Oomoo`1kOol0
0`00Oomoo`2^Ool00`00Oomoo`0FOol2001QOol001Uoo`03001oogoo07]oo`03001oogoo0:moo`03
001oogoo01Aoo`04001oogoo001POol001Uoo`03001oogoo07Yoo`03001oogoo0;1oo`03001oogoo
01Aoo`04001oogoo001POol001Uoo`03001oogoo07Yoo`03001oogoo0;1oo`03001oogoo01=oo`05
001oogooOol0001POol001Uoo`03001oogoo07Uoo`03001oogoo0;9oo`03001oogoo019oo`03001o
ogoo009oo`03001oogoo05eoo`006Goo00<007ooOol0NGoo00<007ooOol0/goo00<007ooOol047oo
00<007ooOol00goo00<007ooOol0GGoo000IOol3001hOol00`00Oomoo`2dOol00`00Oomoo`0?Ool0
0`00Oomoo`04Ool00`00Oomoo`1MOol001Uoo`03001oogoo07Qoo`03001oogoo0;Eoo`03001oogoo
00ioo`03001oogoo00Aoo`03001oogoo05eoo`006Goo00<007ooOol0Mgoo00<007ooOol0]Woo00<0
07ooOol03Goo00<007ooOol01Goo00<007ooOol0GGoo000IOol00`00Oomoo`1gOol00`00Oomoo`2g
Ool00`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomoo`1LOol001Uoo`03001oogoo07Ioo`03001o
ogoo0;Uoo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo05aoo`006Goo00<007ooOol0MWoo
00<007ooOol0^Woo0P002Goo00<007ooOol027oo00<007ooOol0G7oo000IOol00`00Oomoo`1eOol0
0`00Oomoo`2mOol00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`1KOol001Uoo`03001oogoo
07Eoo`03001oogoo0;eoo`8000Aoo`8000eoo`03001oogoo05]oo`006Goo00<007ooOol0M7oo00<0
07ooOol0`7oo10003goo00<007ooOol0Fgoo000IOol00`00Oomoo`1dOol00`00Oomoo`3COol00`00
Oomoo`1KOol001Uoo`03001oogoo07=oo`03001oogoo0=Aoo`03001oogoo05]oo`006Goo00<007oo
Ool0Lgoo00<007ooOol0e7oo00<007ooOol0Fgoo000IOol00`00Oomoo`1bOol00`00Oomoo`3FOol0
0`00Oomoo`1JOol001Uoo`<0079oo`03001oogoo0=Ioo`03001oogoo05Yoo`006Goo00<007ooOol0
LGoo00<007ooOol0f7oo00<007ooOol0FGoo000IOol00`00Oomoo`1aOol00`00Oomoo`3HOol00`00
Oomoo`1IOol001Uoo`03001oogoo071oo`03001oogoo0=Uoo`03001oogoo05Uoo`006Goo00<007oo
Ool0L7oo00<007ooOol0fGoo00<007ooOol0FGoo000IOol00`00Oomoo`1_Ool00`00Oomoo`3JOol0
0`00Oomoo`1IOol001Uoo`03001oogoo06moo`03001oogoo0=Yoo`03001oogoo05Uoo`006Goo00<0
07ooOol0KWoo00<007ooOol0g7oo00<007ooOol0F7oo000IOol00`00Oomoo`1^Ool00`00Oomoo`3L
Ool00`00Oomoo`1HOol001Uoo`03001oogoo06eoo`03001oogoo0=ioo`03001oogoo05Moo`0017oo
0P0017oo0P0017oo0P001goo00<007ooOol0KGoo00<007ooOol0gWoo00<007ooOol0Egoo0003Ool0
1000Oomoo`000goo0P000goo00@007ooOol000Ioo`03001oogoo06aoo`03001oogoo0=moo`03001o
ogoo05Moo`000goo00@007ooOol000Qoo`04001oogoo0006Ool4001ZOol00`00Oomoo`3POol00`00
Oomoo`1GOol000=oo`04001oogoo0008Ool30007Ool00`00Oomoo`1[Ool00`00Oomoo`3POol00`00
Oomoo`1GOol000=oo`04001oogoo0008Ool00`00Oomoo`07Ool00`00Oomoo`1ZOol00`00Oomoo`3R
Ool00`00Oomoo`1FOol000Aoo`8000Yoo`<000Ioo`03001oogoo06Yoo`03001oogoo0>9oo`03001o
ogoo05Ioo`006Goo00<007ooOol0JGoo00<007ooOol0hgoo00<007ooOol0EWoo000IOol00`00Oomo
o`1XOol00`00Oomoo`3UOol00`00Oomoo`1EOol001Uoo`03001oogoo06Qoo`03001oogoo0>Eoo`03
001oogoo05Eoo`006Goo00<007ooOol0Igoo00<007ooOol0iWoo00<007ooOol0EGoo000IOol00`00
Oomoo`1VOol00`00Oomoo`3WOol00`00Oomoo`1EOol001Uoo`03001oogoo06Ioo`03001oogoo0>Qo
o`03001oogoo05Aoo`006Goo00<007ooOol0IGoo00<007ooOol0jGoo00<007ooOol0E7oo000IOol0
0`00Oomoo`1UOol00`00Oomoo`3YOol00`00Oomoo`1DOol001Uoo`03001oogoo06Aoo`03001oogoo
0>Yoo`03001oogoo05Aoo`006Goo0`00Hgoo00<007ooOol0jgoo00<007ooOol0E7oo000IOol00`00
Oomoo`1SOol00`00Oomoo`3/Ool00`00Oomoo`1COol001Uoo`03001oogoo069oo`03001oogoo0>eo
o`03001oogoo05=oo`006Goo00<007ooOol0HWoo00<007ooOol0kWoo00<007ooOol0DWoo000IOol0
0`00Oomoo`1QOol00`00Oomoo`3_Ool00`00Oomoo`1BOol001Uoo`03001oogoo061oo`03001oogoo
0?1oo`03001oogoo059oo`006Goo00<007ooOol0H7oo00<007ooOol0l7oo00<007ooOol0DWoo000I
Ool00`00Oomoo`1OOol00`00Oomoo`3bOol00`00Oomoo`1AOol001Uoo`03001oogoo05ioo`03001o
ogoo0?=oo`03001oogoo055oo`006Goo00<007ooOol0GGoo00<007ooOol0m7oo00<007ooOol0DGoo
000IOol00`00Oomoo`1LOol00`00Oomoo`3eOol00`00Oomoo`1AOol001Uoo`03001oogoo05aoo`03
001oogoo0?Ioo`03001oogoo051oo`006Goo00<007ooOol0Fgoo00<007ooOol0mgoo00<007ooOol0
D7oo000IOol3001JOol00`00Oomoo`3hOol00`00Oomoo`1@Ool001Uoo`03001oogoo05Uoo`03001o
ogoo0?Uoo`03001oogoo051oo`006Goo00<007ooOol0FGoo00<007ooOol0nWoo00<007ooOol0Cgoo
000IOol00`00Oomoo`1HOol00`00Oomoo`3kOol00`00Oomoo`1?Ool001Uoo`03001oogoo05Moo`03
001oogoo0?aoo`03001oogoo04moo`006Goo00<007ooOol0EWoo00<007ooOol0oWoo00<007ooOol0
CWoo000IOol00`00Oomoo`1EOol00`00Oomoo`3oOol00`00Oomoo`1>Ool001Uoo`03001oogoo05Eo
o`03001oogoo0?moo`03001oogoo04ioo`006Goo00<007ooOol0E7oo00<007ooOol0ogoo0Goo00<0
07ooOol0CWoo000IOol00`00Oomoo`1COol00`00Oomoo`3oOol3Ool00`00Oomoo`1=Ool001Uoo`03
001oogoo059oo`03001oogoo0?moo`Eoo`03001oogoo04aoo`006Goo00<007ooOol0DWoo00<007oo
Ool0ogoo1Goo00<007ooOol0C7oo000IOol00`00Oomoo`1AOol00`00Oomoo`3oOol6Ool00`00Oomo
o`1<Ool001Uoo`<0051oo`03001oogoo0?moo`Qoo`03001oogoo04]oo`006Goo00<007ooOol0Cgoo
00<007ooOol0ogoo2Goo00<007ooOol0Bgoo000IOol00`00Oomoo`1>Ool00`00Oomoo`3oOol:Ool0
0`00Oomoo`1;Ool001Uoo`03001oogoo04ioo`03001oogoo0?moo`]oo`03001oogoo04Yoo`006Goo
00<007ooOol0CGoo00<007ooOol0ogoo37oo00<007ooOol0BWoo000IOol00`00Oomoo`1<Ool00`00
Oomoo`3oOol=Ool00`00Oomoo`1:Ool001Uoo`03001oogoo04]oo`03001oogoo0?moo`ioo`03001o
ogoo04Yoo`006Goo00<007ooOol0BWoo00<007ooOol0ogoo3goo00<007ooOol0BWoo000IOol00`00
Oomoo`19Ool00`00Oomoo`3oOolAOol00`00Oomoo`19Ool001Uoo`03001oogoo04Qoo`03001oogoo
0?mooa9oo`03001oogoo04Uoo`006Goo00<007ooOol0Agoo00<007ooOol0ogoo57oo00<007ooOol0
B7oo0004Ool20004Ool20004Ool20007Ool00`00Oomoo`16Ool00`00Oomoo`3oOolEOol00`00Oomo
o`18Ool000=oo`04001oogoo0003Ool20003Ool01000Oomoo`001Woo00<007ooOol0AGoo00<007oo
Ool0ogoo5Woo00<007ooOol0B7oo0003Ool01000Oomoo`0027oo00@007ooOol000Ioo`@004=oo`03
001oogoo0?mooaQoo`03001oogoo04Moo`000goo00@007ooOol000Uoo`8000Moo`03001oogoo04=o
o`03001oogoo0?mooaUoo`03001oogoo04Moo`000goo00@007ooOol000Qoo`04001oogoo0006Ool0
0`00Oomoo`12Ool00`00Oomoo`3oOolKOol00`00Oomoo`16Ool000Aoo`8000Yoo`8000Moo`03001o
ogoo045oo`03001oogoo0?mooaaoo`03001oogoo04Ioo`006Goo00<007ooOol0@7oo00<007ooOol0
ogoo7Goo00<007ooOol0AWoo000IOol00`00Oomoo`0oOol00`00Oomoo`3oOolOOol00`00Oomoo`15
Ool001Uoo`03001oogoo03eoo`800?moob9oo`03001oogoo04Eoo`006Goo00<007ooOol0?7oo00<0
07ooOol0ogoo8Woo00<007ooOol0AGoo000IOol00`00Oomoo`0kOol00`00Oomoo`3oOolTOol00`00
Oomoo`14Ool001Uoo`03001oogoo03Yoo`03001oogoo0?moobEoo`03001oogoo04Aoo`006Goo00<0
07ooOol0>7oo0P00ogoo:Goo00<007ooOol0@goo000IOol00`00Oomoo`0gOol00`00Oomoo`3oOolY
Ool00`00Oomoo`13Ool001Uoo`03001oogoo03Ioo`03001oogoo0?moobYoo`03001oogoo04=oo`00
6Goo0`00=Goo00<007ooOol0ogoo;7oo00<007ooOol0@Woo000IOol00`00Oomoo`0dOol00`00Oomo
o`3oOol]Ool00`00Oomoo`12Ool001Uoo`03001oogoo039oo`800?mooc5oo`03001oogoo045oo`00
6Goo00<007ooOol0<Goo00<007ooOol0ogoo<Goo00<007ooOol0@Goo000IOol00`00Oomoo`0`Ool0
0`00Oomoo`3oOolbOol00`00Oomoo`11Ool001Uoo`03001oogoo02moo`03001oogoo0?moocAoo`03
001oogoo041oo`006Goo00<007ooOol0;Goo0P00ogoo>7oo00<007ooOol0?goo000IOol00`00Oomo
o`0/Ool00`00Oomoo`3oOolhOol00`00Oomoo`0oOol001Uoo`03001oogoo02Yoo`800?mooc]oo`80
041oo`006Goo00<007ooOol0:7oo0P00ogoo?Woo00<007ooOol0?Woo000IOol00`00Oomoo`0WOol0
0`00Oomoo`3oOolnOol00`00Oomoo`0nOol001Uoo`03001oogoo02Eoo`800?mood9oo`03001oogoo
03eoo`006Goo0`008goo0P00ogooAGoo00<007ooOol0?7oo000IOol00`00Oomoo`0ROol00`00Oomo
o`3oOom5Ool00`00Oomoo`0lOol001Uoo`03001oogoo021oo`800?moodUoo`03001oogoo03]oo`00
6Goo00<007ooOol07Goo0`00ogooBgoo00<007ooOol0>goo000IOol00`00Oomoo`0KOol2003oOom?
Ool00`00Oomoo`0jOol001Uoo`03001oogoo01Qoo`<00?mooe5oo`8003]oo`006Goo00<007ooOol0
5Woo0P00ogooEGoo00<007ooOol0>Goo000IOol00`00Oomoo`0COol3003oOomHOol00`00Oomoo`0h
Ool001Uoo`03001oogoo015oo`800?mooe]oo`8003Uoo`006Goo00<007ooOol03Woo0`00ogooGWoo
0P00>7oo000IOol00`00Oomoo`0;Ool3003oOomROol00`00Oomoo`0fOol001Uoo`03001oogoo00Mo
o`@00?moofEoo`8003Moo`006Goo00<007ooOol00goo1000ogooJWoo0P00=Woo000IOol6003oOom_
Ool2000eOol001Uoo`800?moogAoo`8003Aoo`006Goo00<007ooOol0ogooM7oo0P00<goo000IOol0
0`00Oomoo`3oOomeOol2000bOol001Uoo`03001oogoo0?moogIoo`80035oo`006Goo00<007ooOol0
ogooMgoo0P00<7oo000IOol00`00Oomoo`3oOomiOol2000^Ool001Uoo`03001oogoo0?moogYoo`80
02eoo`006Goo00<007ooOol0ogooO7oo0P00:goo000IOol00`00Oomoo`3oOomnOol3000XOol001Uo
o`03001oogoo0?mooh1oo`<002Ioo`003goo0`001goo00<007ooOol0ogooPgoo10008Woo000@Ool0
0`00Oomoo`06Ool00`00Oomoo`3oOon7Ool8000JOol0011oo`03001oogoo00Ioo`@00?mooheooa00
00]oo`0047oo00<007ooOol0ogoo/Woo000@Ool00`00Oomoo`3oOonbOol000moo`800?mookAoo`00
ogooaGoo0000\
\>"],
  ImageRangeCache->{{{0, 451}, {278.25, 0}} -> {-3.24603, -0.0670032, 
  0.0096357, 0.00389772}}]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 653},
WindowMargins->{{Automatic, 19}, {Automatic, -1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "RandomCoalescenceTimes"->{
    Cell[1987, 61, 899, 17, 122, "DefinitionBox",
      CellTags->{
      "RandomCoalescenceTimes", "NumberOfCoalescences", "TotalLength"}]},
  "NumberOfCoalescences"->{
    Cell[1987, 61, 899, 17, 122, "DefinitionBox",
      CellTags->{
      "RandomCoalescenceTimes", "NumberOfCoalescences", "TotalLength"}]},
  "TotalLength"->{
    Cell[1987, 61, 899, 17, 122, "DefinitionBox",
      CellTags->{
      "RandomCoalescenceTimes", "NumberOfCoalescences", "TotalLength"}]},
  "CoalescenceDistribution"->{
    Cell[30529, 733, 610, 12, 94, "DefinitionBox",
      CellTags->{"CoalescenceDistribution", "B"}]},
  "B"->{
    Cell[30529, 733, 610, 12, 94, "DefinitionBox",
      CellTags->{"CoalescenceDistribution", "B"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"RandomCoalescenceTimes", 174321, 9857},
  {"NumberOfCoalescences", 174491, 9861},
  {"TotalLength", 174652, 9865},
  {"CoalescenceDistribution", 174825, 9869},
  {"B", 174937, 9872}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 63, 0, 36, "SubsectionIcon"],
Cell[1805, 53, 179, 6, 24, "Text"],
Cell[1987, 61, 899, 17, 122, "DefinitionBox",
  CellTags->{
  "RandomCoalescenceTimes", "NumberOfCoalescences", "TotalLength"}],
Cell[2891, 81, 111, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3027, 88, 90, 2, 27, "Input"],
Cell[3120, 92, 292, 5, 20, "Output"]
}, Closed]],
Cell[3427, 100, 105, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[3557, 107, 74, 2, 27, "Input"],
Cell[3634, 111, 80, 2, 20, "Output"]
}, Closed]],
Cell[3729, 116, 99, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[3853, 123, 88, 2, 27, "Input"],
Cell[3944, 127, 61, 2, 20, "Output"]
}, Closed]],
Cell[4020, 132, 196, 5, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[4241, 141, 107, 2, 27, "Input"],
Cell[4351, 145, 388, 6, 50, "Output"]
}, Closed]],
Cell[4754, 154, 115, 2, 23, "Input"],

Cell[CellGroupData[{
Cell[4894, 160, 90, 2, 27, "Input"],
Cell[4987, 164, 25527, 566, 184, 3982, 295, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[30529, 733, 610, 12, 94, "DefinitionBox",
  CellTags->{"CoalescenceDistribution", "B"}],
Cell[31142, 747, 133, 3, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[31300, 754, 92, 2, 27, "Input"],
Cell[31395, 758, 376, 6, 38, "Output"]
}, Closed]],
Cell[31786, 767, 1122, 26, 246, "Text"],
Cell[32911, 795, 56, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[32992, 799, 109, 2, 27, "Input"],
Cell[33104, 803, 61, 2, 20, "Output"]
}, Closed]],
Cell[33180, 808, 68, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[33273, 812, 217, 4, 57, "Input"],
Cell[33493, 818, 61, 2, 20, "Output"]
}, Closed]],
Cell[33569, 823, 460, 12, 46, "Text"],
Cell[34032, 837, 60, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[34117, 842, 232, 5, 42, "Input"],
Cell[34352, 849, 139095, 8983, 286, 103655, 8540, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

