(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     36730,       1000]*)
(*NotebookOutlinePosition[     37874,       1038]*)
(*  CellTagsIndexPosition[     37775,       1031]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["The set of all possible family structures", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(\(\ \)\(AllSets[j, 
              k]\)\), \(\(lists\ all\ the\ family\ structures\ that\ could\ \
yield\ j\ families\ and\)\ \n\ \ \(k\ genes\)\)},
          {\(NewS[
              S]\), \(is\ used\ internally\ to\ give\ a\ recursion\ for\ the\ \
set\ of\ possible\ family\ structures\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"AllSets", "NewS"}],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`AllSets[j, k]\)]],
  " lists all the distinct structures consistent with ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ", using a recursive algorithm that works down from ",
  Cell[BoxData[
      \(TraditionalForm\`j = k\)]],
  "; it is very slow for ",
  Cell[BoxData[
      \(TraditionalForm\`j << k\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " large. "
}], "Text"],

Cell["\<\
Suppose that 20 lineages coalesce into 4 families.  This can occur \
in 64 ways:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AllSets[4, 20]\)], "Input",
  CellLabel->"In[158]:="],

Cell[BoxData[
    \({{{4, 5}}, {{1, 2}, {3, 6}}, {{1, 8}, {3, 4}}, {{1, 11}, {3, 3}}, {{1, 
          14}, {3, 2}}, {{1, 17}, {3, 1}}, {{2, 1}, {2, 9}}, {{2, 2}, {2, 
          8}}, {{2, 3}, {2, 7}}, {{2, 4}, {2, 6}}, {{1, 1}, {1, 3}, {2, 
          8}}, {{1, 1}, {1, 5}, {2, 7}}, {{1, 1}, {1, 7}, {2, 6}}, {{1, 
          1}, {1, 9}, {2, 5}}, {{1, 1}, {1, 11}, {2, 4}}, {{1, 1}, {1, 
          13}, {2, 3}}, {{1, 1}, {1, 15}, {2, 2}}, {{1, 2}, {1, 4}, {2, 
          7}}, {{1, 2}, {1, 8}, {2, 5}}, {{1, 2}, {1, 10}, {2, 4}}, {{1, 
          2}, {1, 12}, {2, 3}}, {{1, 2}, {1, 16}, {2, 1}}, {{1, 3}, {1, 
          5}, {2, 6}}, {{1, 3}, {1, 7}, {2, 5}}, {{1, 3}, {1, 9}, {2, 
          4}}, {{1, 3}, {1, 13}, {2, 2}}, {{1, 3}, {1, 15}, {2, 1}}, {{1, 
          4}, {1, 6}, {2, 5}}, {{1, 4}, {1, 10}, {2, 3}}, {{1, 4}, {1, 
          12}, {2, 2}}, {{1, 4}, {1, 14}, {2, 1}}, {{1, 5}, {1, 7}, {2, 
          4}}, {{1, 5}, {1, 9}, {2, 3}}, {{1, 5}, {1, 11}, {2, 2}}, {{1, 
          5}, {1, 13}, {2, 1}}, {{1, 6}, {1, 8}, {2, 3}}, {{1, 6}, {1, 
          10}, {2, 2}}, {{1, 6}, {1, 12}, {2, 1}}, {{1, 7}, {1, 9}, {2, 
          2}}, {{1, 7}, {1, 11}, {2, 1}}, {{1, 8}, {1, 10}, {2, 1}}, {{1, 
          1}, {1, 2}, {1, 3}, {1, 14}}, {{1, 1}, {1, 2}, {1, 4}, {1, 
          13}}, {{1, 1}, {1, 2}, {1, 5}, {1, 12}}, {{1, 1}, {1, 2}, {1, 
          6}, {1, 11}}, {{1, 1}, {1, 2}, {1, 7}, {1, 10}}, {{1, 1}, {1, 
          2}, {1, 8}, {1, 9}}, {{1, 1}, {1, 3}, {1, 4}, {1, 12}}, {{1, 
          1}, {1, 3}, {1, 5}, {1, 11}}, {{1, 1}, {1, 3}, {1, 6}, {1, 
          10}}, {{1, 1}, {1, 3}, {1, 7}, {1, 9}}, {{1, 1}, {1, 4}, {1, 
          5}, {1, 10}}, {{1, 1}, {1, 4}, {1, 6}, {1, 9}}, {{1, 1}, {1, 
          4}, {1, 7}, {1, 8}}, {{1, 1}, {1, 5}, {1, 6}, {1, 8}}, {{1, 2}, {1, 
          3}, {1, 4}, {1, 11}}, {{1, 2}, {1, 3}, {1, 5}, {1, 10}}, {{1, 
          2}, {1, 3}, {1, 6}, {1, 9}}, {{1, 2}, {1, 3}, {1, 7}, {1, 8}}, {{1, 
          2}, {1, 4}, {1, 5}, {1, 9}}, {{1, 2}, {1, 4}, {1, 6}, {1, 8}}, {{1, 
          2}, {1, 5}, {1, 6}, {1, 7}}, {{1, 3}, {1, 4}, {1, 5}, {1, 8}}, {{1, 
          3}, {1, 4}, {1, 6}, {1, 7}}}\)], "Output",
  CellLabel->"Out[158]="]
}, Closed]],

Cell["This becomes very slow for large numbers of genes:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[{j, Timing[AllSets[4, j] // Length]} // Flatten, {j, 10, 60, 
          10}] // TableForm\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"10", \(0.`\ Second\), "9"},
          {"20", \(0.`\ Second\), "64"},
          {"30", \(0.`\ Second\), "206"},
          {"40", \(0.`\ Second\), "478"},
          {"50", \(12.3000000000000109`\ Second\), "920"},
          {"60", \(37.8166666666666628`\ Second\), "1575"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[7]//TableForm="]
}, Closed]],

Cell["\<\
With very many families, the number of possibilities becomes \
extremely large:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[{j, Timing[AllSets[Quotient[j, 2], j] // Length]} // Flatten, {j, 
          10, 40, 10}] // TableForm\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"10", \(0.`\ Second\), "7"},
          {"20", \(0.`\ Second\), "42"},
          {"30", \(15.5666666666666619`\ Second\), "176"},
          {"40", \(99.9333333333333406`\ Second\), "627"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[10]//TableForm="]
}, Closed]],

Cell["\<\
 This gives the pairwise identity for each possible \
structure:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pI = \((PairwiseIdentity /@ AllSets[4, 20])\) // N\)], "Input",
  CellLabel->"In[161]:="],

Cell[BoxData[
    \({0.210526315789473672`, 0.242105263157894734`, 0.242105263157894734`, 
      0.336842105263157876`, 0.494736842105263185`, 0.71578947368421053`, 
      0.378947368421052654`, 0.305263157894736858`, 0.252631578947368407`, 
      0.221052631578947345`, 0.310526315789473716`, 0.273684210526315796`, 
      0.268421052631578938`, 0.29473684210526315`, 0.352631578947368407`, 
      0.44210526315789469`, 0.563157894736842123`, 0.257894736842105309`, 
      0.257894736842105309`, 0.305263157894736858`, 0.384210526315789469`, 
      0.636842105263157876`, 0.226315789473684203`, 0.231578947368421061`, 
      0.268421052631578938`, 0.436842105263157876`, 0.568421052631578938`, 
      0.21578947368421053`, 0.3`, 0.389473684210526283`, 
      0.510526315789473716`, 0.226315789473684203`, 0.273684210526315796`, 
      0.352631578947368407`, 0.463157894736842123`, 0.257894736842105309`, 
      0.326315789473684247`, 0.426315789473684247`, 0.310526315789473716`, 
      0.4`, 0.384210526315789469`, 0.5`, 0.447368421052631592`, 
      0.405263157894736814`, 0.373684210526315796`, 0.352631578947368407`, 
      0.342105263157894734`, 0.394736842105263185`, 0.357894736842105265`, 
      0.331578947368421017`, 0.31578947368421053`, 0.321052631578947345`, 
      0.3`, 0.289473684210526336`, 0.27894736842105261`, 
      0.342105263157894734`, 0.310526315789473716`, 0.289473684210526336`, 
      0.27894736842105261`, 0.27894736842105261`, 0.263157894736842079`, 
      0.247368421052631592`, 0.247368421052631592`, 
      0.236842105263157876`}\)], "Output",
  CellLabel->"Out[161]="]
}, Closed]],

Cell[" This gives the probability of each possible structure:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pd = \((FamilyProbability /@ AllSets[4, 20])\)\)], "Input",
  CellLabel->"In[163]:="],

Cell[BoxData[
    \({1\/969, 4\/969, 4\/969, 4\/969, 4\/969, 4\/969, 2\/323, 2\/323, 
      2\/323, 2\/323, 4\/323, 4\/323, 4\/323, 4\/323, 4\/323, 4\/323, 4\/323, 
      4\/323, 4\/323, 4\/323, 4\/323, 4\/323, 4\/323, 4\/323, 4\/323, 4\/323, 
      4\/323, 4\/323, 4\/323, 4\/323, 4\/323, 4\/323, 4\/323, 4\/323, 4\/323, 
      4\/323, 4\/323, 4\/323, 4\/323, 4\/323, 4\/323, 8\/323, 8\/323, 8\/323, 
      8\/323, 8\/323, 8\/323, 8\/323, 8\/323, 8\/323, 8\/323, 8\/323, 8\/323, 
      8\/323, 8\/323, 8\/323, 8\/323, 8\/323, 8\/323, 8\/323, 8\/323, 8\/323, 
      8\/323, 8\/323}\)], "Output",
  CellLabel->"Out[163]="]
}, Closed]],

Cell["\<\
These sum to one, reassuringly.  The mean pairwise identity is \
0.337:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Plus @@ pd, pd . pI}\)], "Input",
  CellLabel->"In[164]:="],

Cell[BoxData[
    \({1, 0.336842105263158053`}\)], "Output",
  CellLabel->"Out[164]="]
}, Closed]],

Cell["\<\
There are 22 configurations all with probability 8/323, and 31 with \
probability 4/323, making up 93% of the total:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(spdI = 
      Sort[Transpose[{pd, pI, AllSets[4, 20]}]] // TableForm\)], "Input",
  CellLabel->"In[165]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(1\/969\), "0.210526315789473672`", GridBox[{
                {"4", "5"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/969\), "0.242105263157894734`", GridBox[{
                {"1", "2"},
                {"3", "6"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/969\), "0.242105263157894734`", GridBox[{
                {"1", "8"},
                {"3", "4"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/969\), "0.336842105263157876`", GridBox[{
                {"1", "11"},
                {"3", "3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/969\), "0.494736842105263185`", GridBox[{
                {"1", "14"},
                {"3", "2"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/969\), "0.71578947368421053`", GridBox[{
                {"1", "17"},
                {"3", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(2\/323\), "0.221052631578947345`", GridBox[{
                {"2", "4"},
                {"2", "6"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(2\/323\), "0.252631578947368407`", GridBox[{
                {"2", "3"},
                {"2", "7"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(2\/323\), "0.305263157894736858`", GridBox[{
                {"2", "2"},
                {"2", "8"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(2\/323\), "0.378947368421052654`", GridBox[{
                {"2", "1"},
                {"2", "9"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.21578947368421053`", GridBox[{
                {"1", "4"},
                {"1", "6"},
                {"2", "5"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.226315789473684203`", GridBox[{
                {"1", "3"},
                {"1", "5"},
                {"2", "6"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.226315789473684203`", GridBox[{
                {"1", "5"},
                {"1", "7"},
                {"2", "4"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.231578947368421061`", GridBox[{
                {"1", "3"},
                {"1", "7"},
                {"2", "5"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.257894736842105309`", GridBox[{
                {"1", "2"},
                {"1", "4"},
                {"2", "7"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.257894736842105309`", GridBox[{
                {"1", "2"},
                {"1", "8"},
                {"2", "5"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.257894736842105309`", GridBox[{
                {"1", "6"},
                {"1", "8"},
                {"2", "3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.268421052631578938`", GridBox[{
                {"1", "1"},
                {"1", "7"},
                {"2", "6"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.268421052631578938`", GridBox[{
                {"1", "3"},
                {"1", "9"},
                {"2", "4"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.273684210526315796`", GridBox[{
                {"1", "1"},
                {"1", "5"},
                {"2", "7"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.273684210526315796`", GridBox[{
                {"1", "5"},
                {"1", "9"},
                {"2", "3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.29473684210526315`", GridBox[{
                {"1", "1"},
                {"1", "9"},
                {"2", "5"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.3`", GridBox[{
                {"1", "4"},
                {"1", "10"},
                {"2", "3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.305263157894736858`", GridBox[{
                {"1", "2"},
                {"1", "10"},
                {"2", "4"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.310526315789473716`", GridBox[{
                {"1", "1"},
                {"1", "3"},
                {"2", "8"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.310526315789473716`", GridBox[{
                {"1", "7"},
                {"1", "9"},
                {"2", "2"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.326315789473684247`", GridBox[{
                {"1", "6"},
                {"1", "10"},
                {"2", "2"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.352631578947368407`", GridBox[{
                {"1", "1"},
                {"1", "11"},
                {"2", "4"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.352631578947368407`", GridBox[{
                {"1", "5"},
                {"1", "11"},
                {"2", "2"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.384210526315789469`", GridBox[{
                {"1", "2"},
                {"1", "12"},
                {"2", "3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.384210526315789469`", GridBox[{
                {"1", "8"},
                {"1", "10"},
                {"2", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.389473684210526283`", GridBox[{
                {"1", "4"},
                {"1", "12"},
                {"2", "2"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.4`", GridBox[{
                {"1", "7"},
                {"1", "11"},
                {"2", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.426315789473684247`", GridBox[{
                {"1", "6"},
                {"1", "12"},
                {"2", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.436842105263157876`", GridBox[{
                {"1", "3"},
                {"1", "13"},
                {"2", "2"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.44210526315789469`", GridBox[{
                {"1", "1"},
                {"1", "13"},
                {"2", "3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.463157894736842123`", GridBox[{
                {"1", "5"},
                {"1", "13"},
                {"2", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.510526315789473716`", GridBox[{
                {"1", "4"},
                {"1", "14"},
                {"2", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.563157894736842123`", GridBox[{
                {"1", "1"},
                {"1", "15"},
                {"2", "2"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.568421052631578938`", GridBox[{
                {"1", "3"},
                {"1", "15"},
                {"2", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(4\/323\), "0.636842105263157876`", GridBox[{
                {"1", "2"},
                {"1", "16"},
                {"2", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.236842105263157876`", GridBox[{
                {"1", "3"},
                {"1", "4"},
                {"1", "6"},
                {"1", "7"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.247368421052631592`", GridBox[{
                {"1", "2"},
                {"1", "5"},
                {"1", "6"},
                {"1", "7"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.247368421052631592`", GridBox[{
                {"1", "3"},
                {"1", "4"},
                {"1", "5"},
                {"1", "8"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.263157894736842079`", GridBox[{
                {"1", "2"},
                {"1", "4"},
                {"1", "6"},
                {"1", "8"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.27894736842105261`", GridBox[{
                {"1", "1"},
                {"1", "5"},
                {"1", "6"},
                {"1", "8"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.27894736842105261`", GridBox[{
                {"1", "2"},
                {"1", "3"},
                {"1", "7"},
                {"1", "8"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.27894736842105261`", GridBox[{
                {"1", "2"},
                {"1", "4"},
                {"1", "5"},
                {"1", "9"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.289473684210526336`", GridBox[{
                {"1", "1"},
                {"1", "4"},
                {"1", "7"},
                {"1", "8"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.289473684210526336`", GridBox[{
                {"1", "2"},
                {"1", "3"},
                {"1", "6"},
                {"1", "9"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.3`", GridBox[{
                {"1", "1"},
                {"1", "4"},
                {"1", "6"},
                {"1", "9"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.310526315789473716`", GridBox[{
                {"1", "2"},
                {"1", "3"},
                {"1", "5"},
                {"1", "10"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.31578947368421053`", GridBox[{
                {"1", "1"},
                {"1", "3"},
                {"1", "7"},
                {"1", "9"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.321052631578947345`", GridBox[{
                {"1", "1"},
                {"1", "4"},
                {"1", "5"},
                {"1", "10"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.331578947368421017`", GridBox[{
                {"1", "1"},
                {"1", "3"},
                {"1", "6"},
                {"1", "10"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.342105263157894734`", GridBox[{
                {"1", "1"},
                {"1", "2"},
                {"1", "8"},
                {"1", "9"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.342105263157894734`", GridBox[{
                {"1", "2"},
                {"1", "3"},
                {"1", "4"},
                {"1", "11"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.352631578947368407`", GridBox[{
                {"1", "1"},
                {"1", "2"},
                {"1", "7"},
                {"1", "10"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.357894736842105265`", GridBox[{
                {"1", "1"},
                {"1", "3"},
                {"1", "5"},
                {"1", "11"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.373684210526315796`", GridBox[{
                {"1", "1"},
                {"1", "2"},
                {"1", "6"},
                {"1", "11"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.394736842105263185`", GridBox[{
                {"1", "1"},
                {"1", "3"},
                {"1", "4"},
                {"1", "12"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.405263157894736814`", GridBox[{
                {"1", "1"},
                {"1", "2"},
                {"1", "5"},
                {"1", "12"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.447368421052631592`", GridBox[{
                {"1", "1"},
                {"1", "2"},
                {"1", "4"},
                {"1", "13"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {\(8\/323\), "0.5`", GridBox[{
                {"1", "1"},
                {"1", "2"},
                {"1", "3"},
                {"1", "14"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{
        Rational[ 1, 969], 0.21052631578947367, {{4, 5}}}, {
        Rational[ 4, 969], 0.24210526315789474, {{1, 2}, {3, 6}}}, {
        Rational[ 4, 969], 0.24210526315789474, {{1, 8}, {3, 4}}}, {
        Rational[ 4, 969], 0.33684210526315789, {{1, 11}, {3, 3}}}, {
        Rational[ 4, 969], 0.49473684210526314, {{1, 14}, {3, 2}}}, {
        Rational[ 4, 969], 0.71578947368421053, {{1, 17}, {3, 1}}}, {
        Rational[ 2, 323], 0.22105263157894736, {{2, 4}, {2, 6}}}, {
        Rational[ 2, 323], 0.25263157894736843, {{2, 3}, {2, 7}}}, {
        Rational[ 2, 323], 0.30526315789473685, {{2, 2}, {2, 8}}}, {
        Rational[ 2, 323], 0.37894736842105264, {{2, 1}, {2, 9}}}, {
        Rational[ 4, 323], 0.21578947368421053, {{1, 4}, {1, 6}, {2, 5}}}, {
        Rational[ 4, 323], 0.22631578947368422, {{1, 3}, {1, 5}, {2, 6}}}, {
        Rational[ 4, 323], 0.22631578947368422, {{1, 5}, {1, 7}, {2, 4}}}, {
        Rational[ 4, 323], 0.23157894736842105, {{1, 3}, {1, 7}, {2, 5}}}, {
        Rational[ 4, 323], 0.25789473684210529, {{1, 2}, {1, 4}, {2, 7}}}, {
        Rational[ 4, 323], 0.25789473684210529, {{1, 2}, {1, 8}, {2, 5}}}, {
        Rational[ 4, 323], 0.25789473684210529, {{1, 6}, {1, 8}, {2, 3}}}, {
        Rational[ 4, 323], 0.26842105263157895, {{1, 1}, {1, 7}, {2, 6}}}, {
        Rational[ 4, 323], 0.26842105263157895, {{1, 3}, {1, 9}, {2, 4}}}, {
        Rational[ 4, 323], 0.27368421052631581, {{1, 1}, {1, 5}, {2, 7}}}, {
        Rational[ 4, 323], 0.27368421052631581, {{1, 5}, {1, 9}, {2, 3}}}, {
        Rational[ 4, 323], 0.29473684210526313, {{1, 1}, {1, 9}, {2, 5}}}, {
        Rational[ 4, 323], 0.29999999999999999, {{1, 4}, {1, 10}, {2, 3}}}, {
        Rational[ 4, 323], 0.30526315789473685, {{1, 2}, {1, 10}, {2, 4}}}, {
        Rational[ 4, 323], 0.31052631578947371, {{1, 1}, {1, 3}, {2, 8}}}, {
        Rational[ 4, 323], 0.31052631578947371, {{1, 7}, {1, 9}, {2, 2}}}, {
        Rational[ 4, 323], 0.32631578947368423, {{1, 6}, {1, 10}, {2, 2}}}, {
        Rational[ 4, 323], 0.35263157894736841, {{1, 1}, {1, 11}, {2, 4}}}, {
        Rational[ 4, 323], 0.35263157894736841, {{1, 5}, {1, 11}, {2, 2}}}, {
        Rational[ 4, 323], 0.38421052631578945, {{1, 2}, {1, 12}, {2, 3}}}, {
        Rational[ 4, 323], 0.38421052631578945, {{1, 8}, {1, 10}, {2, 1}}}, {
        Rational[ 4, 323], 0.38947368421052631, {{1, 4}, {1, 12}, {2, 2}}}, {
        Rational[ 4, 323], 0.40000000000000002, {{1, 7}, {1, 11}, {2, 1}}}, {
        Rational[ 4, 323], 0.4263157894736842, {{1, 6}, {1, 12}, {2, 1}}}, {
        Rational[ 4, 323], 0.43684210526315792, {{1, 3}, {1, 13}, {2, 2}}}, {
        Rational[ 4, 323], 0.44210526315789472, {{1, 1}, {1, 13}, {2, 3}}}, {
        Rational[ 4, 323], 0.4631578947368421, {{1, 5}, {1, 13}, {2, 1}}}, {
        Rational[ 4, 323], 0.51052631578947372, {{1, 4}, {1, 14}, {2, 1}}}, {
        Rational[ 4, 323], 0.56315789473684208, {{1, 1}, {1, 15}, {2, 2}}}, {
        Rational[ 4, 323], 0.56842105263157894, {{1, 3}, {1, 15}, {2, 1}}}, {
        Rational[ 4, 323], 0.63684210526315788, {{1, 2}, {1, 16}, {2, 1}}}, {
        Rational[ 8, 323], 0.23684210526315788, {{1, 3}, {1, 4}, {1, 6}, {1, 
        7}}}, {
        Rational[ 8, 323], 0.24736842105263157, {{1, 2}, {1, 5}, {1, 6}, {1, 
        7}}}, {
        Rational[ 8, 323], 0.24736842105263157, {{1, 3}, {1, 4}, {1, 5}, {1, 
        8}}}, {
        Rational[ 8, 323], 0.26315789473684209, {{1, 2}, {1, 4}, {1, 6}, {1, 
        8}}}, {
        Rational[ 8, 323], 0.27894736842105261, {{1, 1}, {1, 5}, {1, 6}, {1, 
        8}}}, {
        Rational[ 8, 323], 0.27894736842105261, {{1, 2}, {1, 3}, {1, 7}, {1, 
        8}}}, {
        Rational[ 8, 323], 0.27894736842105261, {{1, 2}, {1, 4}, {1, 5}, {1, 
        9}}}, {
        Rational[ 8, 323], 0.28947368421052633, {{1, 1}, {1, 4}, {1, 7}, {1, 
        8}}}, {
        Rational[ 8, 323], 0.28947368421052633, {{1, 2}, {1, 3}, {1, 6}, {1, 
        9}}}, {
        Rational[ 8, 323], 0.29999999999999999, {{1, 1}, {1, 4}, {1, 6}, {1, 
        9}}}, {
        Rational[ 8, 323], 0.31052631578947371, {{1, 2}, {1, 3}, {1, 5}, {1, 
        10}}}, {
        Rational[ 8, 323], 0.31578947368421051, {{1, 1}, {1, 3}, {1, 7}, {1, 
        9}}}, {
        Rational[ 8, 323], 0.32105263157894737, {{1, 1}, {1, 4}, {1, 5}, {1, 
        10}}}, {
        Rational[ 8, 323], 0.33157894736842103, {{1, 1}, {1, 3}, {1, 6}, {1, 
        10}}}, {
        Rational[ 8, 323], 0.34210526315789475, {{1, 1}, {1, 2}, {1, 8}, {1, 
        9}}}, {
        Rational[ 8, 323], 0.34210526315789475, {{1, 2}, {1, 3}, {1, 4}, {1, 
        11}}}, {
        Rational[ 8, 323], 0.35263157894736841, {{1, 1}, {1, 2}, {1, 7}, {1, 
        10}}}, {
        Rational[ 8, 323], 0.35789473684210527, {{1, 1}, {1, 3}, {1, 5}, {1, 
        11}}}, {
        Rational[ 8, 323], 0.37368421052631579, {{1, 1}, {1, 2}, {1, 6}, {1, 
        11}}}, {
        Rational[ 8, 323], 0.39473684210526316, {{1, 1}, {1, 3}, {1, 4}, {1, 
        12}}}, {
        Rational[ 8, 323], 0.40526315789473683, {{1, 1}, {1, 2}, {1, 5}, {1, 
        12}}}, {
        Rational[ 8, 323], 0.44736842105263158, {{1, 1}, {1, 2}, {1, 4}, {1, 
        13}}}, {
        Rational[ 8, 323], 0.5, {{1, 1}, {1, 2}, {1, 3}, {1, 
        14}}}}]]], "Output",
  CellLabel->"Out[165]//TableForm="]
}, Closed]],

Cell[TextData[{
  "It would be possible to use the more efficient algorithm ",
  Cell[BoxData[
      \(TraditionalForm\`Partitions[k]\)]],
  " in ",
  ButtonBox["DiscreteMath`Combinatorica`",
    ButtonData:>{"DiscreteMath`Combinatorica`", "1.17"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"DiscreteMath`Combinatorica`"],
  ".  This produces all possible partitions of ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "; one would then select those that contained ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " elements.  However, direct enumeration is still impractical above about \
40 lineages."
}], "Text"],

Cell[BoxData[
    \(<< DiscreteMath`Combinatorica`; \)], "Input",
  CellLabel->"In[166]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[Print[Timing[Length[Partitions[j]]]], {j, 10, 40, 10}]; \)], "Input",\

  CellLabel->"In[167]:="],

Cell[BoxData[
    \({0.0166666666664241347`\ Second, 42}\)], "Print"],

Cell[BoxData[
    \({0.25`\ Second, 627}\)], "Print"],

Cell[BoxData[
    \({2.46666666666715173`\ Second, 5604}\)], "Print"],

Cell[BoxData[
    \({18.5`\ Second, 37338}\)], "Print"]
}, Closed]],

Cell["\<\
(Note that there is an obscure clash in loading both \
DiscreteMath`Combinatorica` and Statistics`DataManipulation`: both define \
Ordering[])\
\>", "Text"]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{245, Automatic}, {Automatic, 46}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "AllSets"->{
    Cell[1787, 51, 435, 9, 104, "DefinitionBox",
      CellTags->{"AllSets", "NewS"}]},
  "NewS"->{
    Cell[1787, 51, 435, 9, 104, "DefinitionBox",
      CellTags->{"AllSets", "NewS"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"AllSets", 37562, 1021},
  {"NewS", 37662, 1024}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 67, 0, 36, "SubsectionIcon"],
Cell[1787, 51, 435, 9, 104, "DefinitionBox",
  CellTags->{"AllSets", "NewS"}],
Cell[2225, 62, 510, 19, 36, "Text"],
Cell[2738, 83, 111, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2874, 90, 73, 2, 26, "Input"],
Cell[2950, 94, 2159, 30, 620, "Output"]
}, Closed]],
Cell[5124, 127, 73, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[5222, 131, 152, 3, 42, "Input"],
Cell[5377, 136, 520, 14, 70, "Output"]
}, Closed]],
Cell[5912, 153, 110, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[6047, 160, 166, 3, 42, "Input"],
Cell[6216, 165, 436, 12, 70, "Output"]
}, Closed]],
Cell[6667, 180, 95, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[6787, 187, 109, 2, 26, "Input"],
Cell[6899, 191, 1603, 23, 70, "Output"]
}, Closed]],
Cell[8517, 217, 78, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[8620, 221, 105, 2, 26, "Input"],
Cell[8728, 225, 621, 9, 70, "Output"]
}, Closed]],
Cell[9364, 237, 102, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[9491, 244, 80, 2, 26, "Input"],
Cell[9574, 248, 86, 2, 70, "Output"]
}, Closed]],
Cell[9675, 253, 147, 3, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[9847, 260, 127, 3, 42, "Input"],
Cell[9977, 265, 25428, 683, 70, "Output"]
}, Closed]],
Cell[35420, 951, 628, 17, 48, "Text"],
Cell[36051, 970, 91, 2, 26, "Input"],

Cell[CellGroupData[{
Cell[36167, 976, 120, 3, 42, "Input"],
Cell[36290, 981, 69, 1, 70, "Print"],
Cell[36362, 984, 53, 1, 70, "Print"],
Cell[36418, 987, 69, 1, 70, "Print"],
Cell[36490, 990, 55, 1, 70, "Print"]
}, Closed]],
Cell[36560, 994, 166, 4, 32, "Text"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

