(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    141834,       3407]*)
(*NotebookOutlinePosition[    143053,       3445]*)
(*  CellTagsIndexPosition[    142920,       3438]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Population bottlenecks", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"RandomBottleneckedGenealogy", "[", 
              RowBox[{
                StyleBox["leaves",
                  FontSlant->"Italic"], ",", \({T\_0, T\_1}\), ",", 
                "\[Theta]"}], "]"}], \(gives\ a\ random\ genealogy, \ 
            with\ no\ mutations\ occurring\ in\ time\ interval\ {T\_0, 
                T\_1}\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"RandomBottleneckedGenealogy"],

Cell[TextData[{
  "A sharp reduction in population size is equivalent to a period of \
coalescence during which there are no mutations: the intensity of the \
bottleneck is described by the effective time ",
  Cell[BoxData[
      \(TraditionalForm
      \`1\/T\_b = 
        \(1\/\[Tau]\) 
          \(\[Integral]\(N\_0\/\(N(t)\)\) \[DifferentialD]t\)\)]],
  ".  Hence, a bottleneck of intensity ",
  Cell[BoxData[
      \(TraditionalForm\`T\_b\)]],
  "that ocurred ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_0\ back\ into\ the\ past\ \)\)]],
  "can be represented by a period from ",
  Cell[BoxData[
      \(TraditionalForm\`T\_0\ to\ T\_0 + T\_b\)]],
  "with no mutation."
}], "Text"],

Cell[TextData[{
  "This generates a genealogy with infinite-sites mutation at scaled rate \
\[Theta]=10, connecting 20 lineages.  There is a bottleneck of effective \
intensity ",
  Cell[BoxData[
      \(TraditionalForm\`T\_b\)]],
  "=1 at ",
  Cell[BoxData[
      \(TraditionalForm\`T\_0 = 0.1\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gb = 
      RandomBottleneckedGenealogy[Array[l\_#&, {20}], {0.1, 1.1}, 10]\)], 
  "Input",
  CellLabel->"In[684]:="],

Cell[BoxData[
    \(Node[
      20, {3.37467033630722923`, {}}, {
        Node[19, {3.37467033630722923`, {}}, {
            Node[18, {0.823788854443015416`, {1, 5, 6}}, {
                Node[16, {0.331931530687303411`, {1, 5, 6}}, {
                    Node[l\_9, {0, {1, 5, 6}}, {}], 
                    Node[12, {0.114733042355478076`, {1, 5, 6}}, {
                        Node[l\_12, {0, {1, 5, 6, 34}}, {}], 
                        Node[l\_19, {0, {1, 5, 6}}, {}]}]}], 
                Node[15, {0.197022841726302555`, {1, 5, 6}}, {
                    Node[10, {0.0685804766207851024`, {1, 5, 6, 30}}, {
                        Node[l\_14, {0, {1, 5, 6, 30}}, {}], 
                        Node[3, {0.00442512542029360744`, {1, 5, 6, 30}}, {
                            Node[l\_8, {0, {1, 5, 6, 30}}, {}], 
                            Node[l\_18, {0, {1, 5, 6, 30}}, {}]}]}], 
                    Node[13, {0.13041616002991454`, {1, 5, 6}}, {
                        Node[l\_5, {0, {1, 5, 6}}, {}], 
                        Node[5, {0.00603812684900784635`, {1, 5, 6}}, {
                            Node[l\_16, {0, {1, 5, 6}}, {}], 
                            Node[l\_20, {0, {1, 5, 6, 35}}, {}]}]}]}]}], 
            Node[17, {0.489635659700715919`, {7, 8, 9, 11, 12, 15, 16}}, {
                Node[4, {
                    0.00443490309281992267`, {7, 8, 9, 11, 12, 15, 16}}, {
                    Node[l\_6, {0, {7, 8, 9, 11, 12, 15, 16}}, {}], 
                    Node[l\_11, {0, {7, 8, 9, 11, 12, 15, 16}}, {}]}], 
                Node[14, {0.186854139706307478`, {7, 8, 9, 11, 12, 15, 16}}, {
                    Node[l\_3, {0, {7, 8, 9, 11, 12, 15, 16, 31}}, {}], 
                    Node[11, {
                        0.0866838059638299007`, {7, 8, 9, 11, 12, 15, 16}}, {
                        Node[8, {
                            0.0345950118034393794`, {7, 8, 9, 11, 12, 15, 
                              16}}, {
                            Node[l\_10, {0, {7, 8, 9, 11, 12, 15, 16}}, {}], 
                            Node[1, {
                                0.000588361784973122503`, {7, 8, 9, 11, 12, 
                                  15, 16}}, {
                                Node[l\_2, {
                                    0, {7, 8, 9, 11, 12, 15, 16}}, {}], 
                                Node[l\_13, {
                                    0, {7, 8, 9, 11, 12, 15, 16}}, {}]}]}], 
                        Node[9, {
                            0.0411976144961259471`, {7, 8, 9, 11, 12, 15, 
                              16}}, {
                            Node[l\_17, {0, {7, 8, 9, 11, 12, 15, 16}}, {}], 
                            Node[7, {
                                0.0118066881387145006`, {7, 8, 9, 11, 12, 15, 
                                  16}}, {
                                Node[l\_15, {
                                    0, {7, 8, 9, 11, 12, 15, 16}}, {}], 
                                Node[6, {
                                    0.0106684823484940394`, {7, 8, 9, 11, 12, 
                                      15, 16}}, {
                                    Node[l\_7, {
                                        0, {7, 8, 9, 11, 12, 15, 16}}, {}], 
                                    Node[2, {
                                        0.00249732476808583703`, {7, 8, 9, 
                                        11, 12, 15, 16}}, {
                                        Node[
                                        l\_1, {
                                        0, {7, 8, 9, 11, 12, 15, 16}}, {}], 
                                        Node[
                                        l\_4, {
                                        0, {7, 8, 9, 11, 12, 15, 
                                        16}}, {}]}]}]}]}]}]}]}]}]}]\)], 
  "Output",
  CellLabel->"Out[684]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[PlotGenealogy[gb]]; \)\)], "Input",
  CellLabel->"In[685]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.047619 0.047619 0.0561849 0.0561849 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.69048 .11237 m
.66667 .05618 L
s
.69048 .11237 m
.71429 .05618 L
s
.92857 .11237 m
.90476 .05618 L
s
.92857 .11237 m
.95238 .05618 L
s
.2619 .11237 m
.2381 .05618 L
s
.2619 .11237 m
.28571 .05618 L
s
.5 .11237 m
.47619 .05618 L
s
.5 .11237 m
.52381 .05618 L
s
.40476 .11237 m
.38095 .05618 L
s
.40476 .11237 m
.42857 .05618 L
s
.90476 .16855 m
.85714 .05618 L
s
.90476 .16855 m
.92857 .11237 L
s
.88095 .22474 m
.80952 .05618 L
s
.88095 .22474 m
.90476 .16855 L
s
.66667 .16855 m
.61905 .05618 L
s
.66667 .16855 m
.69048 .11237 L
s
.85714 .28092 m
.7619 .05618 L
s
.85714 .28092 m
.88095 .22474 L
s
.2381 .16855 m
.19048 .05618 L
s
.2381 .16855 m
.2619 .11237 L
s
.78571 .33711 m
.66667 .16855 L
s
.78571 .33711 m
.85714 .28092 L
s
.11905 .11237 m
.09524 .05618 L
s
.11905 .11237 m
.14286 .05618 L
s
.38095 .16855 m
.33333 .05618 L
s
.38095 .16855 m
.40476 .11237 L
s
.7619 .39329 m
.57143 .05618 L
s
.7619 .39329 m
.78571 .33711 L
s
.30952 .22474 m
.2381 .16855 L
s
.30952 .22474 m
.38095 .16855 L
s
.09524 .16855 m
.04762 .05618 L
s
.09524 .16855 m
.11905 .11237 L
s
.71429 .44948 m
.5 .11237 L
s
.71429 .44948 m
.7619 .39329 L
s
.2381 .28092 m
.09524 .16855 L
s
.2381 .28092 m
.30952 .22474 L
s
.5 .50566 m
.2381 .28092 L
s
.5 .50566 m
.71429 .44948 L
s
.5 .56185 m
.5 .50566 L
s
[(1)] .68095 .12361 0 0 Mshowa
[(2)] .91905 .12361 0 0 Mshowa
[(3)] .25238 .12361 0 0 Mshowa
[(4)] .49048 .12361 0 0 Mshowa
[(5)] .39524 .12361 0 0 Mshowa
[(6)] .89524 .17979 0 0 Mshowa
[(7)] .87143 .23598 0 0 Mshowa
[(8)] .65714 .17979 0 0 Mshowa
[(9)] .84762 .29216 0 0 Mshowa
[(10)] .22857 .17979 0 0 Mshowa
[(11)] .77619 .34835 0 0 Mshowa
[(12)] .10952 .12361 0 0 Mshowa
[(13)] .37143 .17979 0 0 Mshowa
[(14)] .75238 .40453 0 0 Mshowa
[(15)] .3 .23598 0 0 Mshowa
[(16)] .08571 .17979 0 0 Mshowa
[(17)] .70476 .46072 0 0 Mshowa
[(18)] .22857 .29216 0 0 Mshowa
[(19)] .49048 .5169 0 0 Mshowa
[(20)] .49048 .57309 0 0 Mshowa
gsave
.04762 .04495 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(9) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.09524 .04495 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(12) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.14286 .04495 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(19) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.19048 .04495 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(14) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.2381 .04495 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.28571 .04495 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(18) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.33333 .04495 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.38095 .04495 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(16) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.42857 .04495 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.47619 .04495 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.52381 .04495 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(11) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.57143 .04495 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.61905 .04495 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.66667 .04495 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.71429 .04495 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(13) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.7619 .04495 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(17) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.80952 .04495 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(15) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.85714 .04495 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(7) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.90476 .04495 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.95238 .04495 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[685]:=",
  ImageSize->{502, 310.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007f0001=Q000`40O003h00Oogoomgoo003oOoog
Ool00?moooMoo`00ogoomgoo003oOoogOol00?moooMoo`00ogoomgoo003oOoogOol00?moooMoo`00
ogoomgoo003oOoogOol00?moooMoo`00ogoomgoo003oOoogOol00?moooMoo`00ogoomgoo003oOoog
Ool00?moooMoo`00ogoomgoo000IOol2000DOol3000017oo000000004Goo0`0000=oo`0000004Goo
0`000Woo00<007ooOol04Woo0`004goo0`0000Aoo`00000001=oo`<001=oo`<00004Ool00000000A
Ool3000017oo000000004Woo0`004goo0`0000Aoo`00000001=oo`<001=oo`<00004Ool00000000C
Ool3000BOol3000017oo000000004Goo0`000Woo00<007ooOol047oo0`0000Aoo`00000001Aoo`03
001oogoo01Aoo`<001Ioo`03001oogoo01Aoo`006Goo0`0057oo00D007ooOomoo`0001=oo`03001o
ogoo00<0015oo`03001oogoo008001Aoo`03001oo`0001Aoo`06001oogoo001oo`005Goo00<007oo
Ool04Woo00H007ooOol007oo000BOol01P00Oomoo`00Ool0019oo`03001oo`0001Aoo`05001oogoo
Ool0000FOol00`00Oomoo`0BOol01P00Oomoo`00Ool001Aoo`03001oogoo019oo`03001oogoo009o
o`03001oogoo011oo`05001oogooOol0000COol00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomo
o`0EOol00`00Oomoo`0DOol2000FOol001=oo`D00004Ool007oo000=Ool50002Ool00`00Oomoo`02
Ool00`00Oomoo`09Ool50002Ool01P00Oomoo`00Ool000Yoo`D0009oo`03001oogoo008000ioo`D0
009oo`03001oogoo00aoo`D0009oo`05001oogooOol0000>Ool5000017oo000000003Goo1@000Woo
00<007ooOol00`002goo1@000goo00D007oo001oo`0000aoo`D00004Ool00000000=Ool50002Ool0
1@00Oomoogoo00003Woo1@000Woo00<007ooOol037oo1@000Woo00H007ooOol007oo000=Ool50003
Ool00`00Oomoo`0:Ool50002Ool01@00Oomoogoo000037oo1@000Woo00<007ooOol00Woo00<007oo
Ool02Goo1@000Woo00<007ooOol00`003Goo1@000goo00<007ooOol03Goo1@000Woo00<007ooOol0
3Woo1@0000=oo`0000005Woo000EOol01000Oomoogoo0`003goo00@007ooOomoo`80009oo`<000eo
o`04001oogooOol20002Ool3000<Ool01000Oomoogoo0P000goo00<007ooOol03Woo00@007ooOomo
o`<000moo`04001oogooOol20002Ool3000?Ool01000Oomoogoo0`003goo00@007ooOomoo`8000=o
o`8000eoo`04001oogooOol3000017oo000000003Woo00<007ooOol00Woo0P003goo00@007ooOomo
o`80009oo`80011oo`04001oogooOol3000?Ool01000Oomoogoo0P000Woo0`003goo00@007ooOomo
o`<000ioo`04001oogooOol20002Ool3000=Ool01000Oomoogoo0P000Woo0`003Goo00@007ooOomo
o`80009oo`<000moo`04001oogooOol3000AOol01000Oomoogoo0P004Woo00<007ooOol00Woo00<0
07ooOol057oo000EOol00`00Oomoo`0COol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0G
Ool00`00Oomoo`0COol00`00Oomoo`0GOol00`00Oomoo`0COol00`00Oomoo`0EOol00`00Oomoo`0F
Ool00`00Oomoo`0COol00`00Oomoo`0GOol00`00Oomoo`0COol00`00Oomoo`0GOol00`00Oomoo`0B
Ool00`00Oomoo`0EOol00`00Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0EOol00`00Oomoo`0E
Ool00`00Oomoo`0IOol001Eoo`03001oogoo01=oo`03001oogoo01Eoo`03001oogoo01Aoo`03001o
ogoo01Moo`03001oogoo01=oo`03001oogoo01Moo`03001oogoo01=oo`03001oogoo01Eoo`03001o
ogoo01Ioo`03001oogoo01=oo`03001oogoo01Moo`03001oogoo01=oo`03001oogoo01Moo`03001o
ogoo019oo`03001oogoo01Eoo`03001oogoo01Eoo`03001oogoo01Moo`03001oogoo01Eoo`03001o
ogoo01Eoo`03001oogoo01Uoo`005Goo00<007ooOol04goo00<007ooOol05Goo00<007ooOol057oo
00<007ooOol05goo00<007ooOol04goo00<007ooOol05goo00<007ooOol04goo00<007ooOol05Goo
00<007ooOol05Woo00<007ooOol04goo00<007ooOol05goo00<007ooOol04goo00<007ooOol05goo
00<007ooOol04Woo00<007ooOol05Goo00<007ooOol05Goo00<007ooOol05goo00<007ooOol05Goo
00<007ooOol05Goo00<007ooOol06Goo000EOol00`00Oomoo`0COol00`00Oomoo`0EOol00`00Oomo
o`0DOol00`00Oomoo`0GOol00`00Oomoo`0COol00`00Oomoo`0GOol00`00Oomoo`0COol00`00Oomo
o`0EOol00`00Oomoo`0FOol00`00Oomoo`0COol00`00Oomoo`0GOol00`00Oomoo`0COol00`00Oomo
o`0GOol00`00Oomoo`0BOol00`00Oomoo`0EOol00`00Oomoo`0EOol00`00Oomoo`0GOol00`00Oomo
o`0EOol00`00Oomoo`0EOol00`00Oomoo`0IOol001=oo`<001=oo`<001Eoo`<001Aoo`<001Moo`<0
01=oo`<001Moo`<001=oo`<001Eoo`<001Ioo`<001=oo`<001Moo`<001=oo`<001Moo`<0019oo`<0
01Eoo`<001Eoo`<001Moo`<001Eoo`<001Eoo`<001]oo`0067oo00<007ooOol05Goo00<007ooOol0
57oo00<007ooOol05Goo00<007ooOol05Goo00<007ooOol05Goo00<007ooOol05Goo00<007ooOol0
57oo00<007ooOol05Goo00<007ooOol05Goo00<007ooOol05Goo00<007ooOol05Goo00<007ooOol0
5Goo00<007ooOol057oo00<007ooOol05Goo00<007ooOol05Goo00<007ooOol05Goo00<007ooOol0
5Goo00<007ooOol057oo00<007ooOol05Goo00<007ooOol05goo000HOol00`00Oomoo`0EOol00`00
Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0EOol00`00Oomoo`0EOol00`00Oomoo`0EOol00`00
Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0EOol00`00Oomoo`0EOol00`00Oomoo`0EOol00`00
Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0EOol00`00Oomoo`0EOol00`00
Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0GOol001Uoo`03001oogoo01Eo
o`03001oogoo019oo`03001oogoo01Moo`03001oogoo01Eoo`03001oogoo01=oo`03001oogoo01Mo
o`03001oogoo01Aoo`03001oogoo01=oo`03001oogoo01Moo`03001oogoo01=oo`03001oogoo01Mo
o`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo01=oo`03001oogoo01Moo`03001oogoo01Eo
o`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo01=oo`03001oogoo01Qoo`006Goo00<007oo
Ool05Goo00<007ooOol04Woo00<007ooOol05goo00<007ooOol05Goo00<007ooOol04goo00<007oo
Ool05goo00<007ooOol057oo00<007ooOol04goo00<007ooOol05goo00<007ooOol04goo00<007oo
Ool05goo00<007ooOol05Goo00<007ooOol057oo00<007ooOol04goo00<007ooOol05goo00<007oo
Ool05Goo00<007ooOol05Goo00<007ooOol057oo00<007ooOol04goo00<007ooOol067oo000IOol0
0`00Oomoo`0EOol00`00Oomoo`0BOol00`00Oomoo`0GOol00`00Oomoo`0EOol00`00Oomoo`0COol0
0`00Oomoo`0GOol00`00Oomoo`0DOol00`00Oomoo`0COol00`00Oomoo`0GOol00`00Oomoo`0COol0
0`00Oomoo`0HOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0COol00`00Oomoo`0GOol0
0`00Oomoo`0EOol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0COol00`00Oomoo`0HOol0
01Yoo`03001oogoo01Eoo`03001oogoo011oo`03001oogoo01Uoo`03001oogoo01Eoo`03001oogoo
015oo`03001oogoo01Uoo`03001oogoo01Aoo`03001oogoo015oo`03001oogoo01Uoo`03001oogoo
015oo`03001oogoo01Yoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo015oo`03001oogoo
01Uoo`03001oogoo01Eoo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo015oo`03001oogoo
01Uoo`006Woo00<007ooOol05Goo00<007ooOol047oo00<007ooOol06Goo00<007ooOol05Goo00<0
07ooOol04Goo00<007ooOol06Goo00<007ooOol057oo00<007ooOol04Goo00<007ooOol06Goo00<0
07ooOol04Goo00<007ooOol06Woo00<007ooOol057oo00<007ooOol057oo00<007ooOol04Goo00<0
07ooOol06Goo00<007ooOol05Goo00<007ooOol05Goo00<007ooOol057oo00<007ooOol04Goo00<0
07ooOol06Goo000KOol00`00Oomoo`0DOol00`00Oomoo`0?Ool00`00Oomoo`0KOol00`00Oomoo`0E
Ool00`00Oomoo`0?Ool00`00Oomoo`0KOol00`00Oomoo`0DOol00`00Oomoo`0?Ool00`00Oomoo`0K
Ool00`00Oomoo`0?Ool00`00Oomoo`0LOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0?
Ool00`00Oomoo`0KOol00`00Oomoo`0EOol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0?
Ool00`00Oomoo`0JOol001]oo`03001oogoo01Eoo`03001oogoo00ioo`03001oogoo01]oo`03001o
ogoo01Eoo`03001oogoo00moo`03001oogoo01]oo`03001oogoo01Aoo`03001oogoo00moo`03001o
ogoo01]oo`03001oogoo00moo`03001oogoo01aoo`03001oogoo01Aoo`03001oogoo01Aoo`03001o
ogoo00moo`03001oogoo01]oo`03001oogoo01Eoo`03001oogoo01Eoo`03001oogoo01Aoo`03001o
ogoo00moo`03001oogoo01Yoo`0077oo00<007ooOol057oo00<007ooOol03Goo00<007ooOol07Goo
00<007ooOol05Goo00<007ooOol03Goo00<007ooOol077oo00<007ooOol05Goo00<007ooOol03Goo
00<007ooOol07Goo00<007ooOol03Goo00<007ooOol07Woo00<007ooOol04goo00<007ooOol05Goo
00<007ooOol03Goo00<007ooOol07Goo00<007ooOol05Goo00<007ooOol057oo00<007ooOol05Goo
00<007ooOol03Goo00<007ooOol06goo000LOol00`00Oomoo`0EOol00`00Oomoo`0<Ool00`00Oomo
o`0MOol00`00Oomoo`0EOol00`00Oomoo`0=Ool00`00Oomoo`0MOol00`00Oomoo`0DOol00`00Oomo
o`0=Ool00`00Oomoo`0MOol00`00Oomoo`0=Ool00`00Oomoo`0NOol00`00Oomoo`0DOol00`00Oomo
o`0DOol00`00Oomoo`0=Ool00`00Oomoo`0MOol00`00Oomoo`0EOol00`00Oomoo`0EOol00`00Oomo
o`0DOol00`00Oomoo`0=Ool00`00Oomoo`0KOol001aoo`03001oogoo01Eoo`03001oogoo00aoo`03
001oogoo01eoo`03001oogoo01Eoo`03001oogoo00eoo`03001oogoo01eoo`03001oogoo01Aoo`03
001oogoo00eoo`03001oogoo01eoo`03001oogoo00eoo`03001oogoo01moo`03001oogoo01=oo`03
001oogoo01Aoo`03001oogoo00eoo`03001oogoo01eoo`03001oogoo01Eoo`03001oogoo01Eoo`03
001oogoo01Aoo`03001oogoo00eoo`03001oogoo01]oo`007Goo00<007ooOol057oo00<007ooOol0
2goo00<007ooOol07goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol07goo00<007ooOol0
57oo00<007ooOol02goo00<007ooOol07goo00<007ooOol02goo00<007ooOol087oo00<007ooOol0
57oo00<007ooOol057oo00<007ooOol02goo00<007ooOol07goo00<007ooOol05Goo00<007ooOol0
5Goo00<007ooOol057oo00<007ooOol02goo00<007ooOol077oo000MOol00`00Oomoo`0EOol00`00
Oomoo`0:Ool00`00Oomoo`0OOol00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`0OOol00`00
Oomoo`0DOol00`00Oomoo`0;Ool00`00Oomoo`0OOol00`00Oomoo`0;Ool00`00Oomoo`0QOol00`00
Oomoo`0COol00`00Oomoo`0DOol00`00Oomoo`0;Ool00`00Oomoo`0OOol00`00Oomoo`0EOol00`00
Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0;Ool00`00Oomoo`0LOol001ioo`03001oogoo01Ao
o`03001oogoo00Uoo`03001oogoo025oo`03001oogoo01Eoo`03001oogoo00Uoo`03001oogoo021o
o`03001oogoo01Eoo`03001oogoo00Uoo`03001oogoo025oo`03001oogoo00Uoo`03001oogoo02=o
o`03001oogoo019oo`03001oogoo01Eoo`03001oogoo00Uoo`03001oogoo025oo`03001oogoo01Eo
o`03001oogoo01Aoo`03001oogoo01Eoo`03001oogoo00Uoo`03001oogoo01eoo`007Woo00<007oo
Ool05Goo00<007ooOol027oo00<007ooOol08Goo00<007ooOol05Goo00<007ooOol02Goo00<007oo
Ool08Goo00<007ooOol057oo00<007ooOol02Goo00<007ooOol08Goo00<007ooOol02Goo00<007oo
Ool08goo00<007ooOol04goo00<007ooOol057oo00<007ooOol02Goo00<007ooOol08Goo00<007oo
Ool05Goo00<007ooOol05Goo00<007ooOol057oo00<007ooOol02Goo00<007ooOol07Goo000OOol0
0`00Oomoo`0DOol00`00Oomoo`08Ool00`00Oomoo`0ROol00`00Oomoo`0DOol00`00Oomoo`09Ool0
0`00Oomoo`0QOol00`00Oomoo`0DOol00`00Oomoo`09Ool00`00Oomoo`0QOol00`00Oomoo`09Ool0
0`00Oomoo`0TOol00`00Oomoo`0BOol00`00Oomoo`0DOol00`00Oomoo`09Ool00`00Oomoo`0ROol0
0`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`09Ool00`00Oomoo`0MOol0
01moo`03001oogoo01Aoo`03001oogoo00Moo`03001oogoo02=oo`03001oogoo01Eoo`03001oogoo
00Moo`03001oogoo02=oo`03001oogoo01Aoo`03001oogoo00Moo`03001oogoo02=oo`03001oogoo
00Moo`03001oogoo02Eoo`03001oogoo01=oo`03001oogoo01Aoo`03001oogoo00Moo`03001oogoo
02=oo`03001oogoo01Eoo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo00Moo`03001oogoo
01ioo`007goo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol08goo00<007ooOol05Goo00<0
07ooOol01goo00<007ooOol08goo00<007ooOol057oo00<007ooOol01goo00<007ooOol08goo00<0
07ooOol01goo00<007ooOol09Woo00<007ooOol04Woo00<007ooOol057oo00<007ooOol01goo00<0
07ooOol08goo00<007ooOol05Goo00<007ooOol05Goo00<007ooOol057oo00<007ooOol01goo00<0
07ooOol07Woo000POol00`00Oomoo`0DOol00`00Oomoo`05Ool00`00Oomoo`0UOol00`00Oomoo`0E
Ool00`00Oomoo`05Ool00`00Oomoo`0TOol00`00Oomoo`0EOol00`00Oomoo`05Ool00`00Oomoo`0U
Ool00`00Oomoo`05Ool00`00Oomoo`0WOol00`00Oomoo`0BOol00`00Oomoo`0EOol00`00Oomoo`05
Ool00`00Oomoo`0UOol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`05
Ool00`00Oomoo`0OOol0021oo`03001oogoo01Aoo`03001oogoo00Eoo`03001oogoo02Eoo`03001o
ogoo01Eoo`03001oogoo00Eoo`03001oogoo02Eoo`03001oogoo01Aoo`03001oogoo00Eoo`03001o
ogoo02Eoo`03001oogoo00Eoo`03001oogoo02Qoo`03001oogoo019oo`03001oogoo01Aoo`03001o
ogoo00Eoo`03001oogoo02Eoo`03001oogoo01Eoo`03001oogoo01Eoo`03001oogoo01Aoo`03001o
ogoo00Eoo`03001oogoo01moo`008Goo00<007ooOol057oo00<007ooOol017oo00<007ooOol09Woo
00<007ooOol057oo00<007ooOol01Goo00<007ooOol09Goo00<007ooOol057oo00<007ooOol01Goo
00<007ooOol09Goo00<007ooOol01Goo00<007ooOol0:Goo00<007ooOol04Goo00<007ooOol057oo
00<007ooOol01Goo00<007ooOol09Woo00<007ooOol05Goo00<007ooOol057oo00<007ooOol057oo
00<007ooOol01Goo00<007ooOol07goo000QOol00`00Oomoo`0DOol00`00Oomoo`03Ool00`00Oomo
o`0WOol00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`0WOol00`00Oomoo`0DOol00`00Oomo
o`03Ool00`00Oomoo`0WOol00`00Oomoo`03Ool00`00Oomoo`0ZOol00`00Oomoo`0BOol00`00Oomo
o`0DOol00`00Oomoo`03Ool00`00Oomoo`0WOol00`00Oomoo`0EOol00`00Oomoo`0EOol00`00Oomo
o`0DOol00`00Oomoo`03Ool00`00Oomoo`0POol0025oo`03001oogoo01Eoo`03001oogoo009oo`03
001oogoo02Moo`03001oogoo01Eoo`03001oogoo00=oo`03001oogoo02Moo`03001oogoo01Aoo`03
001oogoo00=oo`03001oogoo02Moo`03001oogoo00=oo`03001oogoo02]oo`03001oogoo015oo`03
001oogoo01Aoo`03001oogoo00=oo`03001oogoo02Qoo`03001oogoo01Eoo`03001oogoo01Aoo`03
001oogoo01Aoo`03001oogoo00=oo`03001oogoo021oo`008Woo00<007ooOol057oo00D007ooOomo
o`0002]oo`03001oogoo01Eoo`05001oogooOol0000ZOol00`00Oomoo`0EOol01@00Oomoogoo0000
:goo00D007ooOomoo`0002ioo`03001oogoo015oo`03001oogoo01Eoo`05001oogooOol0000[Ool0
0`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0EOol01@00Oomoogoo00008goo000ROol00`00
Oomoo`0DOol01@00Oomoogoo0000:goo00<007ooOol05Goo00D007ooOomoo`0002]oo`03001oogoo
01Aoo`05001oogooOol0000[Ool01@00Oomoogoo0000;goo00<007ooOol04Goo00<007ooOol057oo
00D007ooOomoo`0002]oo`03001oogoo01Eoo`03001oogoo01Eoo`03001oogoo01Aoo`05001oogoo
Ool0000SOol002=oo`03001oogoo01Aoo`03001oo`0002eoo`03001oogoo01Eoo`03001oo`0002ao
o`03001oogoo01Eoo`03001oo`0002eoo`03001oo`00031oo`03001oogoo015oo`03001oogoo01Eo
o`03001oo`0002eoo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo01Eoo`03001oo`0002Ao
o`008goo00<007ooOol057oo00<007oo0000;Goo00<007ooOol05Goo00<007oo0000;Goo00<007oo
Ool057oo00<007oo0000;Goo00<007oo0000<Goo00<007ooOol04Goo00<007ooOol057oo00<007oo
0000;Goo00<007ooOol05Goo00<007ooOol05Goo00<007ooOol057oo00<007oo000097oo000TOol0
0`00Oomoo`0COol00`00Ool0000^Ool00`00Oomoo`0DOol00`00Ool0000]Ool00`00Oomoo`0DOol0
0`00Ool0000]Ool00`00Ool0000aOol00`00Oomoo`0AOol00`00Oomoo`0DOol00`00Ool0000^Ool0
0`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Ool0000TOol002Aoo`03001oogoo
01Aoo`03001oogoo02eoo`03001oogoo01Eoo`03001oogoo02eoo`03001oogoo01Aoo`03001oogoo
02eoo`03001oogoo035oo`03001oogoo015oo`03001oogoo01Aoo`03001oogoo02eoo`03001oogoo
01Eoo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo02=oo`0097oo00<007ooOol057oo00<0
07ooOol0;Goo00<007ooOol05Goo00<007ooOol0;Goo00<007ooOol057oo00<007ooOol0;Goo00<0
07ooOol0<Woo00<007ooOol047oo00<007ooOol057oo00<007ooOol0;Woo00<007ooOol057oo00<0
07ooOol05Goo00<007ooOol057oo00<007ooOol08goo000UOol00`00Oomoo`0BOol00`00Oomoo`0_
Ool00`00Oomoo`0COol00`00Oomoo`0^Ool00`00Oomoo`0COol00`00Oomoo`0_Ool00`00Oomoo`0a
Ool00`00Oomoo`0@Ool00`00Oomoo`0COol00`00Oomoo`0_Ool00`00Oomoo`0EOol00`00Oomoo`0D
Ool00`00Oomoo`0COol00`00Oomoo`0TOol002Eoo`03001oogoo00Yoo`<000=oo`@0031oo`03001o
ogoo00eoo`<000=oo`03001oogoo02moo`03001oogoo00eoo`<0009oo`03001oogoo02Qoo`<000Eo
o`03001oogoo035oo`03001oogoo011oo`03001oogoo00eoo`<0009oo`03001oogoo02moo`03001o
ogoo01Eoo`03001oogoo01Eoo`03001oogoo00eoo`@00003Ool007oo02Eoo`009Woo00<007ooOol0
2Woo00<007ooOol00goo0P00<Woo00<007ooOol03goo00<007oo0000<Woo00<007ooOol047oo0P00
;7oo00<007ooOol017oo00<007ooOol0<Goo00<007ooOol047oo00<007ooOol03Woo00@007ooOol0
03=oo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo00ioo`04001oogoo000WOol002Ioo`03
001oogoo00Yoo`03001oogoo00=oo`80039oo`03001oogoo00moo`03001oo`0003=oo`03001oogoo
00moo`8002Yoo`@000Ioo`03001oogoo035oo`03001oogoo011oo`03001oogoo00eoo`04001oogoo
000cOol00`00Oomoo`0EOol00`00Oomoo`0EOol00`00Oomoo`0>Ool00`00Ool0000WOol002Moo`03
001oogoo00Uoo`03001oogoo00=oo`03001oo`00039oo`03001oogoo00aoo`80009oo`03001oogoo
035oo`03001oogoo00aoo`<00003Ool007oo02Uoo`03001oo`0000Qoo`03001oogoo031oo`03001o
ogoo011oo`03001oogoo00eoo`04001oogoo000dOol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00
Oomoo`0?Ool2000WOol002Moo`03001oogoo00Uoo`03001oogoo009oo`04001oogoo000bOol00`00
Oomoo`0>Ool2000dOol00`00Oomoo`0<Ool01000Oomoo`00:goo00<007oo000027oo00<007ooOol0
<Goo00<007ooOol03goo00<007ooOol03Goo00<007oo0000=Goo00<007ooOol05Goo00<007ooOol0
57oo00<007ooOol037oo00@007ooOol002Qoo`009goo00<007ooOol027oo0P0017oo0`00<goo00<0
07ooOol02goo0`0000=oo`00Ool0=7oo00<007ooOol02goo1000;7oo0P002Goo00<007ooOol0<Goo
00<007ooOol03goo00<007ooOol02goo0P0000=oo`00Ool0=Goo00<007ooOol057oo00<007ooOol0
5Goo00<007ooOol037oo0`00:7oo000XOol00`00Oomoo`0=Ool00`00Oomoo`0dOol00`00Oomoo`0=
Ool00`00Oomoo`0dOol00`00Oomoo`0=Ool00`00Oomoo`0fOol00`00Oomoo`0aOol00`00Oomoo`0?
Ool00`00Oomoo`0=Ool00`00Oomoo`0eOol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0=
Ool00`00Oomoo`0WOol002Qoo`03001oogoo00aoo`03001oogoo03Eoo`03001oogoo00eoo`03001o
ogoo03Eoo`03001oogoo00aoo`03001oogoo03Moo`03001oogoo035oo`03001oogoo00moo`03001o
ogoo00aoo`03001oogoo03Eoo`03001oogoo01Eoo`03001oogoo01Eoo`03001oogoo00aoo`03001o
ogoo02Moo`00:Goo00<007ooOol02goo00<007ooOol0=Woo00<007ooOol02goo00<007ooOol0=Woo
00<007ooOol02goo00<007ooOol0>Goo00<007ooOol0<7oo00<007ooOol03goo00<007ooOol02goo
00<007ooOol0=goo00<007ooOol05Goo00<007ooOol057oo00<007ooOol02goo00<007ooOol0:7oo
000YOol00`00Oomoo`0:Ool00`00Oomoo`0gOol00`00Oomoo`0;Ool00`00Oomoo`0fOol00`00Oomo
o`0;Ool00`00Oomoo`0iOol00`00Oomoo`0aOol00`00Oomoo`0>Ool00`00Oomoo`0;Ool00`00Oomo
o`0gOol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0;Ool00`00Oomoo`0XOol002Uoo`03
001oogoo00Yoo`03001oogoo03Moo`03001oogoo00]oo`03001oogoo03Moo`03001oogoo00Yoo`03
001oogoo03Yoo`03001oogoo031oo`03001oogoo00moo`03001oogoo00Yoo`03001oogoo03Qoo`03
001oogoo01Eoo`03001oogoo01Aoo`03001oogoo00Yoo`03001oogoo02Qoo`00:Woo00<007ooOol0
2Goo00<007ooOol0>7oo00<007ooOol02Goo00<007ooOol0>7oo00<007ooOol02Goo00<007ooOol0
?7oo00<007ooOol0<7oo00<007ooOol03Woo00<007ooOol02Goo00<007ooOol0>Goo00<007ooOol0
5Goo00<007ooOol057oo00<007ooOol02Goo00<007ooOol0:Goo000ZOol00`00Oomoo`08Ool00`00
Oomoo`0iOol00`00Oomoo`09Ool00`00Oomoo`0iOol00`00Oomoo`08Ool00`00Oomoo`0lOol00`00
Oomoo`0`Ool00`00Oomoo`0?Ool00`00Oomoo`08Ool00`00Oomoo`0iOol00`00Oomoo`0EOol00`00
Oomoo`0EOol00`00Oomoo`08Ool00`00Oomoo`0YOol002]oo`03001oogoo00Moo`03001oogoo03Yo
o`03001oogoo00Moo`03001oogoo03Yoo`03001oogoo00Moo`03001oogoo03ioo`03001oogoo031o
o`03001oogoo00ioo`03001oogoo00Moo`03001oogoo03]oo`03001oogoo01Eoo`03001oogoo01Ao
o`03001oogoo00Moo`03001oogoo02Yoo`00:goo00<007ooOol01goo00<007ooOol0>Woo00<007oo
Ool01goo00<007ooOol0>Woo00<007ooOol01goo00<007ooOol0?goo00<007ooOol0<7oo00<007oo
Ool03Goo00<007ooOol01goo00<007ooOol0>goo00<007ooOol05Goo00<007ooOol057oo00<007oo
Ool01goo00<007ooOol0:Woo000/Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`00Oomoo`05Ool0
0`00Oomoo`0lOol00`00Oomoo`05Ool00`00Oomoo`10Ool00`00Oomoo`0`Ool00`00Oomoo`0>Ool0
0`00Oomoo`05Ool00`00Oomoo`0mOol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`05Ool0
0`00Oomoo`0[Ool002aoo`03001oogoo00Eoo`03001oogoo03aoo`03001oogoo00Eoo`03001oogoo
03aoo`03001oogoo00Eoo`03001oogoo045oo`03001oogoo031oo`03001oogoo00eoo`03001oogoo
00Eoo`03001oogoo03eoo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo00Eoo`03001oogoo
02]oo`00;7oo00<007ooOol017oo00<007ooOol0?Goo00<007ooOol01Goo00<007ooOol0?Goo00<0
07ooOol017oo00<007ooOol0@Goo00<007ooOol0<7oo00<007ooOol03Woo00<007ooOol017oo00<0
07ooOol0?Woo00<007ooOol05Goo00<007ooOol057oo00<007ooOol017oo00<007ooOol0:goo000]
Ool00`00Oomoo`03Ool00`00Oomoo`0nOol00`00Oomoo`03Ool00`00Oomoo`0nOol00`00Oomoo`03
Ool00`00Oomoo`13Ool00`00Oomoo`0`Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`0o
Ool00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`03Ool00`00Oomoo`0/Ool002eoo`03001o
ogoo00=oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo03ioo`03001oogoo00=oo`03001o
ogoo04Aoo`03001oogoo02moo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo03moo`03001o
ogoo01Eoo`03001oogoo01Aoo`03001oogoo00=oo`03001oogoo02aoo`00;Woo00D007ooOomoo`00
049oo`05001oogooOol00012Ool01@00Oomoogoo0000Agoo00<007ooOol0<7oo00<007ooOol03Goo
00D007ooOomoo`0004=oo`03001oogoo01Eoo`03001oogoo01Aoo`05001oogooOol0000_Ool002io
o`05001oogooOol00012Ool01@00Oomoogoo0000@Woo00D007ooOomoo`0004Qoo`03001oogoo031o
o`03001oogoo00aoo`05001oogooOol00013Ool00`00Oomoo`0EOol00`00Oomoo`0DOol01@00Oomo
ogoo0000;goo000_Ool00`00Ool00014Ool00`00Ool00014Ool00`00Ool0001:Ool00`00Oomoo`0_
Ool00`00Oomoo`0=Ool00`00Ool00015Ool00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Ool0000`
Ool002moo`03001oo`0004Aoo`03001oo`0004Aoo`03001oo`0004Yoo`03001oogoo031oo`03001o
ogoo00aoo`03001oo`0004Eoo`03001oogoo01Eoo`03001oogoo01Aoo`03001oo`00031oo`00;goo
00<007oo0000A7oo00<007oo0000A7oo00<007oo0000Bgoo00<007ooOol0;goo00<007ooOol037oo
00<007oo0000AWoo00<007ooOol05Goo00<007ooOol04goo00<007oo0000<7oo000`Ool20015Ool2
0014Ool2001=Ool00`00Oomoo`0_Ool00`00Oomoo`0<Ool00`00Oomoo`15Ool00`00Oomoo`0EOol0
0`00Oomoo`0DOol00`00Oomoo`0_Ool0039oo`03001oogoo04Aoo`03001oogoo041oo`03001oogoo
04eoo`03001oogoo02moo`03001oogoo00aoo`03001oogoo04Eoo`03001oogoo01Eoo`03001oogoo
01Aoo`03001oogoo02moo`00<goo00<007ooOol0A7oo00<007ooOol0?Woo00<007ooOol0Cgoo00<0
07ooOol0;goo00<007ooOol037oo00<007ooOol0AGoo00<007ooOol05Goo00<007ooOol04Woo00<0
07ooOol0<7oo000VOol30004Ool20005Ool00`00Oomoo`0fOol30004Ool20005Ool2000hOol30002
Ool4001?Ool00`00Oomoo`0_Ool00`00Oomoo`06Ool20005Ool00`00Oomoo`14Ool00`00Oomoo`0E
Ool00`00Oomoo`0>Ool20002Ool00`00Oomoo`0`Ool002Moo`03001oogoo009oo`04001oogoo0005
Ool2000gOol00`00Oomoo`02Ool01000Oomoo`001Woo00<007ooOol0=Woo00@007oo000000Aoo`03
001oogoo04eoo`03001oogoo02moo`03001oogoo00Aoo`04001oogoo0005Ool00`00Oomoo`14Ool0
0`00Oomoo`0EOol00`00Oomoo`0<Ool01P00Oomoo`00Ool0039oo`009goo00<007ooOol00Woo00@0
07ooOol000Moo`03001oogoo03Aoo`03001oogoo009oo`04001oogoo0007Ool00`00Oomoo`0eOol2
0006Ool00`00Oomoo`1>Ool00`00Oomoo`0_Ool00`00Oomoo`03Ool01000Oomoo`001Goo00<007oo
Ool0A7oo00<007ooOol05Goo00<007ooOol037oo00<007ooOol00P00<goo000WOol00`00Oomoo`02
Ool30009Ool00`00Oomoo`0cOol00`00Oomoo`02Ool01000Oomoo`0027oo00<007ooOol0=7oo00<0
07ooOol00goo0P00DGoo00<007ooOol0;goo00<007ooOol017oo0P001goo00<007ooOol0A7oo00<0
07ooOol057oo00<007ooOol037oo0`0000=oo`00Ool0<Woo000WOol00`00Oomoo`02Ool00`00Oomo
o`0:Ool2000cOol00`00Oomoo`02Ool01000Oomoo`002Goo0P00<goo0P001goo00<007ooOol0Cgoo
00<007ooOol0;goo00<007ooOol00Woo00@007ooOol000Moo`03001oogoo04=oo`03001oogoo01Eo
o`03001oogoo00]oo`04001oogoo000dOol002Ioo`8000Eoo`<000]oo`03001oogoo02moo`8000Eo
o`8000aoo`03001oogoo02ioo`@000Aoo`<005=oo`03001oogoo02ioo`03001oogoo00=oo`8000Qo
o`03001oogoo04=oo`03001oogoo01Eoo`03001oogoo00aoo`<003Aoo`00?7oo00<007ooOol0A7oo
00<007ooOol0;7oo00<007ooOol0G7oo00<007ooOol0;goo00<007ooOol03Goo00<007ooOol0@goo
00<007ooOol05Goo00<007ooOol03Goo00<007ooOol0<Woo000mOol00`00Oomoo`14Ool2000[Ool0
0`00Oomoo`1NOol00`00Oomoo`0^Ool00`00Oomoo`0>Ool00`00Oomoo`12Ool00`00Oomoo`0EOol0
0`00Oomoo`0<Ool00`00Oomoo`0cOol003ioo`8004Ioo`03001oogoo02Moo`03001oogoo061oo`03
001oogoo02ioo`03001oogoo00ioo`03001oogoo049oo`03001oogoo01Eoo`03001oogoo00]oo`03
001oogoo03=oo`00@7oo00<007ooOol0A7oo00<007ooOol097oo0P00Hgoo00<007ooOol0;goo00<0
07ooOol03Goo00<007ooOol0@Woo00<007ooOol05Goo00<007ooOol02Woo00<007ooOol0=7oo0011
Ool00`00Oomoo`14Ool00`00Oomoo`0ROol00`00Oomoo`1TOol00`00Oomoo`0^Ool00`00Oomoo`0>
Ool00`00Oomoo`12Ool00`00Oomoo`0DOol00`00Oomoo`0:Ool00`00Oomoo`0dOol0049oo`03001o
ogoo04Aoo`80025oo`03001oogoo06Eoo`03001oogoo02moo`03001oogoo00ioo`03001oogoo045o
o`03001oogoo01Eoo`03001oogoo00Uoo`03001oogoo03Aoo`00@goo0P00AWoo00<007ooOol07Goo
00<007ooOol0Igoo00<007ooOol0;Woo00<007ooOol03Woo00<007ooOol0@Goo00<007ooOol05Goo
00<007ooOol027oo00<007ooOol0=Goo0015Ool00`00Oomoo`14Ool00`00Oomoo`0JOol2001[Ool0
0`00Oomoo`0^Ool00`00Oomoo`0>Ool00`00Oomoo`11Ool00`00Oomoo`0EOol00`00Oomoo`07Ool0
0`00Oomoo`0eOol004Ioo`03001oogoo04Aoo`8001Uoo`03001oogoo06]oo`03001oogoo02ioo`03
001oogoo00moo`03001oogoo041oo`03001oogoo01Eoo`03001oogoo00Moo`03001oogoo03Eoo`00
Agoo00<007ooOol0AGoo00<007ooOol05Goo00<007ooOol0KGoo00<007ooOol0;Woo00<007ooOol0
3goo00<007ooOol0@7oo00<007ooOol05Goo00<007ooOol01Goo00<007ooOol0=Woo0018Ool20016
Ool00`00Oomoo`0COol00`00Oomoo`1_Ool00`00Oomoo`0]Ool00`00Oomoo`0?Ool00`00Oomoo`10
Ool00`00Oomoo`0EOol00`00Oomoo`05Ool00`00Oomoo`0fOol004Yoo`03001oogoo04Aoo`03001o
ogoo011oo`80079oo`03001oogoo02ioo`03001oogoo00moo`03001oogoo03moo`03001oogoo01Eo
o`03001oogoo00Aoo`03001oogoo03Moo`00Bgoo00<007ooOol0A7oo0P003goo00<007ooOol0Lgoo
00<007ooOol0;Woo00<007ooOol03goo00<007ooOol0?goo00<007ooOol05Goo00<007ooOol00goo
00<007ooOol0=goo001<Ool20016Ool00`00Oomoo`0;Ool00`00Oomoo`1eOol00`00Oomoo`0]Ool0
0`00Oomoo`0?Ool00`00Oomoo`0oOol00`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`0gOol0
04ioo`03001oogoo04Aoo`03001oogoo00Uoo`03001oogoo07Ioo`03001oogoo02ioo`03001oogoo
00moo`03001oogoo03moo`03001oogoo01Eoo`05001oogooOol0000jOol004moo`03001oogoo04Ao
o`8000Moo`8007Yoo`03001oogoo02eoo`03001oogoo011oo`03001oogoo03ioo`03001oogoo01Eo
o`05001oogooOol0000jOol0051oo`03001oogoo04Eoo`03001oogoo00=oo`03001oogoo07Yoo`03
001oogoo02ioo`03001oogoo011oo`03001oogoo03ioo`03001oogoo01Eoo`03001oo`0003]oo`00
DGoo0P00AWoo00D007ooOomoo`0007ioo`03001oogoo02eoo`03001oogoo011oo`03001oogoo03io
o`03001oogoo01Eoo`03001oo`0003]oo`00Dgoo00<007ooOol0A7oo00<007oo0000P7oo00<007oo
Ool0;Goo00<007ooOol047oo00<007ooOol0?Goo00<007ooOol05Goo00<007oo0000>goo001DOol0
0`00Oomoo`13Ool20021Ool00`00Oomoo`0^Ool00`00Oomoo`0@Ool00`00Oomoo`0mOol00`00Oomo
o`0EOol00`00Oomoo`0jOol005Eoo`03001oogoo045oo`03001oogoo089oo`03001oogoo02eoo`03
001oogoo011oo`03001oogoo03eoo`03001oogoo01Eoo`03001oogoo03Yoo`00EWoo0P00@7oo00<0
07ooOol0Q7oo00<007ooOol0;Goo00<007ooOol047oo00<007ooOol0?Goo00<007ooOol04goo00<0
07ooOol0>goo001HOol00`00Oomoo`0fOol30002Ool40025Ool00`00Oomoo`0]Ool00`00Oomoo`0A
Ool00`00Oomoo`0lOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0kOol005Uoo`03001o
ogoo03Ioo`04001oogoo0004Ool00`00Oomoo`23Ool00`00Oomoo`0]Ool00`00Oomoo`0AOol00`00
Oomoo`0lOol00`00Oomoo`0=Ool01@00Oomoogoo0000?Woo001JOol00`00Oomoo`0eOol00`00Ool0
0005Ool00`00Oomoo`24Ool00`00Oomoo`0/Ool00`00Oomoo`0AOol00`00Oomoo`0lOol00`00Oomo
o`0>Ool01000Oomoo`00?Woo001KOol2000eOol20003Ool30027Ool00`00Oomoo`0]Ool00`00Oomo
o`0AOol00`00Oomoo`0kOol00`00Oomoo`0>Ool01000Oomoo`00?Woo001MOol00`00Oomoo`0aOol2
0004Ool00`00Oomoo`28Ool00`00Oomoo`0/Ool00`00Oomoo`0BOol00`00Oomoo`0kOol00`00Oomo
o`0>Ool2000oOol005ioo`03001oogoo02moo`<000Aoo`@008Moo`03001oogoo02eoo`03001oogoo
015oo`03001oogoo03]oo`03001oogoo00]oo`D003moo`00Ggoo0P00;Woo00<007ooOol0TGoo00<0
07ooOol0;Goo00<007ooOol04Goo00<007ooOol0>goo00<007ooOol03Goo00<007ooOol0?Woo001Q
Ool00`00Oomoo`0YOol2002EOol00`00Oomoo`0/Ool00`00Oomoo`0BOol00`00Oomoo`0jOol00`00
Oomoo`0=Ool00`00Oomoo`0nOol0069oo`03001oogoo02Moo`03001oogoo09Eoo`03001oogoo02eo
o`03001oogoo019oo`03001oogoo03Yoo`03001oogoo00]oo`03001oogoo03moo`00Hgoo00<007oo
Ool09Goo00<007ooOol0Ugoo00<007ooOol0;7oo00<007ooOol04Woo00<007ooOol0>Woo00<007oo
Ool02goo00<007ooOol0?goo001TOol2000TOol00`00Oomoo`2IOol00`00Oomoo`0/Ool00`00Oomo
o`0BOol00`00Oomoo`0iOol00`00Oomoo`0;Ool00`00Oomoo`0oOol006Ioo`03001oogoo01moo`80
09aoo`03001oogoo02aoo`03001oogoo01=oo`03001oogoo03Uoo`03001oogoo00Uoo`03001oogoo
041oo`00Igoo00<007ooOol07Goo00<007ooOol0WGoo00<007ooOol0;7oo00<007ooOol04Woo00<0
07ooOol0>Goo00<007ooOol02Goo00<007ooOol0@7oo001XOol00`00Oomoo`0KOol00`00Oomoo`2O
Ool00`00Oomoo`0[Ool00`00Oomoo`0COol00`00Oomoo`0iOol00`00Oomoo`07Ool00`00Oomoo`11
Ool006Uoo`8001Uoo`800:9oo`03001oogoo02aoo`03001oogoo01=oo`03001oogoo03Qoo`03001o
ogoo00Moo`03001oogoo045oo`00Jgoo00<007ooOol05Goo00<007ooOol0Xgoo00<007ooOol0;7oo
00<007ooOol04goo00<007ooOol0>7oo00<007ooOol01Goo00<007ooOol0@Woo001/Ool00`00Oomo
o`0COol00`00Oomoo`2TOol00`00Oomoo`0/Ool00`00Oomoo`0COol00`00Oomoo`0hOol00`00Oomo
o`05Ool00`00Oomoo`12Ool006eoo`03001oogoo015oo`03001oogoo0:Ioo`03001oogoo02aoo`03
001oogoo01=oo`03001oogoo03Moo`03001oogoo00Eoo`03001oogoo049oo`00KWoo0P003goo0P00
ZWoo00<007ooOol0:goo00<007ooOol057oo00<007ooOol0=goo00<007ooOol00goo00<007ooOol0
@goo001`Ool00`00Oomoo`0;Ool00`00Oomoo`2ZOol00`00Oomoo`0/Ool00`00Oomoo`0COol00`00
Oomoo`0gOol00`00Oomoo`03Ool00`00Oomoo`13Ool0075oo`03001oogoo00Uoo`03001oogoo0:ao
o`03001oogoo02]oo`03001oogoo01Aoo`03001oogoo03Moo`05001oogooOol00016Ool0079oo`80
00Moo`800;1oo`03001oogoo02]oo`03001oogoo01Aoo`03001oogoo03Ioo`05001oogooOol00016
Ool007Aoo`03001oogoo00=oo`03001oogoo0;1oo`03001oogoo02aoo`03001oogoo01Aoo`03001o
ogoo03Ioo`03001oo`0004Moo`00MGoo00D007ooOomoo`000;Aoo`03001oogoo02]oo`03001oogoo
01Aoo`03001oogoo03Ioo`03001oo`0004Moo`00MWoo00<007oo0000]Woo00<007ooOol0:goo00<0
07ooOol057oo00<007ooOol0=Goo00<007oo0000Agoo001gOol2002fOol00`00Oomoo`0[Ool00`00
Oomoo`0EOol00`00Oomoo`0dOol20018Ool007Uoo`03001oogoo0;Aoo`03001oogoo02]oo`03001o
ogoo01Aoo`03001oogoo03=oo`03001oogoo04Qoo`00NWoo00<007ooOol0/goo00<007ooOol0:goo
00<007ooOol05Goo00<007ooOol0<Goo00<007ooOol0BGoo001kOol00`00Oomoo`2cOol00`00Oomo
o`0[Ool00`00Oomoo`0EOol00`00Oomoo`0^Ool2001<Ool006eoo`<000Aoo`8000Ioo`03001oogoo
0;=oo`03001oogoo02Yoo`03001oogoo01Ioo`03001oogoo02]oo`<004eoo`00KWoo00<007ooOol0
0Woo00@007ooOol000Ioo`03001oogoo0;9oo`03001oogoo02]oo`03001oogoo01Eoo`03001oogoo
02]oo`04001oogoo001<Ool006ioo`03001oogoo009oo`04001oogoo0007Ool2002cOol00`00Oomo
o`0[Ool00`00Oomoo`0EOol00`00Oomoo`0YOol00`00Ool00002001<Ool006ioo`03001oogoo00=o
o`8000Yoo`03001oogoo0;5oo`03001oogoo02Yoo`03001oogoo01Ioo`03001oogoo02Ioo`800005
Ool007ooOol0001<Ool006ioo`03001oogoo009oo`04001oogoo000:Ool00`00Oomoo`2`Ool00`00
Oomoo`0[Ool00`00Oomoo`0EOol00`00Oomoo`0UOol01@00Oomoogoo00000Woo00<007ooOol0BWoo
001]Ool20005Ool2000<Ool00`00Oomoo`2`Ool00`00Oomoo`0ZOol00`00Oomoo`0FOol00`00Oomo
o`0SOol00`00Oomoo`03Ool2001=Ool008=oo`03001oogoo0;1oo`03001oogoo02Yoo`03001oogoo
01Ioo`03001oogoo021oo`8005Eoo`00Q7oo00<007ooOol0[goo00<007ooOol0:Woo00<007ooOol0
5goo00<007ooOol07Woo00<007ooOol0EGoo0025Ool2002`Ool00`00Oomoo`0ZOol00`00Oomoo`0F
Ool00`00Oomoo`0MOol00`00Oomoo`1FOol008Moo`03001oogoo0:eoo`03001oogoo02]oo`03001o
ogoo01Ioo`03001oogoo01]oo`03001oogoo05Moo`00R7oo00<007ooOol0[Goo00<007ooOol0:Woo
00<007ooOol05goo00<007ooOol067oo0P00FWoo0029Ool00`00Oomoo`2]Ool00`00Oomoo`0ZOol0
0`00Oomoo`0FOol00`00Oomoo`0GOol00`00Oomoo`1JOol008Yoo`03001oogoo0:aoo`03001oogoo
02Yoo`03001oogoo01Moo`03001oogoo01Eoo`03001oogoo05]oo`00Rgoo00<007ooOol0[7oo00<0
07ooOol0:Woo00<007ooOol05goo00<007ooOol04Woo0P00GWoo002<Ool2002]Ool00`00Oomoo`0Y
Ool00`00Oomoo`0HOol00`00Oomoo`0@Ool00`00Oomoo`1NOol008ioo`03001oogoo0:Yoo`03001o
ogoo02Yoo`03001oogoo01Moo`03001oogoo00moo`03001oogoo05moo`00Sgoo00<007ooOol0ZWoo
00<007ooOol0:Goo00<007ooOol067oo00<007ooOol03Goo00<007ooOol0H7oo002@Ool00`00Oomo
o`2ZOol00`00Oomoo`0YOol00`00Oomoo`0HOol00`00Oomoo`0:Ool2001SOol0095oo`03001oogoo
0:Uoo`03001oogoo02Yoo`03001oogoo01Moo`03001oogoo00Uoo`03001oogoo06=oo`00TWoo00<0
07ooOol0ZGoo00<007ooOol0:Goo00<007ooOol067oo00<007ooOol01goo00<007ooOol0I7oo002C
Ool2002YOol00`00Oomoo`0ZOol00`00Oomoo`0HOol00`00Oomoo`04Ool2001WOol009Eoo`03001o
ogoo0:Moo`03001oogoo02Uoo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo06Moo`00UWoo
00<007ooOol0Ygoo00<007ooOol0:Goo00<007ooOol067oo00D007ooOomoo`0006Yoo`00Ugoo00<0
07ooOol0YWoo00<007ooOol0:Goo00<007ooOol06Goo00<007oo0000Jgoo002HOol00`00Oomoo`2V
Ool00`00Oomoo`0YOol00`00Oomoo`0IOol00`00Oomoo`1ZOol009Uoo`800:Moo`03001oogoo02Uo
o`03001oogoo01Qoo`03001oogoo06Yoo`00Vgoo00<007ooOol0Y7oo00<007ooOol0:Goo00<007oo
Ool05goo00<007ooOol0Jgoo002LOol00`00Oomoo`2TOol00`00Oomoo`0YOol00`00Oomoo`0FOol0
0`00Oomoo`1[Ool009eoo`03001oogoo0:Aoo`03001oogoo02Qoo`03001oogoo00eoo`<000=oo`<0
06ioo`00WWoo00<007ooOol0Xgoo00<007ooOol0:Goo00<007ooOol03Goo00<007ooOol00goo0P00
KWoo002OOol00`00Oomoo`2SOol00`00Oomoo`0XOol00`00Oomoo`0=Ool00`00Oomoo`03Ool2001^
Ool00:1oo`800:=oo`03001oogoo02Uoo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo06eo
o`00XWoo00<007ooOol0XGoo00<007ooOol0:7oo00<007ooOol037oo00<007ooOol00goo00<007oo
Ool0KGoo002SOol00`00Oomoo`2QOol00`00Oomoo`0XOol00`00Oomoo`0:Ool20004Ool2001_Ool0
0:Aoo`03001oogoo0:1oo`03001oogoo02Uoo`03001oogoo00moo`03001oogoo06ioo`00YGoo00<0
07ooOol0X7oo00<007ooOol0:7oo00<007ooOol03Woo00<007ooOol0Kgoo002VOol00`00Oomoo`2P
Ool00`00Oomoo`0XOol00`00Oomoo`0=Ool00`00Oomoo`1_Ool00:Moo`800:1oo`03001oogoo02Qo
o`03001oogoo00eoo`03001oogoo06moo`00ZGoo00<007ooOol0WWoo00<007ooOol0:7oo00<007oo
Ool02goo00<007ooOol0L7oo002ZOol00`00Oomoo`2NOol00`00Oomoo`0WOol00`00Oomoo`0;Ool0
0`00Oomoo`1`Ool00:]oo`03001oogoo09eoo`03001oogoo02Qoo`03001oogoo00Uoo`03001oogoo
075oo`00[7oo00<007ooOol0WGoo00<007ooOol0:7oo00<007ooOol027oo00<007ooOol0LGoo002]
Ool00`00Oomoo`2LOol00`00Oomoo`0XOol00`00Oomoo`07Ool00`00Oomoo`1bOol00:ioo`8009eo
o`03001oogoo02Qoo`03001oogoo00Ioo`03001oogoo079oo`00/7oo00<007ooOol0Vgoo00<007oo
Ool09goo00<007ooOol01Woo00<007ooOol0LWoo002aOol00`00Oomoo`2JOol00`00Oomoo`0XOol0
0`00Oomoo`04Ool00`00Oomoo`1cOol00;9oo`03001oogoo09Yoo`03001oogoo02Moo`03001oogoo
00Aoo`03001oogoo07=oo`00/goo00<007ooOol0VWoo00<007ooOol09goo00<007ooOol00Woo00<0
07ooOol0M7oo002dOol00`00Oomoo`2IOol00`00Oomoo`0WOol00`00Oomoo`02Ool00`00Oomoo`1d
Ool00;Eoo`8009Yoo`03001oogoo02Moo`04001oogoo001gOol00;Moo`03001oogoo09Qoo`03001o
ogoo02Moo`03001oo`0007Moo`00^7oo00<007ooOol0Ugoo00<007ooOol09goo00<007oo0000Mgoo
002iOol00`00Oomoo`2GOol00`00Oomoo`0WOol00`00Oomoo`1fOol00;Yoo`03001oogoo09Ioo`03
001oogoo02Moo`03001oogoo07Ioo`00^goo00<007ooOol0UWoo00<007ooOol09Goo00<007ooOol0
Mgoo002lOol2002GOol00`00Oomoo`0SOol00`00Oomoo`1hOol00;ioo`03001oogoo09Aoo`03001o
ogoo01]oo`<000Aoo`<007Uoo`00_goo00<007ooOol0U7oo00<007ooOol06goo00<007ooOol00Woo
00<007oo0000NWoo0030Ool00`00Oomoo`2DOol00`00Oomoo`0JOol01000Oomoogoo1@00NGoo0031
Ool00`00Oomoo`2COol00`00Oomoo`0JOol02000Oomoo`00Ool007oo001jOol00<9oo`03001oogoo
09=oo`03001oogoo01Uoo`08001oogoo001oo`00Ool007Yoo`00`goo0P00U7oo00<007ooOol05goo
0P0000=oo`00Ool00Woo0P00NWoo0035Ool00`00Oomoo`2AOol00`00Oomoo`0IOol00`00Oomoo`1n
Ool00<Ioo`03001oogoo095oo`03001oogoo01Moo`03001oogoo07moo`00agoo00<007ooOol0T7oo
00<007ooOol05Woo00<007ooOol0P7oo0038Ool00`00Oomoo`2@Ool00`00Oomoo`0DOol00`00Oomo
o`21Ool00<Uoo`03001oogoo091oo`03001oogoo019oo`03001oogoo089oo`00bWoo0P00T7oo00<0
07ooOol04Woo00<007ooOol0PWoo003<Ool00`00Oomoo`2>Ool00`00Oomoo`0@Ool00`00Oomoo`23
Ool00<eoo`03001oogoo08ioo`03001oogoo00ioo`03001oogoo08Aoo`00cWoo00<007ooOol0SGoo
00<007ooOol03Goo00<007ooOol0QGoo003?Ool00`00Oomoo`2=Ool00`00Oomoo`0;Ool00`00Oomo
o`26Ool00=1oo`03001oogoo08eoo`03001oogoo00Uoo`03001oogoo08Moo`00dGoo0P00SGoo00<0
07ooOol027oo00<007ooOol0R7oo003COol00`00Oomoo`2;Ool00`00Oomoo`07Ool00`00Oomoo`28
Ool00=Aoo`03001oogoo08Yoo`03001oogoo00Ioo`03001oogoo08Uoo`00eGoo00<007ooOol0RWoo
00<007ooOol017oo00<007ooOol0RWoo003FOol00`00Oomoo`2:Ool00`00Oomoo`02Ool00`00Oomo
o`2;Ool00=Moo`03001oogoo08Uoo`05001oogooOol0002>Ool00=Qoo`8008Yoo`03001oo`0008mo
o`00fWoo00<007ooOol0QWoo0`00T7oo003KOol00`00Oomoo`21Ool4002COol00=aoo`03001oogoo
07aoo`@009Moo`00gGoo00<007ooOol0N7oo0`00Vgoo003NOol2001dOol40003Ool30004Ool00`00
Oomoo`2AOol00>1oo`03001oogoo06eoo`@000Qoo`03001oogoo00=oo`03001oogoo095oo`00hGoo
00<007ooOol0J7oo100037oo00<007ooOol017oo00<007ooOol0T7oo003ROol00`00Oomoo`1SOol4
000@Ool00`00Oomoo`04Ool00`00Oomoo`2@Ool00>=oo`03001oogoo05moo`<001Aoo`03001oogoo
00Eoo`03001oogoo08moo`00i7oo00<007ooOol0FWoo10005Woo0P0017oo1000TGoo003UOol2001F
Ool4002eOol00>Moo`03001oogoo04moo`@00;Uoo`00j7oo00<007ooOol0BWoo1000_Goo003YOol0
0`00Oomoo`15Ool40031Ool00>Yoo`03001oogoo045oo`<00<Eoo`00jgoo00<007ooOol0?7oo1000
b7oo003/Ool2000hOol4003<Ool00>ioo`03001oogoo035oo`@00=1oo`00kgoo00<007ooOol0;7oo
1000e7oo003`Ool00`00Oomoo`0WOol4003HOol00?5oo`03001oogoo02=oo`<00=aoo`00lWoo00<0
07ooOol07Woo1000ggoo003cOol2000JOol4003SOol00?Eoo`03001oogoo01=oo`@00>Moo`00mWoo
00<007ooOol03Woo1000jgoo003gOol00`00Oomoo`0:Ool3003_Ool00?Qoo`03001oogoo00Eoo`@0
0?9oo`00nGoo00<007ooOol01000mWoo003jOol2003jOol00?Yoo`03001oogoo0?Uoo`00nWoo00<0
07ooOol0nGoo003jOol00`00Oomoo`3iOol00?1oo`<000=oo`<00003Ool007oo0?Yoo`00lGoo00<0
07ooOol01Goo0P00ngoo003aOol00`00Oomoo`03Ool4003kOol00?5oo`03001oogoo009oo`03001o
ogoo00800?]oo`00lGoo00<007ooOol00Woo00<007ooOol00P00ngoo003`Ool20005Ool200000goo
001oo`3jOol00?Yoo`03001oogoo0?Uoo`00nWoo00<007ooOol0nGoo003jOol00`00Oomoo`3iOol0
0?Yoo`03001oogoo0?Uoo`00nWoo00<007ooOol0nGoo003jOol00`00Oomoo`3iOol00?Yoo`03001o
ogoo0?Uoo`00nWoo00<007ooOol0nGoo003jOol00`00Oomoo`3iOol00?Yoo`03001oogoo0?Uoo`00
nWoo00<007ooOol0nGoo003jOol00`00Oomoo`3iOol00?Yoo`03001oogoo0?Uoo`00nWoo00<007oo
Ool0nGoo003jOol00`00Oomoo`3iOol00?Yoo`03001oogoo0?Uoo`00nWoo00<007ooOol0nGoo003j
Ool00`00Oomoo`3iOol00?Yoo`03001oogoo0?Uoo`00ogoomgoo003oOoogOol00?moooMoo`00l7oo
10000goo0P00oGoo003aOol00`00Oomoo`02Ool01000Oomoo`00o7oo003bOol01@00Oomoogoo0000
0Woo00<007ooOol0nWoo003cOol01000Oomoo`000Woo00<007ooOol0nWoo003`Ool01000Oomoo`00
0Woo00@007ooOol00?aoo`00lGoo0P0017oo0P00oGoo003oOoogOol00?moooMoo`00ogoomgoo003o
OoogOol00?moooMoo`00ogoomgoo003oOoogOol00?moooMoo`00ogoomgoo003oOoogOol00?moooMo
o`00ogoomgoo003oOoogOol00?moooMoo`00ogoomgoo003oOoogOol00?moooMoo`00ogoomgoo003o
OoogOol00001\
\>"],
  ImageRangeCache->{{{0, 501}, {309.125, 0}} -> {-1.01736, -1.00005, 
  0.0419855, 0.0355844}}]
}, Closed]],

Cell["\<\
This shows those branches that carry mutations; the time interval \
they span; the number of mutations; and the expected number inj the absence \
of a bottleneck.  The last row shows the total number of mutations (14) and \
the expected number with no bottleneck (46.48):\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(smT = \(smN = 0\); \n
    tl = \(\((
            t0 = \(ExtractInformation[gb, #]\)\[LeftDoubleBracket]1
                \[RightDoubleBracket]; 
            t1 = \(ExtractInformation[gb, Last[Ancestors[gb, #]]]
                  \)\[LeftDoubleBracket]1\[RightDoubleBracket]; \n\t\t
            nm = NumberOfMutations[gb, #]; smT += \((t1 - t0)\); smN += nm; \n
            \t\t{#, {t0, t1}, nm, 10 \((t1 - t0)\)/2})\)&\)/@
        Sort[DeleteCases[Nodes[gb], 
            gb\[LeftDoubleBracket]1\[RightDoubleBracket]]]; \n\t\t
    Append[DeleteCases[tl, {_, _, 0, _}], {Total, smT, smN, smT*10/2}] // 
      TableForm\)], "Input",
  CellLabel->"In[686]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"10", GridBox[{
                {"0.0685804766207851024`"},
                {"0.197022841726302555`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "1", "0.642211825527587176`"},
          {"17", GridBox[{
                {"0.489635659700715919`"},
                {"3.37467033630722923`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "7", "14.4251733830325656`"},
          {"18", GridBox[{
                {"0.823788854443015416`"},
                {"3.37467033630722923`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "3", "12.754407409321069`"},
          {\(l\_3\), GridBox[{
                {"0"},
                {"0.186854139706307478`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "1", "0.934270698531537391`"},
          {\(l\_12\), GridBox[{
                {"0"},
                {"0.114733042355478076`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "1", "0.573665211777390382`"},
          {\(l\_20\), GridBox[{
                {"0"},
                {"0.00603812684900784635`"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "1", "0.0301906342450392317`"},
          {"Total", "9.29523882255006306`", "14", "46.4761941127503153`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{10, {0.068580476620785105, 0.19702284172630255}, 1, 
        0.64221182552758715}, {17, {0.48963565970071588, 3.3746703363072292}, 
        7, 14.425173383032565}, {18, {0.82378885444301542, 
        3.3746703363072292}, 3, 12.754407409321068}, {
        Subscript[ l, 3], {0, 0.18685413970630749}, 1, 
        0.93427069853153744}, {
        Subscript[ l, 12], {0, 0.11473304235547808}, 1, 
        0.57366521177739038}, {
        Subscript[ l, 20], {0, 0.0060381268490078462}, 1, 
        0.030190634245039233}, {Total, 9.2952388225500631, 14, 
        46.476194112750314}}]]], "Output",
  CellLabel->"Out[686]//TableForm="]
}, Closed]],

Cell["\<\
Note that there are no mutations in the interval {0.1, 1.1}.  If an \
interval spans part of the forbidden time interval, a random number of \
mutations is drawn, with the appropriately reduced expectation.\
\>", "Text"],

Cell["\<\
Because many coalescences occurred in the absence of mutation, the \
genealogy cannot be reconstructed from the configuration of mutations: there \
are many multifurcations that cannot be resolved:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(S = GenealogyToMatrix[gb]; S // MatrixForm\)], "Input",
  CellLabel->"In[695]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", "1", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0"},
            {"1", "1", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0", "1", 
              "0"},
            {"1", "1", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0"},
            {"1", "1", "1", "0", "0", "0", "0", "0", "0", "0", "1", "0", "0", 
              "0"},
            {"1", "1", "1", "0", "0", "0", "0", "0", "0", "0", "1", "0", "0", 
              "0"},
            {"1", "1", "1", "0", "0", "0", "0", "0", "0", "0", "1", "0", "0", 
              "0"},
            {"1", "1", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0"},
            {"1", "1", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0"},
            {"1", "1", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "1"},
            {"0", "0", "0", "1", "1", "1", "1", "1", "1", "1", "0", "0", "0", 
              "0"},
            {"0", "0", "0", "1", "1", "1", "1", "1", "1", "1", "0", "0", "0", 
              "0"},
            {"0", "0", "0", "1", "1", "1", "1", "1", "1", "1", "0", "1", "0", 
              "0"},
            {"0", "0", "0", "1", "1", "1", "1", "1", "1", "1", "0", "0", "0", 
              "0"},
            {"0", "0", "0", "1", "1", "1", "1", "1", "1", "1", "0", "0", "0", 
              "0"},
            {"0", "0", "0", "1", "1", "1", "1", "1", "1", "1", "0", "0", "0", 
              "0"},
            {"0", "0", "0", "1", "1", "1", "1", "1", "1", "1", "0", "0", "0", 
              "0"},
            {"0", "0", "0", "1", "1", "1", "1", "1", "1", "1", "0", "0", "0", 
              "0"},
            {"0", "0", "0", "1", "1", "1", "1", "1", "1", "1", "0", "0", "0", 
              "0"},
            {"0", "0", "0", "1", "1", "1", "1", "1", "1", "1", "0", "0", "0", 
              "0"},
            {"0", "0", "0", "1", "1", "1", "1", "1", "1", "1", "0", "0", "0", 
              "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[695]//MatrixForm="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(gb2 = MatrixToGenealogy[S, Leaves[gb], Mutations[gb]]\)], "Input",
  CellLabel->"In[696]:="],

Cell[BoxData[
    \(Node[
      1, {0, {}}, {
        Node[2, {0, {1, 5, 6}}, {Node[l\_9, {0, {1, 5, 6}}, {}], 
            Node[l\_12, {0, {1, 5, 6, 34}}, {}], 
            Node[l\_19, {0, {1, 5, 6}}, {}], 
            Node[3, {0, {1, 5, 6, 30}}, {Node[l\_14, {0, {1, 5, 6, 30}}, {}], 
                Node[l\_8, {0, {1, 5, 6, 30}}, {}], 
                Node[l\_18, {0, {1, 5, 6, 30}}, {}]}], 
            Node[l\_5, {0, {1, 5, 6}}, {}], Node[l\_16, {0, {1, 5, 6}}, {}], 
            Node[l\_20, {0, {1, 5, 6, 35}}, {}]}], 
        Node[4, {0, {7, 8, 9, 11, 12, 15, 16}}, {
            Node[l\_6, {0, {7, 8, 9, 11, 12, 15, 16}}, {}], 
            Node[l\_11, {0, {7, 8, 9, 11, 12, 15, 16}}, {}], 
            Node[l\_3, {0, {7, 8, 9, 11, 12, 15, 16, 31}}, {}], 
            Node[l\_10, {0, {7, 8, 9, 11, 12, 15, 16}}, {}], 
            Node[l\_2, {0, {7, 8, 9, 11, 12, 15, 16}}, {}], 
            Node[l\_13, {0, {7, 8, 9, 11, 12, 15, 16}}, {}], 
            Node[l\_17, {0, {7, 8, 9, 11, 12, 15, 16}}, {}], 
            Node[l\_15, {0, {7, 8, 9, 11, 12, 15, 16}}, {}], 
            Node[l\_7, {0, {7, 8, 9, 11, 12, 15, 16}}, {}], 
            Node[l\_1, {0, {7, 8, 9, 11, 12, 15, 16}}, {}], 
            Node[l\_4, {0, {7, 8, 9, 11, 12, 15, 16}}, {}]}]}]\)], "Output",
  CellLabel->"Out[696]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[PlotGenealogy[gb2]]; \)\)], "Input",
  CellLabel->"In[697]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.047619 0.047619 0.123607 0.123607 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .49443 m
.2381 .37082 L
s
.5 .49443 m
.71429 .24721 L
s
.2381 .37082 m
.04762 .12361 L
s
.2381 .37082 m
.09524 .12361 L
s
.2381 .37082 m
.14286 .12361 L
s
.2381 .37082 m
.2381 .24721 L
s
.2381 .37082 m
.33333 .12361 L
s
.2381 .37082 m
.38095 .12361 L
s
.2381 .37082 m
.42857 .12361 L
s
.2381 .24721 m
.19048 .12361 L
s
.2381 .24721 m
.2381 .12361 L
s
.2381 .24721 m
.28571 .12361 L
s
.71429 .24721 m
.47619 .12361 L
s
.71429 .24721 m
.52381 .12361 L
s
.71429 .24721 m
.57143 .12361 L
s
.71429 .24721 m
.61905 .12361 L
s
.71429 .24721 m
.66667 .12361 L
s
.71429 .24721 m
.71429 .12361 L
s
.71429 .24721 m
.7619 .12361 L
s
.71429 .24721 m
.80952 .12361 L
s
.71429 .24721 m
.85714 .12361 L
s
.71429 .24721 m
.90476 .12361 L
s
.71429 .24721 m
.95238 .12361 L
s
[(1)] .49048 .51915 0 0 Mshowa
[(2)] .22857 .39554 0 0 Mshowa
[(3)] .22857 .27193 0 0 Mshowa
[(4)] .70476 .27193 0 0 Mshowa
gsave
.04762 .09889 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(9) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.09524 .09889 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(12) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.14286 .09889 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(19) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.19048 .09889 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(14) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.2381 .09889 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.28571 .09889 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(18) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.33333 .09889 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.38095 .09889 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(16) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.42857 .09889 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.47619 .09889 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.52381 .09889 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(11) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.57143 .09889 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.61905 .09889 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.66667 .09889 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.71429 .09889 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(13) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.7619 .09889 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(17) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.80952 .09889 -70.7188 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(15) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.85714 .09889 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(7) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.90476 .09889 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.95238 .09889 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(l) show
69.000000 14.562500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[697]:=",
  ImageSize->{626, 386.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009b0001PQ000`40O003h00OogooogooM7oo003o
OoooOomdOol00?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00ogooogoo
M7oo003oOoooOomdOol00?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00
ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomo
ogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol0
0?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00ogooogooM7oo003oOooo
OomdOol00?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00ogooogooM7oo
003oOoooOomdOol00?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00ogoo
ogooM7oo003oOoooOomdOol00?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomoogAo
o`00ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol00?mo
oomoogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00ogooogooM7oo003oOoooOomd
Ool00?mooomoogAoo`00ogooogooM7oo000OOol2000JOol3000017oo000000005Woo0`0000=oo`00
000067oo0`000Woo00<007ooOol067oo0`006Goo0`0000Aoo`00000001Qoo`<001Uoo`<00004Ool0
0000000GOol3000017oo000000006Goo0`0067oo0`0000Aoo`00000001Uoo`<001Uoo`<00004Ool0
0000000HOol3000IOol3000017oo000000005goo0`000Woo00<007ooOol05Goo0`0000Aoo`000000
01Yoo`03001oogoo01Yoo`<001aoo`03001oogoo01Yoo`007goo0`006Woo00D007ooOomoo`0001Qo
o`03001oogoo00<001Qoo`03001oogoo008001Yoo`03001oo`0001Yoo`06001oogoo001oo`006Woo
00<007ooOol067oo00H007ooOol007oo000HOol01P00Oomoo`00Ool001Uoo`03001oo`0001Uoo`05
001oogooOol0000LOol00`00Oomoo`0HOol01P00Oomoo`00Ool001Uoo`03001oogoo01Uoo`03001o
ogoo009oo`03001oogoo01Ioo`05001oogooOol0000HOol00`00Oomoo`02Ool00`00Oomoo`0HOol0
0`00Oomoo`0KOol00`00Oomoo`0JOol2000LOol001Uoo`D00004Ool007oo000COol50002Ool00`00
Oomoo`02Ool00`00Oomoo`0>Ool50002Ool01P00Oomoo`00Ool0015oo`D0009oo`03001oogoo0080
01Aoo`D0009oo`03001oogoo019oo`D0009oo`05001oogooOol0000COol5000017oo000000004goo
1@000Woo00<007ooOol00`004Goo1@000goo00D007oo001oo`0001=oo`D00004Ool00000000BOol5
0002Ool01@00Oomoogoo000057oo1@000Woo00<007ooOol04Woo1@000Woo00H007ooOol007oo000B
Ool50003Ool00`00Oomoo`0AOol50002Ool01@00Oomoogoo00004Woo1@000Woo00<007ooOol00Woo
00<007ooOol03Woo1@000Woo00<007ooOol00`004goo1@000goo00<007ooOol04goo1@000Woo00<0
07ooOol057oo1@0000=oo`00000077oo000KOol01000Oomoogoo0`005Goo00@007ooOomoo`80009o
o`<0019oo`04001oogooOol20002Ool3000COol01000Oomoogoo0P000goo00<007ooOol057oo00@0
07ooOomoo`<001Eoo`04001oogooOol20002Ool3000DOol01000Oomoogoo0`005Goo00@007ooOomo
o`8000=oo`8001=oo`04001oogooOol3000017oo000000005Goo00<007ooOol00Woo0P0057oo00@0
07ooOomoo`80009oo`8001Ioo`04001oogooOol3000EOol01000Oomoogoo0P000Woo0`0057oo00@0
07ooOomoo`<001Eoo`04001oogooOol20002Ool3000COol01000Oomoogoo0P000Woo0`004Woo00@0
07ooOomoo`80009oo`<001Eoo`04001oogooOol3000GOol01000Oomoogoo0P0067oo00<007ooOol0
0Woo00<007ooOol06Woo000KOol00`00Oomoo`0IOol00`00Oomoo`0JOol00`00Oomoo`0KOol00`00
Oomoo`0MOol00`00Oomoo`0IOol00`00Oomoo`0LOol00`00Oomoo`0IOol00`00Oomoo`0KOol00`00
Oomoo`0MOol00`00Oomoo`0HOol00`00Oomoo`0MOol00`00Oomoo`0IOol00`00Oomoo`0LOol00`00
Oomoo`0IOol00`00Oomoo`0KOol00`00Oomoo`0JOol00`00Oomoo`0MOol00`00Oomoo`0KOol00`00
Oomoo`0KOol00`00Oomoo`0OOol001]oo`03001oogoo01Uoo`03001oogoo01Yoo`03001oogoo01]o
o`03001oogoo01eoo`03001oogoo01Uoo`03001oogoo01aoo`03001oogoo01Uoo`03001oogoo01]o
o`03001oogoo01eoo`03001oogoo01Qoo`03001oogoo01eoo`03001oogoo01Uoo`03001oogoo01ao
o`03001oogoo01Uoo`03001oogoo01]oo`03001oogoo01Yoo`03001oogoo01eoo`03001oogoo01]o
o`03001oogoo01]oo`03001oogoo01moo`006goo00<007ooOol06Goo00<007ooOol06Woo00<007oo
Ool06goo00<007ooOol07Goo00<007ooOol06Goo00<007ooOol077oo00<007ooOol06Goo00<007oo
Ool06goo00<007ooOol07Goo00<007ooOol067oo00<007ooOol07Goo00<007ooOol06Goo00<007oo
Ool077oo00<007ooOol06Goo00<007ooOol06goo00<007ooOol06Woo00<007ooOol07Goo00<007oo
Ool06goo00<007ooOol06goo00<007ooOol07goo000KOol00`00Oomoo`0IOol00`00Oomoo`0JOol0
0`00Oomoo`0KOol00`00Oomoo`0MOol00`00Oomoo`0IOol00`00Oomoo`0LOol00`00Oomoo`0IOol0
0`00Oomoo`0KOol00`00Oomoo`0MOol00`00Oomoo`0HOol00`00Oomoo`0MOol00`00Oomoo`0IOol0
0`00Oomoo`0LOol00`00Oomoo`0IOol00`00Oomoo`0KOol00`00Oomoo`0JOol00`00Oomoo`0MOol0
0`00Oomoo`0KOol00`00Oomoo`0KOol00`00Oomoo`0OOol001Uoo`<001Uoo`<001Yoo`<001]oo`<0
01eoo`<001Uoo`<001aoo`<001Uoo`<001]oo`<001eoo`<001Qoo`<001eoo`<001Uoo`<001aoo`<0
01Uoo`<001]oo`<001Yoo`<001eoo`<001]oo`<001]oo`<0025oo`00ogooogooM7oo003oOoooOomd
Ool00?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00ogooogooM7oo003o
OoooOomdOol00?mooomoogAoo`00ogooogooM7oo000NOol00`00Oomoo`0JOol00`00Oomoo`0KOol0
0`00Oomoo`0KOol00`00Oomoo`0KOol00`00Oomoo`0JOol00`00Oomoo`0KOol00`00Oomoo`0KOol0
0`00Oomoo`0JOol00`00Oomoo`0KOol2000LOol2000LOol2000KOol00`00Oomoo`0KOol00`00Oomo
o`0KOol00`00Oomoo`0JOol00`00Oomoo`0KOol00`00Oomoo`0JOol2000LOol2000KOol2000OOol0
01ioo`03001oogoo01Yoo`03001oogoo01]oo`03001oogoo01]oo`03001oogoo01]oo`03001oogoo
01Yoo`03001oogoo01]oo`03001oogoo01]oo`03001oogoo01Yoo`03001oogoo01eoo`8001aoo`03
001oogoo01]oo`03001oogoo01Qoo`03001oogoo01]oo`03001oogoo01]oo`03001oogoo01Yoo`03
001oogoo01]oo`03001oogoo01Uoo`03001oogoo01]oo`03001oogoo01Uoo`80025oo`007goo00<0
07ooOol06Woo00<007ooOol06goo00<007ooOol06goo00<007ooOol06Woo00<007ooOol06Goo00<0
07ooOol06goo00<007ooOol06goo00<007ooOol06Woo00<007ooOol087oo0P006goo0P0077oo00<0
07ooOol067oo00<007ooOol06goo00<007ooOol06Woo00<007ooOol06Goo00<007ooOol06goo00<0
07ooOol06Goo00<007ooOol06Woo0P006Woo0P008goo000POol00`00Oomoo`0IOol00`00Oomoo`0K
Ool00`00Oomoo`0KOol00`00Oomoo`0JOol00`00Oomoo`0IOol00`00Oomoo`0KOol00`00Oomoo`0K
Ool00`00Oomoo`0IOol00`00Oomoo`0SOol2000KOol00`00Oomoo`0JOol00`00Oomoo`0HOol00`00
Oomoo`0JOol00`00Oomoo`0JOol00`00Oomoo`0IOol00`00Oomoo`0JOol00`00Oomoo`0IOol00`00
Oomoo`0JOol00`00Oomoo`0HOol2000UOol0025oo`03001oogoo01Uoo`03001oogoo01Yoo`03001o
ogoo01]oo`03001oogoo01Yoo`03001oogoo01Uoo`03001oogoo01]oo`03001oogoo01Yoo`03001o
ogoo01Uoo`03001oogoo02Ioo`8001Yoo`8001]oo`03001oogoo01Qoo`03001oogoo01Uoo`03001o
ogoo01Yoo`03001oogoo01Uoo`03001oogoo01Uoo`03001oogoo01Uoo`03001oogoo01Uoo`8001Uo
o`8002Moo`008Goo00<007ooOol06Woo00<007ooOol06Woo00<007ooOol06goo00<007ooOol06Goo
00<007ooOol067oo00<007ooOol06goo00<007ooOol06Woo00<007ooOol06Woo00<007ooOol0:7oo
0P006Woo0P006Woo00<007ooOol067oo00<007ooOol06Goo00<007ooOol06Goo00<007ooOol067oo
00<007ooOol06Woo00<007ooOol067oo00<007ooOol067oo0P006Goo0P00:Goo000ROol00`00Oomo
o`0IOol00`00Oomoo`0JOol00`00Oomoo`0KOol00`00Oomoo`0IOol00`00Oomoo`0HOol00`00Oomo
o`0KOol00`00Oomoo`0JOol00`00Oomoo`0IOol00`00Oomoo`0[Ool2000JOol00`00Oomoo`0HOol2
000HOol00`00Oomoo`0IOol00`00Oomoo`0IOol00`00Oomoo`0HOol00`00Oomoo`0IOol00`00Oomo
o`0GOol2000JOol00`00Oomoo`0HOol00`00Oomoo`0YOol002=oo`03001oogoo01Uoo`03001oogoo
01Yoo`03001oogoo01]oo`03001oogoo01Qoo`03001oogoo01Qoo`03001oogoo01]oo`03001oogoo
01Uoo`03001oogoo01Uoo`03001oogoo02ioo`8001Uoo`8001Yoo`03001oogoo01Ioo`03001oogoo
01Uoo`03001oogoo01Qoo`03001oogoo01Qoo`03001oogoo01Qoo`03001oogoo01Moo`03001oogoo
01Qoo`8001Uoo`8002aoo`0097oo00<007ooOol067oo00<007ooOol06Woo00<007ooOol06goo00<0
07ooOol067oo00<007ooOol05goo00<007ooOol06goo00<007ooOol06Woo00<007ooOol067oo00<0
07ooOol0<Goo00<007ooOol067oo00<007ooOol067oo00<007ooOol05Woo00<007ooOol067oo00<0
07ooOol067oo00<007ooOol05goo00<007ooOol067oo00<007ooOol05goo00<007ooOol067oo00<0
07ooOol05goo0P00;Woo000UOol00`00Oomoo`0HOol00`00Oomoo`0IOol00`00Oomoo`0KOol00`00
Oomoo`0HOol00`00Oomoo`0GOol00`00Oomoo`0KOol00`00Oomoo`0IOol00`00Oomoo`0HOol00`00
Oomoo`0cOol2000IOol2000IOol00`00Oomoo`0FOol00`00Oomoo`0GOol00`00Oomoo`0HOol00`00
Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`0GOol2000HOol2000`Ool002Eo
o`03001oogoo01Uoo`03001oogoo01Uoo`03001oogoo01]oo`03001oogoo01Moo`03001oogoo01Io
o`03001oogoo01]oo`03001oogoo01Yoo`03001oogoo01Qoo`03001oogoo03Eoo`8001Uoo`03001o
ogoo01Moo`03001oogoo01Eoo`03001oogoo01Qoo`03001oogoo01Moo`03001oogoo01Ioo`03001o
ogoo01Qoo`03001oogoo01Ioo`03001oogoo01Moo`03001oogoo01Ioo`80039oo`009Woo00<007oo
Ool067oo00<007ooOol06Goo00<007ooOol06goo00<007ooOol05goo00<007ooOol05Woo00<007oo
Ool06goo00<007ooOol06Goo00<007ooOol067oo00<007ooOol0>7oo0P0067oo0P0067oo00<007oo
Ool05Goo00<007ooOol05goo00<007ooOol05goo00<007ooOol05Woo00<007ooOol05goo00<007oo
Ool05Woo00<007ooOol05Woo0P005goo0P00=7oo000WOol00`00Oomoo`0HOol00`00Oomoo`0HOol0
0`00Oomoo`0KOol00`00Oomoo`0GOol00`00Oomoo`0FOol00`00Oomoo`0KOol00`00Oomoo`0HOol0
0`00Oomoo`0HOol00`00Oomoo`0kOol2000HOol00`00Oomoo`0FOol00`00Oomoo`0EOol00`00Oomo
o`0FOol00`00Oomoo`0GOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomo
o`0FOol00`00Oomoo`0EOol2000fOol002Qoo`03001oogoo01Moo`03001oogoo01Uoo`03001oogoo
01]oo`03001oogoo01Ioo`03001oogoo01Eoo`03001oogoo01]oo`03001oogoo01Uoo`03001oogoo
01Moo`03001oogoo03ioo`8001Moo`8001Moo`8001Ioo`03001oogoo01Ioo`03001oogoo01Ioo`03
001oogoo01Eoo`03001oogoo01Ioo`03001oogoo01Eoo`8001Moo`8001Ioo`8003Qoo`00:7oo00<0
07ooOol067oo00<007ooOol067oo00<007ooOol06goo00<007ooOol05Woo00<007ooOol05Goo00<0
07ooOol06goo00<007ooOol067oo00<007ooOol067oo00<007ooOol0@7oo0P005goo00<007ooOol0
5Woo00<007ooOol057oo00<007ooOol05Goo00<007ooOol05Woo00<007ooOol05Goo00<007ooOol0
5Woo00<007ooOol057oo00<007ooOol05Woo00<007ooOol057oo0P00>Woo000YOol00`00Oomoo`0G
Ool00`00Oomoo`0IOol00`00Oomoo`0KOol00`00Oomoo`0EOol00`00Oomoo`0EOol00`00Oomoo`0J
Ool00`00Oomoo`0IOol00`00Oomoo`0GOol00`00Oomoo`13Ool2000FOol2000GOol00`00Oomoo`0C
Ool00`00Oomoo`0FOol00`00Oomoo`0EOol00`00Oomoo`0EOol00`00Oomoo`0EOol00`00Oomoo`0D
Ool00`00Oomoo`0EOol2000EOol2000lOol002Yoo`03001oogoo01Moo`03001oogoo01Qoo`03001o
ogoo01]oo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo01]oo`03001oogoo01Qoo`03001o
ogoo01Moo`03001oogoo04Ioo`8001Ioo`8001Ioo`03001oogoo01=oo`03001oogoo01Eoo`03001o
ogoo01Eoo`03001oogoo01Aoo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo01Aoo`8001Eo
o`8003ioo`00:goo00<007ooOol05goo00<007ooOol05goo00<007ooOol06goo00<007ooOol05Goo
00<007ooOol057oo00<007ooOol06goo00<007ooOol05goo00<007ooOol05goo00<007ooOol0BGoo
0P005Woo00<007ooOol057oo00<007ooOol04goo00<007ooOol057oo00<007ooOol05Goo00<007oo
Ool057oo00<007ooOol057oo00<007ooOol057oo00<007ooOol057oo00<007ooOol04goo0P00@7oo
000/Ool00`00Oomoo`0FOol00`00Oomoo`0HOol00`00Oomoo`0KOol00`00Oomoo`0DOol00`00Oomo
o`0COol00`00Oomoo`0KOol00`00Oomoo`0HOol00`00Oomoo`0GOol00`00Oomoo`1;Ool2000EOol2
000EOol00`00Oomoo`0COol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0COol00`00Oomo
o`0EOol00`00Oomoo`0COol00`00Oomoo`0COol2000DOol20012Ool002aoo`03001oogoo01Moo`03
001oogoo01Moo`03001oogoo01]oo`03001oogoo01Aoo`03001oogoo01=oo`03001oogoo01]oo`03
001oogoo01Moo`03001oogoo01Moo`03001oogoo04ioo`8001Eoo`03001oogoo01=oo`8001=oo`03
001oogoo01Aoo`03001oogoo01Aoo`03001oogoo01=oo`03001oogoo01Aoo`03001oogoo019oo`80
01Eoo`03001oogoo01=oo`03001oogoo049oo`00;Goo00<007ooOol05Woo00<007ooOol067oo00<0
07ooOol06goo00<007ooOol04goo00<007ooOol04goo00<007ooOol06goo00<007ooOol05goo00<0
07ooOol05Woo00<007ooOol0DGoo0P0057oo0P005Goo00<007ooOol04Goo00<007ooOol057oo00<0
07ooOol04goo00<007ooOol04goo00<007ooOol04goo00<007ooOol04Woo00<007ooOol04goo0P00
57oo0P00AGoo000^Ool00`00Oomoo`0FOol00`00Oomoo`0GOol00`00Oomoo`0KOol00`00Oomoo`0C
Ool00`00Oomoo`0BOol00`00Oomoo`0KOol00`00Oomoo`0GOol00`00Oomoo`0FOol00`00Oomoo`1D
Ool2000DOol00`00Oomoo`0COol00`00Oomoo`0AOol00`00Oomoo`0COol00`00Oomoo`0COol00`00
Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol20017
Ool002moo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01]oo`03001oogoo01=oo`03001o
ogoo019oo`03001oogoo01]oo`03001oogoo01Moo`03001oogoo01Ioo`03001oogoo05Ioo`8001=o
o`8001Aoo`03001oogoo015oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo019oo`03001o
ogoo01=oo`03001oogoo015oo`03001oogoo019oo`8001=oo`8004Uoo`00;goo00<007ooOol05Woo
00<007ooOol05goo00<007ooOol06goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol06Woo
00<007ooOol05goo00<007ooOol05Woo00<007ooOol0FGoo00<007ooOol04Woo00<007ooOol04Woo
00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol04Woo
00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Goo0P00Bgoo000`Ool00`00Oomoo`0FOol0
0`00Oomoo`0FOol00`00Oomoo`0KOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0KOol0
0`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`1KOol2000COol2000COol00`00Oomoo`0@Ool0
0`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol0
0`00Oomoo`0AOol2000BOol2001=Ool0035oo`03001oogoo01Eoo`03001oogoo01Moo`03001oogoo
01]oo`03001oogoo015oo`03001oogoo015oo`03001oogoo01]oo`03001oogoo01Ioo`03001oogoo
01Eoo`03001oogoo05ioo`8001=oo`03001oogoo015oo`03001oogoo011oo`03001oogoo019oo`03
001oogoo015oo`03001oogoo015oo`03001oogoo015oo`03001oogoo015oo`03001oogoo015oo`03
001oogoo011oo`8004moo`00<Woo00<007ooOol05Goo00<007ooOol05Woo00<007ooOol06goo00<0
07ooOol04Goo00<007ooOol047oo00<007ooOol06goo00<007ooOol05Woo00<007ooOol05Goo00<0
07ooOol0HGoo0P004Woo0P004Woo0P004Goo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol0
47oo00<007ooOol04Goo00<007ooOol047oo0P004Woo0P004Goo0P00DGoo000bOol00`00Oomoo`0E
Ool00`00Oomoo`0FOol00`00Oomoo`0KOol00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`0K
Ool00`00Oomoo`0FOol00`00Oomoo`0EOol00`00Oomoo`1SOol2000BOol2000BOol00`00Oomoo`0?
Ool00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0?
Ool00`00Oomoo`0@Ool2000AOol2001COol003=oo`03001oogoo01Eoo`03001oogoo01Ioo`03001o
ogoo01]oo`03001oogoo011oo`03001oogoo011oo`03001oogoo01Yoo`03001oogoo01Ioo`03001o
ogoo01Eoo`03001oogoo06Ioo`80019oo`03001oogoo011oo`03001oogoo00ioo`03001oogoo015o
o`03001oogoo011oo`03001oogoo011oo`03001oogoo011oo`03001oogoo00moo`03001oogoo011o
o`03001oogoo00moo`8005Eoo`00=7oo00<007ooOol05Goo00<007ooOol05Goo00<007ooOol06goo
00<007ooOol047oo00<007ooOol03goo00<007ooOol06goo00<007ooOol05Woo00<007ooOol057oo
00<007ooOol0JGoo0P004Goo0P004Goo00<007ooOol03Woo00<007ooOol047oo00<007ooOol047oo
00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo0P0047oo0P00Egoo
000eOol00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0KOol00`00Oomoo`0@Ool00`00Oomo
o`0?Ool00`00Oomoo`0KOol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`1/Ool2000AOol0
0`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool0
0`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0>Ool2001IOol003Ioo`03
001oogoo01Aoo`03001oogoo01Eoo`03001oogoo01]oo`03001oogoo00moo`03001oogoo00moo`03
001oogoo01Yoo`03001oogoo01Eoo`03001oogoo01Eoo`03001oogoo06ioo`80011oo`80011oo`03
001oogoo00ioo`03001oogoo00moo`03001oogoo00moo`03001oogoo00moo`03001oogoo00moo`03
001oogoo00ioo`03001oogoo00ioo`8000moo`8005]oo`00=Woo00<007ooOol057oo00<007ooOol0
5Goo00<007ooOol06goo00<007ooOol03goo00<007ooOol03Woo00<007ooOol06goo00<007ooOol0
5Goo00<007ooOol057oo00<007ooOol0LGoo0P0047oo00<007ooOol03Woo0P003goo00<007ooOol0
3Woo00<007ooOol03goo00<007ooOol03Woo00<007ooOol03goo00<007ooOol03Goo0P0047oo00<0
07ooOol03Woo00<007ooOol0Fgoo000gOol00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0K
Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0KOol00`00Oomoo`0DOol00`00Oomoo`0D
Ool00`00Oomoo`1dOol2000?Ool2000@Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomoo`0>
Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool2000?Ool2001N
Ool003Qoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo01]oo`03001oogoo00ioo`03001o
ogoo00eoo`03001oogoo01]oo`03001oogoo01Eoo`03001oogoo01=oo`03001oogoo07Moo`8000mo
o`03001oogoo00ioo`03001oogoo00aoo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00eo
o`03001oogoo00ioo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo00eoo`80061oo`00>Goo
00<007ooOol04goo00<007ooOol057oo00<007ooOol06goo00<007ooOol03Woo00<007ooOol03Goo
00<007ooOol06goo00<007ooOol057oo00<007ooOol057oo00<007ooOol0NGoo0P003Woo0P003goo
00<007ooOol037oo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol03Woo
00<007ooOol037oo00<007ooOol03Goo0P003Woo0P00HWoo000iOol00`00Oomoo`0DOol00`00Oomo
o`0DOol00`00Oomoo`0KOol00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0JOol00`00Oomo
o`0DOol00`00Oomoo`0DOol00`00Oomoo`1lOol2000>Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool0
0`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool0
0`00Oomoo`0=Ool00`00Oomoo`0<Ool2001TOol003Yoo`03001oogoo01=oo`03001oogoo01Aoo`03
001oogoo01]oo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo01]oo`03001oogoo01Aoo`03
001oogoo01=oo`03001oogoo07moo`8000eoo`8000ioo`03001oogoo00]oo`03001oogoo00eoo`03
001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00aoo`80
00eoo`8006Ioo`00>goo00<007ooOol04goo00<007ooOol057oo00<007ooOol06goo00<007ooOol0
37oo00<007ooOol037oo00<007ooOol06goo00<007ooOol04goo00<007ooOol04goo00<007ooOol0
PWoo0P003Goo0P003Goo0P0037oo00<007ooOol03Goo00<007ooOol037oo00<007ooOol037oo00<0
07ooOol037oo00<007ooOol02goo0P003Goo0P003Goo0P00J7oo000lOol00`00Oomoo`0COol00`00
Oomoo`0COol00`00Oomoo`0KOol00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0KOol00`00
Oomoo`0DOol00`00Oomoo`0BOol00`00Oomoo`25Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00
Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00
Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool2001ZOol003eoo`03001oogoo019oo`03001o
ogoo01=oo`03001oogoo01]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo01]oo`03001o
ogoo01=oo`03001oogoo01=oo`03001oogoo08Ioo`8000eoo`8000eoo`03001oogoo00Yoo`03001o
ogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00Yoo`03001o
ogoo00]oo`8000aoo`8006aoo`00?Goo00<007ooOol04goo00<007ooOol04goo00<007ooOol06goo
00<007ooOol02goo00<007ooOol02goo00<007ooOol06Woo00<007ooOol057oo00<007ooOol04Woo
00<007ooOol0RGoo0P003Goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007oo
Ool02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007oo
Ool02Woo0P00KWoo000nOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0KOol00`00Oomo
o`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0KOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomo
o`2<Ool2000<Ool2000<Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomo
o`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool2000;Ool2001`Ool003moo`03
001oogoo019oo`03001oogoo01=oo`03001oogoo01]oo`03001oogoo00Yoo`03001oogoo00Yoo`03
001oogoo01]oo`03001oogoo019oo`03001oogoo019oo`03001oogoo08moo`8000aoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`80079oo`00@7oo00<007ooOol0
4Goo00<007ooOol04goo00<007ooOol06goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol0
6Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol0TGoo0P002goo0P002goo00<007ooOol0
2Goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol02Goo0P002Woo0P00M7oo0010Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00
Oomoo`0KOol00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0KOol00`00Oomoo`0BOol00`00
Oomoo`0BOol00`00Oomoo`2DOol2000;Ool00`00Oomoo`09Ool2000:Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool2000;Ool00`00Oomoo`09
Ool00`00Oomoo`1dOol0045oo`03001oogoo019oo`03001oogoo019oo`03001oogoo01]oo`03001o
ogoo00Uoo`03001oogoo00Uoo`03001oogoo01]oo`03001oogoo019oo`03001oogoo015oo`03001o
ogoo09Moo`8000Yoo`8000]oo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Uoo`03001o
ogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`8000Yoo`8007Moo`00@Woo
00<007ooOol04Goo00<007ooOol04Woo00<007ooOol06goo00<007ooOol02Goo00<007ooOol027oo
00<007ooOol06goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol0VWoo0P002Woo00<007oo
Ool02Goo00<007ooOol01goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo0P00NGoo0013Ool00`00Oomo
o`0AOol00`00Oomoo`0BOol00`00Oomoo`0KOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`0KOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`2LOol20009Ool2000:Ool00`00Oomo
o`07Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool20009Ool2001kOol004=oo`03001oogoo015oo`03001oogoo019oo`03
001oogoo01]oo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo01Yoo`03001oogoo019oo`03
001oogoo015oo`03001oogoo09moo`8000Uoo`8000Uoo`03001oogoo00Moo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`80
00Uoo`8007eoo`00A7oo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol06goo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol06goo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol0
XWoo0P002Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<0
07ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo0P00
Ogoo0015Ool00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0KOol00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`0KOol00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`2UOol20008
Ool20008Ool20007Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`06Ool20008Ool20008Ool20021Ool004Ioo`03001oogoo011oo`03001oogoo015o
o`03001oogoo01]oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo01Yoo`03001oogoo015o
o`03001oogoo015oo`03001oogoo0:Moo`8000Qoo`03001oogoo00Moo`03001oogoo00Eoo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Eoo`03001o
ogoo00Moo`03001oogoo00Ioo`8008=oo`00Agoo00<007ooOol047oo00<007ooOol047oo00<007oo
Ool06goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol06goo00<007ooOol04Goo00<007oo
Ool047oo00<007ooOol0ZWoo0P001goo0P0027oo00<007ooOol01Goo00<007ooOol01Woo00<007oo
Ool01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Goo00<007ooOol01Woo0P001goo
0P00QGoo0017Ool00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0KOol00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`0KOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`2]Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool2
0027Ool004Qoo`03001oogoo011oo`03001oogoo011oo`03001oogoo01]oo`03001oogoo00Ioo`03
001oogoo00Eoo`03001oogoo01]oo`03001oogoo015oo`03001oogoo00moo`03001oogoo0:moo`80
00Moo`8000Moo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03
001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`8000Ioo`8008Uoo`00BGoo00<007ooOol0
3goo00<007ooOol04Goo00<007ooOol06goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
6goo00<007ooOol047oo00<007ooOol03goo00<007ooOol0/Woo0P001goo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol017oo0P00Rgoo001:Ool00`00Oomoo`0?Ool00`00
Oomoo`0@Ool00`00Oomoo`0KOol00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`0JOol00`00
Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`2dOol20006Ool20006Ool00`00Oomoo`04Ool00`00
Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`04Ool20005Ool2002=Ool004Yoo`03001oogoo011oo`03001oogoo00moo`03001oogoo01]o
o`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo01]oo`03001oogoo011oo`03001oogoo00mo
o`03001oogoo0;Moo`8000Ioo`03001oogoo00Aoo`8000Eoo`03001oogoo00Aoo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00=oo`8000Ioo`03001oogoo00Aoo`03001o
ogoo08eoo`00Bgoo00<007ooOol03goo00<007ooOol047oo00<007ooOol06goo00<007ooOol017oo
00<007ooOol017oo00<007ooOol06goo00<007ooOol03goo00<007ooOol03goo00<007ooOol0^Woo
0P001Goo0P001Woo00<007ooOol00goo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo
00<007ooOol017oo00<007ooOol00goo00<007ooOol017oo0P001Goo0P00T7oo001<Ool00`00Oomo
o`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0KOol00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomo
o`0JOol00`00Oomoo`0@Ool00`00Oomoo`0>Ool00`00Oomoo`2mOol20005Ool20005Ool00`00Oomo
o`02Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool20005Ool2002BOol004eoo`03001oogoo00ioo`03001oogoo011oo`03
001oogoo01]oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo01]oo`03001oogoo00moo`03
001oogoo00moo`03001oogoo0;moo`8000Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
00Aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo00=oo`8009Aoo`00CWoo00<007ooOol03Woo00<007ooOol03goo00<007ooOol0
6goo00<007ooOol00goo00<007ooOol00goo00<007ooOol06Woo00<007ooOol03goo00<007ooOol0
3goo00<007ooOol0`Woo0P0017oo0P0017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
0goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo0P0017oo0P00
UWoo001>Ool00`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`0KOol00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`0KOol00`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`35Ool20004
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool2002HOol004mo
o`03001oogoo00ioo`03001oogoo00moo`03001oogoo01]oo`03001oogoo009oo`03001oogoo009o
o`03001oogoo01]oo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo0<Qoo`8000=oo`8000=o
o`80009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`04001o
ogooOol20003Ool20003Ool2002JOol0051oo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo
01]oo`03001oogoo009oo`03001oogoo009oo`03001oogoo01Yoo`03001oogoo00moo`03001oogoo
00ioo`03001oogoo0<Yoo`8000=oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0017oo00@007ooOomoo`8009aoo`00DGoo00<0
07ooOol03Goo00<007ooOol03goo00<007ooOol06goo00D007ooOomoo`0000=oo`03001oogoo01]o
o`03001oogoo00ioo`03001oogoo00ioo`03001oogoo0<eoo`80009oo`8000=oo`04001oogoo0004
Ool01@00Oomoogoo00000goo00<007ooOol00Woo00@007ooOol000=oo`80009oo`8009ioo`00DGoo
00<007ooOol03Woo00<007ooOol03Woo00<007ooOol06goo00D007ooOomoo`0000=oo`03001oogoo
01]oo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo0=1oo`80009oo`05001oogooOol00002
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`04001oogoo0003Ool00`00Oomoo`02002P
Ool0059oo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo01]oo`05001oogooOol00003Ool0
0`00Oomoo`0JOol00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`3COol200000goo00000002
Ool01000Oomoo`000Woo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`0200000goo
0000002ROol005=oo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo01]oo`04001oogoo0002
Ool00`00Oomoo`0KOol00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`3EOol01000Oomoo`00
0Woo00<007oo00000goo00@007ooOol0009oo`07001oogooOol007oo00000Woo00@007oo00000:Ao
o`00E7oo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol06goo00@007ooOol0009oo`03001o
ogoo01Yoo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo0=Moo`800007Ool00000Ool007oo
00000Woo00@007ooOol0009oo`07001oogoo001oo`00Ool01000YWoo001DOol00`00Oomoo`0=Ool0
0`00Oomoo`0=Ool00`00Oomoo`0KOol01P00Oomoo`00Ool001eoo`03001oogoo00eoo`03001oogoo
00eoo`03001oogoo0=Yoo`800003Ool0000000<00007Ool007ooOol007oo00000Woo1@0000=oo`00
Ool0Ygoo001EOol00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0KOol01@00Ool007oo0000
7Goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol0gGoo0P0000=oo`00Ool00P0000Moo`00
Ool007oo001oo`0200000goo001oo`02002YOol005Ioo`03001oogoo00aoo`03001oogoo00eoo`03
001oogoo01]oo`05001oo`00Ool0000LOol00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`3P
Ool500001Goo001oo`00Ool01`00Zgoo001GOol00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomo
o`0KOol3000MOol00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`3ROol400001Goo00000000
Ool01000[Goo001HOol00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0KOol3000LOol00`00
Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`3UOol9002_Ool005Qoo`03001oogoo00aoo`03001o
ogoo00aoo`03001oogoo01]oo`<001aoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo0>Qo
o`D00;5oo`00FGoo00<007ooOol037oo00<007ooOol037oo00<007ooOol06goo00<007ooOol06goo
00<007ooOol037oo00<007ooOol02goo00<007ooOol0jgoo00<007ooOol0/Goo001JOol00`00Oomo
o`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0KOol00`00Oomoo`0JOol00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`3[Ool00`00Oomoo`2aOol005]oo`03001oogoo00]oo`03001oogoo00aoo`03
001oogoo01Yoo`03001oogoo01Yoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo0>]oo`03
001oogoo0;9oo`00Fgoo00<007ooOol02goo00<007ooOol037oo00<007ooOol06Woo00<007ooOol0
6Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol0jgoo00<007ooOol0/goo001LOol00`00
Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomoo`0IOol00`00Oomoo`0;Ool00`00
Oomoo`0;Ool00`00Oomoo`3[Ool00`00Oomoo`2dOol005eoo`03001oogoo00]oo`03001oogoo00]o
o`03001oogoo01Uoo`03001oogoo01Uoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo0>Yo
o`03001oogoo0;Eoo`00GWoo00<007ooOol02Woo00<007ooOol02goo00<007ooOol06Goo00<007oo
Ool067oo00<007ooOol02goo00<007ooOol02goo00<007ooOol0jWoo00<007ooOol0]Woo001OOol0
0`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`0HOol00`00Oomoo`0;Ool0
0`00Oomoo`0:Ool00`00Oomoo`3ZOol00`00Oomoo`2gOol005moo`03001oogoo00Yoo`03001oogoo
00]oo`03001oogoo01Qoo`03001oogoo01Qoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
0>Yoo`03001oogoo0;Qoo`00H7oo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol067oo00<0
07ooOol05goo00<007ooOol02goo00<007ooOol02Goo00<007ooOol0jgoo00<007ooOol0^7oo001Q
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`0:
Ool00`00Oomoo`0:Ool00`00Oomoo`3ZOol00`00Oomoo`2iOol0069oo`03001oogoo00Uoo`03001o
ogoo00Yoo`03001oogoo01Moo`03001oogoo01Ioo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo0>Yoo`03001oogoo0;Yoo`00HWoo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol05goo
00<007ooOol05Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0jWoo00<007ooOol0^goo
001SOol00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomo
o`09Ool00`00Oomoo`09Ool00`00Oomoo`3ZOol00`00Oomoo`2lOol006Aoo`03001oogoo00Uoo`03
001oogoo00Uoo`03001oogoo00ioo`<000Eoo`03001oogoo01Eoo`03001oogoo00Yoo`03001oogoo
00Uoo`03001oogoo0>Uoo`03001oogoo009oo`<00;Qoo`00IGoo00<007ooOol027oo00<007ooOol0
2Woo00<007ooOol047oo00<007ooOol00Woo00<007ooOol05Goo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol0jGoo00<007ooOol017oo00<007ooOol0]goo001UOol00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool00`00Oomoo`0EOol00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`3ZOol00`00Oomoo`02Ool4002hOol006Ioo`03001oogoo00Uoo`03001o
ogoo00Qoo`03001oogoo00ioo`8000Eoo`03001oogoo01Aoo`03001oogoo00Uoo`03001oogoo00Qo
o`03001oogoo0>Yoo`03001oogoo00=oo`03001oo`000;Uoo`00Igoo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol03goo00<007ooOol00Woo00<007ooOol057oo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol0jGoo00<007ooOol017oo00<007oo0000^Goo001XOol00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`0<Ool30005Ool00`00Oomoo`0COol00`00Oomoo`09Ool00`00Oomo
o`08Ool00`00Oomoo`3YOol00`00Oomoo`06Ool2002iOol006Uoo`03001oogoo00Moo`03001oogoo
00Uoo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo
0>Uoo`03001oogoo0<9oo`00JGoo00<007ooOol027oo00<007ooOol027oo00<007ooOol04goo00<0
07ooOol04goo00<007ooOol027oo00<007ooOol01goo00<007ooOol0jGoo00<007ooOol0`goo001Z
Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`3XOol00`00Oomoo`34Ool006]oo`03001oogoo00Moo`03001o
ogoo00Qoo`03001oogoo019oo`03001oogoo019oo`03001oogoo00Moo`03001oogoo00Qoo`03001o
ogoo0>Qoo`03001oogoo0<Eoo`00K7oo00<007ooOol01goo00<007ooOol01goo00<007ooOol04Woo
00<007ooOol04Goo00<007ooOol027oo00<007ooOol01goo00<007ooOol0jGoo00<007ooOol0aGoo
001/Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`3YOol00`00Oomoo`36Ool006eoo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo015oo`03001oogoo015oo`03001oogoo00Moo`03001oogoo00Ioo`03
001oogoo0>Uoo`03001oogoo0<Moo`00KWoo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0
4Goo00<007ooOol047oo00<007ooOol01goo00<007ooOol01goo00<007ooOol0j7oo00<007ooOol0
b7oo001_Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00
Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`3XOol00`00Oomoo`39Ool0071oo`03001oogoo00Io
o`03001oogoo00Ioo`03001oogoo011oo`03001oogoo011oo`03001oogoo00Ioo`03001oogoo00Io
o`03001oogoo0>Qoo`03001oogoo0<Yoo`00L7oo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool047oo00<007ooOol03goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0j7oo00<007oo
Ool0bgoo001aOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`3WOol00`00Oomoo`3<Ool0079oo`03001oogoo
00Eoo`03001oogoo00Ioo`03001oogoo00moo`03001oogoo00ioo`03001oogoo00Ioo`03001oogoo
00Ioo`03001oogoo0>Qoo`03001oogoo0<aoo`00Lgoo00<007ooOol01Goo00<007ooOol01Woo00<0
07ooOol03Woo00<007ooOol03Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol0j7oo00<0
07ooOol0cGoo001cOol00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`0>Ool00`00Oomoo`0>
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`3XOol00`00Oomoo`3>Ool007Aoo`03001o
ogoo00Eoo`03001oogoo00Eoo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo00Ioo`03001o
ogoo00Eoo`03001oogoo0>Moo`03001oogoo0<moo`00MGoo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol03Goo00<007ooOol03Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0igoo
00<007ooOol0d7oo001fOol00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool00`00Oomo
o`0=Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`3WOol00`00Oomoo`3AOol007Ioo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo0>Moo`03001oogoo0=9oo`00Mgoo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol037oo00<007ooOol037oo00<007ooOol017oo00<007ooOol017oo00<007ooOol0
igoo00<007ooOol0dgoo001hOol00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00
Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`3WOol00`00Oomoo`3COol007Uo
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Ao
o`03001oogoo00Aoo`03001oogoo0>Moo`03001oogoo0=Aoo`00NWoo00<007ooOol00goo00<007oo
Ool017oo00<007ooOol02goo00<007ooOol02goo00<007ooOol017oo00<007ooOol00goo00<007oo
Ool0igoo00<007ooOol0eGoo001jOol00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`3WOol00`00Oomoo`3FOol0
07]oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00=oo`03001oogoo00Aoo`03001oogoo0>Ioo`03001oogoo0=Moo`00O7oo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol017oo00<007ooOol00goo00<0
07ooOol0iWoo00<007ooOol0f7oo001mOol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`3VOol00`00Oomoo`3I
Ool007eoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo00Uoo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo0>Moo`03001oogoo0=Uoo`00OWoo00<007ooOol00goo
00<007ooOol00goo00<007ooOol027oo00<007ooOol027oo00<007ooOol00goo00<007ooOol00goo
00<007ooOol0iWoo00<007ooOol0fWoo001oOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`3VOol00`00Oomo
o`3KOol0081oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo009oo`03001oogoo009oo`03001oogoo0>Ioo`03001oogoo0=aoo`00PGoo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol0iWoo00<007ooOol0gGoo0021Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`3UOol00`00
Oomoo`3NOol0089oo`03001oogoo009oo`05001oogooOol00009Ool00`00Oomoo`06Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`3UOol00`00Oomoo`3OOol008=oo`05001oogooOol00004
Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01@00Oomoogoo0000igoo00<007oo
Ool0h7oo0024Ool01@00Oomoogoo00000goo00<007ooOol01Woo00<007ooOol01Woo00D007ooOomo
o`0000=oo`03001oogoo0>Ioo`03001oogoo0>1oo`00Q7oo00D007ooOomoo`0000Aoo`03001oogoo
00Eoo`03001oogoo00Eoo`05001oogooOol00003Ool00`00Oomoo`3VOol00`00Oomoo`3QOol008Eo
o`05001oogooOol00003Ool00`00Oomoo`05Ool00`00Oomoo`05Ool01@00Oomoogoo00000goo00<0
07ooOol0iGoo00<007ooOol0hWoo0026Ool01@00Oomoogoo00000Woo00<007ooOol01Goo00<007oo
Ool017oo00D007ooOomoo`0000=oo`03001oogoo0>Eoo`03001oogoo0>=oo`00Qgoo00@007ooOol0
00=oo`03001oogoo00Aoo`03001oogoo00Aoo`05001oogooOol00002Ool00`00Oomoo`3UOol00`00
Oomoo`3TOol008Moo`05001oogooOol00002Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01000Oomo
o`000Woo00<007ooOol0iGoo00<007ooOol0iGoo0028Ool01000Oomoo`000goo00<007ooOol00goo
00<007ooOol00goo00D007ooOomoo`00009oo`03001oogoo0>Aoo`03001oogoo0>Ioo`00RGoo00@0
07ooOol0009oo`03001oogoo00=oo`03001oogoo00=oo`04001oogoo0002Ool00`00Oomoo`3TOol0
0`00Oomoo`3WOol008Yoo`06001oogoo001oo`001Goo00<007ooOol00goo00<007oo00000Woo00<0
07ooOol0iGoo00<007ooOol0igoo002;Ool00`00Ool00002Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool01P00Oomoo`00Ool00>Moo`03001oogoo0>Qoo`00Rgoo00H007ooOol007oo0004Ool00`00Oomo
o`02Ool00`00Ool00002Ool00`00Oomoo`3TOol00`00Oomoo`3YOol008aoo`03001oo`00009oo`05
001oogooOol00003Ool01P00Oomoo`00Ool00>Ioo`03001oogoo0>Yoo`00SGoo00D007oo001oo`00
00=oo`09001oogooOol007oo001oo`000>Ioo`03001oogoo0>]oo`00SWoo0P0000=oo`00Ool00Woo
00@007ooOomoo`800003Ool007oo0>Eoo`03001oogoo0>aoo`00SWoo00D007oo001oo`00009oo`08
001oogoo001oo`00Ool00>Eoo`03001oogoo0>eoo`00Sgoo00@007oo0000009oo`03001oogoo0080
0003Ool007oo0>Eoo`03001oogoo0>eoo`00T7oo0`000Woo00@007oo001oo`800>Ioo`03001oogoo
0>ioo`00TGoo0`0000=oo`00Ool00`00iWoo00<007ooOol0kgoo002BOol200000goo001oo`02003V
Ool00`00Oomoo`3`Ool0099oo`L00>Eoo`03001oogoo0?5oo`00Tgoo1@00iGoo00<007ooOol0lWoo
002DOol3003UOol00`00Oomoo`3cOol009Eoo`800>Aoo`03001oogoo0?Aoo`00Ugoo0P00hWoo00<0
07ooOol0m7oo002IOol2003OOol00`00Oomoo`3eOol009]oo`800=aoo`03001oogoo0?Ioo`00WGoo
0`00f7oo00<007ooOol0mgoo002POol2003EOol00`00Oomoo`3hOol00:9oo`800=9oo`03001oogoo
0?Uoo`00Y7oo0P00cgoo00<007ooOol0nWoo002VOol2003<Ool00`00Oomoo`3kOol00:Qoo`800<Yo
o`03001oogoo0?]oo`00ZWoo0P00agoo00<007ooOol0o7oo002/Ool20034Ool00`00Oomoo`3mOol0
0:ioo`800<5oo`03001oogoo0?ioo`00/7oo0`00_Goo00<007ooOol0ogoo002=Ool4000ROol2002j
Ool00`00Oomoo`3oOol1Ool008ioo`03001oogoo02Aoo`800;Moo`03001oogoo0?moo`9oo`00Sgoo
00<007ooOol09Goo0P00]Goo00<007ooOol0ogoo0Woo002@Ool00`00Oomoo`0VOol2002bOol00`00
Oomoo`3oOol3Ool008eoo`04001oogoo000ZOol2002_Ool00`00Oomoo`3oOol4Ool008ioo`8002eo
o`800:aoo`03001oogoo0?moo`Eoo`00_goo0P00ZGoo00<007ooOol0ogoo1Woo0031Ool3002UOol0
0`00Oomoo`3oOol7Ool00<Aoo`800:9oo`03001oogoo0?moo`Qoo`00aWoo0P00Wgoo00<007ooOol0
ogoo2Goo0038Ool2002MOol00`00Oomoo`3oOol9Ool00<Yoo`8009Yoo`03001oogoo0?moo`Yoo`00
c7oo0P00Ugoo00<007ooOol0ogoo2goo003>Ool2002DOol00`00Oomoo`3oOol<Ool00=1oo`80095o
o`03001oogoo0?moo`eoo`00dWoo0P00SWoo00<007ooOol0ogoo3Woo003DOol3002:Ool00`00Oomo
o`3oOol?Ool00=Moo`8008Moo`03001oogoo0?mooa1oo`00fGoo0P00QGoo00<007ooOol0ogoo47oo
003KOol20022Ool00`00Oomoo`3oOolAOol00=eoo`8007moo`03001oogoo0?mooa9oo`00ggoo0P00
O7oo00<007ooOol0ogoo4goo003QOol2001iOol00`00Oomoo`3oOolDOol00>=oo`8007Ioo`03001o
ogoo0?mooaEoo`00iGoo0`00LWoo00<007ooOol0ogoo5Woo003XOol2001_Ool00`00Oomoo`3oOolG
Ool00>Yoo`8006eoo`03001oogoo0?mooaMoo`00k7oo0P00JWoo00<007ooOol0ogoo67oo003^Ool2
001WOol00`00Oomoo`3oOolIOol00?1oo`8006Aoo`03001oogoo0?mooaYoo`00lWoo0P00HGoo00<0
07ooOol0ogoo6goo003dOol2001NOol00`00Oomoo`3oOolLOol00?Ioo`8005]oo`03001oogoo0?mo
oaeoo`00n7oo0`00F7oo00<007ooOol0ogoo7Goo003kOol2001EOol00`00Oomoo`3oOolNOol00?eo
o`80059oo`03001oogoo0?mooamoo`00ogoo0P00Cgoo00<007ooOol0ogoo87oo003oOol2Ool2001<
Ool00`00Oomoo`3oOolQOol00?moo`Aoo`8004Uoo`03001oogoo0?moob9oo`00ogoo1Woo0P00AWoo
00<007ooOol0ogoo8goo003oOol8Ool20013Ool00`00Oomoo`3oOolTOol00?moo`Yoo`80045oo`03
001oogoo0?moobAoo`00ogoo37oo0`00?Goo00<007ooOol0ogoo9Goo003oOol?Ool2000jOol00`00
Oomoo`3oOolVOol00?mooa5oo`8003Moo`03001oogoo0?moobMoo`00ogoo4goo0P00=7oo00<007oo
Ool0ogoo:7oo003oOolEOol2000aOol00`00Oomoo`3oOolYOol00?mooaMoo`8002ioo`03001oogoo
0?moobYoo`00ogoo6Goo0P00:goo00<007ooOol0ogoo:goo003oOolKOol2000YOol00`00Oomoo`3o
Ool[Ool00?mooaeoo`<002Eoo`03001oogoo0?moobaoo`00ogoo87oo0P008Woo00<007ooOol0ogoo
;Goo003oOolROol2000OOol00`00Oomoo`3oOol^Ool00?moobAoo`8001aoo`03001oogoo0?moobmo
o`00ogoo9Woo0P006Goo00<007ooOol0ogoo<7oo003oOolXOol2000FOol00`00Oomoo`3oOolaOol0
0?moobYoo`8001Aoo`03001oogoo0?mooc5oo`00ogoo;7oo0P004Goo00<007ooOol0ogoo<Woo003o
Ool^Ool2000>Ool00`00Oomoo`3oOolcOol00?mooc1oo`<000Yoo`03001oogoo0?moocAoo`00ogoo
<goo0P001goo00<007ooOol0ogoo=Goo003oOoleOol20004Ool00`00Oomoo`3oOolfOol00?moocMo
o`800003Ool007oo0?moocQoo`00ogoo>Goo00<007ooOol0ogoo>7oo003oOoooOomdOol00?mooomo
ogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol0
0?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00ogooogooM7oo003oOooo
OomdOol00?mooc5oo`<00?mood1oo`00ogoo<Woo00<007ooOol0ogoo?goo003oOolbOol00`00Oomo
o`3oOoloOol00?mooc9oo`03001oogoo0?moocmoo`00ogoo<Woo00<007ooOol0ogoo?goo003oOola
Ool2003oOom1Ool00?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00ogoo
ogooM7oo003oOoooOomdOol00?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomoogAo
o`00ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol00?mo
oomoogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00ogooogooM7oo003oOoooOomd
Ool00?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00ogooogooM7oo003o
OoooOomdOol00?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00ogooogoo
M7oo003oOoooOomdOol00?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00
ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomo
ogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol0
0?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00ogooogooM7oo003oOooo
OomdOol00?mooomoogAoo`00ogooogooM7oo003oOoooOomdOol00?mooomoogAoo`00\
\>"],
  ImageRangeCache->{{{0, 625}, {385.688, 0}} -> {-1.01593, -1.00003, 
  0.033651, 0.0129639}}]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(DeletedMutations[
              g, {T\_0, 
                T\_1}]\), \(lists\ those\ mutations\ that\ should\ be\ \
deleted\ because\ they\ occurred\ in\ time\ interval\ \(\({T\_0, 
                  T\_1}\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"DeletedMutations"],

Cell["\<\
RandomBottleneckedGenealogy[] works by calling RandomGenealogy[], \
and then deleting mutations in the forbidden interval:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(g = RandomGenealogy[Array[l\_#&, {20}], MutationRate \[Rule] 10]\ 
    \)\)], "Input",
  CellLabel->"In[687]:="],

Cell[BoxData[
    \(Node[
      20, {1.96152280702956982`, {}}, {
        Node[19, {1.96152280702956982`, {}}, {
            Node[17, {0.748261766844325748`, {1, 2, 3, 4}}, {
                Node[2, {0.0127381307775069285`, {1, 2, 3, 4, 10}}, {
                    Node[l\_10, {0, {1, 2, 3, 4, 10}}, {}], 
                    Node[l\_17, {0, {1, 2, 3, 4, 10}}, {}]}], 
                Node[16, {0.576121873725828326`, {1, 2, 3, 4}}, {
                    Node[5, {
                        0.0240621793270805062`, {1, 2, 3, 4, 17, 18, 19, 20, 
                          21}}, {
                        Node[l\_11, {
                            0, {1, 2, 3, 4, 17, 18, 19, 20, 21}}, {}], 
                        Node[l\_20, {
                            0, {1, 2, 3, 4, 17, 18, 19, 20, 21}}, {}]}], 
                    Node[15, {0.251980544188845279`, {1, 2, 3, 4}}, {
                        Node[3, {
                            0.0150649435273087277`, {1, 2, 3, 4, 25, 26, 
                              27}}, {
                            Node[l\_3, {0, {1, 2, 3, 4, 25, 26, 27}}, {}], 
                            Node[l\_16, {0, {1, 2, 3, 4, 25, 26, 27}}, {}]}], 
                        Node[10, {0.104760345617333117`, {1, 2, 3, 4}}, {
                            Node[l\_7, {0, {1, 2, 3, 4, 29}}, {}], 
                            Node[9, {0.0702427997729411224`, {1, 2, 3, 4}}, {
                                Node[l\_2, {0, {1, 2, 3, 4}}, {}], 
                                Node[l\_5, {0, {1, 2, 3, 4}}, {}]}]}]}]}]}], 
            Node[18, {0.821056166134617093`, {5, 6, 7, 8, 9}}, {
                Node[7, {
                    0.0310279374205783886`, {5, 6, 7, 8, 9, 11, 12, 13, 
                      14}}, {Node[
                      l\_15, {0, {5, 6, 7, 8, 9, 11, 12, 13, 14}}, {}], 
                    Node[6, {
                        0.0292260365527908483`, {5, 6, 7, 8, 9, 11, 12, 13, 
                          14}}, {
                        Node[l\_4, {0, {5, 6, 7, 8, 9, 11, 12, 13, 14}}, {}], 
                        Node[l\_6, {
                            0, {5, 6, 7, 8, 9, 11, 12, 13, 14}}, {}]}]}], 
                Node[14, {0.236220311188898346`, {5, 6, 7, 8, 9, 15, 16}}, {
                    Node[l\_18, {
                        0, {5, 6, 7, 8, 9, 15, 16, 22, 23, 24}}, {}], 
                    Node[13, {
                        0.23267370583658522`, {5, 6, 7, 8, 9, 15, 16}}, {
                        Node[1, {
                            0.0126245126703950605`, {5, 6, 7, 8, 9, 15, 16, 
                              28}}, {
                            Node[l\_8, {0, {5, 6, 7, 8, 9, 15, 16, 28}}, {}], 
                            Node[l\_14, {
                                0, {5, 6, 7, 8, 9, 15, 16, 28}}, {}]}], 
                        Node[12, {
                            0.172294113954580829`, {5, 6, 7, 8, 9, 15, 16}}, {
                            Node[11, {
                                0.148492704081585902`, {5, 6, 7, 8, 9, 15, 
                                  16}}, {
                                Node[l\_1, {0, {5, 6, 7, 8, 9, 15, 16}}, {}], 
                                Node[l\_13, {
                                    0, {5, 6, 7, 8, 9, 15, 16, 30, 31, 32, 
                                      33}}, {}]}], 
                            Node[8, {
                                0.0331016613333823706`, {5, 6, 7, 8, 9, 15, 
                                  16}}, {
                                Node[l\_12, {
                                    0, {5, 6, 7, 8, 9, 15, 16}}, {}], 
                                Node[4, {
                                    0.0176901503372407642`, {5, 6, 7, 8, 9, 
                                      15, 16}}, {
                                    Node[l\_9, {
                                        0, {5, 6, 7, 8, 9, 15, 16}}, {}], 
                                    Node[l\_19, {
                                        0, {5, 6, 7, 8, 9, 15, 
                                        16}}, {}]}]}]}]}]}]}]}]}]\)], "Output",\

  CellLabel->"Out[687]="]
}, Closed]],

Cell["These are the mutations to be deleted:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\t\ \ \ dl = DeletedMutations[g, {0.1, 1.1}]\)\)], "Input",
  CellLabel->"In[688]:="],

Cell[BoxData[
    \({2, 4, 5, 6, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 23, 24, 
      26, 27, 28, 30, 33}\)], "Output",
  CellLabel->"Out[688]="]
}, Closed]],

Cell[TextData[{
  "This deletes them from ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\t\t
    TransformInformation[g, 
      ReplacePart[#2, 
          Complement[#2\[LeftDoubleBracket]2\[RightDoubleBracket], dl], 2]&]
      \)\)], "Input",
  CellLabel->"In[692]:="],

Cell[BoxData[
    \(Node[
      20, {1.96152280702956982`, {}}, {
        Node[19, {1.96152280702956982`, {}}, {
            Node[17, {0.748261766844325748`, {1, 3}}, {
                Node[2, {0.0127381307775069285`, {1, 3}}, {
                    Node[l\_10, {0, {1, 3}}, {}], 
                    Node[l\_17, {0, {1, 3}}, {}]}], 
                Node[16, {0.576121873725828326`, {1, 3}}, {
                    Node[5, {0.0240621793270805062`, {1, 3}}, {
                        Node[l\_11, {0, {1, 3}}, {}], 
                        Node[l\_20, {0, {1, 3}}, {}]}], 
                    Node[15, {0.251980544188845279`, {1, 3}}, {
                        Node[3, {0.0150649435273087277`, {1, 3, 25}}, {
                            Node[l\_3, {0, {1, 3, 25}}, {}], 
                            Node[l\_16, {0, {1, 3, 25}}, {}]}], 
                        Node[10, {0.104760345617333117`, {1, 3}}, {
                            Node[l\_7, {0, {1, 3, 29}}, {}], 
                            Node[9, {0.0702427997729411224`, {1, 3}}, {
                                Node[l\_2, {0, {1, 3}}, {}], 
                                Node[l\_5, {0, {1, 3}}, {}]}]}]}]}]}], 
            Node[18, {0.821056166134617093`, {7, 8, 9}}, {
                Node[7, {0.0310279374205783886`, {7, 8, 9}}, {
                    Node[l\_15, {0, {7, 8, 9}}, {}], 
                    Node[6, {0.0292260365527908483`, {7, 8, 9}}, {
                        Node[l\_4, {0, {7, 8, 9}}, {}], 
                        Node[l\_6, {0, {7, 8, 9}}, {}]}]}], 
                Node[14, {0.236220311188898346`, {7, 8, 9}}, {
                    Node[l\_18, {0, {7, 8, 9, 22}}, {}], 
                    Node[13, {0.23267370583658522`, {7, 8, 9}}, {
                        Node[1, {0.0126245126703950605`, {7, 8, 9}}, {
                            Node[l\_8, {0, {7, 8, 9}}, {}], 
                            Node[l\_14, {0, {7, 8, 9}}, {}]}], 
                        Node[12, {0.172294113954580829`, {7, 8, 9}}, {
                            Node[11, {0.148492704081585902`, {7, 8, 9}}, {
                                Node[l\_1, {0, {7, 8, 9}}, {}], 
                                Node[l\_13, {0, {7, 8, 9, 31, 32}}, {}]}], 
                            Node[8, {0.0331016613333823706`, {7, 8, 9}}, {
                                Node[l\_12, {0, {7, 8, 9}}, {}], 
                                Node[4, {0.0176901503372407642`, {7, 8, 9}}, {
                                    Node[l\_9, {0, {7, 8, 9}}, {}], 
                                    Node[l\_19, {
                                        0, {7, 8, 9}}, {}]}]}]}]}]}]}]}]}]
      \)], "Output",
  CellLabel->"Out[692]="]
}, Closed]],

Cell["Those mutations have indeed been deleted:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Intersection[Mutations[%], dl]\)], "Input",
  CellLabel->"In[693]:="],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[693]="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 653},
WindowMargins->{{Automatic, 2}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00`0001804P000000_02@?o/onh3109BI085:0?l0@00005X0FP000003[0;@001
0000I00100000@0000000BL?0040000000000000000000000000000000000?nL
ojH?50^J00P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "RandomBottleneckedGenealogy"->{
    Cell[1790, 53, 508, 11, 50, "DefinitionBox",
      CellTags->"RandomBottleneckedGenealogy"]},
  "DeletedMutations"->{
    Cell[133403, 3218, 364, 8, 46, "DefinitionBox",
      CellTags->"DeletedMutations"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"RandomBottleneckedGenealogy", 142683, 3428},
  {"DeletedMutations", 142805, 3431}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 48, 0, 36, "SubsectionIcon"],
Cell[1790, 53, 508, 11, 50, "DefinitionBox",
  CellTags->"RandomBottleneckedGenealogy"],
Cell[2301, 66, 692, 19, 80, "Text"],
Cell[2996, 87, 317, 10, 36, "Text"],

Cell[CellGroupData[{
Cell[3338, 101, 137, 4, 27, "Input"],
Cell[3478, 107, 3846, 66, 275, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[7361, 178, 88, 2, 23, "Input"],
Cell[7452, 182, 56934, 1417, 317, 21657, 976, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[64401, 1602, 295, 5, 46, "Text"],

Cell[CellGroupData[{
Cell[64721, 1611, 676, 13, 147, "Input"],
Cell[65400, 1626, 2698, 67, 198, "Output"]
}, Closed]],
Cell[68113, 1696, 230, 4, 32, "Text"],
Cell[68346, 1702, 221, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[68592, 1710, 101, 2, 27, "Input"],
Cell[68696, 1714, 2131, 45, 334, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[70864, 1764, 112, 2, 23, "Input"],
Cell[70979, 1768, 1297, 23, 155, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[72313, 1796, 89, 2, 23, "Input"],
Cell[72405, 1800, 60983, 1415, 393, 20629, 912, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[133403, 3218, 364, 8, 46, "DefinitionBox",
  CellTags->"DeletedMutations"],
Cell[133770, 3228, 146, 3, 36, "Text"],

Cell[CellGroupData[{
Cell[133941, 3235, 134, 3, 27, "Input"],
Cell[134078, 3240, 4082, 72, 290, "Output"]
}, Closed]],
Cell[138175, 3315, 61, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[138261, 3319, 107, 2, 27, "Input"],
Cell[138371, 3323, 155, 3, 20, "Output"]
}, Closed]],
Cell[138541, 3329, 117, 5, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[138683, 3338, 203, 6, 42, "Input"],
Cell[138889, 3346, 2659, 44, 215, "Output"]
}, Closed]],
Cell[141563, 3393, 64, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[141652, 3397, 89, 2, 27, "Input"],
Cell[141744, 3401, 62, 2, 20, "Output"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

