(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    116861,       3863]*)
(*NotebookOutlinePosition[    118216,       3905]*)
(*  CellTagsIndexPosition[    118068,       3897]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["The structure of genealogies", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"Node", "[", 
              RowBox[{"i", ",", 
                RowBox[{"{", 
                  StyleBox["info",
                    FontSlant->"Italic"], "}"}], 
                ",", \({Node[j, \[Ellipsis]], Node[k, \[Ellipsis]]}\)}], 
              "]"}], 
            RowBox[{
              RowBox[{
                
                RowBox[{\(denotes\ a\ node\ in\ a\ branching\ tree . \ \ This\
\ node\ is\ labelled\ by\ i\), ";", " ", 
                  RowBox[{
                  "information", " ", "on", " ", "it", " ", "is", " ", 
                    "given", " ", "by", " ", "the", " ", "list", " ", 
                    RowBox[{
                      RowBox[{"{", 
                        StyleBox["info",
                          FontSlant->"Italic"], "}"}], ".", "  ", "The"}], 
                    " ", "node", " ", "has", " ", "descendant", " ", "nodes", 
                    " ", "labelled", " ", "j"}]}], ",", " ", \(\(k\)\(.\)\)}],
               " "}]},
          {
            RowBox[{"Node", "[", 
              RowBox[{"i", ",", 
                RowBox[{"{", 
                  StyleBox["info",
                    FontSlant->"Italic"], "}"}], ",", \({}\)}], "]"}], 
            RowBox[{\(denotes\ a\ terminal\ node\), ",", " ", 
              RowBox[{"or", " ", 
                RowBox[{
                  StyleBox["leaf",
                    FontSlant->"Italic"], "."}]}]}]}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"Node"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(<< Genealogies`Genealogies`; \)], "Input",
  CellLabel->"In[679]:="],

Cell[TextData[{
  "\tA rooted genealogy is described by a nested set of nodes.  Each node is \
labelled, and may also contain a list of information.  The final element of \
Node[] is a list of descendant nodes, with the same structure.  For a \
terminal node (or ",
  StyleBox["leaf",
    FontSlant->"Italic"],
  "), this set would be empty.  For a bifurcating tree, this set would \
contain two Node[] structures.   For example, suppose a set of objects, \
labelled ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b, c, d, e, f, g, h}\)]],
  ", are related as below:"
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.111111 0.111111 0.103006 0.103006 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.16667 .20601 m
.11111 .10301 L
s
.16667 .20601 m
.22222 .10301 L
s
.38889 .20601 m
.33333 .10301 L
s
.38889 .20601 m
.44444 .10301 L
s
.66667 .20601 m
.55556 .10301 L
s
.66667 .20601 m
.66667 .10301 L
s
.66667 .20601 m
.77778 .10301 L
s
.72222 .30902 m
.66667 .20601 L
s
.72222 .30902 m
.88889 .10301 L
s
.61111 .41202 m
.38889 .20601 L
s
.61111 .41202 m
.72222 .30902 L
s
.5 .51503 m
.16667 .20601 L
s
.5 .51503 m
.61111 .41202 L
s
gsave
.14444 .22661 -79.7812 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
90.562500 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.36667 .22661 -79.7812 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
90.562500 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.64444 .22661 -87.5625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
90.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
100.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(g) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
106.125000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.7 .32962 -95.3438 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
90.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
100.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(g) show
106.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
115.687500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(h) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
121.687500 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.58889 .43262 -110.906 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
90.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
100.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
106.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
115.687500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
121.687500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
131.250000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(g) show
137.250000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
146.812500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(h) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
152.812500 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.47778 .53563 -126.469 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
90.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
100.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
106.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
115.687500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
121.687500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
131.250000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
137.250000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
146.812500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
152.812500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
162.375000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(g) show
168.375000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
177.937500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(h) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
183.937500 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.11111 .0824 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.22222 .0824 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.33333 .0824 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.44444 .0824 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.55556 .0824 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.66667 .0824 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.77778 .0824 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(g) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.88889 .0824 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(h) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[75]:=",
  ImageSize->{482, 297.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007R0001:A000`40O003h00Oogoohgoo003oOooS
Ool00?moon=oo`00ogoohgoo003oOooSOol00?moon=oo`00ogoohgoo003oOooSOol00?moon=oo`00
ogoohgoo003oOooSOol00?moon=oo`00ogoohgoo003oOooSOol00?moon=oo`00ogoohgoo003oOooS
Ool00?moon=oo`00ogoohgoo003oOooSOol00?moon=oo`00ogoohgoo003oOooSOol00?moon=oo`00
ogoohgoo003oOooSOol00?moon=oo`00ogoohgoo003oOooSOol00?moon=oo`00ogoohgoo003oOooS
Ool00?moon=oo`00ogoohgoo003oOooSOol0031oo`03001oogoo00Ioo`03001oogoo02Yoo`03001o
ogoo00Ioo`03001oogoo02Uoo`03001oogoo00Ioo`03001oogoo02Uoo`03001oogoo00Ioo`03001o
ogoo02Yoo`03001oogoo00Ioo`03001oogoo02Uoo`03001oogoo00Ioo`03001oogoo02Uoo`03001o
ogoo00<000=oo`03001oogoo02Yoo`03001oogoo00Ioo`03001oogoo031oo`00;goo00<007ooOol0
27oo00<007ooOol0:7oo00<007ooOol027oo00<007ooOol09goo00<007ooOol027oo00<007ooOol0
9goo00<007ooOol027oo00<007ooOol0:7oo00<007ooOol027oo00<007ooOol09goo00<007ooOol0
27oo00<007ooOol09goo00<007ooOol017oo00D007ooOomoo`0002Yoo`03001oogoo00Qoo`03001o
ogoo02moo`00;goo00@007ooOomoo`@000=oo`03001oogoo02Qoo`03001oogoo00@000Aoo`03001o
ogoo02Moo`04001oogooOol30004Ool00`00Oomoo`0WOol01000Oomoogoo10000goo00<007ooOol0
:7oo00@007ooOomoo`<000Aoo`03001oogoo02Moo`03001oogoo00D000=oo`03001oogoo02Moo`04
001oogooOol40003Ool00`00Oomoo`0XOol00`00Oomoo`060002Ool00`00Oomoo`0_Ool002moo`04
001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`0XOol01@00Oomoogoo00000Woo00D007ooOomo
o`0002Uoo`04001oogoo0003Ool01@00Oomoogoo0000:Goo00@007ooOol0009oo`03001oogoo009o
o`03001oogoo02Qoo`04001oogoo0007Ool00`00Oomoo`0WOol00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`0WOol01000Oomoo`000goo00D007ooOomoo`0002Yoo`05001oogooOol00002Ool0
1@00Oomoogoo0000<Goo000^Ool00`00Oomoo`02Ool30005Ool00`00Oomoo`0VOol00`00Oomoo`02
Ool01000Oomoo`0017oo00<007ooOol09Goo00D007ooOomoo`0000Qoo`03001oogoo02Eoo`05001o
ogooOol00002Ool00`00Oomoo`03Ool00`00Oomoo`0VOol01000Oomoogoo1@0017oo00<007ooOol0
9Goo00<007ooOol00goo00<007ooOol017oo00<007ooOol09Goo00D007ooOomoo`0000=oo`03001o
ogoo009oo`03001oogoo02Ioo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`0^Ool002mo
o`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`0XOol01@00Oomoogoo00000Woo00D007oo
Oomoo`0002Uoo`04001oogoo0003Ool01@00Oomoogoo0000:Goo00@007ooOol0009oo`03001oogoo
009oo`03001oogoo02Qoo`04001oogoo0003Ool01@00Oomoogoo0000:Goo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol09goo00@007ooOol000=oo`05001oogooOol0000ZOol01@00Oomoogoo
00000Woo00D007ooOomoo`00035oo`00;goo00@007ooOomoo`8000Eoo`03001oogoo02Qoo`04001o
ogooOol30004Ool00`00Oomoo`0WOol01000Oomoogoo0`0017oo00<007ooOol09goo00@007ooOomo
o`<000Aoo`03001oogoo02Qoo`04001oogooOol30004Ool00`00Oomoo`0WOol01000Oomoogoo1000
0goo00<007ooOol09goo00@007ooOomoo`D0009oo`03001oogoo02Qoo`04001oogooOol30004Ool0
0`00Oomoo`0_Ool0031oo`03001oogoo00Ioo`03001oogoo02Yoo`04001oogoo0005Ool00`00Oomo
o`0YOol00`00Oomoo`06Ool00`00Oomoo`0YOol00`00Oomoo`02Ool01@00Oomoogoo0000;7oo00<0
07ooOol01Woo00<007ooOol0:Goo00D007ooOomoo`0000Aoo`03001oogoo02Uoo`03001oogoo00Io
o`03001oogoo02Yoo`04001oogoo0005Ool00`00Oomoo`0`Ool006Qoo`8006Yoo`8006Yoo`8006Io
o`8003Qoo`00ogoohgoo003oOooSOol00?moon=oo`00ogoohgoo003oOooSOol003Eoo`03001oogoo
03=oo`03001oogoo039oo`03001oogoo039oo`03001oogoo03=oo`8003=oo`03001oogoo035oo`80
03Eoo`03001oogoo03Aoo`00=Goo00<007ooOol0<goo00<007ooOol0<Woo00<007ooOol0<Woo00<0
07ooOol0=Goo00<007ooOol0<7oo00<007ooOol0<7oo00<007ooOol0=Goo00<007ooOol0=7oo000f
Ool00`00Oomoo`0aOol00`00Oomoo`0dOol00`00Oomoo`0`Ool00`00Oomoo`0gOol00`00Oomoo`0_
Ool00`00Oomoo`0_Ool00`00Oomoo`0eOol00`00Oomoo`0eOol003Ioo`03001oogoo035oo`03001o
ogoo03Aoo`03001oogoo031oo`03001oogoo03Qoo`03001oogoo02ioo`03001oogoo02ioo`03001o
ogoo03Eoo`03001oogoo03Ioo`00=goo00<007ooOol0;goo00<007ooOol0=Woo00<007ooOol0;Woo
00<007ooOol0>Woo00<007ooOol0;Goo00<007ooOol0;Goo00<007ooOol0=Goo00<007ooOol0=goo
000gOol00`00Oomoo`0_Ool00`00Oomoo`0fOol00`00Oomoo`0^Ool00`00Oomoo`0kOol00`00Oomo
o`0/Ool00`00Oomoo`0/Ool00`00Oomoo`0eOol00`00Oomoo`0hOol003Qoo`03001oogoo02eoo`03
001oogoo03Qoo`03001oogoo02aoo`03001oogoo03eoo`03001oogoo02]oo`03001oogoo02]oo`03
001oogoo03Ioo`03001oogoo03Qoo`00>Goo00<007ooOol0:goo00<007ooOol0>Woo00<007ooOol0
:goo00<007ooOol0?Woo00<007ooOol0:Woo00<007ooOol0:Woo00<007ooOol0=Woo00<007ooOol0
>Goo000iOol00`00Oomoo`0[Ool00`00Oomoo`0jOol00`00Oomoo`0ZOol00`00Oomoo`10Ool00`00
Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0fOol00`00Oomoo`0jOol003Yoo`03001oogoo02Uo
o`03001oogoo03aoo`03001oogoo02Uoo`03001oogoo045oo`03001oogoo02Qoo`03001oogoo02Qo
o`03001oogoo03Ioo`03001oogoo03]oo`00>Woo00<007ooOol0:Goo00<007ooOol0?7oo00<007oo
Ool0:7oo00<007ooOol0@goo00<007ooOol09goo00<007ooOol09goo00<007ooOol0=Woo00<007oo
Ool0?7oo000kOol00`00Oomoo`0WOol00`00Oomoo`0nOol00`00Oomoo`0WOol00`00Oomoo`14Ool0
0`00Oomoo`0VOol00`00Oomoo`0VOol00`00Oomoo`0gOol00`00Oomoo`0lOol003]oo`03001oogoo
02Moo`03001oogoo03ioo`03001oogoo02Ioo`03001oogoo04Ioo`03001oogoo02Eoo`03001oogoo
02Eoo`03001oogoo03Moo`03001oogoo03eoo`00?7oo00<007ooOol09Goo00<007ooOol0@7oo00<0
07ooOol097oo00<007ooOol0B7oo00<007ooOol097oo00<007ooOol097oo00<007ooOol0=goo00<0
07ooOol0?Woo000lOol00`00Oomoo`0UOol00`00Oomoo`10Ool00`00Oomoo`0TOol00`00Oomoo`19
Ool00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomoo`0gOol00`00Oomoo`0oOol003eoo`03001o
ogoo02=oo`03001oogoo049oo`03001oogoo029oo`03001oogoo04]oo`03001oogoo029oo`03001o
ogoo029oo`03001oogoo03Moo`03001oogoo041oo`00?Goo00<007ooOol08goo00<007ooOol0@Woo
00<007ooOol08Woo00<007ooOol0C7oo00<007ooOol08Goo00<007ooOol08Goo00<007ooOol0=goo
00<007ooOol0@Goo000nOol00`00Oomoo`0QOol00`00Oomoo`14Ool00`00Oomoo`0POol00`00Oomo
o`1>Ool2000QOol00`00Oomoo`0OOol2000jOol00`00Oomoo`11Ool003ioo`03001oogoo025oo`03
001oogoo04Aoo`03001oogoo021oo`03001oogoo051oo`03001oogoo01ioo`03001oogoo01ioo`03
001oogoo03Uoo`03001oogoo049oo`00?goo00<007ooOol07goo00<007ooOol0AWoo00<007ooOol0
7Woo00<007ooOol0DWoo00<007ooOol07Goo00<007ooOol07Goo00<007ooOol0>Goo00<007ooOol0
@goo0010Ool00`00Oomoo`0MOol00`00Oomoo`18Ool00`00Oomoo`0MOol00`00Oomoo`1COol00`00
Oomoo`0LOol00`00Oomoo`0LOol00`00Oomoo`0iOol00`00Oomoo`14Ool0041oo`03001oogoo01eo
o`03001oogoo04Qoo`03001oogoo01aoo`03001oogoo05Eoo`03001oogoo01]oo`03001oogoo01]o
o`03001oogoo03Uoo`03001oogoo04Eoo`00@Goo00<007ooOol06goo00<007ooOol0BWoo00<007oo
Ool06goo00<007ooOol0EWoo00<007ooOol06Woo00<007ooOol06Woo00<007ooOol0>Woo00<007oo
Ool0AGoo0011Ool00`00Oomoo`0KOol00`00Oomoo`1:Ool00`00Oomoo`0JOol00`00Oomoo`1HOol0
0`00Oomoo`0IOol00`00Oomoo`0IOol00`00Oomoo`0jOol00`00Oomoo`16Ool0049oo`03001oogoo
01Uoo`03001oogoo04aoo`03001oogoo01Uoo`03001oogoo05Uoo`03001oogoo01Qoo`03001oogoo
01Qoo`03001oogoo03Yoo`03001oogoo04Moo`00@Woo00<007ooOol06Goo00<007ooOol0C7oo00<0
07ooOol067oo00<007ooOol0Fgoo00<007ooOol05goo00<007ooOol05goo00<007ooOol0>Woo00<0
07ooOol0B7oo0013Ool00`00Oomoo`0GOol00`00Oomoo`1>Ool00`00Oomoo`0GOol00`00Oomoo`1L
Ool00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0jOol00`00Oomoo`19Ool004=oo`03001o
ogoo01Moo`03001oogoo04ioo`03001oogoo01Ioo`03001oogoo05ioo`03001oogoo01Eoo`03001o
ogoo01Eoo`03001oogoo03]oo`03001oogoo04Uoo`00A7oo00<007ooOol05Goo00<007ooOol0D7oo
00<007ooOol05Goo00<007ooOol0Ggoo00<007ooOol057oo00<007ooOol057oo00<007ooOol0>goo
00<007ooOol0BWoo0014Ool00`00Oomoo`0EOol00`00Oomoo`1@Ool00`00Oomoo`0DOol00`00Oomo
o`1QOol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0kOol00`00Oomoo`1;Ool004Eoo`03
001oogoo01=oo`03001oogoo059oo`03001oogoo01=oo`03001oogoo069oo`03001oogoo019oo`03
001oogoo019oo`03001oogoo03]oo`03001oogoo04aoo`00AGoo00<007ooOol04goo00<007ooOol0
DWoo00<007ooOol04Woo00<007ooOol0I7oo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol0
>goo00<007ooOol0CGoo0016Ool00`00Oomoo`0AOol00`00Oomoo`1DOol00`00Oomoo`0AOol00`00
Oomoo`1UOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0lOol00`00Oomoo`1=Ool004Mo
o`03001oogoo00moo`03001oogoo05Ioo`03001oogoo00moo`03001oogoo06Moo`80011oo`03001o
ogoo00ioo`8003ioo`03001oogoo04ioo`00Agoo00<007ooOol03goo00<007ooOol0EWoo00<007oo
Ool03goo00<007ooOol0JGoo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol0?Goo00<007oo
Ool0Cgoo0018Ool00`00Oomoo`0=Ool00`00Oomoo`1HOol00`00Oomoo`0=Ool00`00Oomoo`1[Ool0
0`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0mOol00`00Oomoo`1@Ool004Qoo`03001oogoo
00eoo`03001oogoo05Qoo`03001oogoo00eoo`03001oogoo06aoo`03001oogoo00]oo`03001oogoo
00]oo`03001oogoo03eoo`03001oogoo055oo`00BGoo00<007ooOol02goo00<007ooOol0FWoo00<0
07ooOol02goo00<007ooOol0KWoo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol0?Woo00<0
07ooOol0DGoo0019Ool00`00Oomoo`0;Ool00`00Oomoo`1JOol00`00Oomoo`0:Ool00`00Oomoo`1`
Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0nOol00`00Oomoo`1BOol004Yoo`03001o
ogoo00Uoo`03001oogoo05aoo`03001oogoo00Uoo`03001oogoo075oo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo03ioo`03001oogoo05=oo`00BWoo00<007ooOol02Goo00<007ooOol0G7oo
00<007ooOol027oo00<007ooOol0Lgoo00<007ooOol01goo00<007ooOol01goo00<007ooOol0?Woo
00<007ooOol0E7oo001;Ool00`00Oomoo`07Ool00`00Oomoo`1NOol00`00Oomoo`07Ool00`00Oomo
o`1dOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0nOol00`00Oomoo`1EOol004]oo`03
001oogoo00Moo`03001oogoo05ioo`03001oogoo00Ioo`03001oogoo07Ioo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo03ioo`03001oogoo05Ioo`00C7oo00<007ooOol01Goo00<007ooOol0
H7oo00<007ooOol01Goo00<007ooOol0Mgoo00<007ooOol017oo00<007ooOol017oo00<007ooOol0
?goo00<007ooOol0EWoo001<Ool00`00Oomoo`05Ool00`00Oomoo`1POol00`00Oomoo`04Ool00`00
Oomoo`1iOol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0oOol00`00Oomoo`1GOol004eo
o`03001oogoo00=oo`03001oogoo069oo`03001oogoo00=oo`03001oogoo07Yoo`03001oogoo009o
o`03001oogoo009oo`03001oogoo03moo`03001oogoo05Qoo`00CWoo00D007ooOomoo`0006Ioo`05
001oogooOol0001nOol01@00Oomoogoo00000goo00<007ooOol0?goo00<007ooOol0FGoo001>Ool0
1@00Oomoogoo0000IWoo00D007ooOomoo`0007moo`04001oogoo0002Ool00`00Oomoo`0oOol00`00
Oomoo`1JOol004moo`03001oo`0006Qoo`03001oo`00085oo`05001oo`00Ool00012Ool00`00Oomo
o`1JOol004moo`03001oo`0006Qoo`03001oo`00089oo`<0049oo`03001oogoo05]oo`00D7oo0P00
JGoo0P00Pgoo00<007ooOol0@7oo00<007ooOol0G7oo001BOol00`00Oomoo`1XOol00`00Oomoo`20
Ool00`00Oomoo`0oOol00`00Oomoo`1MOol005=oo`03001oogoo06Qoo`03001oogoo081oo`03001o
ogoo03eoo`03001oogoo05ioo`00E7oo00<007ooOol0J7oo00<007ooOol0Ogoo00<007ooOol0?Goo
00<007ooOol0GWoo001EOol00`00Oomoo`1XOol00`00Oomoo`1oOol00`00Oomoo`0kOol00`00Oomo
o`1OOol005Ioo`03001oogoo06Qoo`03001oogoo07ioo`03001oogoo03Yoo`03001oogoo061oo`00
>Goo00<007ooOol01goo00<007ooOol02goo00<007ooOol00goo00<007ooOol0BGoo00<007ooOol0
1goo00<007ooOol037oo00<007ooOol00goo00<007ooOol0G7oo00<007ooOol01goo00<007ooOol0
37oo00<007ooOol01Woo0`000goo00<007ooOol0<Woo00<007ooOol0HGoo000hOol00`00Oomoo`09
Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`17Ool00`00Oomoo`09Ool00`00Oomoo`0<
Ool00`00Oomoo`03Ool00`00Oomoo`1JOol00`00Oomoo`09Ool00`00Oomoo`0<Ool00`00Oomoo`06
Ool00`00Ool00003Ool00`00Oomoo`0`Ool00`00Oomoo`1ROol003Qoo`04001oogooOol40004Ool0
0`00Oomoo`03Ool40004Ool00`00Oomoo`04Ool00`00Oomoo`16Ool01000Oomoogoo0`001Goo00<0
07ooOol01Goo10000goo00<007ooOol017oo00<007ooOol0FGoo00@007ooOomoo`<000Eoo`03001o
ogoo00=oo`D000Aoo`03001oogoo00Eoo`@000=oo`03001oogoo031oo`03001oogoo069oo`00>7oo
00@007ooOol0009oo`03001oogoo00Yoo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`15
Ool01000Oomoo`000goo00<007ooOol02Goo00@007ooOol000Aoo`03001oogoo00Eoo`03001oogoo
05Qoo`04001oogoo000@Ool00`00Oomoo`0;Ool00`00Oomoo`020003Ool00`00Oomoo`0_Ool00`00
Oomoo`1SOol003Moo`03001oogoo009oo`<000aoo`04001oogoo0004Ool00`00Oomoo`05Ool00`00
Oomoo`13Ool01@00Oomoogoo00003goo00@007ooOol000Eoo`03001oogoo00Eoo`03001oogoo05Io
o`04001oogooOol5000<Ool00`00Oomoo`0;Ool00`00Oomoo`020004Ool00`00Oomoo`0]Ool00`00
Oomoo`1TOol003Qoo`04001oogoo0002Ool00`00Oomoo`0:Ool01000Oomoo`000goo00<007ooOol0
1goo00<007ooOol0@goo00@007ooOol000=oo`03001oogoo00Uoo`04001oogoo0004Ool00`00Oomo
o`07Ool00`00Oomoo`1FOol01000Oomoo`000goo00<007ooOol02Woo00<007ooOol02goo00D007oo
Oomoo`0000=oo`03001oogoo02eoo`03001oogoo06Eoo`00>7oo00@007ooOomoo`8000eoo`<000Ao
o`03001oogoo00Qoo`8004=oo`04001oogooOol3000=Ool30004Ool00`00Oomoo`08Ool00`00Oomo
o`1EOol01000Oomoogoo0`0037oo100037oo1@000Woo00<007ooOol0;7oo00<007ooOol0IWoo000i
Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`11Ool00`00Oomoo`0B
Ool01@00Oomoogoo000037oo00<007ooOol0EGoo00<007ooOol047oo00<007ooOol047oo00<007oo
0000;Woo00<007ooOol0Igoo001:Ool2000DOol00`00Oomoo`1DOol2000AOol2001YOol2000@Ool0
0`00Oomoo`0^Ool00`00Oomoo`1WOol0065oo`03001oogoo06Qoo`03001oogoo07Uoo`03001oogoo
02aoo`03001oogoo06Qoo`00HWoo00<007ooOol0J7oo00<007ooOol0NGoo00<007ooOol0:Woo00<0
07ooOol0JGoo001SOol00`00Oomoo`1XOol00`00Oomoo`1hOol00`00Oomoo`0YOol00`00Oomoo`1Z
Ool006Aoo`03001oogoo06Qoo`03001oogoo07Qoo`03001oogoo02Moo`03001oogoo06]oo`00IGoo
00<007ooOol0J7oo00<007ooOol0Mgoo00<007ooOol09goo00<007ooOol0Jgoo001VOol00`00Oomo
o`1XOol00`00Oomoo`1gOol00`00Oomoo`0UOol00`00Oomoo`1/Ool006Moo`03001oogoo06Qoo`03
001oogoo07Ioo`03001oogoo02Aoo`03001oogoo06eoo`00J7oo00<007ooOol0J7oo00<007ooOol0
MWoo00<007ooOol08Woo00<007ooOol0KWoo001YOol00`00Oomoo`1XOol00`00Oomoo`1eOol00`00
Oomoo`0QOol00`00Oomoo`1_Ool006Yoo`03001oogoo06Qoo`03001oogoo07Eoo`03001oogoo021o
o`03001oogoo06moo`00Jgoo0P00JGoo00<007ooOol0MGoo00<007ooOol07Woo00<007ooOol0L7oo
001]Ool00`00Oomoo`1WOol00`00Oomoo`1dOol00`00Oomoo`0MOol00`00Oomoo`1aOol006ioo`03
001oogoo06Moo`03001oogoo07Aoo`03001oogoo01]oo`03001oogoo079oo`00Kgoo00<007ooOol0
Igoo0P00M7oo00<007ooOol06Woo00<007ooOol0Lgoo001`Ool00`00Oomoo`1XOol00`00Oomoo`1b
Ool00`00Oomoo`0IOol00`00Oomoo`1cOol0075oo`03001oogoo06Qoo`03001oogoo075oo`03001o
ogoo01Qoo`03001oogoo07Aoo`00LWoo00<007ooOol0J7oo00<007ooOol0LGoo00<007ooOol05Woo
00<007ooOol0MGoo001cOol00`00Oomoo`1XOol00`00Oomoo`1`Ool00`00Oomoo`0EOol00`00Oomo
o`1fOol007Aoo`03001oogoo06Qoo`03001oogoo071oo`03001oogoo01=oo`03001oogoo07Moo`00
MGoo00<007ooOol0J7oo00<007ooOol0Kgoo00<007ooOol04goo00<007ooOol0Mgoo001fOol00`00
Oomoo`1XOol00`00Oomoo`1_Ool00`00Oomoo`0AOol00`00Oomoo`1hOol007Moo`03001oogoo06Qo
o`03001oogoo06moo`03001oogoo00moo`03001oogoo07Uoo`00N7oo0P00JGoo00<007ooOol0KWoo
00<007ooOol03Woo00<007ooOol0NWoo001jOol00`00Oomoo`1WOol00`00Oomoo`1^Ool00`00Oomo
o`0<Ool00`00Oomoo`1kOol007]oo`03001oogoo06Moo`03001oogoo06eoo`03001oogoo00]oo`03
001oogoo07aoo`00O7oo00<007ooOol0Igoo00<007ooOol0KGoo00<007ooOol02Woo00<007ooOol0
O7oo001mOol00`00Oomoo`1WOol00`00Oomoo`1/Ool00`00Oomoo`09Ool00`00Oomoo`1mOol007io
o`03001oogoo06Moo`8006eoo`03001oogoo00Moo`03001oogoo07ioo`00Ogoo00<007ooOol0J7oo
00<007ooOol0JWoo00<007ooOol01Woo00<007ooOol0Ogoo0020Ool00`00Oomoo`1XOol00`00Oomo
o`1ZOol00`00Oomoo`04Ool00`00Oomoo`20Ool0085oo`03001oogoo06Qoo`03001oogoo06Yoo`03
001oogoo00=oo`03001oogoo081oo`00PWoo00<007ooOol0J7oo00<007ooOol0JGoo00<007ooOol0
0Woo00<007ooOol0PGoo0023Ool00`00Oomoo`1XOol00`00Oomoo`1YOol01000Oomoo`00Q7oo0024
Ool00`00Oomoo`1XOol00`00Oomoo`1XOol00`00Ool00025Ool008Eoo`8006Uoo`03001oogoo06Mo
o`8008Ioo`00Qgoo00<007ooOol0Igoo00<007ooOol0IGoo00<007ooOol0QWoo0028Ool00`00Oomo
o`1WOol00`00Oomoo`1SOol00`00Oomoo`27Ool008Uoo`03001oogoo06Moo`03001oogoo065oo`03
001oogoo08Qoo`00RWoo00<007ooOol0Igoo00<007ooOol0Ggoo00<007ooOol0RGoo002;Ool00`00
Oomoo`1WOol00`00Oomoo`1MOol00`00Oomoo`2:Ool008aoo`03001oogoo06Moo`03001oogoo03]o
o`03001oogoo00Moo`03001oogoo00aoo`03001oogoo00Aoo`03001oo`00008000Aoo`03001oogoo
00]oo`03001oogoo07Aoo`00SGoo00<007ooOol0Igoo00<007ooOol0>Goo00<007ooOol02Goo00<0
07ooOol037oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol02goo00<0
07ooOol0Lgoo002>Ool00`00Oomoo`1WOol2000iOol01000Oomoogoo0`001Goo00<007ooOol00goo
1@0017oo00D007ooOomoo`0000=oo`@000Aoo`03001oogoo00=oo`H0009oo`03001oogoo07=oo`00
Sgoo00<007ooOol0J7oo00<007ooOol0=Woo00@007ooOol0011oo`03001oogoo00Moo`05001oogoo
Ool00003Ool00`00Oomoo`09Ool01000Oomoo`000goo00<007ooOol0Lgoo002@Ool00`00Oomoo`1X
Ool00`00Oomoo`0dOol01000Oomoogoo1@0037oo00<007ooOol01Woo00<007ooOol00Woo00D007oo
Oomoo`0000]oo`04001oogoo0004Ool00`00Oomoo`1bOol0095oo`03001oogoo06Qoo`03001oogoo
03Aoo`04001oogoo0003Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`03Ool01@00Oomo
ogoo00002goo00@007ooOol000=oo`03001oogoo07=oo`00TWoo00<007ooOol0J7oo00<007ooOol0
<goo00@007ooOomoo`<000aoo`@000=oo`8000Moo`D000Yoo`<000Aoo`03001oogoo07=oo`00Tgoo
0P00JGoo00<007ooOol0<goo00<007ooOol047oo00<007ooOol00Woo00<007ooOol05Woo00<007oo
Ool00goo00<007ooOol0M7oo002EOol00`00Oomoo`1WOol00`00Oomoo`16Ool200000goo001oo`0G
Ool2001lOol009Ioo`03001oogoo06Moo`03001oogoo04Moo`03001oogoo09Eoo`00Ugoo00<007oo
Ool0Igoo00<007ooOol0AGoo00<007ooOol0UWoo002HOol00`00Oomoo`1WOol00`00Oomoo`13Ool0
0`00Oomoo`2GOol009Uoo`03001oogoo06Moo`03001oogoo045oo`03001oogoo09Qoo`00VWoo00<0
07ooOol0Igoo00<007ooOol0?goo00<007ooOol0VGoo002KOol00`00Oomoo`1WOol00`00Oomoo`0m
Ool00`00Oomoo`2JOol009aoo`03001oogoo06Moo`03001oogoo03]oo`03001oogoo09]oo`00WGoo
00<007ooOol0Igoo0P00>Woo00<007ooOol0W7oo002NOol00`00Oomoo`1XOol00`00Oomoo`0fOol0
0`00Oomoo`2MOol009moo`03001oogoo06Qoo`03001oogoo03Aoo`03001oogoo09ioo`00X7oo0P00
JGoo00<007ooOol0<Goo0P00XGoo002ROol00`00Oomoo`1WOol00`00Oomoo`0_Ool00`00Oomoo`2Q
Ool00:=oo`03001oogoo06Moo`03001oogoo02eoo`03001oogoo0:9oo`00Y7oo00<007ooOol0Igoo
00<007ooOol0:goo00<007ooOol0Xgoo002UOol00`00Oomoo`1WOol00`00Oomoo`0YOol00`00Oomo
o`2TOol00:Ioo`03001oogoo06Moo`03001oogoo02Moo`03001oogoo0:Eoo`00Ygoo00<007ooOol0
Igoo00<007ooOol09Goo00<007ooOol0YWoo002XOol00`00Oomoo`1WOol00`00Oomoo`0SOol00`00
Oomoo`2WOol00:Uoo`03001oogoo06Moo`03001oogoo025oo`03001oogoo0:Qoo`00ZWoo00<007oo
Ool0Igoo00<007ooOol07goo00<007ooOol0ZGoo002[Ool00`00Oomoo`1WOol00`00Oomoo`0MOol0
0`00Oomoo`2ZOol00:aoo`03001oogoo06Moo`8001aoo`03001oogoo0:]oo`00[Goo0P00JGoo00<0
07ooOol05goo0P00[Woo002_Ool00`00Oomoo`1WOol00`00Oomoo`0EOol00`00Oomoo`2^Ool00;1o
o`03001oogoo06Moo`03001oogoo01=oo`03001oogoo0:moo`00/Goo00<007ooOol0Igoo00<007oo
Ool04Goo00<007ooOol0/7oo002bOol00`00Oomoo`1WOol00`00Oomoo`0?Ool00`00Oomoo`2aOol0
0;=oo`03001oogoo06Moo`03001oogoo00eoo`03001oogoo0;9oo`00]7oo00<007ooOol0Igoo00<0
07ooOol02goo00<007ooOol0/goo002eOol00`00Oomoo`1WOol00`00Oomoo`09Ool00`00Oomoo`2d
Ool00;Ioo`03001oogoo06Moo`03001oogoo00Moo`03001oogoo0;Eoo`00]goo00<007ooOol0Igoo
00<007ooOol01Goo00<007ooOol0]Woo002hOol00`00Oomoo`1WOol00`00Oomoo`03Ool00`00Oomo
o`2gOol00;Uoo`03001oogoo06Moo`05001oogooOol0002jOol00;Yoo`03001oogoo06Moo`03001o
o`000;]oo`00^goo0P00Igoo0P00_7oo002mOol00`00Oomoo`1SOol00`00Oomoo`2lOol00;ioo`03
001oogoo065oo`03001oogoo0;eoo`00_goo00<007ooOol0Ggoo00<007ooOol0_Woo0030Ool00`00
Oomoo`1MOol00`00Oomoo`2oOol00<5oo`03001oogoo02]oo`03001oogoo00Moo`03001oogoo00ao
o`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Ioo`<000Aoo`03001o
ogoo00aoo`03001oogoo09Uoo`00`Woo00<007ooOol0:Goo00<007ooOol02Goo00<007ooOol037oo
00<007ooOol03Goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol027oo00<007ooOol00Woo
00<007ooOol037oo00<007ooOol0V7oo0033Ool00`00Oomoo`0XOol01000Oomoogoo0`001Goo00<0
07ooOol017oo100017oo00<007ooOol01Goo0`001Goo00H007ooOomoo`00Ool50004Ool00`00Oomo
o`05Ool40004Ool00`00Oomoo`04Ool60002Ool00`00Oomoo`2HOol00<Aoo`03001oogoo02Moo`04
001oogoo0003Ool00`00Oomoo`08Ool01000Oomoo`0037oo00<007ooOol02Goo00<007ooOol00Woo
00<007ooOol02goo00D007ooOomoo`0000aoo`04001oogoo0003Ool00`00Oomoo`2HOol00<Eoo`03
001oogoo02Eoo`05001oogooOol0000>Ool01000Oomoo`0037oo1@001Woo00<007ooOol00goo00<0
07ooOol02goo00D007ooOomoo`0000aoo`04001oogoo0004Ool00`00Oomoo`2GOol00<Ioo`03001o
ogoo02Eoo`04001oogoo0003Ool00`00Oomoo`08Ool01000Oomoo`0037oo00D007ooOomoo`0000Eo
o`03001oogoo00Aoo`03001oogoo00]oo`05001oogooOol0000<Ool01000Oomoo`000goo00<007oo
Ool0V7oo0037Ool00`00Oomoo`0TOol01000Oomoogoo0`0037oo0`003Goo0`001Goo00<007ooOol0
17oo100037oo1@002goo0`0017oo00<007ooOol0V7oo0038Ool2000UOol00`00Oomoo`0AOol00`00
Oomoo`0AOol20008Ool00`00Oomoo`0LOol00`00Oomoo`03Ool00`00Oomoo`2IOol00<Yoo`03001o
ogoo03Eoo`80019oo`03001oogoo00Uoo`8001]oo`800:5oo`00bgoo00<007ooOol0Agoo00<007oo
Ool0bWoo003<Ool00`00Oomoo`15Ool00`00Oomoo`3;Ool00<eoo`03001oogoo04=oo`03001oogoo
0<aoo`00cWoo00<007ooOol0@Goo00<007ooOol0cGoo003?Ool00`00Oomoo`0oOol00`00Oomoo`3>
Ool00=1oo`03001oogoo03eoo`03001oogoo0<moo`00dGoo00<007ooOol0>goo00<007ooOol0d7oo
003BOol00`00Oomoo`0iOol00`00Oomoo`3AOol00==oo`03001oogoo03Moo`03001oogoo0=9oo`00
e7oo00<007ooOol0=Goo00<007ooOol0dgoo003EOol2000cOol2003FOol00=Moo`03001oogoo02mo
o`03001oogoo0=Ioo`00f7oo00<007ooOol0;Goo00<007ooOol0egoo003IOol00`00Oomoo`0[Ool0
0`00Oomoo`3HOol00=Yoo`03001oogoo02Uoo`03001oogoo0=Uoo`00fgoo00<007ooOol09goo00<0
07ooOol0fWoo003LOol00`00Oomoo`0UOol00`00Oomoo`3KOol00=eoo`03001oogoo02=oo`03001o
ogoo0=aoo`00gWoo00<007ooOol08Goo00<007ooOol0gGoo003OOol00`00Oomoo`0OOol00`00Oomo
o`3NOol00>1oo`03001oogoo01eoo`03001oogoo0=moo`00hGoo00<007ooOol06goo00<007ooOol0
h7oo003ROol00`00Oomoo`0IOol00`00Oomoo`3QOol00>=oo`8001Moo`800>Aoo`00iGoo00<007oo
Ool04goo00<007ooOol0i7oo003VOol00`00Oomoo`0AOol00`00Oomoo`3UOol00>Moo`03001oogoo
00moo`03001oogoo0>Ioo`00j7oo00<007ooOol03Goo00<007ooOol0igoo003YOol00`00Oomoo`0;
Ool00`00Oomoo`3XOol00>Yoo`03001oogoo00Uoo`03001oogoo0>Uoo`00jgoo00<007ooOol01goo
00<007ooOol0jWoo003/Ool00`00Oomoo`05Ool00`00Oomoo`3[Ool00>eoo`03001oogoo00=oo`03
001oogoo0>aoo`00kWoo00D007ooOomoo`000>moo`00kgoo00<007oo0000l7oo003`Ool00`00Oomo
o`3_Ool00?moon=oo`00ogoohgoo003oOooSOol00?moon=oo`00ogoohgoo002ZOol00`00Oomoo`07
Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0=
Ool00`00Oomoo`05Ool30004Ool00`00Oomoo`0<Ool00`00Oomoo`2oOol00:Uoo`03001oogoo00Uo
o`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eo
o`03001oogoo00Moo`03001oogoo009oo`03001oogoo00aoo`03001oogoo0;ioo`00ZGoo00@007oo
Oomoo`@000Aoo`03001oogoo00=oo`@000Eoo`03001oogoo00Eoo`<000Eoo`03001oogoo00Eoo`@0
00Aoo`03001oogoo00Aoo`<000Eoo`03001oogoo00Aoo`D000Aoo`03001oogoo00Aoo`@000Aoo`03
001oogoo00Aoo`H0009oo`03001oogoo0;ioo`00ZGoo00@007ooOol0009oo`03001oogoo00Yoo`04
001oogoo000;Ool01@00Oomoogoo00002goo00@007ooOol000]oo`03001oogoo00moo`03001oogoo
00Yoo`05001oogooOol0000<Ool01000Oomoo`000goo00<007ooOol0_Woo002XOol00`00Oomoo`02
Ool3000<Ool01000Oomoo`002goo00<007ooOol03Goo00@007ooOol000]oo`D000eoo`03001oogoo
00Yoo`05001oogooOol0000<Ool01000Oomoo`0017oo00<007ooOol0_Goo002YOol01000Oomoo`00
0Woo00<007ooOol02Woo00@007ooOol000]oo`05001oogooOol0000;Ool01000Oomoo`002goo00D0
07ooOomoo`0000eoo`03001oogoo00Yoo`05001oogooOol0000<Ool01000Oomoo`000goo00<007oo
Ool0_Woo002YOol01000Oomoogoo0P003Goo0`003Goo0`003Goo0`0037oo0`003Goo10002goo1@00
2goo0`0017oo00<007ooOol0_Woo002ZOol00`00Oomoo`0?Ool00`00Oomoo`0OOol00`00Oomoo`0K
Ool00`00Oomoo`0KOol00`00Oomoo`03Ool00`00Oomoo`2oOol00;]oo`80021oo`8001ioo`8001Yo
o`800<Moo`00ogoohgoo003oOooSOol00?moon=oo`00ogoohgoo003oOooSOol00?moon=oo`00ogoo
hgoo003oOooSOol00?moon=oo`00ogoohgoo003oOooSOol00?moon=oo`00ogoohgoo003oOooSOol0
0?moon=oo`00ogoohgoo003oOooSOol00?moon=oo`00ogoohgoo003oOooSOol00?moon=oo`00ogoo
hgoo003oOooSOol00?moon=oo`00ogoohgoo003oOooSOol00?moon=oo`00ogoohgoo003oOooSOol0
0?moon=oo`00ogoohgoo003oOooSOol00?moon=oo`00ogoohgoo003oOooSOol00001\
\>"],
  ImageRangeCache->{{{0, 481}, {296.75, 0}} -> {-1.00797, -1.00003, \
0.0187442, 0.020219}}],

Cell["This structure would be represented by:", "Text"],

Cell[BoxData[
    \(tr = 
      Node[{a, b, c, d, e, f, gg, 
          h}, {2.3}, {Node[{a, b}, {0.4}, {Node[{a}, {0}, {}], 
              Node[{b}, {0}, {}]}], 
          Node[{c, d, e, f, gg, 
              h}, {1.8}, {Node[{c, d}, {1}, {Node[{c}, {0}, {}], 
                  Node[{d}, {0}, {}]}], 
              Node[{e, f, gg, 
                  h}, {1.7}, {Node[{e, f, gg}, {1.5}, {Node[{e}, {0}, {}], 
                      Node[{f}, {0}, {}], Node[{gg}, {0}, {}]}], 
                  Node[{h}, {0}, {}]}]}]}]; \)], "Input",
  CellLabel->"In[560]:="],

Cell["\<\
Note that here, each node is labelled by the set of objects which \
it includes.  Any other labelling could be used instead - for example, an \
integer.   The nodes also carry the time at which coalescence occurred: the \
depth of the whole tree is 2.3, for example.  \
\>", "Text"],

Cell["\<\
Note also that this tree includes a trifurcation: nodes may have \
any number of descendants.\
\>", "Text"],

Cell[TextData[{
  "This representation is similar to, but more flexible than, that used by \
the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package ",
  ButtonBox["DiscreteMath`Tree`",
    ButtonData:>{"DiscreteMath`Tree`", None},
    ButtonStyle->"AddOnsLink"],
  ".  That package allows only integer labels, and bifurcating trees.  Also, \
it uses lists rather than the special structure indicated by Node[]."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Node", "[", 
                  RowBox[{"i", ",", 
                    RowBox[{"{", 
                      StyleBox["info",
                        FontSlant->"Italic"], "}"}], 
                    ",", \({j, k, \[Ellipsis]}\)}], "]"}], ",", "\n", 
                " ", \(Node[j, {info}, {i}] \[Ellipsis]\)}], 
              "}"}], \(denotes\ an\ unrooted\ genealogy . \ \ Node\ i\ is\ \
related\ to\ nodes\ labelled\ j, \ k\ \(\(\[Ellipsis]\)\(.\)\)\ , \ 
            while\ node\ j\ is\ a\ leaf, \ 
            related\ only\ to\ node\ \(\(i\)\(.\)\)\)},
          {\(UnrootedGenealogy[
              g]\), \(gives\ an\ unrooted\ \(\(genealogy\)\(.\)\)\)},
          {\(RootedGenealogy[g, 
              i]\), \(roots\ an\ unrooted\ genealogy\ at\ node\ i\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"UnrootedGenealogy", "RootedGenealogy"}],

Cell["\<\
An unrooted genealogy is described by a list of all the nodes, \
together with their relatives.  Terminal nodes are included in the list, in \
order that information associated with them can be recorded.  This structure \
is simple, but not as compact as is possible: each branch is listed \
twice.\
\>", "Text"],

Cell["The tree given above would have unrooted form:", "MathCaption"],

Cell[GraphicsData["PICT", "\<\
0P@0000004h0JP0A0_l<0?ooool000000000001Z0000CP000000002Q06@035M?
DT@0000004h0JP2Q09H03040000100000000000N00402P000000CP1Z02`0200D
1EAYKFEc00<0500=00`0;P040000000@04h0JP1>06X0:`<G0F40X02G0:40UP0<
0@0000400000000002P0:@020F80X02G0:40UP0<0@0000400000000002/H7`5S
0:00U`2Q09H03040000100000000000Y505T002P09L0X@2F00`100000@000000
0000:00U05l1I@2P09L0X@2F00`100000@0000000000:`4C0FH0X02G0:40UP0<
0@0000400000000002XB0FL00:00U`2Q09H03040000100000000000X00h0GP5X
0:00U`0R0280FoXC02<9000R03@0EPT@0280301Il2808``70280?`0L2Nh08`TC
0280;P0U90008P0C00T<200R02D020ge02<S502Q09H03040000100000000000X
01L05`EkHBaRO@2P09L0X@2F00`100000@0000000000:00e00L5Nf</I7d0X02G
0:40UP0<0@0000400000000002/a2PMkIBaV;6Mm0:00U`3o\>"], "Graphics",
  ImageSize->{156, 114.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["This structure would be represented by:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(utr = UnrootedGenealogy[tr]; utr // TableForm\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(Node[{a}, {0}, {{a, b}}]\)},
          {\(Node[{b}, {0}, {{a, b}}]\)},
          {\(Node[{c}, {0}, {{c, d}}]\)},
          {\(Node[{d}, {0}, {{c, d}}]\)},
          {\(Node[{e}, {0}, {{e, f, g}}]\)},
          {\(Node[{f}, {0}, {{e, f, g}}]\)},
          {\(Node[{g}, {0}, {{e, f, g}}]\)},
          {\(Node[{h}, {0}, {{e, f, g, h}}]\)},
          {
            RowBox[{"Node", "[", 
              RowBox[{\({a, b}\), ",", 
                RowBox[{"{", 
                  StyleBox["0.4`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->1], "}"}], 
                ",", \({{a}, {b}, {a, b, c, d, e, f, g, h}}\)}], "]"}]},
          {\(Node[{c, d}, {1}, {{c}, {d}, {c, d, e, f, g, h}}]\)},
          {
            RowBox[{"Node", "[", 
              RowBox[{\({e, f, g}\), ",", 
                RowBox[{"{", 
                  StyleBox["1.5`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->2], "}"}], 
                ",", \({{e}, {f}, {g}, {e, f, g, h}}\)}], "]"}]},
          {
            RowBox[{"Node", "[", 
              RowBox[{\({e, f, g, h}\), ",", 
                RowBox[{"{", 
                  StyleBox["1.7`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->2], "}"}], 
                ",", \({{e, f, g}, {h}, {c, d, e, f, g, h}}\)}], "]"}]},
          {
            RowBox[{"Node", "[", 
              RowBox[{\({c, d, e, f, g, h}\), ",", 
                RowBox[{"{", 
                  StyleBox["1.8`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->2], "}"}], 
                ",", \({{c, d}, {e, f, g, h}, {a, b, c, d, e, f, g, h}}\)}], 
              "]"}]},
          {
            RowBox[{"Node", "[", 
              RowBox[{\({a, b, c, d, e, f, g, h}\), ",", 
                RowBox[{"{", 
                  StyleBox["2.29999999999999982`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->2], "}"}], 
                ",", \({{a, b}, {c, d, e, f, g, h}}\)}], "]"}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Node[ {a}, {0}, {{a, b}}], 
        Node[ {b}, {0}, {{a, b}}], 
        Node[ {c}, {0}, {{c, d}}], 
        Node[ {d}, {0}, {{c, d}}], 
        Node[ {e}, {0}, {{e, f, g}}], 
        Node[ {f}, {0}, {{e, f, g}}], 
        Node[ {g}, {0}, {{e, f, g}}], 
        Node[ {h}, {0}, {{e, f, g, h}}], 
        Node[ {a, b}, {0.40000000000000002}, {{a}, {b}, {a, b, c, d, e, f, g, 
          h}}], 
        Node[ {c, d}, {1}, {{c}, {d}, {c, d, e, f, g, h}}], 
        Node[ {e, f, g}, {1.5}, {{e}, {f}, {g}, {e, f, g, h}}], 
        Node[ {e, f, g, h}, {1.7}, {{e, f, g}, {h}, {c, d, e, f, g, h}}], 
        Node[ {c, d, e, f, g, h}, {1.8}, {{c, d}, {e, f, g, h}, {a, b, c, d, 
          e, f, g, h}}], 
        Node[ {a, b, c, d, e, f, g, h}, {2.2999999999999998}, {{a, b}, {c, d, 
          e, f, g, h}}]}]]], "Output",
  CellLabel->"Out[22]//TableForm="]
}, Closed]],

Cell["\<\
Here, the nodes are labelled by the set of leaves that descend from \
them; however, any arbitrary label could be used.  Information about each \
node is preserved.\
\>", "Text"],

Cell[TextData[{
  "This restores the original rooted genealogy by rooting the unrooted \
genealogy at ",
  Cell[BoxData[
      \(TraditionalForm\`\(\({a, b, c, d, e, f, g, h}\)\(:\)\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rg = RootedGenealogy[utr, {a, b, c, d, e, f, g, h}]\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    RowBox[{"Node", "[", 
      RowBox[{\({a, b, c, d, e, f, g, h}\), ",", 
        RowBox[{"{", 
          StyleBox["2.29999999999999982`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"Node", "[", 
              RowBox[{\({a, b}\), ",", 
                RowBox[{"{", 
                  StyleBox["0.4`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->1], "}"}], 
                ",", \({Node[{a}, {0}, {}], Node[{b}, {0}, {}]}\)}], "]"}], 
            ",", 
            RowBox[{"Node", "[", 
              RowBox[{\({c, d, e, f, g, h}\), ",", 
                RowBox[{"{", 
                  StyleBox["1.8`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->2], "}"}], ",", 
                RowBox[{"{", 
                  
                  RowBox[{\(Node[{c, d}, {1}, {Node[{c}, {0}, {}], 
                        Node[{d}, {0}, {}]}]\), ",", 
                    RowBox[{"Node", "[", 
                      RowBox[{\({e, f, g, h}\), ",", 
                        RowBox[{"{", 
                          StyleBox["1.7`",
                            StyleBoxAutoDelete->True,
                            PrintPrecision->2], "}"}], ",", 
                        RowBox[{"{", 
                          RowBox[{
                            RowBox[{"Node", "[", 
                              RowBox[{\({e, f, g}\), ",", 
                                RowBox[{"{", 
                                  StyleBox["1.5`",
                                    StyleBoxAutoDelete->True,
                                    PrintPrecision->2], "}"}], 
                                ",", \({Node[{e}, {0}, {}], 
                                  Node[{f}, {0}, {}], Node[{g}, {0}, {}]}\)}],
                               "]"}], ",", \(Node[{h}, {0}, {}]\)}], "}"}]}], 
                      "]"}]}], "}"}]}], "]"}]}], "}"}]}], "]"}]], "Output",
  CellLabel->"Out[23]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[PlotGenealogy[rg]]; \)], "Input",
  CellLabel->"In[24]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.111111 0.111111 0.103006 0.103006 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.16667 .20601 m
.11111 .10301 L
s
.16667 .20601 m
.22222 .10301 L
s
.38889 .20601 m
.33333 .10301 L
s
.38889 .20601 m
.44444 .10301 L
s
.66667 .20601 m
.55556 .10301 L
s
.66667 .20601 m
.66667 .10301 L
s
.66667 .20601 m
.77778 .10301 L
s
.72222 .30902 m
.66667 .20601 L
s
.72222 .30902 m
.88889 .10301 L
s
.61111 .41202 m
.38889 .20601 L
s
.61111 .41202 m
.72222 .30902 L
s
.5 .51503 m
.16667 .20601 L
s
.5 .51503 m
.61111 .41202 L
s
gsave
.14444 .22661 -79.7812 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
90.562500 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.36667 .22661 -79.7812 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
90.562500 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.64444 .22661 -87.5625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
90.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
100.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(g) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
106.125000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.7 .32962 -95.3438 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
90.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
100.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(g) show
106.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
115.687500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(h) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
121.687500 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.58889 .43262 -110.906 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
90.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
100.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
106.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
115.687500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
121.687500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
131.250000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(g) show
137.250000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
146.812500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(h) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
152.812500 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.47778 .53563 -126.469 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
90.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
100.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
106.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
115.687500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
121.687500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
131.250000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
137.250000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
146.812500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
152.812500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
162.375000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(g) show
168.375000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
177.937500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(h) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
183.937500 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.11111 .0824 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.22222 .0824 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.33333 .0824 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.44444 .0824 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.55556 .0824 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.66667 .0824 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.77778 .0824 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(g) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.88889 .0824 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(h) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[24]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Closed]],

Cell["Any other node could be chosen as the root:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rg = RootedGenealogy[utr, {a, b}]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    RowBox[{"Node", "[", 
      RowBox[{\({a, b}\), ",", 
        RowBox[{"{", 
          StyleBox["0.4`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\(Node[{a}, {0}, {}]\), ",", \(Node[{b}, {0}, {}]\), ",", 
            RowBox[{"Node", "[", 
              RowBox[{\({a, b, c, d, e, f, g, h}\), ",", 
                RowBox[{"{", 
                  StyleBox["2.29999999999999982`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->2], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{"Node", "[", 
                    RowBox[{\({c, d, e, f, g, h}\), ",", 
                      RowBox[{"{", 
                        StyleBox["1.8`",
                          StyleBoxAutoDelete->True,
                          PrintPrecision->2], "}"}], ",", 
                      RowBox[{"{", 
                        
                        RowBox[{\(Node[{c, d}, {1}, {Node[{c}, {0}, {}], 
                              Node[{d}, {0}, {}]}]\), ",", 
                          RowBox[{"Node", "[", 
                            RowBox[{\({e, f, g, h}\), ",", 
                              RowBox[{"{", 
                                StyleBox["1.7`",
                                  StyleBoxAutoDelete->True,
                                  PrintPrecision->2], "}"}], ",", 
                              RowBox[{"{", 
                                RowBox[{
                                  RowBox[{"Node", "[", 
                                    RowBox[{\({e, f, g}\), ",", 
                                      RowBox[{"{", 
                                        StyleBox["1.5`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2], "}"}], 
                                      ",", \({Node[{e}, {0}, {}], 
                                        Node[{f}, {0}, {}], 
                                        Node[{g}, {0}, {}]}\)}], "]"}], 
                                  ",", \(Node[{h}, {0}, {}]\)}], "}"}]}], 
                            "]"}]}], "}"}]}], "]"}], "}"}]}], "]"}]}], 
          "}"}]}], "]"}]], "Output",
  CellLabel->"Out[25]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[PlotGenealogy[rg]]; \)], "Input",
  CellLabel->"In[26]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.111111 0.111111 0.0882906 0.0882906 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .52974 m
.11111 .08829 L
s
.5 .52974 m
.22222 .08829 L
s
.5 .52974 m
.61111 .44145 L
s
.38889 .17658 m
.33333 .08829 L
s
.38889 .17658 m
.44444 .08829 L
s
.66667 .17658 m
.55556 .08829 L
s
.66667 .17658 m
.66667 .08829 L
s
.66667 .17658 m
.77778 .08829 L
s
.72222 .26487 m
.66667 .17658 L
s
.72222 .26487 m
.88889 .08829 L
s
.61111 .35316 m
.38889 .17658 L
s
.61111 .35316 m
.72222 .26487 L
s
.61111 .44145 m
.61111 .35316 L
s
gsave
.47778 .5474 -79.7812 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
90.562500 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.36667 .19424 -79.7812 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
90.562500 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.64444 .19424 -87.5625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
90.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
100.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(g) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
106.125000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.7 .28253 -95.3438 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
90.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
100.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(g) show
106.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
115.687500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(h) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
121.687500 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.58889 .37082 -110.906 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
90.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
100.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
106.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
115.687500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
121.687500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
131.250000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(g) show
137.250000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
146.812500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(h) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
152.812500 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.58889 .45911 -126.469 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
90.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
100.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
106.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
115.687500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
121.687500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
131.250000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
137.250000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
146.812500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
152.812500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
162.375000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(g) show
168.375000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
177.937500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(h) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
183.937500 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.11111 .07063 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.22222 .07063 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.33333 .07063 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.44444 .07063 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.55556 .07063 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.66667 .07063 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.77778 .07063 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(g) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.88889 .07063 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(h) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Closed]],

Cell["\<\
PlotGenealogy[] cannot plot unrooted genealogies directly; however, \
RootedGenealogy[] can be used to generate a rooted genealogy that can be \
plotted.\
\>", "Text"]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{245, Automatic}, {Automatic, 46}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Node"->{
    Cell[1774, 51, 1552, 37, 102, "DefinitionBox",
      CellTags->"Node"]},
  "UnrootedGenealogy"->{
    Cell[53921, 1482, 1001, 21, 102, "DefinitionBox",
      CellTags->{"UnrootedGenealogy", "RootedGenealogy"}]},
  "RootedGenealogy"->{
    Cell[53921, 1482, 1001, 21, 102, "DefinitionBox",
      CellTags->{"UnrootedGenealogy", "RootedGenealogy"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Node", 117690, 3884},
  {"UnrootedGenealogy", 117792, 3887},
  {"RootedGenealogy", 117929, 3890}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 54, 0, 36, "SubsectionIcon"],
Cell[1774, 51, 1552, 37, 102, "DefinitionBox",
  CellTags->"Node"],
Cell[3329, 90, 46, 0, 28, "MathCaption"],
Cell[3378, 92, 88, 2, 26, "Input"],
Cell[3469, 96, 580, 13, 80, "Text"],
Cell[4052, 111, 48390, 1328, 304, 25779, 1044, "GraphicsData", "PostScript", \
"Graphics"],
Cell[52445, 1441, 55, 0, 22, "Text"],
Cell[52503, 1443, 558, 12, 122, "Input"],
Cell[53064, 1457, 292, 5, 50, "Text"],
Cell[53359, 1464, 117, 3, 22, "Text"],
Cell[53479, 1469, 439, 11, 53, "Text"],
Cell[53921, 1482, 1001, 21, 102, "DefinitionBox",
  CellTags->{"UnrootedGenealogy", "RootedGenealogy"}],
Cell[54925, 1505, 322, 6, 50, "Text"],
Cell[55250, 1513, 69, 0, 28, "MathCaption"],
Cell[55322, 1515, 841, 14, 121, 746, 11, "GraphicsData", "PICT", "Graphics"],
Cell[56166, 1531, 62, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[56253, 1535, 103, 2, 27, "Input"],
Cell[56359, 1539, 3128, 75, 70, "Output"]
}, Closed]],
Cell[59502, 1617, 188, 4, 32, "Text"],
Cell[59693, 1623, 206, 5, 40, "MathCaption"],

Cell[CellGroupData[{
Cell[59924, 1632, 109, 2, 27, "Input"],
Cell[60036, 1636, 2044, 45, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[62117, 1686, 83, 2, 23, "Input"],
Cell[62203, 1690, 25931, 1049, 70, 25779, 1044, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Closed]],
Cell[88149, 2742, 66, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[88240, 2746, 91, 2, 27, "Input"],
Cell[88334, 2750, 2272, 46, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[90643, 2801, 83, 2, 23, "Input"],
Cell[90729, 2805, 25936, 1049, 70, 25784, 1044, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Closed]],
Cell[116680, 3857, 177, 4, 32, "Text"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

