(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11040,        282]*)
(*NotebookOutlinePosition[     11923,        310]*)
(*  CellTagsIndexPosition[     11879,        306]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Calculating the moment generating function over all \
topologies\
\>", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MomentGeneratingFunction[{{a}, {b}, \[Ellipsis]}, \[Omega], \
\[Theta]]\), \(gives\ the\ generating\ function\ for\ all\ tree\ topologies, \
\ in\ terms\ of\ variables\ \[Omega][
                S]\ which\ correspond\ to\ those\ mutations\ in\ branches\ \
ancestral\ to\ the\ set\ of\ leaves\ S . \ \ Stores\ \(\(results\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell[TextData[{
  "Suppose that there is a set of leaves {a,b,c\[Ellipsis]}, connected by an \
unknown genealogy.  There is a simple recursion for the generating function \
which gives the distrubution of mutations and (implicitly) of topologies.  \
Let the number of mutations on branches ancestral to the set of leaves S be \
",
  Cell[BoxData[
      \(TraditionalForm\`j\_S; \ 
      this\ corresponds\ to\ the\ variable\ \[Omega]\_S\)]],
  " in the generating function.  The recursion is:"
}], "Text"],

Cell[BoxData[
    \(TextForm\`P\&~\_n[\[Omega]\+_] = \(\[Sum]\+\(i \[NotEqual] j\)P\&~\_\(n \
- 1\)[\(\[Omega]\+_\^*\)]\)\/\(\(\[Lambda]\_n\) \((1 - \(\[Phi]\_n\) \(\[Sum]\
\[Omega]\_i\))\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "where the sum is over all possible pairwise coalescences of leaf ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " with leaf ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ", and ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{"(", 
            FormBox[\(\[Omega]\+_\),
              "TraditionalForm"], ")"}], "*"], TraditionalForm]]],
  " represents a coalescence between those leaves.  The recursion is simple \
to calculate, though intractable for more than a few leaves:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mgf = 
      MomentGeneratingFunction[{{a}, {b}, {c}, {d}}, \[Omega], \[Theta]]\)], \
"Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(\((\((2\ \((1\/\(\((1 + \[Theta])\)\ \((1 - \(\[Theta]\ \((\[Omega][{a, \
b}] + \[Omega][{c, d}])\)\)\/\(2\ \((1 + \[Theta])\)\))\)\) + 
                    1\/\(\((1 + \[Theta])\)\ \((1 - \(\[Theta]\ \
\((\[Omega][{b}] + \[Omega][{a, c, d}])\)\)\/\(2\ \((1 + \[Theta])\)\))\)\) + 
                    1\/\(\((1 + \[Theta])\)\ \((1 - \(\[Theta]\ \
\((\[Omega][{a}] + \[Omega][{b, c, d}])\)\)\/\(2\ \((1 + \
\[Theta])\)\))\)\))\))\)/\((3\ \((2 + \[Theta])\)\ \((1 - \(\[Theta]\ \((\
\[Omega][{a}] + \[Omega][{b}] + \[Omega][{c, d}])\)\)\/\(3\ \((2 + \
\[Theta])\)\))\))\) + \((2\ \((1\/\(\((1 + \[Theta])\)\ \((1 - \(\[Theta]\ \
\((\[Omega][{a, d}] + \[Omega][{b, c}])\)\)\/\(2\ \((1 + \[Theta])\)\))\)\) + 
                    1\/\(\((1 + \[Theta])\)\ \((1 - \(\[Theta]\ \
\((\[Omega][{c}] + \[Omega][{b, a, d}])\)\)\/\(2\ \((1 + \[Theta])\)\))\)\) + 
                    1\/\(\((1 + \[Theta])\)\ \((1 - \(\[Theta]\ \
\((\[Omega][{b}] + \[Omega][{c, a, d}])\)\)\/\(2\ \((1 + \
\[Theta])\)\))\)\))\))\)/\((3\ \((2 + \[Theta])\)\ \((1 - \(\[Theta]\ \((\
\[Omega][{b}] + \[Omega][{c}] + \[Omega][{a, d}])\)\)\/\(3\ \((2 + \
\[Theta])\)\))\))\) + \((2\ \((1\/\(\((1 + \[Theta])\)\ \((1 - \(\[Theta]\ \
\((\[Omega][{a, c}] + \[Omega][{b, d}])\)\)\/\(2\ \((1 + \[Theta])\)\))\)\) + 
                    1\/\(\((1 + \[Theta])\)\ \((1 - \(\[Theta]\ \
\((\[Omega][{c}] + \[Omega][{a, b, d}])\)\)\/\(2\ \((1 + \[Theta])\)\))\)\) + 
                    1\/\(\((1 + \[Theta])\)\ \((1 - \(\[Theta]\ \
\((\[Omega][{a}] + \[Omega][{c, b, d}])\)\)\/\(2\ \((1 + \
\[Theta])\)\))\)\))\))\)/\((3\ \((2 + \[Theta])\)\ \((1 - \(\[Theta]\ \((\
\[Omega][{a}] + \[Omega][{c}] + \[Omega][{b, d}])\)\)\/\(3\ \((2 + \
\[Theta])\)\))\))\) + \((2\ \((1\/\(\((1 + \[Theta])\)\ \((1 - \(\[Theta]\ \
\((\[Omega][{a, b}] + \[Omega][{c, d}])\)\)\/\(2\ \((1 + \[Theta])\)\))\)\) + 
                    1\/\(\((1 + \[Theta])\)\ \((1 - \(\[Theta]\ \
\((\[Omega][{d}] + \[Omega][{c, a, b}])\)\)\/\(2\ \((1 + \[Theta])\)\))\)\) + 
                    1\/\(\((1 + \[Theta])\)\ \((1 - \(\[Theta]\ \
\((\[Omega][{c}] + \[Omega][{d, a, b}])\)\)\/\(2\ \((1 + \
\[Theta])\)\))\)\))\))\)/\((3\ \((2 + \[Theta])\)\ \((1 - \(\[Theta]\ \((\
\[Omega][{c}] + \[Omega][{d}] + \[Omega][{a, b}])\)\)\/\(3\ \((2 + \
\[Theta])\)\))\))\) + \((2\ \((1\/\(\((1 + \[Theta])\)\ \((1 - \(\[Theta]\ \
\((\[Omega][{a, c}] + \[Omega][{b, d}])\)\)\/\(2\ \((1 + \[Theta])\)\))\)\) + 
                    1\/\(\((1 + \[Theta])\)\ \((1 - \(\[Theta]\ \
\((\[Omega][{d}] + \[Omega][{b, a, c}])\)\)\/\(2\ \((1 + \[Theta])\)\))\)\) + 
                    1\/\(\((1 + \[Theta])\)\ \((1 - \(\[Theta]\ \
\((\[Omega][{b}] + \[Omega][{d, a, c}])\)\)\/\(2\ \((1 + \
\[Theta])\)\))\)\))\))\)/\((3\ \((2 + \[Theta])\)\ \((1 - \(\[Theta]\ \((\
\[Omega][{b}] + \[Omega][{d}] + \[Omega][{a, c}])\)\)\/\(3\ \((2 + \
\[Theta])\)\))\))\) + \((2\ \((1\/\(\((1 + \[Theta])\)\ \((1 - \(\[Theta]\ \
\((\[Omega][{a, d}] + \[Omega][{b, c}])\)\)\/\(2\ \((1 + \[Theta])\)\))\)\) + 
                    1\/\(\((1 + \[Theta])\)\ \((1 - \(\[Theta]\ \
\((\[Omega][{d}] + \[Omega][{a, b, c}])\)\)\/\(2\ \((1 + \[Theta])\)\))\)\) + 
                    1\/\(\((1 + \[Theta])\)\ \((1 - \(\[Theta]\ \
\((\[Omega][{a}] + \[Omega][{d, b, c}])\)\)\/\(2\ \((1 + \
\[Theta])\)\))\)\))\))\)/\((3\ \((2 + \[Theta])\)\ \((1 - \(\[Theta]\ \((\
\[Omega][{a}] + \[Omega][{d}] + \[Omega][{b, c}])\)\)\/\(3\ \((2 + \
\[Theta])\)\))\))\))\)/\((2\ \((3 + \[Theta])\)\ \((1 - \(\[Theta]\ \((\
\[Omega][{a}] + \[Omega][{b}] + \[Omega][{c}] + \[Omega][{d}])\)\)\/\(4\ \((3 \
+ \[Theta])\)\))\))\)\)], "Output",
  CellLabel->"Out[4]="]
}, Closed]],

Cell["\<\
This expression is complicated: applying Factor[] or Simplify[] is \
disastrous even with just four leaves.\
\>", "Text"],

Cell["\tThe overall probability sums to 1:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mgf /. \[Omega][_] :> 1 // Factor\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[9]="]
}, Closed]],

Cell["\<\
\tThis is the generating function for the distribution of the \
number of segregating sites for four lineages:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mgf /. \[Omega][_] :> \[Nu] // Factor\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(\(-\(6\/\(\((\(-3\) - \[Theta] + \[Theta]\ \[Nu])\)\ \((\(-2\) - \
\[Theta] + \[Theta]\ \[Nu])\)\ \((\(-1\) - \[Theta] + \[Theta]\ \
\[Nu])\)\)\)\)\)], "Output",
  CellLabel->"Out[6]="]
}, Closed]],

Cell["\tThis is the probability that no mutations will be seen:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mgf /. \[Omega][_] :> 0\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(6\/\(\((1 + \[Theta])\)\ \((2 + \[Theta])\)\ \((3 + \[Theta])\)\)\)], \
"Output",
  CellLabel->"Out[7]="]
}, Closed]],

Cell["\<\
\tThis is the generating function for the distribution of the \
number of mutations in terminal branches (and hence, seen only in a single \
lineage:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(mgf /. \[Omega][{_}] :> \[Nu]\) /. \[Omega][_] :> 1 // 
      Factor\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \(\(3\ \((\(-6\) - \[Theta] + \[Theta]\ \[Nu])\)\)\/\(\((\(-3\) - \
\[Theta] + \[Theta]\ \[Nu])\)\^2\ \((\(-2\) - \[Theta] + \[Theta]\ \[Nu])\)\)\
\)], "Output",
  CellLabel->"Out[12]="]
}, Closed]],

Cell["\<\
Note that the generating function contains information about the \
topology.  The simplified m.g.f. gives the joint distribution of the numbers \
of mutations along each of these three potential branches:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mgf2 = \(mgf /. {\[Omega][{a, b}] \[Rule] \[Omega]ab, \[Omega][{c, 
                  d}] \[Rule] \[Omega]cd, \[Omega][{a, 
                  c}] \[Rule] \[Omega]ac}\) /. \[Omega][_] :> 0\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \(\(1\/\(2\ \((3 + \[Theta])\)\)\) \((4\/\(\((1 + \[Theta])\)\ \((2 + \
\[Theta])\)\) + \(2\ \((2\/\(1 + \[Theta]\) + 1\/\(\((1 + \[Theta])\)\ \((1 - \
\(\[Theta]\ \[Omega]ac\)\/\(2\ \((1 + \[Theta])\)\))\)\))\)\)\/\(3\ \((2 + \
\[Theta])\)\) + \(2\ \((2\/\(1 + \[Theta]\) + 1\/\(\((1 + \[Theta])\)\ \((1 - \
\(\[Theta]\ \[Omega]ac\)\/\(2\ \((1 + \[Theta])\)\))\)\))\)\)\/\(3\ \((2 + \
\[Theta])\)\ \((1 - \(\[Theta]\ \[Omega]ac\)\/\(3\ \((2 + \[Theta])\)\))\)\) \
+ \(2\ \((2\/\(1 + \[Theta]\) + 1\/\(\((1 + \[Theta])\)\ \((1 - \(\[Theta]\ \
\((\[Omega]ab + \[Omega]cd)\)\)\/\(2\ \((1 + \[Theta])\)\))\)\))\)\)\/\(3\ \
\((2 + \[Theta])\)\ \((1 - \(\[Theta]\ \[Omega]ab\)\/\(3\ \((2 + \
\[Theta])\)\))\)\) + \(2\ \((2\/\(1 + \[Theta]\) + 1\/\(\((1 + \[Theta])\)\ \
\((1 - \(\[Theta]\ \((\[Omega]ab + \[Omega]cd)\)\)\/\(2\ \((1 + \
\[Theta])\)\))\)\))\)\)\/\(3\ \((2 + \[Theta])\)\ \((1 - \(\[Theta]\ \
\[Omega]cd\)\/\(3\ \((2 + \[Theta])\)\))\)\))\)\)], "Output",
  CellLabel->"Out[16]="]
}, Closed]],

Cell["\<\
It would be impossible to observe mutations shared by just {a,b}, \
just {c,d}, and just {a,c}. Because of this constraint, there are no terms \
involving all three variables:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[mgf2, \[Omega]ab, \[Omega]cd, \[Omega]ac]\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[20]="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{815, 638},
WindowMargins->{{Automatic, 62}, {Automatic, 12}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 101, 3, 24, "SubsubsectionIcon"],
Cell[1843, 56, 447, 7, 68, "DefinitionBox"],
Cell[2293, 65, 505, 10, 50, "Text"],
Cell[2801, 77, 215, 3, 57, "NumberedEquation"],
Cell[3019, 82, 546, 16, 36, "Text"],

Cell[CellGroupData[{
Cell[3590, 102, 138, 4, 26, "Input"],
Cell[3731, 108, 3633, 52, 579, "Output"]
}, Closed]],
Cell[7379, 163, 131, 3, 18, "Text"],
Cell[7513, 168, 52, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[7590, 172, 90, 2, 26, "Input"],
Cell[7683, 176, 59, 2, 20, "Output"]
}, Closed]],
Cell[7757, 181, 134, 3, 18, "Text"],

Cell[CellGroupData[{
Cell[7916, 188, 94, 2, 26, "Input"],
Cell[8013, 192, 205, 4, 38, "Output"]
}, Closed]],
Cell[8233, 199, 73, 0, 18, "Text"],

Cell[CellGroupData[{
Cell[8331, 203, 80, 2, 26, "Input"],
Cell[8414, 207, 125, 3, 38, "Output"]
}, Closed]],
Cell[8554, 213, 173, 4, 18, "Text"],

Cell[CellGroupData[{
Cell[8752, 221, 128, 3, 26, "Input"],
Cell[8883, 226, 204, 4, 38, "Output"]
}, Closed]],
Cell[9102, 233, 228, 4, 32, "Text"],

Cell[CellGroupData[{
Cell[9355, 241, 245, 4, 26, "Input"],
Cell[9603, 247, 1006, 14, 88, "Output"]
}, Closed]],
Cell[10624, 264, 199, 4, 32, "Text"],

Cell[CellGroupData[{
Cell[10848, 272, 101, 2, 26, "Input"],
Cell[10952, 276, 60, 2, 20, "Output"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

