(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     69988,       1342]*)
(*NotebookOutlinePosition[     71301,       1383]*)
(*  CellTagsIndexPosition[     71138,       1375]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Equilibrium under short- and long-range migration", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MomentEquilibrium[U, c, m, p, 
              r, \[Delta]p]\), \(gives\ the\ equilibrium\ moment\ in\ deme\ \
0, \ measured\ after\ short - range\ migration\ from\ demes\  - 1, \ \(+1\) 
              on\ either\ side . \ Stores\ \(\(results\)\(.\)\)\)},
          {\(MomentEquilibrium[U, c, m\_l, m\_s, p\&_, 
              r, \[Delta]pl, \[Delta]ps]\), \(allows\ for\ two\ migration\ \
rates\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"MomentEquilibrium"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(<< Multilocus`EstimatingD`; \)], "Input",
  CellLabel->"In[409]:="],

Cell[TextData[{
  "This gives the pairwise within-genome association between loci ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(j\)\(\ \)\)\)]],
  "at equilibrium:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MomentEquilibrium[{i, j}, c, m, p\&_, r, \[Delta]p]\)], "Input",
  CellLabel->"In[24]:=  (7:58:00 on 4/10/01)"],

Cell[BoxData[
    \(\(1\/\(2\ \((1 - r[{}, {i, j}])\)\)\) \((m\ \((1 - 
              p\&_)\)\ p\&_\ \((2\ \[Delta]p[{i}]\ \[Delta]p[{j}] + 
              r[{i}, {j}]\ \[Delta]p[{j}]\ \[Delta]p[{\(i\^*\)}] + 
              r[{i}, {j}]\ \[Delta]p[{i}]\ \[Delta]p[{\(j\^*\)}])\))\)\)], \
"Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[TextData[{
  "The recombination rates are expressed as ",
  Cell[BoxData[
      \(TraditionalForm\`r[U, V]\)]],
  ", the probability that a gamete will inherit the set of loci U from one \
genome,  and V from the other."
}], "Text"],

Cell[TextData[{
  "Note: ",
  StyleBox["The convention here differs from that in Multilocus`Multilocus`, \
in that r[U,V] and r[V,U] are pooled.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell["Written more simply:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MomentEquilibrium[{i, j}, c, m, p\&_, 
        r, \[Delta]p] /. {r[{i}, {j}] \[Rule] rec, 
        r[{}, {i, j}] \[Rule] 1 - rec}\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(\(-\(\(m\ \((\(-1\) + 
                p\&_)\)\ p\&_\ \((2\ \[Delta]p[{i}]\ \[Delta]p[{j}] + 
                rec\ \[Delta]p[{j}]\ \[Delta]p[{\(i\^*\)}] + 
                rec\ \[Delta]p[{i}]\ \[Delta]p[{\(j\^*\)}])\)\)\/\(2\ rec\)\)\
\)\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell[TextData[{
  "There are two source demes.   Migration is at a rate ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(q\&_\),
            "TraditionalForm"], "m"}], TraditionalForm]]],
  " from one, and ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\&_\) m\)]],
  " from the other; the source demes differ in allele frequency by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]p\_i\)]],
  " at locus ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ".  (Note that the actual allele frequencies in the source demes do not \
affect the moments).  The source demes are assumed to have the same \
multilocus associations as the central deme.  This is an approximation to \
migration across a shallow cline: in fact, associations will decrease away \
from the centre, and so this approximation will tend to overestimate \
associations."
}], "Text"],

Cell[TextData[{
  "This is the association between genes at loci ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " on different genomes:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MomentEquilibrium[{i, \(j\^*\)}, c, m, p\&_, 
        r, \[Delta]p] /. {r[{i}, {j}] \[Rule] rec, 
        r[{}, {i, j}] \[Rule] 1 - rec}\)], "Input",
  CellLabel->"In[26]:=  (7:59:41 on 4/10/01)"],

Cell[BoxData[
    \(\(-m\)\ \((\(-1\) + 
          p\&_)\)\ p\&_\ \[Delta]p[{i}]\ \[Delta]p[{\(j\^*\)}]\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Note",
    FontWeight->"Bold"],
  ": this uses the obsolete ",
  ButtonBox["multilocus notation",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"multilocus notation"],
  ", which may cause trouble."
}], "Text"],

Cell["\<\
MomentEquilibrium[] also allows for a combination of long-range and \
short-range migration:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MomentEquilibrium[{i, j}, c, ml, ms, pb, 
        r, \[Delta]pl, \[Delta]ps] /. {r[{i}, {j}] \[Rule] rec, 
        r[{}, {i, j}] \[Rule] 1 - rec}\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(\(1\/\(2\ \((ml\ \((1 - rec)\) + rec)\)\)\) \((\((\(-1\) + 
              pb)\)\ pb\ \((\(-2\)\ ml\ \[Delta]pl[{i}]\ \[Delta]pl[{j}] - 
              ml\ rec\ \[Delta]pl[{j}]\ \[Delta]pl[{\(i\^*\)}] + 
              ml\^2\ rec\ \[Delta]pl[{j}]\ \[Delta]pl[{\(i\^*\)}] - 
              ml\ rec\ \[Delta]pl[{i}]\ \[Delta]pl[{\(j\^*\)}] + 
              ml\^2\ rec\ \[Delta]pl[{i}]\ \[Delta]pl[{\(j\^*\)}] - 
              2\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{j}] - 
              ms\ rec\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}] + 
              ml\ ms\ rec\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}] - 
              ms\ rec\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}] + 
              ml\ ms\ rec\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}])\))\)\)], \
"Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell["\<\
Long-range migration is from source demes that are in \
Hardy-Weinberg and linkage disequilibrium.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(CumulantEquilibrium[U, c, m, pb, 
              r, \[Delta]p]\), \(gives\ the\ equilibrium\ cumulant\ in\ deme\ \
0, \ measured\ after\ short - range\ migration\ from\ demes\  - 1, \ \(+1\) 
              on\ either\ side . \ Stores\ \(\(results\)\(.\)\)\)},
          {\(CumulantEquilibrium[U, c, m\_l, m\_s, p\&_, 
              r, \[Delta]pl, \[Delta]ps]\), \(allows\ for\ two\ migration\ \
rates\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"CumulantEquilibrium"],

Cell["\<\
The general algebraic expressions can be very complicated for more \
than a few loci: it may only be feasible to calculate results for unlinked \
loci or numerical values.  \
\>", "Text"],

Cell["\<\
This gives the four-way cumulant at equilibrium, assuming no \
linkage:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CumulantEquilibrium[{i, j, k, l}, c, m, p\&_, ur, \[Delta]p]\)], "Input",\

  CellLabel->"In[8]:="],

Cell[BoxData[
    \(\(-\(1\/28\)\)\ m\ \((\(-1\) + 
          p\&_)\)\ p\&_\ \((32\ \[Delta]p[{i}]\ \[Delta]p[{j}]\ \
\[Delta]p[{k}]\ \[Delta]p[{l}] - 
          96\ p\&_\ \[Delta]p[{i}]\ \[Delta]p[{j}]\ \[Delta]p[{k}]\ \
\[Delta]p[{l}] - 
          120\ m\ p\&_\ \[Delta]p[{i}]\ \[Delta]p[{j}]\ \[Delta]p[{k}]\ \
\[Delta]p[{l}] + 
          96\ p\&_\^2\ \[Delta]p[{i}]\ \[Delta]p[{j}]\ \[Delta]p[{k}]\ \
\[Delta]p[{l}] + 
          120\ m\ p\&_\^2\ \[Delta]p[{i}]\ \[Delta]p[{j}]\ \[Delta]p[{k}]\ \
\[Delta]p[{l}] + 
          2\ \[Delta]p[{j}]\ \[Delta]p[{k}]\ \[Delta]p[{l}]\ \
\[Delta]p[{\(i\^*\)}] - 
          6\ p\&_\ \[Delta]p[{j}]\ \[Delta]p[{k}]\ \[Delta]p[{l}]\ \
\[Delta]p[{\(i\^*\)}] - 
          15\ m\ p\&_\ \[Delta]p[{j}]\ \[Delta]p[{k}]\ \[Delta]p[{l}]\ \
\[Delta]p[{\(i\^*\)}] + 
          6\ p\&_\^2\ \[Delta]p[{j}]\ \[Delta]p[{k}]\ \[Delta]p[{l}]\ \
\[Delta]p[{\(i\^*\)}] + 
          15\ m\ p\&_\^2\ \[Delta]p[{j}]\ \[Delta]p[{k}]\ \[Delta]p[{l}]\ \
\[Delta]p[{\(i\^*\)}] + 
          2\ \[Delta]p[{i}]\ \[Delta]p[{k}]\ \[Delta]p[{l}]\ \
\[Delta]p[{\(j\^*\)}] - 
          6\ p\&_\ \[Delta]p[{i}]\ \[Delta]p[{k}]\ \[Delta]p[{l}]\ \
\[Delta]p[{\(j\^*\)}] - 
          15\ m\ p\&_\ \[Delta]p[{i}]\ \[Delta]p[{k}]\ \[Delta]p[{l}]\ \
\[Delta]p[{\(j\^*\)}] + 
          6\ p\&_\^2\ \[Delta]p[{i}]\ \[Delta]p[{k}]\ \[Delta]p[{l}]\ \
\[Delta]p[{\(j\^*\)}] + 
          15\ m\ p\&_\^2\ \[Delta]p[{i}]\ \[Delta]p[{k}]\ \[Delta]p[{l}]\ \
\[Delta]p[{\(j\^*\)}] + 
          2\ \[Delta]p[{k}]\ \[Delta]p[{l}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(j\^*\)}] - 
          6\ p\&_\ \[Delta]p[{k}]\ \[Delta]p[{l}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(j\^*\)}] - 
          2\ m\ p\&_\ \[Delta]p[{k}]\ \[Delta]p[{l}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(j\^*\)}] + 
          6\ p\&_\^2\ \[Delta]p[{k}]\ \[Delta]p[{l}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(j\^*\)}] + 
          2\ m\ p\&_\^2\ \[Delta]p[{k}]\ \[Delta]p[{l}]\ \
\[Delta]p[{\(i\^*\)}]\ \[Delta]p[{\(j\^*\)}] + 
          2\ \[Delta]p[{i}]\ \[Delta]p[{j}]\ \[Delta]p[{l}]\ \
\[Delta]p[{\(k\^*\)}] - 
          6\ p\&_\ \[Delta]p[{i}]\ \[Delta]p[{j}]\ \[Delta]p[{l}]\ \
\[Delta]p[{\(k\^*\)}] - 
          15\ m\ p\&_\ \[Delta]p[{i}]\ \[Delta]p[{j}]\ \[Delta]p[{l}]\ \
\[Delta]p[{\(k\^*\)}] + 
          6\ p\&_\^2\ \[Delta]p[{i}]\ \[Delta]p[{j}]\ \[Delta]p[{l}]\ \
\[Delta]p[{\(k\^*\)}] + 
          15\ m\ p\&_\^2\ \[Delta]p[{i}]\ \[Delta]p[{j}]\ \[Delta]p[{l}]\ \
\[Delta]p[{\(k\^*\)}] + 
          2\ \[Delta]p[{j}]\ \[Delta]p[{l}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(k\^*\)}] - 
          6\ p\&_\ \[Delta]p[{j}]\ \[Delta]p[{l}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(k\^*\)}] - 
          2\ m\ p\&_\ \[Delta]p[{j}]\ \[Delta]p[{l}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(k\^*\)}] + 
          6\ p\&_\^2\ \[Delta]p[{j}]\ \[Delta]p[{l}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(k\^*\)}] + 
          2\ m\ p\&_\^2\ \[Delta]p[{j}]\ \[Delta]p[{l}]\ \
\[Delta]p[{\(i\^*\)}]\ \[Delta]p[{\(k\^*\)}] + 
          2\ \[Delta]p[{i}]\ \[Delta]p[{l}]\ \[Delta]p[{\(j\^*\)}]\ \
\[Delta]p[{\(k\^*\)}] - 
          6\ p\&_\ \[Delta]p[{i}]\ \[Delta]p[{l}]\ \[Delta]p[{\(j\^*\)}]\ \
\[Delta]p[{\(k\^*\)}] - 
          2\ m\ p\&_\ \[Delta]p[{i}]\ \[Delta]p[{l}]\ \[Delta]p[{\(j\^*\)}]\ \
\[Delta]p[{\(k\^*\)}] + 
          6\ p\&_\^2\ \[Delta]p[{i}]\ \[Delta]p[{l}]\ \[Delta]p[{\(j\^*\)}]\ \
\[Delta]p[{\(k\^*\)}] + 
          2\ m\ p\&_\^2\ \[Delta]p[{i}]\ \[Delta]p[{l}]\ \
\[Delta]p[{\(j\^*\)}]\ \[Delta]p[{\(k\^*\)}] + 
          2\ \[Delta]p[{l}]\ \[Delta]p[{\(i\^*\)}]\ \[Delta]p[{\(j\^*\)}]\ \
\[Delta]p[{\(k\^*\)}] - 
          6\ p\&_\ \[Delta]p[{l}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(j\^*\)}]\ \[Delta]p[{\(k\^*\)}] + 
          3\ m\ p\&_\ \[Delta]p[{l}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(j\^*\)}]\ \[Delta]p[{\(k\^*\)}] + 
          6\ p\&_\^2\ \[Delta]p[{l}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(j\^*\)}]\ \[Delta]p[{\(k\^*\)}] - 
          3\ m\ p\&_\^2\ \[Delta]p[{l}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(j\^*\)}]\ \[Delta]p[{\(k\^*\)}] + 
          2\ \[Delta]p[{i}]\ \[Delta]p[{j}]\ \[Delta]p[{k}]\ \
\[Delta]p[{\(l\^*\)}] - 
          6\ p\&_\ \[Delta]p[{i}]\ \[Delta]p[{j}]\ \[Delta]p[{k}]\ \
\[Delta]p[{\(l\^*\)}] - 
          15\ m\ p\&_\ \[Delta]p[{i}]\ \[Delta]p[{j}]\ \[Delta]p[{k}]\ \
\[Delta]p[{\(l\^*\)}] + 
          6\ p\&_\^2\ \[Delta]p[{i}]\ \[Delta]p[{j}]\ \[Delta]p[{k}]\ \
\[Delta]p[{\(l\^*\)}] + 
          15\ m\ p\&_\^2\ \[Delta]p[{i}]\ \[Delta]p[{j}]\ \[Delta]p[{k}]\ \
\[Delta]p[{\(l\^*\)}] + 
          2\ \[Delta]p[{j}]\ \[Delta]p[{k}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(l\^*\)}] - 
          6\ p\&_\ \[Delta]p[{j}]\ \[Delta]p[{k}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(l\^*\)}] - 
          2\ m\ p\&_\ \[Delta]p[{j}]\ \[Delta]p[{k}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(l\^*\)}] + 
          6\ p\&_\^2\ \[Delta]p[{j}]\ \[Delta]p[{k}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(l\^*\)}] + 
          2\ m\ p\&_\^2\ \[Delta]p[{j}]\ \[Delta]p[{k}]\ \
\[Delta]p[{\(i\^*\)}]\ \[Delta]p[{\(l\^*\)}] + 
          2\ \[Delta]p[{i}]\ \[Delta]p[{k}]\ \[Delta]p[{\(j\^*\)}]\ \
\[Delta]p[{\(l\^*\)}] - 
          6\ p\&_\ \[Delta]p[{i}]\ \[Delta]p[{k}]\ \[Delta]p[{\(j\^*\)}]\ \
\[Delta]p[{\(l\^*\)}] - 
          2\ m\ p\&_\ \[Delta]p[{i}]\ \[Delta]p[{k}]\ \[Delta]p[{\(j\^*\)}]\ \
\[Delta]p[{\(l\^*\)}] + 
          6\ p\&_\^2\ \[Delta]p[{i}]\ \[Delta]p[{k}]\ \[Delta]p[{\(j\^*\)}]\ \
\[Delta]p[{\(l\^*\)}] + 
          2\ m\ p\&_\^2\ \[Delta]p[{i}]\ \[Delta]p[{k}]\ \
\[Delta]p[{\(j\^*\)}]\ \[Delta]p[{\(l\^*\)}] + 
          2\ \[Delta]p[{k}]\ \[Delta]p[{\(i\^*\)}]\ \[Delta]p[{\(j\^*\)}]\ \
\[Delta]p[{\(l\^*\)}] - 
          6\ p\&_\ \[Delta]p[{k}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(j\^*\)}]\ \[Delta]p[{\(l\^*\)}] + 
          3\ m\ p\&_\ \[Delta]p[{k}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(j\^*\)}]\ \[Delta]p[{\(l\^*\)}] + 
          6\ p\&_\^2\ \[Delta]p[{k}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(j\^*\)}]\ \[Delta]p[{\(l\^*\)}] - 
          3\ m\ p\&_\^2\ \[Delta]p[{k}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(j\^*\)}]\ \[Delta]p[{\(l\^*\)}] + 
          2\ \[Delta]p[{i}]\ \[Delta]p[{j}]\ \[Delta]p[{\(k\^*\)}]\ \
\[Delta]p[{\(l\^*\)}] - 
          6\ p\&_\ \[Delta]p[{i}]\ \[Delta]p[{j}]\ \[Delta]p[{\(k\^*\)}]\ \
\[Delta]p[{\(l\^*\)}] - 
          2\ m\ p\&_\ \[Delta]p[{i}]\ \[Delta]p[{j}]\ \[Delta]p[{\(k\^*\)}]\ \
\[Delta]p[{\(l\^*\)}] + 
          6\ p\&_\^2\ \[Delta]p[{i}]\ \[Delta]p[{j}]\ \[Delta]p[{\(k\^*\)}]\ \
\[Delta]p[{\(l\^*\)}] + 
          2\ m\ p\&_\^2\ \[Delta]p[{i}]\ \[Delta]p[{j}]\ \
\[Delta]p[{\(k\^*\)}]\ \[Delta]p[{\(l\^*\)}] + 
          2\ \[Delta]p[{j}]\ \[Delta]p[{\(i\^*\)}]\ \[Delta]p[{\(k\^*\)}]\ \
\[Delta]p[{\(l\^*\)}] - 
          6\ p\&_\ \[Delta]p[{j}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(k\^*\)}]\ \[Delta]p[{\(l\^*\)}] + 
          3\ m\ p\&_\ \[Delta]p[{j}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(k\^*\)}]\ \[Delta]p[{\(l\^*\)}] + 
          6\ p\&_\^2\ \[Delta]p[{j}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(k\^*\)}]\ \[Delta]p[{\(l\^*\)}] - 
          3\ m\ p\&_\^2\ \[Delta]p[{j}]\ \[Delta]p[{\(i\^*\)}]\ \
\[Delta]p[{\(k\^*\)}]\ \[Delta]p[{\(l\^*\)}] + 
          2\ \[Delta]p[{i}]\ \[Delta]p[{\(j\^*\)}]\ \[Delta]p[{\(k\^*\)}]\ \
\[Delta]p[{\(l\^*\)}] - 
          6\ p\&_\ \[Delta]p[{i}]\ \[Delta]p[{\(j\^*\)}]\ \
\[Delta]p[{\(k\^*\)}]\ \[Delta]p[{\(l\^*\)}] + 
          3\ m\ p\&_\ \[Delta]p[{i}]\ \[Delta]p[{\(j\^*\)}]\ \
\[Delta]p[{\(k\^*\)}]\ \[Delta]p[{\(l\^*\)}] + 
          6\ p\&_\^2\ \[Delta]p[{i}]\ \[Delta]p[{\(j\^*\)}]\ \
\[Delta]p[{\(k\^*\)}]\ \[Delta]p[{\(l\^*\)}] - 
          3\ m\ p\&_\^2\ \[Delta]p[{i}]\ \[Delta]p[{\(j\^*\)}]\ \
\[Delta]p[{\(k\^*\)}]\ \[Delta]p[{\(l\^*\)}])\)\)], "Output",
  CellLabel->"Out[8]="]
}, Closed]],

Cell["\<\
CumulantEquilibrium[] also allows for a combination of long-range \
and short-range migration.  \
\>", "Text"],

Cell["\<\
Here, there is no linkage, and the source demes for long-range \
migration are fixed (\[Delta]pl=1):\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ur[A_List, B_List] := 2\^\(1 - Length[A] - Length[B]\);\)\), "\n", 
    \(CumulantEquilibrium[{i, j, k, l}, c, ml, ms, pb, ur, 
      1 &, \[Delta]ps]\)}], "Input",
  CellLabel->"In[27]:=  (8:05:54 on 4/10/01)"],

Cell[BoxData[
    \(\(-\(\(1\/\(4\ \((1 + ml)\)\^2\ \((7 + ml)\)\)\) \((\((\(-1\) + 
                pb)\)\ pb\ \((60\ ml + 92\ ml\^2 + 4\ ml\^3 - 28\ ml\^4 - 
                180\ ml\ pb - 984\ ml\^2\ pb + 288\ ml\^3\ pb + 
                120\ ml\^4\ pb - 12\ ml\^5\ pb + 180\ ml\ pb\^2 + 
                984\ ml\^2\ pb\^2 - 288\ ml\^3\ pb\^2 - 120\ ml\^4\ pb\^2 + 
                12\ ml\^5\ pb\^2 - 
                92\ ml\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}] + 
                80\ ml\^2\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}] + 
                12\ ml\^3\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}] + 
                92\ ml\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}] - 
                80\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}] - 
                12\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}] - 
                92\ ml\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{k}] + 
                80\ ml\^2\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{k}] + 
                12\ ml\^3\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{k}] + 
                92\ ml\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{k}] - 
                80\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{k}] - 
                12\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{k}] - 
                92\ ml\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{k}] + 
                80\ ml\^2\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{k}] + 
                12\ ml\^3\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{k}] + 
                92\ ml\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{k}] - 
                80\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{k}] - 
                12\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{k}] - 
                92\ ml\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{l}] + 
                80\ ml\^2\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{l}] + 
                12\ ml\^3\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{l}] + 
                92\ ml\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{l}] - 
                80\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{l}] - 
                12\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{l}] - 
                92\ ml\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{l}] + 
                80\ ml\^2\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{l}] + 
                12\ ml\^3\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{l}] + 
                92\ ml\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{l}] - 
                80\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{l}] - 
                12\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{l}] - 
                92\ ml\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{l}] + 
                80\ ml\^2\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{l}] + 
                12\ ml\^3\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{l}] + 
                92\ ml\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{l}] - 
                80\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{l}] - 
                12\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{l}] + 
                32\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}] + 
                64\ ml\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\
\ \[Delta]ps[{l}] + 
                32\ ml\^2\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{l}] - 
                96\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\
\ \[Delta]ps[{l}] - 
                192\ ml\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{l}] - 
                96\ ml\^2\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{l}] - 
                120\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{l}] + 
                120\ ml\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{l}] + 
                96\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{l}] + 
                192\ ml\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{l}] + 
                96\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{l}] + 
                120\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{l}] - 
                120\ ml\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{l}] - 
                30\ ml\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}] + 
                42\ ml\^2\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}] - 
                10\ ml\^3\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}] - 
                2\ ml\^4\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}] + 
                30\ ml\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}] - 
                42\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}] \
+ 10\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}] + 
                2\ ml\^4\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}] \
- 30\ ml\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}] + 
                42\ ml\^2\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}] - 
                10\ ml\^3\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}] - 
                2\ ml\^4\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}] + 
                30\ ml\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}] - 
                42\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}] \
+ 10\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}] + 
                2\ ml\^4\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}] \
- 30\ ml\ ms\ pb\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] + 
                42\ ml\^2\ ms\ pb\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] - 
                10\ ml\^3\ ms\ pb\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] - 
                2\ ml\^4\ ms\ pb\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] + 
                30\ ml\ ms\ pb\^2\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] - 
                42\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] \
+ 10\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] + 
                2\ ml\^4\ ms\ pb\^2\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] \
+ 2\ ms\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}] + 
                2\ ml\ ms\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}] - 
                2\ ml\^2\ ms\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] - 
                2\ ml\^3\ ms\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] - 
                6\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}] - 
                6\ ml\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] + 
                6\ ml\^2\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] + 
                6\ ml\^3\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] - 
                15\ ms\^2\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] + 
                108\ ml\ ms\^2\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] + 
                3\ ml\^2\ ms\^2\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] + 
                6\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] + 
                6\ ml\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] - 
                6\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] - 
                6\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] + 
                15\ ms\^2\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] - 
                108\ ml\ ms\^2\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] - 
                3\ ml\^2\ ms\^2\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}] - 
                30\ ml\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}] + 
                42\ ml\^2\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}] - 
                10\ ml\^3\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}] - 
                2\ ml\^4\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}] + 
                30\ ml\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}] - 
                42\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}] \
+ 10\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}] + 
                2\ ml\^4\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}] \
- 30\ ml\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{\(j\^*\)}] + 
                42\ ml\^2\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{\(j\^*\)}] - 
                10\ ml\^3\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{\(j\^*\)}] - 
                2\ ml\^4\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{\(j\^*\)}] + 
                30\ ml\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{\(j\^*\)}] - 
                42\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{\(j\^*\)}] \
+ 10\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{\(j\^*\)}] + 
                2\ ml\^4\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{\(j\^*\)}] \
- 30\ ml\ ms\ pb\ \[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] + 
                42\ ml\^2\ ms\ pb\ \[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] - 
                10\ ml\^3\ ms\ pb\ \[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] - 
                2\ ml\^4\ ms\ pb\ \[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] + 
                30\ ml\ ms\ pb\^2\ \[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] - 
                42\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] \
+ 10\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] + 
                2\ ml\^4\ ms\ pb\^2\ \[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] \
+ 2\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}] + 
                2\ ml\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}] - 
                2\ ml\^2\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] - 
                2\ ml\^3\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] - 
                6\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}] - 
                6\ ml\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] + 
                6\ ml\^2\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] + 
                6\ ml\^3\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] - 
                15\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] + 
                108\ ml\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] + 
                3\ ml\^2\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] + 
                6\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] + 
                6\ ml\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] - 
                6\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] - 
                6\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] + 
                
                15\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] - 
                108\ ml\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] - 
                3\ ml\^2\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(j\^*\)}] + 
                4\ ml\ ms\ pb\ \[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] \
- 4\ ml\^3\ ms\ pb\ \[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] - 
                4\ ml\ ms\ pb\^2\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}] + 
                4\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}] + 
                2\ ms\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] + 
                2\ ml\ ms\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] - 
                2\ ml\^2\ ms\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] - 
                2\ ml\^3\ ms\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] - 
                6\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] - 
                6\ ml\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \[Delta]ps[{\
\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] + 
                6\ ml\^2\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] + 
                6\ ml\^3\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] - 
                2\ ms\^2\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] + 
                22\ ml\ ms\^2\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] - 
                18\ ml\^2\ ms\^2\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] - 
                2\ ml\^3\ ms\^2\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] + 
                6\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] + 
                6\ ml\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] - 
                6\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] - 
                6\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] + 
                2\ ms\^2\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] - 
                22\ ml\ ms\^2\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] + 
                18\ ml\^2\ ms\^2\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] + 
                2\ ml\^3\ ms\^2\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}] - 
                30\ ml\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{\(k\^*\)}] + 
                42\ ml\^2\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{\(k\^*\)}] - 
                10\ ml\^3\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{\(k\^*\)}] - 
                2\ ml\^4\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{\(k\^*\)}] + 
                30\ ml\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{\(k\^*\)}] - 
                42\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{\(k\^*\)}] \
+ 10\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{\(k\^*\)}] + 
                2\ ml\^4\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{\(k\^*\)}] \
- 30\ ml\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{\(k\^*\)}] + 
                42\ ml\^2\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{\(k\^*\)}] - 
                10\ ml\^3\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{\(k\^*\)}] - 
                2\ ml\^4\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{\(k\^*\)}] + 
                30\ ml\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{\(k\^*\)}] - 
                42\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{\(k\^*\)}] \
+ 10\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{\(k\^*\)}] + 
                2\ ml\^4\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{\(k\^*\)}] \
- 30\ ml\ ms\ pb\ \[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] + 
                42\ ml\^2\ ms\ pb\ \[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] - 
                10\ ml\^3\ ms\ pb\ \[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] - 
                2\ ml\^4\ ms\ pb\ \[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] + 
                30\ ml\ ms\ pb\^2\ \[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] - 
                42\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] \
+ 10\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] + 
                2\ ml\^4\ ms\ pb\^2\ \[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] \
+ 2\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(k\^*\)}] + 
                2\ ml\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(k\^*\)}] - 
                2\ ml\^2\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] - 
                2\ ml\^3\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] - 
                6\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(k\^*\)}] - 
                6\ ml\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] + 
                6\ ml\^2\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] + 
                6\ ml\^3\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] - 
                15\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] + 
                108\ ml\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] + 
                3\ ml\^2\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] + 
                6\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] + 
                6\ ml\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] - 
                6\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] - 
                6\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] + 
                15\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] - 
                108\ ml\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] - 
                3\ ml\^2\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{l}]\ \[Delta]ps[{\(k\^*\)}] + 
                4\ ml\ ms\ pb\ \[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] \
- 4\ ml\^3\ ms\ pb\ \[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                4\ ml\ ms\ pb\^2\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}] + 
                4\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}] + 
                2\ ms\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                2\ ml\ ms\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                2\ ml\^2\ ms\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                2\ ml\^3\ ms\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                6\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                6\ ml\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \[Delta]ps[{\
\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                6\ ml\^2\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                6\ ml\^3\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                2\ ms\^2\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                22\ ml\ ms\^2\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                18\ ml\^2\ ms\^2\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                2\ ml\^3\ ms\^2\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                6\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                6\ ml\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                6\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                6\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                
                2\ ms\^2\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                22\ ml\ ms\^2\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                18\ ml\^2\ ms\^2\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                2\ ml\^3\ ms\^2\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                4\ ml\ ms\ pb\ \[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] \
- 4\ ml\^3\ ms\ pb\ \[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                4\ ml\ ms\ pb\^2\ \[Delta]ps[{\(j\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}] + 
                4\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{\(j\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}] + 
                2\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                2\ ml\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                2\ ml\^2\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                2\ ml\^3\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                6\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                6\ ml\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{l}]\ \[Delta]ps[{\
\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                6\ ml\^2\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                6\ ml\^3\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                2\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                22\ ml\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                18\ ml\^2\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                2\ ml\^3\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                
                6\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                6\ ml\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                6\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                6\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                2\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                22\ ml\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                18\ ml\^2\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                2\ ml\^3\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                2\ ms\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                2\ ml\ ms\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                2\ ml\^2\ ms\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                2\ ml\^3\ ms\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                6\ ms\ pb\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                6\ ml\ ms\ pb\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                6\ ml\^2\ ms\ pb\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                6\ ml\^3\ ms\ pb\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                3\ ms\^2\ pb\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                3\ ml\^2\ ms\^2\ pb\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                
                6\ ms\ pb\^2\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                6\ ml\ ms\ pb\^2\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                6\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                6\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                3\ ms\^2\ pb\^2\ \[Delta]ps[{l}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] + 
                3\ ml\^2\ ms\^2\ pb\^2\ \[Delta]ps[{l}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}] - 
                30\ ml\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{\(l\^*\)}] + 
                42\ ml\^2\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{\(l\^*\)}] - 
                10\ ml\^3\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ml\^4\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{\(l\^*\)}] + 
                30\ ml\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{\(l\^*\)}] - 
                42\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{\(l\^*\)}] \
+ 10\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{\(l\^*\)}] + 
                2\ ml\^4\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{\(l\^*\)}] \
- 30\ ml\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{\(l\^*\)}] + 
                42\ ml\^2\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{\(l\^*\)}] - 
                10\ ml\^3\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ml\^4\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{\(l\^*\)}] + 
                30\ ml\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{\(l\^*\)}] - 
                42\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{\(l\^*\)}] \
+ 10\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{\(l\^*\)}] + 
                2\ ml\^4\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{\(l\^*\)}] \
- 30\ ml\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] + 
                42\ ml\^2\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] - 
                10\ ml\^3\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ml\^4\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] + 
                30\ ml\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] - 
                42\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] \
+ 10\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] + 
                2\ ml\^4\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] \
+ 2\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(l\^*\)}] + 
                2\ ml\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(l\^*\)}] - 
                2\ ml\^2\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ml\^3\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(l\^*\)}] - 
                6\ ml\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ml\^2\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ml\^3\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] - 
                15\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] + 
                108\ ml\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] + 
                3\ ml\^2\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ml\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] + 
                15\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] - 
                108\ ml\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] - 
                3\ ml\^2\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{k}]\ \[Delta]ps[{\(l\^*\)}] + 
                4\ ml\ ms\ pb\ \[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] \
- 4\ ml\^3\ ms\ pb\ \[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                4\ ml\ ms\ pb\^2\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(l\^*\)}] + 
                4\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(l\^*\)}] + 
                2\ ms\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                2\ ml\ ms\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ml\^2\ ms\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ml\^3\ ms\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ml\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \[Delta]ps[{\
\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ml\^2\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ml\^3\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ms\^2\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                22\ ml\ ms\^2\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                18\ ml\^2\ ms\^2\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ml\^3\ ms\^2\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ml\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                
                2\ ms\^2\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                22\ ml\ ms\^2\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                18\ ml\^2\ ms\^2\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                2\ ml\^3\ ms\^2\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                4\ ml\ ms\ pb\ \[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] \
- 4\ ml\^3\ ms\ pb\ \[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                4\ ml\ ms\ pb\^2\ \[Delta]ps[{\(j\^*\)}]\ \
\[Delta]ps[{\(l\^*\)}] + 
                4\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{\(j\^*\)}]\ \
\[Delta]ps[{\(l\^*\)}] + 
                2\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                2\ ml\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ml\^2\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ml\^3\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ml\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \[Delta]ps[{\
\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ml\^2\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ml\^3\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                22\ ml\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                18\ ml\^2\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ml\^3\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                
                6\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ml\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                2\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                22\ ml\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                18\ ml\^2\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                2\ ml\^3\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                2\ ms\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                2\ ml\ ms\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ml\^2\ ms\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ml\^3\ ms\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ml\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ml\^2\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ml\^3\ ms\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                3\ ms\^2\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                3\ ml\^2\ ms\^2\ pb\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                
                6\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ml\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                3\ ms\^2\ pb\^2\ \[Delta]ps[{k}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                3\ ml\^2\ ms\^2\ pb\^2\ \[Delta]ps[{k}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                4\ ml\ ms\ pb\ \[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] \
- 4\ ml\^3\ ms\ pb\ \[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                4\ ml\ ms\ pb\^2\ \[Delta]ps[{\(k\^*\)}]\ \
\[Delta]ps[{\(l\^*\)}] + 
                4\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{\(k\^*\)}]\ \
\[Delta]ps[{\(l\^*\)}] + 
                2\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                2\ ml\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ml\^2\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ml\^3\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ml\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \[Delta]ps[{\
\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ml\^2\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ml\^3\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                22\ ml\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                18\ ml\^2\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ml\^3\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ml\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                2\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                22\ ml\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                18\ ml\^2\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                2\ ml\^3\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{j}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                2\ ms\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                2\ ml\ ms\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ml\^2\ ms\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ml\^3\ ms\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ml\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ml\^2\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ml\^3\ ms\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                3\ ms\^2\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                3\ ml\^2\ ms\^2\ pb\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ml\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                3\ ms\^2\ pb\^2\ \[Delta]ps[{j}]\ \[Delta]ps[{\(i\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                3\ ml\^2\ ms\^2\ pb\^2\ \[Delta]ps[{j}]\ \
\[Delta]ps[{\(i\^*\)}]\ \[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                2\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                2\ ml\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ml\^2\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                2\ ml\^3\ ms\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ml\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ml\^2\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ml\^3\ ms\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                3\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                3\ ml\^2\ ms\^2\ pb\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                6\ ml\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ml\^2\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                6\ ml\^3\ ms\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] - 
                3\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \[Delta]ps[{\(j\^*\)}]\ \
\[Delta]ps[{\(k\^*\)}]\ \[Delta]ps[{\(l\^*\)}] + 
                3\ ml\^2\ ms\^2\ pb\^2\ \[Delta]ps[{i}]\ \
\[Delta]ps[{\(j\^*\)}]\ \[Delta]ps[{\(k\^*\)}]\ \
\[Delta]ps[{\(l\^*\)}])\))\)\)\)\)], "Output",
  CellLabel->"Out[10]="]
}, Closed]],

Cell[TextData[{
  "*** Note that the variable ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  "  is a dummy - only used internally to represent moments."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(AdmixtureFrequency[X, c, m\_l, m\_s, p\&_, 
              p, \[Delta]pl, \[Delta]ps, 
              S]\), \(gives\ the\ frequency\ of\ genotype\ X\ under\ an\ \
admixture\ model, \ assuming\ unlinked\ \(\(loci\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"AdmixtureFrequency"],

Cell["\<\
Here is the frequency of diploid genotype {0,2,1}, assuming no \
linkage and both long and short-range migration:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AdmixtureFrequency[{0, 2, 1}, c, 0.01, 0.2, 0.3, p, 1 &, 
      1 &, {i, j, k}]\)], "Input",
  CellLabel->"In[410]:="],

Cell[BoxData[
    \(\(-0.0397513577888348468`\) + 0.0382214892931153293`\ \((1 - p[i])\) - 
      0.0382214892931153329`\ p[j] + 
      0.0546403366336633578`\ \((1 - p[i])\)\ p[j] + 
      0.0191107446465576664`\ \((1 - p[k])\) - 
      0.0273201683168316789`\ \((1 - p[i])\)\ \((1 - p[k])\) + 
      0.0273201683168316789`\ p[j]\ \((1 - p[k])\) - 
      0.0408474418604651212`\ \((1 - p[i])\)\ p[j]\ \((1 - p[k])\) - 
      0.0191107446465576664`\ p[k] + 
      0.0273201683168316789`\ \((1 - p[i])\)\ p[k] - 
      0.0273201683168316789`\ p[j]\ p[k] + 
      0.0408474418604651212`\ \((1 - p[i])\)\ p[j]\ p[k] + 
      0.0382214892931153293`\ \((1 - p[\(i\^*\)])\) - 
      0.0624042884030977074`\ \((1 - p[i])\)\ \((1 - p[\(i\^*\)])\) + 
      0.062404288403097734`\ p[j]\ \((1 - p[\(i\^*\)])\) - 
      0.0352799999999999869`\ \((1 - p[i])\)\ p[j]\ \((1 - p[\(i\^*\)])\) - 
      0.031202144201548867`\ \((1 - p[k])\)\ \((1 - p[\(i\^*\)])\) + 
      0.0176399999999999934`\ \((1 - p[i])\)\ \((1 - p[k])\)\ \((1 - 
            p[\(i\^*\)])\) - 
      0.0176399999999999934`\ p[j]\ \((1 - p[k])\)\ \((1 - p[\(i\^*\)])\) + 
      0.130553465346534647`\ \((1 - p[i])\)\ p[
          j]\ \((1 - p[k])\)\ \((1 - p[\(i\^*\)])\) + 
      0.031202144201548867`\ p[k]\ \((1 - p[\(i\^*\)])\) - 
      0.0176399999999999934`\ \((1 - p[i])\)\ p[k]\ \((1 - p[\(i\^*\)])\) + 
      0.0176399999999999934`\ p[j]\ p[k]\ \((1 - p[\(i\^*\)])\) - 
      0.130553465346534647`\ \((1 - p[i])\)\ p[j]\ p[
          k]\ \((1 - p[\(i\^*\)])\) - 0.0382214892931153329`\ p[\(j\^*\)] + 
      0.062404288403097734`\ \((1 - p[i])\)\ p[\(j\^*\)] - 
      0.0624042884030977074`\ p[j]\ p[\(j\^*\)] + 
      0.0352799999999999869`\ \((1 - p[i])\)\ p[j]\ p[\(j\^*\)] + 
      0.031202144201548867`\ \((1 - p[k])\)\ p[\(j\^*\)] - 
      0.0176399999999999934`\ \((1 - p[i])\)\ \((1 - p[k])\)\ p[\(j\^*\)] + 
      0.0176399999999999934`\ p[j]\ \((1 - p[k])\)\ p[\(j\^*\)] - 
      0.130553465346534647`\ \((1 - p[i])\)\ p[
          j]\ \((1 - p[k])\)\ p[\(j\^*\)] - 
      0.031202144201548867`\ p[k]\ p[\(j\^*\)] + 
      0.0176399999999999934`\ \((1 - p[i])\)\ p[k]\ p[\(j\^*\)] - 
      0.0176399999999999934`\ p[j]\ p[k]\ p[\(j\^*\)] + 
      0.130553465346534647`\ \((1 - p[i])\)\ p[j]\ p[k]\ p[\(j\^*\)] + 
      0.0546403366336633578`\ \((1 - p[\(i\^*\)])\)\ p[\(j\^*\)] - 
      0.0352799999999999869`\ \((1 - p[i])\)\ \((1 - 
            p[\(i\^*\)])\)\ p[\(j\^*\)] + 
      0.0352799999999999869`\ p[j]\ \((1 - p[\(i\^*\)])\)\ p[\(j\^*\)] - 
      0.088199999999999985`\ \((1 - p[i])\)\ p[
          j]\ \((1 - p[\(i\^*\)])\)\ p[\(j\^*\)] - 
      0.0176399999999999934`\ \((1 - p[k])\)\ \((1 - 
            p[\(i\^*\)])\)\ p[\(j\^*\)] + 
      0.0440999999999999925`\ \((1 - p[i])\)\ \((1 - p[k])\)\ \((1 - 
            p[\(i\^*\)])\)\ p[\(j\^*\)] - 
      0.0440999999999999925`\ p[
          j]\ \((1 - p[k])\)\ \((1 - p[\(i\^*\)])\)\ p[\(j\^*\)] + 
      0.0176399999999999934`\ p[k]\ \((1 - p[\(i\^*\)])\)\ p[\(j\^*\)] - 
      0.0440999999999999925`\ \((1 - p[i])\)\ p[
          k]\ \((1 - p[\(i\^*\)])\)\ p[\(j\^*\)] + 
      0.0440999999999999925`\ p[j]\ p[
          k]\ \((1 - p[\(i\^*\)])\)\ p[\(j\^*\)] + 
      0.0191107446465576664`\ \((1 - p[\(k\^*\)])\) - 
      0.031202144201548867`\ \((1 - p[i])\)\ \((1 - p[\(k\^*\)])\) + 
      0.031202144201548867`\ p[j]\ \((1 - p[\(k\^*\)])\) - 
      0.0176399999999999934`\ \((1 - p[i])\)\ p[j]\ \((1 - p[\(k\^*\)])\) + 
      0.0312021442015488537`\ p[k]\ \((1 - p[\(k\^*\)])\) - 
      0.0176399999999999934`\ \((1 - p[i])\)\ p[k]\ \((1 - p[\(k\^*\)])\) + 
      0.0176399999999999934`\ p[j]\ p[k]\ \((1 - p[\(k\^*\)])\) - 
      0.130553465346534647`\ \((1 - p[i])\)\ p[j]\ p[
          k]\ \((1 - p[\(k\^*\)])\) - 
      0.0273201683168316789`\ \((1 - p[\(i\^*\)])\)\ \((1 - p[\(k\^*\)])\) + 
      0.0176399999999999934`\ \((1 - p[i])\)\ \((1 - p[\(i\^*\)])\)\ \((1 - 
            p[\(k\^*\)])\) - 
      0.0176399999999999934`\ p[
          j]\ \((1 - p[\(i\^*\)])\)\ \((1 - p[\(k\^*\)])\) + 
      0.0440999999999999925`\ \((1 - p[i])\)\ p[
          j]\ \((1 - p[\(i\^*\)])\)\ \((1 - p[\(k\^*\)])\) - 
      0.0176399999999999934`\ p[
          k]\ \((1 - p[\(i\^*\)])\)\ \((1 - p[\(k\^*\)])\) + 
      0.0440999999999999925`\ \((1 - p[i])\)\ p[
          k]\ \((1 - p[\(i\^*\)])\)\ \((1 - p[\(k\^*\)])\) - 
      0.0440999999999999925`\ p[j]\ p[
          k]\ \((1 - p[\(i\^*\)])\)\ \((1 - p[\(k\^*\)])\) + 
      0.0273201683168316789`\ p[\(j\^*\)]\ \((1 - p[\(k\^*\)])\) - 
      0.0176399999999999934`\ \((1 - p[i])\)\ p[\(j\^*\)]\ \((1 - 
            p[\(k\^*\)])\) + 
      0.0176399999999999934`\ p[j]\ p[\(j\^*\)]\ \((1 - p[\(k\^*\)])\) - 
      0.0440999999999999925`\ \((1 - p[i])\)\ p[
          j]\ p[\(j\^*\)]\ \((1 - p[\(k\^*\)])\) + 
      0.0176399999999999934`\ p[k]\ p[\(j\^*\)]\ \((1 - p[\(k\^*\)])\) - 
      0.0440999999999999925`\ \((1 - p[i])\)\ p[
          k]\ p[\(j\^*\)]\ \((1 - p[\(k\^*\)])\) + 
      0.0440999999999999925`\ p[j]\ p[
          k]\ p[\(j\^*\)]\ \((1 - p[\(k\^*\)])\) - 
      0.0408474418604651212`\ \((1 - p[\(i\^*\)])\)\ p[\(j\^*\)]\ \((1 - 
            p[\(k\^*\)])\) + 
      0.130553465346534647`\ \((1 - p[i])\)\ \((1 - 
            p[\(i\^*\)])\)\ p[\(j\^*\)]\ \((1 - p[\(k\^*\)])\) - 
      0.130553465346534647`\ p[
          j]\ \((1 - p[\(i\^*\)])\)\ p[\(j\^*\)]\ \((1 - p[\(k\^*\)])\) - 
      0.130553465346534647`\ p[
          k]\ \((1 - p[\(i\^*\)])\)\ p[\(j\^*\)]\ \((1 - 
            p[\(k\^*\)])\) + \((1 - p[i])\)\ p[j]\ p[
          k]\ \((1 - p[\(i\^*\)])\)\ p[\(j\^*\)]\ \((1 - p[\(k\^*\)])\) - 
      0.0191107446465576664`\ p[\(k\^*\)] + 
      0.031202144201548867`\ \((1 - p[i])\)\ p[\(k\^*\)] - 
      0.031202144201548867`\ p[j]\ p[\(k\^*\)] + 
      0.0176399999999999934`\ \((1 - p[i])\)\ p[j]\ p[\(k\^*\)] + 
      0.0312021442015488537`\ \((1 - p[k])\)\ p[\(k\^*\)] - 
      0.0176399999999999934`\ \((1 - p[i])\)\ \((1 - p[k])\)\ p[\(k\^*\)] + 
      0.0176399999999999934`\ p[j]\ \((1 - p[k])\)\ p[\(k\^*\)] - 
      0.130553465346534647`\ \((1 - p[i])\)\ p[
          j]\ \((1 - p[k])\)\ p[\(k\^*\)] + 
      0.0273201683168316789`\ \((1 - p[\(i\^*\)])\)\ p[\(k\^*\)] - 
      0.0176399999999999934`\ \((1 - p[i])\)\ \((1 - 
            p[\(i\^*\)])\)\ p[\(k\^*\)] + 
      0.0176399999999999934`\ p[j]\ \((1 - p[\(i\^*\)])\)\ p[\(k\^*\)] - 
      0.0440999999999999925`\ \((1 - p[i])\)\ p[
          j]\ \((1 - p[\(i\^*\)])\)\ p[\(k\^*\)] - 
      0.0176399999999999934`\ \((1 - p[k])\)\ \((1 - 
            p[\(i\^*\)])\)\ p[\(k\^*\)] + 
      0.0440999999999999925`\ \((1 - p[i])\)\ \((1 - p[k])\)\ \((1 - 
            p[\(i\^*\)])\)\ p[\(k\^*\)] - 
      0.0440999999999999925`\ p[
          j]\ \((1 - p[k])\)\ \((1 - p[\(i\^*\)])\)\ p[\(k\^*\)] - 
      0.0273201683168316789`\ p[\(j\^*\)]\ p[\(k\^*\)] + 
      0.0176399999999999934`\ \((1 - p[i])\)\ p[\(j\^*\)]\ p[\(k\^*\)] - 
      0.0176399999999999934`\ p[j]\ p[\(j\^*\)]\ p[\(k\^*\)] + 
      0.0440999999999999925`\ \((1 - p[i])\)\ p[
          j]\ p[\(j\^*\)]\ p[\(k\^*\)] + 
      0.0176399999999999934`\ \((1 - p[k])\)\ p[\(j\^*\)]\ p[\(k\^*\)] - 
      0.0440999999999999925`\ \((1 - p[i])\)\ \((1 - 
            p[k])\)\ p[\(j\^*\)]\ p[\(k\^*\)] + 
      0.0440999999999999925`\ p[
          j]\ \((1 - p[k])\)\ p[\(j\^*\)]\ p[\(k\^*\)] + 
      0.0408474418604651212`\ \((1 - 
            p[\(i\^*\)])\)\ p[\(j\^*\)]\ p[\(k\^*\)] - 
      0.130553465346534647`\ \((1 - p[i])\)\ \((1 - 
            p[\(i\^*\)])\)\ p[\(j\^*\)]\ p[\(k\^*\)] + 
      0.130553465346534647`\ p[
          j]\ \((1 - p[\(i\^*\)])\)\ p[\(j\^*\)]\ p[\(k\^*\)] - 
      0.130553465346534647`\ \((1 - p[k])\)\ \((1 - 
            p[\(i\^*\)])\)\ p[\(j\^*\)]\ p[\(k\^*\)] + \((1 - p[i])\)\ p[
          j]\ \((1 - p[k])\)\ \((1 - 
            p[\(i\^*\)])\)\ p[\(j\^*\)]\ p[\(k\^*\)]\)], "Output",
  CellLabel->"Out[410]="]
}, Closed]],

Cell["\<\
This uses DiploidGenotypeFrequency[] and MomentEquilibrium[]. It \
stores results. AdmixtureFrequency[] is very slow, since it uses a symbolic \
expression.  It is better to use the compiled version of \
DiploidGenotypeFrequency[] if numerical values are required..\
\>", "Text"],

Cell["\<\
The internal code just replaces c[U] in DiploidGenotypeFrequency[] \
by MomentEquilibrium[[U,\[Ellipsis]] \
\>", "Text"],

Cell[TextData[{
  "*** Note that the variable ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  "  is a dummy - only used internally to represent moments."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{862, 651},
WindowMargins->{{70, Automatic}, {Automatic, 6}},
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "MomentEquilibrium"->{
    Cell[1817, 53, 543, 10, 72, "DefinitionBox",
      CellTags->"MomentEquilibrium"]},
  "CumulantEquilibrium"->{
    Cell[7333, 224, 552, 10, 72, "DefinitionBox",
      CellTags->"CumulantEquilibrium"]},
  "AdmixtureFrequency"->{
    Cell[60782, 1158, 370, 7, 38, "DefinitionBox",
      CellTags->"AdmixtureFrequency"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"MomentEquilibrium", 70790, 1362},
  {"CumulantEquilibrium", 70905, 1365},
  {"AdmixtureFrequency", 71022, 1368}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 75, 0, 36, "SubsectionIcon"],
Cell[1817, 53, 543, 10, 72, "DefinitionBox",
  CellTags->"MomentEquilibrium"],
Cell[2363, 65, 46, 0, 28, "MathCaption"],
Cell[2412, 67, 87, 2, 27, "Input"],
Cell[2502, 71, 244, 8, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2771, 83, 131, 2, 27, "Input"],
Cell[2905, 87, 319, 6, 38, "Output"]
}, Open  ]],
Cell[3239, 96, 237, 6, 22, "Text"],
Cell[3479, 104, 205, 6, 24, "Text"],
Cell[3687, 112, 43, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3755, 116, 186, 4, 27, "Input"],
Cell[3944, 122, 295, 6, 37, "Output"]
}, Open  ]],
Cell[4254, 131, 877, 22, 50, "Text"],
Cell[5134, 155, 217, 8, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5376, 167, 216, 4, 27, "Input"],
Cell[5595, 173, 141, 3, 21, "Output"]
}, Open  ]],
Cell[5751, 179, 289, 9, 24, "Text"],
Cell[6043, 190, 123, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6191, 197, 202, 4, 27, "Input"],
Cell[6396, 203, 797, 13, 66, "Output"]
}, Open  ]],
Cell[7208, 219, 122, 3, 22, "Text"],
Cell[7333, 224, 552, 10, 72, "DefinitionBox",
  CellTags->"CumulantEquilibrium"],
Cell[7888, 236, 197, 4, 22, "Text"],
Cell[8088, 242, 102, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[8215, 249, 119, 3, 27, "Input"],
Cell[8337, 254, 7717, 152, 70, "Output"]
}, Closed]],
Cell[16069, 409, 120, 3, 18, "Text"],
Cell[16192, 414, 131, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[16348, 421, 234, 4, 43, "Input"],
Cell[16585, 427, 44009, 721, 2198, "Output"]
}, Closed]],
Cell[60609, 1151, 170, 5, 18, "Text"],
Cell[60782, 1158, 370, 7, 38, "DefinitionBox",
  CellTags->"AdmixtureFrequency"],
Cell[61155, 1167, 144, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[61324, 1174, 138, 3, 27, "Input"],
Cell[61465, 1179, 7897, 140, 70, "Output"]
}, Closed]],
Cell[69377, 1322, 289, 5, 32, "Text"],
Cell[69669, 1329, 130, 3, 22, "Text"],
Cell[69802, 1334, 170, 5, 22, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

