(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5144,        146]*)
(*NotebookOutlinePosition[      5989,        173]*)
(*  CellTagsIndexPosition[      5945,        169]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Overview", "SubsectionIcon"],

Cell[TextData[{
  "\tThis section includes the basic functions needed to represent diploid \
associations under migration and recombination.  They use an older and less \
general convention than ",
  ButtonBox["Multilocus`Multilocus`",
    ButtonData:>{"Introduction to multilocus algebra", 
      "Multilocus`Multilocus`"},
    ButtonStyle->"AddOnsLink"],
  ", which should be used in preference.  An ",
  ButtonBox["example",
    ButtonData:>{"Migration example", None},
    ButtonStyle->"AddOnsLink"],
  " of associations under migration is given there.  The package \
Multilocus`EstimatingD`  does not depend on the package \
Multilocus`Multilocus`, but should not clash with it."
}], "Text"],

Cell["\<\
\tThere are two basic routines.  MomentAfterMigration[] allows for \
an arbitrary pattern of immigration, and simply gives the appropriate linear \
mixture of moments; it could be used for haploid or diploid migration.   \
MomentAfterRecombination[] just calls \
Recombined[c[U],r]/.RandomMating[c]/.Symmetrise[c] to give the effect of \
recombination, followed by random union of gametes. \
\>", "Text"],

Cell[TextData[{
  "\tThe other functions described in this section apply to a more specific \
model of admixture (see Barton, ",
  ButtonBox["2000",
    ButtonData:>{"References", "Barton 2000"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"2000"],
  ").  There can be migration into deme 0 from two neighbouring demes, \
labelled -1, 1, at rates ",
  Cell[BoxData[
      \(TraditionalForm\`m\_s\[VeryThinSpace]q\&_\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(m\_s\) p\&_\)]],
  ", respectively.  These demes are assumed to differ in allele frequency by \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]p\_\(s, i\)\)]],
  "at locus ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ", but to have the same linkage disequilibria as the deme of interest.   \
This as an approximation to a shallow cline, in which disequilibrium changes \
gradually; it is therefore referred to as ",
  StyleBox["short-range migration",
    FontSlant->"Italic"],
  ".  There can also be migration into deme 0 from two demes, labelled -2, 2, \
at rates ",
  Cell[BoxData[
      \(TraditionalForm\`m\_l\[VeryThinSpace]q\&_\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(m\_l\) p\&_\)]],
  ", respectively.  These demes are assumed to differ in allele frequency by \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]p\_\(l, i\)\)]],
  "at locus ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ", and to be in Hardy-Weinberg and linkage equilibrium.  This represents ",
  StyleBox["long-range migration",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[TextData[{
  "Note that ",
  Cell[BoxData[
      \(TraditionalForm\`p\&_, \ q\&_\)]],
  " describe relative rates of migration, rather than allele frequencies.  \
The assumption that these relative rates are the same for both kinds of \
migration is restrictive, but simple."
}], "Text"],

Cell[TextData[{
  "Note that with short-range migration, and large ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]p\_s\)]],
  ", negative genotype frequencies may be predicted.  This is because the \
approximation that neighbouring demes have the same moments breaks down for \
large ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Delta]p\_s\)\(.\)\)\)]]
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{770, 615},
WindowMargins->{{Automatic, 72}, {Automatic, 28}},
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 34, 0, 36, "SubsectionIcon"],
Cell[1776, 53, 696, 15, 51, "Text"],
Cell[2475, 70, 414, 7, 50, "Text"],
Cell[2892, 79, 1564, 44, 103, "Text"],
Cell[4459, 125, 292, 7, 36, "Text"],
Cell[4754, 134, 374, 9, 36, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

