(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8373,        256]*)
(*NotebookOutlinePosition[     11860,        348]*)
(*  CellTagsIndexPosition[     11669,        339]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["The effect of recombination", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MomentAfterRecombination[U, c, 
              r]\), \(gives\ the\ moment\ after\ recombination\ and\ random\ \
\(\(mating\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"MomentAfterRecombination"],

Cell["\<\
This gives the pairwise linkage disequilibrium after recombination \
and random mating:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MomentAfterRecombination[{i\ , j}, c, r] // Simplify\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(1\/2\ \((c[{i, j}]\ r[{}, {i, j}] + 
          c[{\(i\^*\), \(j\^*\)}]\ r[{}, {i, j}] + \((c[{i, \(j\^*\)}] + 
                c[{j, \(i\^*\)}])\)\ r[{i}, {j}])\)\)], "Output",
  CellLabel->"Out[68]="]
}, Open  ]],

Cell["The recombination rates can be written in a simpler form:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MomentAfterRecombination[{i\ , j}, c, r] /. {r[{i}, {j}] \[Rule] rec, 
        r[{}, {i, j}] \[Rule] 1 - rec}\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(1\/2\ \((\ \((1 - rec)\)\ \((c[{i, j}] + c[{\(i\^*\), \(j\^*\)}])\) + \ 
          rec\ \((c[{i, \(j\^*\)}] + \ 
                rec\ c[{j, \(i\^*\)}])\))\)\)], "Output",
  CellLabel->"Out[71]="]
}, Open  ]],

Cell[TextData[{
  "Note:",
  StyleBox[" EstimatingD` uses an older convention, in which r[A,B] and \
r[B,A] are pooled.  This is ",
    FontWeight->"Plain"],
  "not",
  StyleBox[" the case for Multilocus`Multilocus`;",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell["This gives the same, for the cross-genome association:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MomentAfterRecombination[{i\ , \(j\^*\)}, c, r] // Simplify\)], "Input",\

  CellLabel->"In[69]:="],

Cell[BoxData[
    \(1\/4\ \((c[{i}] + c[{\(i\^*\)}])\)\ \((c[{j}] + 
          c[{\(j\^*\)}])\)\)], "Output",
  CellLabel->"Out[69]="]
}, Open  ]],

Cell["\<\
Note that this does not make any assumption about the reference \
point, and so c[{i}] etc. are non-zero.\
\>", "Text"],

Cell["\<\
MomentAfterRecombination[U,c,r] just calls \
Recombined[c[U],r]/.RandomMatingObsolete[c]/.Symmetrise[c]\
\>", "Text"],

Cell[TextData[{
  StyleBox["Note",
    FontWeight->"Bold"],
  ":  This section uses  an obsolete version of the ",
  ButtonBox["multilocus notation",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"multilocus notation"],
  ", which may cause trouble."
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(Recombined[c[U], 
              r]\), \(gives\ the\ value\ of\ c[U]\ after\ recombination; \ 
            it\ is\ a\ sum\ over\ all\ partitions\ of\ \(\(U\)\(.\)\)\)},
          {\(RandomMating[
              c]\), \(simplifies\ the\ moments\ c[]\ on\ the\ assumption\ of\ \
random\ mating\ between\ \(\(diploids\)\(.\)\)\)},
          {\(RandomUnionObsolete[
              c]\), \(simplifies\ the\ moments\ c[]\ on\ the\ assumption\ of\ \
random\ union\ of\ gametes\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"Recombined", "RandomUnionObsolete", "RandomMating"}],

Cell[TextData[{
  "This gives the association between i and j from the maternal genome, and \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(k\^*\)\ from\ the\ paternal\ genome\)\(,\)\(\ \
\)\)\)]],
  "after recombination:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Recombined[c[{i, j, \(k\^*\)}], r]\)], "Input",
  CellLabel->"In[12]:=  (14:24:55 on 4/10/01)"],

Cell[BoxData[
    \(1\/4\ c[{i, j, \(k\&^\)}]\ r[{}, {i, j}] + 
      1\/4\ c[{i, j, \(\(k\&^\)\^*\)}]\ r[{}, {i, j}] + 
      1\/4\ c[{\(i\^*\), \(j\^*\), \(k\&^\)}]\ r[{}, {i, j}] + 
      1\/4\ c[{\(i\^*\), \(j\^*\), \(\(k\&^\)\^*\)}]\ r[{}, {i, j}] + 
      1\/4\ c[{i, \(j\^*\), \(k\&^\)}]\ r[{i}, {j}] + 
      1\/4\ c[{i, \(j\^*\), \(\(k\&^\)\^*\)}]\ r[{i}, {j}] + 
      1\/4\ c[{j, \(i\^*\), \(k\&^\)}]\ r[{i}, {j}] + 
      1\/4\ c[{j, \(i\^*\), \(\(k\&^\)\^*\)}]\ r[{i}, {j}]\)], "Output",
  CellLabel->"Out[12]=  (14:24:55 on 4/10/01)"]
}, Open  ]],

Cell[TextData[{
  "This is written in terms of associations between males & females of a \
mated pair (for example, ",
  Cell[BoxData[
      \(\(\(c[{i, j, \(\(k\&^\)\^*\)}]\)\(\ \)\)\)]],
  ").  With random mating:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. RandomMating[c]\)], "Input",
  CellLabel->"In[13]:=  (14:24:59 on 4/10/01)"],

Cell[BoxData[
    \(1\/4\ c[{k}]\ c[{i, j}]\ r[{}, {i, j}] + 
      1\/4\ c[{\(k\^*\)}]\ c[{i, j}]\ r[{}, {i, j}] + 
      1\/4\ c[{k}]\ c[{\(i\^*\), \(j\^*\)}]\ r[{}, {i, j}] + 
      1\/4\ c[{\(k\^*\)}]\ c[{\(i\^*\), \(j\^*\)}]\ r[{}, {i, j}] + 
      1\/4\ c[{k}]\ c[{i, \(j\^*\)}]\ r[{i}, {j}] + 
      1\/4\ c[{\(k\^*\)}]\ c[{i, \(j\^*\)}]\ r[{i}, {j}] + 
      1\/4\ c[{k}]\ c[{j, \(i\^*\)}]\ r[{i}, {j}] + 
      1\/4\ c[{\(k\^*\)}]\ c[{j, \(i\^*\)}]\ r[{i}, {j}]\)], "Output",
  CellLabel->"Out[13]=  (14:24:59 on 4/10/01)"]
}, Open  ]],

Cell[TextData[{
  "This simplifies still further if one assumes random union of gametes, such \
that ",
  Cell[BoxData[
      \(TraditionalForm\`c[{i, \(j\^*\)}] = \(\(c[{i}] 
            c[{\(j\^*\)}]\)\(:\)\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. RandomUnionObsolete[c]\)], "Input",
  CellLabel->"In[14]:=  (14:25:09 on 4/10/01)"],

Cell[BoxData[
    \(1\/4\ c[{k}]\ c[{i, j}]\ r[{}, {i, j}] + 
      1\/4\ c[{\(k\^*\)}]\ c[{i, j}]\ r[{}, {i, j}] + 
      1\/4\ c[{k}]\ c[{\(i\^*\), \(j\^*\)}]\ r[{}, {i, j}] + 
      1\/4\ c[{\(k\^*\)}]\ c[{\(i\^*\), \(j\^*\)}]\ r[{}, {i, j}] + 
      1\/4\ c[{j}]\ c[{k}]\ c[{\(i\^*\)}]\ r[{i}, {j}] + 
      1\/4\ c[{i}]\ c[{k}]\ c[{\(j\^*\)}]\ r[{i}, {j}] + 
      1\/4\ c[{j}]\ c[{\(i\^*\)}]\ c[{\(k\^*\)}]\ r[{i}, {j}] + 
      1\/4\ c[{i}]\ c[{\(j\^*\)}]\ c[{\(k\^*\)}]\ r[{i}, {j}]\)], "Output",
  CellLabel->"Out[14]=  (14:25:09 on 4/10/01)"]
}, Open  ]],

Cell[TextData[{
  "Note: ",
  StyleBox[" RandomUnionObsolete[c] only applies within EstimatingD`, which \
uses an ",
    FontWeight->"Plain"],
  ButtonBox["obsolete",
    ButtonData:>{"Bugs", "Obsolete EstimatingD"},
    ButtonStyle->"AddOnsLink"],
  StyleBox[" notation.  It is different from ",
    FontWeight->"Plain"],
  ButtonBox["RandomUnion",
    ButtonData:>{"Random union", "RandomUnion"},
    ButtonStyle->"AddOnsLink"],
  StyleBox["[], which is defined more generally by Multilocus`Multilocus`.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{827, 662},
WindowMargins->{{88, Automatic}, {Automatic, 8}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "MomentAfterRecombination"->{
    Cell[1795, 53, 288, 6, 37, "DefinitionBox",
      CellTags->"MomentAfterRecombination"]},
  "Recombined"->{
    Cell[4339, 144, 651, 12, 74, "DefinitionBox",
      CellTags->{"Recombined", "RandomUnionObsolete", "RandomMating"}]},
  "RandomUnionObsolete"->{
    Cell[4339, 144, 651, 12, 74, "DefinitionBox",
      CellTags->{"Recombined", "RandomUnionObsolete", "RandomMating"}]},
  "RandomMating"->{
    Cell[4339, 144, 651, 12, 74, "DefinitionBox",
      CellTags->{"Recombined", "RandomUnionObsolete", "RandomMating"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"MomentAfterRecombination", 11116, 323},
  {"Recombined", 11228, 326},
  {"RandomUnionObsolete", 11378, 329},
  {"RandomMating", 11521, 332}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 53, 0, 36, "SubsectionIcon"],
Cell[1795, 53, 288, 6, 37, "DefinitionBox",
  CellTags->"MomentAfterRecombination"],
Cell[2086, 61, 118, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2229, 68, 110, 2, 27, "Input"],
Cell[2342, 72, 221, 4, 36, "Output"]
}, Open  ]],
Cell[2578, 79, 82, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2685, 84, 167, 3, 27, "Input"],
Cell[2855, 89, 215, 4, 36, "Output"]
}, Open  ]],
Cell[3085, 96, 277, 9, 24, "Text"],
Cell[3365, 107, 77, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3467, 111, 119, 3, 27, "Input"],
Cell[3589, 116, 134, 3, 36, "Output"]
}, Open  ]],
Cell[3738, 122, 129, 3, 22, "Text"],
Cell[3870, 127, 127, 3, 22, "Text"],
Cell[4000, 132, 336, 10, 24, "Text"],
Cell[4339, 144, 651, 12, 74, "DefinitionBox",
  CellTags->{"Recombined", "RandomUnionObsolete", "RandomMating"}],
Cell[4993, 158, 245, 7, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5263, 169, 115, 2, 27, "Input"],
Cell[5381, 173, 548, 9, 64, "Output"]
}, Open  ]],
Cell[5944, 185, 235, 6, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[6204, 195, 101, 2, 27, "Input"],
Cell[6308, 199, 532, 9, 64, "Output"]
}, Open  ]],
Cell[6855, 211, 233, 6, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7113, 221, 108, 2, 27, "Input"],
Cell[7224, 225, 552, 9, 64, "Output"]
}, Open  ]],
Cell[7791, 237, 566, 16, 38, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

