(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    242322,       3994]*)
(*NotebookOutlinePosition[    315623,       6621]*)
(*  CellTagsIndexPosition[    315214,       6605]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Alternative measures of association", "Subsection"],

Cell[TextData[{
  "There are many alternative measures of association between multiple loci, \
each best suited for different purposes; these are reviewed by Dawson (",
  ButtonBox["2000",
    ButtonData:>{"Multilocus references", "Dawson 2000"},
    ButtonStyle->"AddOnsLink"],
  ") and Christiansen (",
  ButtonBox["1998",
    ButtonData:>{"Multilocus references", "Christiansen 1998"},
    ButtonStyle->"AddOnsLink"],
  ").  This section documents measures that simplify the dynamics under \
recombination.   Cumulant measures, which simplify selection on an additive \
trait, are documented ",
  ButtonBox["below",
    ButtonData:>{"Multilocus cumulants", None},
    ButtonStyle->"AddOnsLink"],
  ". "
}], "Text"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Multilocus`Multilocus`;\)\)], "Input",
  CellLabel->"In[60]:="],

Cell[CellGroupData[{

Cell["Baake's measure", "SubsectionIcon",
  CellTags->"Baake"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            
            FormBox[\(\[GothicCapitalD]\_\[DoubleStruckCapitalU] /. 
                ToBaake[]\),
              
              "TraditionalForm"], \(transforms\ linkage\ disequilibria, \ \
\[GothicCapitalD], \ to\ Baake' s\ measure, \ \(\(\[GothicZ]\)\(.\)\)\)},
          {
            FormBox[\(\[GothicZ]\_\[DoubleStruckCapitalU] /. FromBaake[]\),
              "TraditionalForm"], \(transforms\ Baake' 
              s\ measure, \ \[GothicZ], \ 
            to\ linkage\ disequilibria, \ \(\(\[GothicCapitalD]\)\(.\)\(\ \
\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"ToBaake", "FromBaake"}],

Cell[TextData[{
  "Baake (",
  ButtonBox["2001",
    ButtonData:>{"Multilocus references", "Baake 2001"},
    ButtonStyle->"AddOnsLink"],
  ") defines a measure of association among genes which decays exponentially \
under weak recombination (that is, in continuous time, or in discrete time, \
but with no more than one crossover per generation).  The definition depends \
on gene order, but not on recombination rates."
}], "Text"],

Cell[TextData[{
  "NOTE: ",
  StyleBox["the order of the genes is taken to be the same as the order of \
the subscripts.   Therefore, ",
    FontWeight->"Plain"],
  StyleBox[ButtonBox["Symmetrise",
    ButtonData:>{"Disequilibrium", "Symmetrise"},
    ButtonStyle->"AddOnsLink"],
    FontWeight->"Plain"],
  StyleBox["[] should be used with care, since it reorders the subscripts.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell["\<\
This expresses the four-way linkage disequilibrium inmterms of \
Baake's measure:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]} /. ToBaake[]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(\(-\[GothicZ]\_{\[DoubleStruckI]}\)\ \[GothicZ]\_{\[DoubleStruckJ]}\ \
\[GothicZ]\_{\[DoubleStruckK]}\ \[GothicZ]\_{\[DoubleStruckL]} + \
\[GothicZ]\_{\[DoubleStruckK]}\ \[GothicZ]\_{\[DoubleStruckL]}\ \[GothicZ]\_{\
\[DoubleStruckI], \[DoubleStruckJ]} + \[GothicZ]\_{\[DoubleStruckI]}\ \
\[GothicZ]\_{\[DoubleStruckL]}\ \[GothicZ]\_{\[DoubleStruckJ], \
\[DoubleStruckK]} + \[GothicZ]\_{\[DoubleStruckI]}\ \[GothicZ]\_{\
\[DoubleStruckJ]}\ \[GothicZ]\_{\[DoubleStruckK], \[DoubleStruckL]} - \
\[GothicZ]\_{\[DoubleStruckI], \[DoubleStruckJ]}\ \[GothicZ]\_{\
\[DoubleStruckK], \[DoubleStruckL]} - \[GothicZ]\_{\[DoubleStruckL]}\ \
\[GothicZ]\_{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]} - \
\[GothicZ]\_{\[DoubleStruckI]}\ \[GothicZ]\_{\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]} + \[GothicZ]\_{\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell[TextData[{
  "This is a sum over all partitions that respect gene order; the algorithm \
uses ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          ButtonBox["PartitionSet",
            ButtonData:>{"Set partitions", "Ordered"},
            ButtonStyle->"AddOnsLink"], "[", \(\[DoubleStruckCapitalU], j, 
          Ordered \[Rule] True\), "]"}], TraditionalForm]]],
  "."
}], "Text"],

Cell["This transforms the expression back:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. FromBaake[] // Simplify\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            
            FormBox[\(d[{\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK]}] /. ToBaake[d, z]\),
              "TraditionalForm"], \(transforms\ disequilibria, \ d, \ 
            to\ Baake' s\ measure, \ \(\(z\)\(.\)\)\)},
          {
            
            FormBox[\(z[{\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK]}] /. FromBaake[z, d]\),
              
              "TraditionalForm"], \(makes\ the\ opposite\ \
\(\(transformation\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["The rules can work with arbitrary symbols:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(d[{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]}] /. 
      ToBaake[d, z]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(z[{\[DoubleStruckI]}]\ z[{\[DoubleStruckJ]}]\ z[{\[DoubleStruckK]}] - 
      z[{\[DoubleStruckK]}]\ z[{\[DoubleStruckI], \[DoubleStruckJ]}] - 
      z[{\[DoubleStruckI]}]\ z[{\[DoubleStruckJ], \[DoubleStruckK]}] + 
      z[{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]}]\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. FromBaake[z, d] // Simplify\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(d[{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]}]\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Checking that Baake's measures decay exponentially", "SubsubsectionIcon"],

Cell[TextData[{
  "In order to apply recombination to Baake's disequilibrium measure, we must \
define ",
  ButtonBox["stages",
    ButtonData:>{"Life cycle", None},
    ButtonStyle->"AddOnsLink"],
  " in the life cycle:"
}], "Text"],

Cell[BoxData[{
    \(\(DefineContext[\[GothicCapitalG], {Sex}];\)\), "\[IndentingNewLine]", 
    \(\(DefineContext[\[GothicCapitalZ], {Sex, 
          SexOfOrigin}];\)\), "\[IndentingNewLine]", 
    \(\(DefineContext[\[GothicCapitalA], {Sex, 
          SexOfOrigin}];\)\), "\[IndentingNewLine]", 
    \(\(DefineContext[\(\[GothicCapitalG]\^*\), {Sex}];\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell[TextData[{
  ButtonBox["LinkedRecombination",
    ButtonData:>{"RecombinationDocumentation.nb", "LinkedRecombination"},
    ButtonStyle->"Hyperlink"],
  "[A,B,{i,j,k,l},c] simplifies the recombination rates, assuming gene order \
{i,j,k,l}:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LinkedRecombination[{i, j}, {k}, {i, j, k, l}, c]\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \(1\/2\ \((1 - c[i, j])\)\ c[j, k]\)], "Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell[TextData[{
  "These rules convert ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicZ]\_\[DoubleStruckCapitalU]\)]],
  " into an expression involving ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_\[DoubleStruckCapitalV]\)]],
  "(FromBaake[]); apply Recombination[] and UnionOfGametes[]; simplify \
reference points and recombination rates; and finally convert back to an \
expression in terms of the ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicZ]\_\[DoubleStruckCapitalU]\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\(\(\(\(\(\(\(\[GothicZ]\_{i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}} /. FromBaake[]\) /. 
                        Recombination[{\[GothicCapitalZ], \(\[GothicCapitalG]\
\^*\)}, RecombinationRate]\) /. SymmetricRecombination[]\) /. 
                    UnionOfGametes[]\) /. RandomUnion[\[GothicCapitalG]]\) /. 
                ReferencePointSame[\(\[GothicCapitalG]\^*\), {\
\[GothicCapitalZ], \[GothicCapitalG]}]\) /. 
              ReferencePointZero[\(\[GothicCapitalG]\^*\)]\) /. 
            SymmetricSexes[]\) /. 
          ToBaake[]\) /. \[GothicR]\_\(A_, B_\) \[RuleDelayed] 
          LinkedRecombination[A, B, {i, j, k, l}, c] // Simplify\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(\[GothicZ]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, k\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \((\(-1\) + c[i, j])\)\ \((\(-1\) + 
            c[j, k])\) + \[GothicZ]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicZ]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, \
k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ c[i, j]\ c[j, k]\)], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell["\<\
If we make the further assumption that recombination is rare, we \
see that the three-way association decays exponentially, at a rate equal to \
the sum of the constituent recombination rates:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SlowChange[% /. 
            c[a__] \[RuleDelayed] \[GothicS]\ c[a]] /. \[GothicS] \[Rule] 1 // 
      Simplify\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(\(-\[GothicZ]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, k\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\)\ \((\(-1\) + c[i, j] + c[j, k])\)\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell["This does the same for the four-way association:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\(\(\(\(\(\(\(\[GothicZ]\_{i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}, l\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}} /. FromBaake[]\) /. 
                        Recombination[{\[GothicCapitalZ], \(\[GothicCapitalG]\
\^*\)}, RecombinationRate]\) /. SymmetricRecombination[]\) /. 
                    UnionOfGametes[]\) /. RandomUnion[\[GothicCapitalG]]\) /. 
                ReferencePointSame[\(\[GothicCapitalG]\^*\), {\
\[GothicCapitalZ], \[GothicCapitalG]}]\) /. 
              ReferencePointZero[\(\[GothicCapitalG]\^*\)]\) /. 
            SymmetricSexes[]\) /. 
          ToBaake[]\) /. \[GothicR]\_\(A_, B_\) \[RuleDelayed] 
          LinkedRecombination[A, B, {i, j, k, l}, c] // Simplify\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(\(-\[GothicZ]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, l\_{\[GothicCapitalG], \[GothicCapitalF]}}\)\ \((\(-1\) + 
            c[i, j])\)\ \((\(-1\) + c[j, k])\)\ \((\(-1\) + 
            c[k, l])\) + \((\(-\[GothicZ]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, l\_{\[GothicCapitalG], \[GothicCapitalF]}}\)\ \
\[GothicZ]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, \
k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ c[i, 
                j]\ \((\(-1\) + 
                  c[j, k])\) + \((\(-\[GothicZ]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\)\ \[GothicZ]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}, l\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \((\(-1\) + 
                        c[i, j])\) + \[GothicZ]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicZ]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}, \
l\_{\[GothicCapitalG], \[GothicCapitalF]}}\ c[i, j])\)\ c[j, k])\)\ c[k, 
          l] + \[GothicZ]\_{j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ c[i, 
          j]\ \((\(-\[GothicZ]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, k\
\_{\[GothicCapitalG], \[GothicCapitalF]}, l\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\)\ c[j, 
                k]\ \((\(-1\) + 
                  c[k, l])\) - \[GothicZ]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicZ]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, \
l\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \((\(-1\) + c[j, k])\)\ c[k, 
                l])\)\)], "Output",
  CellLabel->"Out[29]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SlowChange[% /. 
            c[a__] \[RuleDelayed] \[GothicS]\ c[a]] /. \[GothicS] \[Rule] 1 // 
      Simplify\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(\(-\[GothicZ]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}, k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, l\_{\[GothicCapitalG], \[GothicCapitalF]}}\)\ \((\(-1\) + 
          c[i, j] + c[j, k] + c[k, l])\)\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Bennett's principal components", "SubsectionIcon",
  CellTags->"Bennett"],

Cell[TextData[{
  "These measures, defined by Bennett (",
  ButtonBox["1954",
    ButtonData:>{"Multilocus references", "Bennett 1954"},
    ButtonStyle->"AddOnsLink"],
  "), decay exponentially for arbitrary recombination rates. Dawson (",
  ButtonBox["2000",
    ButtonData:>{"Multilocus references", "Dawson 2000"},
    ButtonStyle->"AddOnsLink"],
  ") reviews their history and their relation with other measures, and gives \
an explicit algorithm for calculating them.  This is more efficient (but more \
complicated) than that used here."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            
            FormBox[\(\[GothicCapitalD]\_\[DoubleStruckCapitalU] /. 
                ToBennett[]\),
              
              "TraditionalForm"], \(transforms\ linkage\ disequilibria, \ \
\[GothicCapitalD], \ to\ Bennett' s\ measure, \ \(\(\[GothicB]\)\(.\)\)\)},
          {
            FormBox[\(\[GothicB]\_\[DoubleStruckCapitalU] /. FromBennett[]\),
              "TraditionalForm"], \(transforms\ Bennett' 
              s\ measure, \ \[GothicB], \ 
            to\ linkage\ disequilibria, \ \(\(\[GothicCapitalD]\)\(.\)\(\ \
\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"ToBennett", "FromBennett"}],

Cell["\<\
This is Bennett's measure of association amongst three genes:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicB]\_{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]} /. 
        FromBennett[] // Expand\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(2\ \[GothicCapitalD]\_{\[DoubleStruckI]}\ \[GothicCapitalD]\_{\
\[DoubleStruckJ]}\ \[GothicCapitalD]\_{\[DoubleStruckK]} - \
\[GothicCapitalD]\_{\[DoubleStruckK]}\ \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ]} - \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckK]} - \
\[GothicCapitalD]\_{\[DoubleStruckI]}\ \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK]}\)], "Output",
  CellLabel->"Out[64]="]
}, Open  ]],

Cell["This is the same as the cumulant measure:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicK]\_{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]} /. 
        ToMoments[] // Expand\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(2\ \[GothicCapitalD]\_{\[DoubleStruckI]}\ \[GothicCapitalD]\_{\
\[DoubleStruckJ]}\ \[GothicCapitalD]\_{\[DoubleStruckK]} - \
\[GothicCapitalD]\_{\[DoubleStruckK]}\ \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ]} - \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckK]} - \
\[GothicCapitalD]\_{\[DoubleStruckI]}\ \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK]}\)], "Output",
  CellLabel->"Out[66]="]
}, Open  ]],

Cell["Differences only emerge with more than 3 loci:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicB]\_{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]} /. FromBennett[]\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(\(-\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\
\[DoubleStruckJ]}\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \
\[GothicCapitalD]\_{\[DoubleStruckL]}\ \[GothicCapitalD]\_{\[DoubleStruckM]} \
+ \[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]} + \(\((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckJ]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]}\ \[GothicCapitalD]\_{\[DoubleStruckM]} \
- \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckK]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckK], \[DoubleStruckL]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckK]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckK], \[DoubleStruckM]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckL]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckL], \[DoubleStruckM]})\) + \
\[GothicCapitalD]\_{\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]})\)\ \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckJ]}, {\[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI], \[DoubleStruckJ]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckI]}\ \
\[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckK]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \[GothicCapitalD]\
\_{\[DoubleStruckM]} - \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckL]})\) - \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckM]})\) - \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckL]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckL], \
\[DoubleStruckM]})\) + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]})\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, \
{\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckJ]}, {\[DoubleStruckI], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckJ]}, {\[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\((\(-\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\
\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckK]})\)\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]}\ \[GothicCapitalD]\_{\[DoubleStruckM]} \
- \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckL]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckM]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckL]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckL], \[DoubleStruckM]})\) + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckL], \[DoubleStruckM]})\)\ \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckK]}, {\[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI], \[DoubleStruckK]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckI]}\ \
\[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \[GothicCapitalD]\
\_{\[DoubleStruckM]} - \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckL]})\) - \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckM]})\) - \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckL]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckL], \
\[DoubleStruckM]})\) + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]})\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, \
{\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckK]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckK]}, {\[DoubleStruckJ], \[DoubleStruckL], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckK]}\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) - \
\[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \[GothicCapitalD]\
\_{\[DoubleStruckK]}\ \[GothicCapitalD]\_{\[DoubleStruckL]} - \
\[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \[GothicCapitalD]\
\_{\[DoubleStruckK]} - \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckJ]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ]})\) - \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckK]})\) - \[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]})\) + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \[GothicCapitalD]\
\_{\[DoubleStruckL]} - \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckJ]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ]})\) - \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckL]})\) - \[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckL]})\) + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckL]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \[GothicCapitalD]\
\_{\[DoubleStruckL]} - \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckK]})\) - \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckL]})\) - \[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckL]})\) + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckL]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \[GothicCapitalD]\
\_{\[DoubleStruckL]} - \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]})\) - \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckL]})\) - \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckL]})\) + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]})\) + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL]} + \(\((\(-\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckJ]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ]})\)\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckL]})\)\ \[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckJ]}, {\
\[DoubleStruckK], \[DoubleStruckL]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI], \[DoubleStruckJ]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \
\[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckI]}\ \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckL]})\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\[DoubleStruckJ]}, {\
\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckJ]}, {\[DoubleStruckK], \
\[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \
\[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckK]}\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckJ]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ]})\)\ \((\[GothicR]\_\({\[DoubleStruckK]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckL]}\) + \[GothicR]\_\({\[DoubleStruckL]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckJ]}, {\[DoubleStruckK], \
\[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckK]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckL]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\)\) + \(\((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckK]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckL]})\)\ \[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckK]}, {\
\[DoubleStruckJ], \[DoubleStruckL]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI], \[DoubleStruckK]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckI]}\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckL]})\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\[DoubleStruckK]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckK]}, {\[DoubleStruckJ], \
\[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckK]}\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckK]})\)\ \((\[GothicR]\_\({\[DoubleStruckJ]}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\[DoubleStruckL]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckK]}, {\[DoubleStruckJ], \
\[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckL]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckK]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\)\) + \(\((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckL]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]})\)\ \[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckL]}, {\
\[DoubleStruckJ], \[DoubleStruckK]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI], \[DoubleStruckL]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckK]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckL]})\)\ \((\[GothicR]\_\({\[DoubleStruckJ]}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\[DoubleStruckK]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckL]}, {\[DoubleStruckJ], \
\[DoubleStruckK]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckK]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckI]}\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]})\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\[DoubleStruckL]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckL]}, {\[DoubleStruckJ], \
\[DoubleStruckK]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckL]}\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckK]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\)\))\) + \(\((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckL]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]}\ \[GothicCapitalD]\_{\[DoubleStruckM]} \
- \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]} + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckK]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckM]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckK]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckK], \[DoubleStruckM]})\) + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]})\)\ \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckL]}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI], \[DoubleStruckL]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckI]}\ \
\[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \[GothicCapitalD]\
\_{\[DoubleStruckM]} - \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]})\) - \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckM]})\) - \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckM]})\) + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]})\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, \
{\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckL]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckL]}, {\[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckL]}\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) - \
\[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \[GothicCapitalD]\
\_{\[DoubleStruckK]}\ \[GothicCapitalD]\_{\[DoubleStruckM]} - \
\[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \[GothicCapitalD]\
\_{\[DoubleStruckK]} - \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckJ]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ]})\) - \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckK]})\) - \[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]})\) + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \[GothicCapitalD]\
\_{\[DoubleStruckM]} - \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckJ]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ]})\) - \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckM]})\) - \[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckM]})\) + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckM]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \[GothicCapitalD]\
\_{\[DoubleStruckM]} - \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckK]})\) - \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckM]})\) - \[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckM]})\) + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckM]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \[GothicCapitalD]\
\_{\[DoubleStruckM]} - \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]})\) - \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckM]})\) - \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckM]})\) + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]})\) + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckM]} + \(\((\(-\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckJ]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ]})\)\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckM]})\)\ \[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckJ]}, {\
\[DoubleStruckK], \[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI], \[DoubleStruckJ]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckI]}\ \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckM]})\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckJ]}, {\
\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckJ]}, {\[DoubleStruckK], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckK]}\ \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckJ]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ]})\)\ \((\[GothicR]\_\({\[DoubleStruckK]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckJ]}, {\[DoubleStruckK], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckK]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\)\) + \(\((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckK]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckM]})\)\ \[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckK]}, {\
\[DoubleStruckJ], \[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI], \[DoubleStruckK]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckI]}\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckM]})\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckK]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckK]}, {\[DoubleStruckJ], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckK]}\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\ \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckK]})\)\ \((\[GothicR]\_\({\[DoubleStruckJ]}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckK]}, {\[DoubleStruckJ], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckK]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\)\) + \(\((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckM]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]})\)\ \[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckM]}, {\
\[DoubleStruckJ], \[DoubleStruckK]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI], \[DoubleStruckM]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckK]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckM]})\)\ \((\[GothicR]\_\({\[DoubleStruckJ]}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckK]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckM]}, {\[DoubleStruckJ], \
\[DoubleStruckK]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckK]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckI]}\ \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]})\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckM]}, {\[DoubleStruckJ], \
\[DoubleStruckK]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckK]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\)\))\) - \[GothicCapitalD]\_{\
\[DoubleStruckK]}\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckJ]}\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} - \[GothicCapitalD]\_{\[DoubleStruckM]}\
\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\
\[DoubleStruckJ]}\ \[GothicCapitalD]\_{\[DoubleStruckL]} - \
\[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckJ]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckL]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckL]})\) + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL]})\) \
- \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \[GothicCapitalD]\
\_{\[DoubleStruckM]} - \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckJ]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ]})\) - \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckM]})\) - \[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckM]})\) + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckM]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \[GothicCapitalD]\
\_{\[DoubleStruckM]} - \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckL]})\) - \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckM]})\) - \[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckL]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckL], \
\[DoubleStruckM]})\) + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckL], \[DoubleStruckM]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \[GothicCapitalD]\
\_{\[DoubleStruckM]} - \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckL]})\) - \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckM]})\) - \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckL]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckL], \
\[DoubleStruckM]})\) + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]})\) + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL], \
\[DoubleStruckM]} + \(\((\(-\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckJ]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ]})\)\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckL]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckL], \
\[DoubleStruckM]})\)\ \[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckJ]}, {\
\[DoubleStruckL], \[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI], \[DoubleStruckJ]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckL], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckI]}\ \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckL]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckL], \
\[DoubleStruckM]})\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, {\[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckJ]}, {\
\[DoubleStruckI], \[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckJ]}, {\[DoubleStruckL], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\ \[GothicR]\_\({}, {\[DoubleStruckL], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckL]}\ \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckJ]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ]})\)\ \((\[GothicR]\_\({\[DoubleStruckL]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckJ]}, {\[DoubleStruckL], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckL]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckL]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckM]})\)\ \[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckL]}, {\
\[DoubleStruckJ], \[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI], \[DoubleStruckL]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckI]}\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckM]})\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, {\[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckL]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckL]}, {\[DoubleStruckJ], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckL]}\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\ \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckL]})\)\ \((\[GothicR]\_\({\[DoubleStruckJ]}, {\[DoubleStruckI], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckL]}, {\[DoubleStruckJ], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckM]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckL]})\)\ \[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckM]}, {\
\[DoubleStruckJ], \[DoubleStruckL]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI], \[DoubleStruckM]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckM]})\)\ \((\[GothicR]\_\({\[DoubleStruckJ]}, {\[DoubleStruckI], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckL]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckM]}, {\[DoubleStruckJ], \
\[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckL]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckI]}\ \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckL]})\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, {\[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckM]}, {\[DoubleStruckJ], \
\[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\)\))\) - \[GothicCapitalD]\_{\
\[DoubleStruckJ]}\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]}\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} - \[GothicCapitalD]\_{\[DoubleStruckM]}\
\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\
\[DoubleStruckK]}\ \[GothicCapitalD]\_{\[DoubleStruckL]} - \
\[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckK]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckL]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckK]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckK], \[DoubleStruckL]})\) + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL]})\) \
- \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \[GothicCapitalD]\
\_{\[DoubleStruckM]} - \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckK]})\) - \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckM]})\) - \[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckM]})\) + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckM]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \[GothicCapitalD]\
\_{\[DoubleStruckM]} - \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckL]})\) - \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckM]})\) - \[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckL]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckL], \
\[DoubleStruckM]})\) + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckL], \[DoubleStruckM]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckK]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \[GothicCapitalD]\
\_{\[DoubleStruckM]} - \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckL]})\) - \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckM]})\) - \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckL]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckL], \
\[DoubleStruckM]})\) + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]})\) + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]} + \(\((\(-\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckK]})\)\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckL]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckL], \
\[DoubleStruckM]})\)\ \[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckK]}, {\
\[DoubleStruckL], \[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI], \[DoubleStruckK]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckL], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckI]}\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckL]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckL], \
\[DoubleStruckM]})\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, {\[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckK]}, {\
\[DoubleStruckI], \[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckK]}, {\[DoubleStruckL], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckK]}\)\ \[GothicR]\_\({}, {\[DoubleStruckL], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckL]}\ \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckK]})\)\ \((\[GothicR]\_\({\[DoubleStruckL]}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckK]}, {\[DoubleStruckL], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckL]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckK]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckL]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckM]})\)\ \[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckL]}, {\
\[DoubleStruckK], \[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI], \[DoubleStruckL]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckI]}\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckM]})\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, {\[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckL]}, {\
\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckL]}, {\[DoubleStruckK], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckL]}\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckK]}\ \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckL]})\)\ \((\[GothicR]\_\({\[DoubleStruckK]}, {\[DoubleStruckI], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckL]}, {\[DoubleStruckK], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckK]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckM]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckL]})\)\ \[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckM]}, {\
\[DoubleStruckK], \[DoubleStruckL]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI], \[DoubleStruckM]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \
\[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckK]}\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckM]})\)\ \((\[GothicR]\_\({\[DoubleStruckK]}, {\[DoubleStruckI], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckL]}, {\
\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckM]}, {\[DoubleStruckK], \
\[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckK]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckL]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckI]}\ \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckL]})\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, {\[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckM]}, {\[DoubleStruckK], \
\[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \
\[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\))\) + \(\((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckM]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]}\ \[GothicCapitalD]\_{\[DoubleStruckL]} \
- \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]} + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckK]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckL]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckK]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckK], \[DoubleStruckL]})\) + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]})\)\ \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckM]}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI], \[DoubleStruckM]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckI]}\ \
\[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \[GothicCapitalD]\
\_{\[DoubleStruckL]} - \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]})\) - \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckL]})\) - \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckL]})\) + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]})\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, \
{\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckM]}, {\[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\((\(-\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\
\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]})\)\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]}\ \[GothicCapitalD]\_{\[DoubleStruckM]} \
- \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckL]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckM]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckL]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckL], \[DoubleStruckM]})\) + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckL], \[DoubleStruckM]})\)\ \
\[GothicR]\_\({\[DoubleStruckJ], \[DoubleStruckK]}, {\[DoubleStruckI], \
\[DoubleStruckL], \[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckJ], \[DoubleStruckK]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckJ]}\ \
\[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \[GothicCapitalD]\
\_{\[DoubleStruckM]} - \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckL]})\) - \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckM]})\) - \[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckL]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckL], \
\[DoubleStruckM]})\) + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckL], \[DoubleStruckM]})\)\ \((\[GothicR]\_\({\[DoubleStruckJ]}, \
{\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckK]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckJ], \
\[DoubleStruckK]}, {\[DoubleStruckI], \[DoubleStruckL], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckK]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckL]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]})\)\ \((\(-\(\(\[GothicR]\_\({\[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\)\ \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckL]}, {\[DoubleStruckJ], \
\[DoubleStruckK]}\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckL]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckK]}\
\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL]}\)\)\)\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckL]}, {\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckJ], \[DoubleStruckK]}, {\[DoubleStruckI], \
\[DoubleStruckL], \[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckM]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckL]}\
\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckK]}\) + \
\[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckM]})\)\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]})\)\ \((\(-\(\(\[GothicR]\_\({\[DoubleStruckL]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\)\ \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckM]}, {\[DoubleStruckJ], \
\[DoubleStruckK]}\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckM]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckK]}\
\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckM]}\)\)\)\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckM]}, {\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\) + \
\[GothicR]\_\({\[DoubleStruckJ], \[DoubleStruckK]}, {\[DoubleStruckI], \
\[DoubleStruckL], \[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckL]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckM]}\
\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckK]}\) + \
\[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckL]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]}\ \[GothicCapitalD]\_{\[DoubleStruckM]} \
- \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckK]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckM]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckK]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckK], \[DoubleStruckM]})\) + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckM]})\)\ \
\[GothicR]\_\({\[DoubleStruckJ], \[DoubleStruckL]}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckJ], \[DoubleStruckL]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckJ]}\ \
\[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \[GothicCapitalD]\
\_{\[DoubleStruckM]} - \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckK]})\) - \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckM]})\) - \[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckM]})\) + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckM]})\)\ \((\[GothicR]\_\({\[DoubleStruckJ]}, \
{\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckL]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckJ], \
\[DoubleStruckL]}, {\[DoubleStruckI], \[DoubleStruckK], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckL]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckK]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckL]})\)\ \((\(-\(\(\[GothicR]\_\({\[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\)\ \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckK]}, {\[DoubleStruckJ], \
\[DoubleStruckL]}\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckK]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckL]}\
\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL]}\)\)\)\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckK]}, {\[DoubleStruckJ], \[DoubleStruckL], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckJ], \[DoubleStruckL]}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckM]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckK]}\
\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckL]}\) + \
\[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckK]}\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckM]})\)\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckL]})\)\ \((\(-\(\(\[GothicR]\_\({\[DoubleStruckK]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL], \[DoubleStruckM]}\)\ \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckM]}, {\[DoubleStruckJ], \
\[DoubleStruckL]}\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckM]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckL]}\
\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL], \
\[DoubleStruckM]}\)\)\)\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckM]}, {\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\) + \
\[GothicR]\_\({\[DoubleStruckJ], \[DoubleStruckL]}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckK]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckM]}\
\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckL]}\) + \
\[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) - \
\[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \[GothicCapitalD]\
\_{\[DoubleStruckL]}\ \[GothicCapitalD]\_{\[DoubleStruckM]} - \
\[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \[GothicCapitalD]\
\_{\[DoubleStruckL]} - \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]})\) - \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckL]})\) - \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckL]})\) + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \[GothicCapitalD]\
\_{\[DoubleStruckM]} - \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]})\) - \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckM]})\) - \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckM]})\) + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \[GothicCapitalD]\
\_{\[DoubleStruckM]} - \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckL]})\) - \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckM]})\) - \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckL]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckL], \
\[DoubleStruckM]})\) + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckK]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \[GothicCapitalD]\
\_{\[DoubleStruckM]} - \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckL]})\) - \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckM]})\) - \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckL]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckL], \
\[DoubleStruckM]})\) + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]})\) + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]} + \(\((\(-\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]})\)\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckL]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckL], \
\[DoubleStruckM]})\)\ \[GothicR]\_\({\[DoubleStruckJ], \[DoubleStruckK]}, {\
\[DoubleStruckL], \[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckJ], \[DoubleStruckK]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckL], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckL]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckL], \
\[DoubleStruckM]})\)\ \((\[GothicR]\_\({\[DoubleStruckJ]}, {\[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckK]}, {\
\[DoubleStruckJ], \[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckJ], \[DoubleStruckK]}, {\[DoubleStruckL], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckK]}\)\ \[GothicR]\_\({}, {\[DoubleStruckL], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckL]}\ \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]})\)\ \((\[GothicR]\_\({\[DoubleStruckL]}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckM]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckJ], \[DoubleStruckK]}, {\[DoubleStruckL], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckL]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckK]}\) + \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckL]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckM]})\)\ \[GothicR]\_\({\[DoubleStruckJ], \[DoubleStruckL]}, {\
\[DoubleStruckK], \[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckJ], \[DoubleStruckL]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckM]})\)\ \((\[GothicR]\_\({\[DoubleStruckJ]}, {\[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckL]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckJ], \[DoubleStruckL]}, {\[DoubleStruckK], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckL]}\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckK]}\ \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckL]})\)\ \((\[GothicR]\_\({\[DoubleStruckK]}, {\[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckM]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckJ], \[DoubleStruckL]}, {\[DoubleStruckK], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckK]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckM]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckL]})\)\ \[GothicR]\_\({\[DoubleStruckJ], \[DoubleStruckM]}, {\
\[DoubleStruckK], \[DoubleStruckL]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckJ], \[DoubleStruckM]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \
\[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckK]}\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckM]})\)\ \((\[GothicR]\_\({\[DoubleStruckK]}, {\[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckL]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckJ], \[DoubleStruckM]}, {\[DoubleStruckK], \
\[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckK]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckL]}\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\ \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckL]})\)\ \((\[GothicR]\_\({\[DoubleStruckJ]}, {\[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckM]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckJ], \[DoubleStruckM]}, {\[DoubleStruckK], \
\[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \
\[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\))\) + \(\((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckM]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]}\ \[GothicCapitalD]\_{\[DoubleStruckL]} \
- \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckK]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckL]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckK]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckK], \[DoubleStruckL]})\) + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL]})\)\ \
\[GothicR]\_\({\[DoubleStruckJ], \[DoubleStruckM]}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckL]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckJ], \[DoubleStruckM]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckJ]}\ \
\[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \[GothicCapitalD]\
\_{\[DoubleStruckL]} - \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckK]})\) - \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckL]})\) - \[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckL]})\) + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckL]})\)\ \((\[GothicR]\_\({\[DoubleStruckJ]}, \
{\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\[DoubleStruckJ], \
\[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckK], \
\[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckK]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckM]})\)\ \((\(-\(\(\[GothicR]\_\({\[DoubleStruckL]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\)\ \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckK]}, {\[DoubleStruckJ], \
\[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckK]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckM]}\
\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckM]}\)\)\)\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckK]}, {\[DoubleStruckJ], \[DoubleStruckL], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckJ], \[DoubleStruckM]}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckL]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckK]}\
\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckM]}\) + \
\[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckK]}\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckL]})\)\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckM]})\)\ \((\(-\(\(\[GothicR]\_\({\[DoubleStruckK]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL], \[DoubleStruckM]}\)\ \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckL]}, {\[DoubleStruckJ], \
\[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckL]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckM]}\
\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL], \
\[DoubleStruckM]}\)\)\)\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckL]}, {\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckJ], \[DoubleStruckM]}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckK]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckL]}\
\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckM]}\) + \
\[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\((\(-\[GothicCapitalD]\_{\
\[DoubleStruckK]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckK], \[DoubleStruckL]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckJ]}\ \[GothicCapitalD]\_{\[DoubleStruckM]} \
- \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckJ]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckM]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckM]})\) + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckM]})\)\ \
\[GothicR]\_\({\[DoubleStruckK], \[DoubleStruckL]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckK], \[DoubleStruckL]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckK]}\ \
\[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \[GothicCapitalD]\
\_{\[DoubleStruckM]} - \[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckJ]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ]})\) - \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckM]})\) - \[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckM]})\) + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckM]})\)\ \((\[GothicR]\_\({\[DoubleStruckK]}, \
{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckL]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckK], \
\[DoubleStruckL]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckK]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckL]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckJ]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckL]})\)\ \((\(-\(\(\[GothicR]\_\({\[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\)\ \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckJ]}, {\[DoubleStruckK], \
\[DoubleStruckL]}\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \[DoubleStruckL]}\
\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL]}\)\)\)\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckJ]}, {\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckK], \[DoubleStruckL]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckM]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ]}\
\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \[DoubleStruckL]}\) + \
\[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckM]})\)\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckL]})\)\ \((\(-\(\(\[GothicR]\_\({\[DoubleStruckJ]}, {\
\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\ \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckM]}, {\[DoubleStruckK], \
\[DoubleStruckL]}\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckM]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \[DoubleStruckL]}\
\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\)\)\)\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckM]}, {\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\) + \
\[GothicR]\_\({\[DoubleStruckK], \[DoubleStruckL]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckJ]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckM]}\
\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \[DoubleStruckL]}\) + \
\[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \((\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \
\[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckM]})\)\ \((\(-\(\(\
\[GothicR]\_\({\[DoubleStruckL]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\)\ \((\[GothicR]\_\({\[DoubleStruckJ]}, {\
\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckK]}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckM]}, {\[DoubleStruckJ], \
\[DoubleStruckK]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckM]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\)\)\)\) - \
\(\[GothicR]\_\({\[DoubleStruckK]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\)\ \((\[GothicR]\_\({\[DoubleStruckJ]}, {\
\[DoubleStruckI], \[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckL]}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckM]}, {\[DoubleStruckJ], \
\[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckM]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckL], \[DoubleStruckM]}\)\) - \(\[GothicR]\_\({\
\[DoubleStruckJ]}, {\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\)\ \((\[GothicR]\_\({\[DoubleStruckK]}, {\[DoubleStruckI], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckL]}, {\
\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckM]}, {\[DoubleStruckK], \
\[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckM]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckM]}, {\[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL]}\) + \[GothicR]\_\({\[DoubleStruckJ], \[DoubleStruckK]}, {\
\[DoubleStruckI], \[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckJ], \[DoubleStruckL]}, {\[DoubleStruckI], \[DoubleStruckK], \
\[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckK], \[DoubleStruckL]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckM]}\))\))\)/\((\(-\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckK]}\)\ \[GothicR]\_\({}, \
{\[DoubleStruckL]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\))\) + \(\
\[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckM]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckL]})\)\ \((\(-\(\(\[GothicR]\_\({\[DoubleStruckI]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\ \
\[GothicR]\_\({\[DoubleStruckJ], \[DoubleStruckM]}, {\[DoubleStruckK], \
\[DoubleStruckL]}\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckM]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \[DoubleStruckL]}\
\) + \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\)\)\)\) + \[GothicR]\_\({\[DoubleStruckJ], \
\[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL]}\) + \
\[GothicR]\_\({\[DoubleStruckK], \[DoubleStruckL]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckM]}\
\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \[DoubleStruckL]}\) + \
\[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \((\[GothicCapitalD]\_{\
\[DoubleStruckI]}\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \
\[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckM]})\)\ \((\(-\(\(\
\[GothicR]\_\({\[DoubleStruckL]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckK]}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckK]}, {\[DoubleStruckJ], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckM]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\)\)\)\) + \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckK]}, {\[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\) - \(\[GothicR]\_\({\[DoubleStruckK]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL], \[DoubleStruckM]}\)\ \
\((\[GothicR]\_\({\[DoubleStruckI]}, {\[DoubleStruckJ], \[DoubleStruckL], \
\[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckL]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckL]}, {\[DoubleStruckJ], \[DoubleStruckM]}\))\)\)\/\(\(-\
\[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckM]}\)\) + \
\[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL], \
\[DoubleStruckM]}\)\) + \[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckL]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\) - \(\[GothicR]\_\({\
\[DoubleStruckI]}, {\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\)\ \((\[GothicR]\_\({\[DoubleStruckK]}, {\[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckL]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckJ], \[DoubleStruckM]}, {\[DoubleStruckK], \
\[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckM]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \[GothicR]\_\({\
\[DoubleStruckJ], \[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckK], \
\[DoubleStruckL]}\) + \[GothicR]\_\({\[DoubleStruckK], \[DoubleStruckL]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckM]}\))\))\)/\((\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckK]}\)\ \[GothicR]\_\({}, \
{\[DoubleStruckL]}\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\))\) + \((\
\[GothicCapitalD]\_{\[DoubleStruckI]}\ \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \
\[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckK]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckK], \[DoubleStruckL]})\)\ \((\(-\(\(\
\[GothicR]\_\({\[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckJ]}, {\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL]}\) + \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckJ]}, {\[DoubleStruckK], \
\[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckK], \
\[DoubleStruckL]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\)\)\)\) + \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckJ]}, {\[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\) - \(\[GothicR]\_\({\[DoubleStruckJ]}, {\
\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\ \
\((\[GothicR]\_\({\[DoubleStruckI]}, {\[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckM]}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckM]}, {\[DoubleStruckK], \[DoubleStruckL]}\))\)\)\/\(\(-\
\[GothicR]\_\({}, {\[DoubleStruckK], \[DoubleStruckL]}\)\) + \
\[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\)\) + \[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckM]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\) - \(\[GothicR]\_\({\
\[DoubleStruckI]}, {\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\)\ \((\[GothicR]\_\({\[DoubleStruckJ]}, {\[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckM]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckJ], \[DoubleStruckM]}, {\[DoubleStruckK], \
\[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckK], \
\[DoubleStruckL]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \[GothicR]\_\({\
\[DoubleStruckJ], \[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckK], \
\[DoubleStruckL]}\) + \[GothicR]\_\({\[DoubleStruckK], \[DoubleStruckL]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckM]}\))\))\)/\((\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\ \[GothicR]\_\({}, \
{\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \
\[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\))\) + \(\((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckM]})\)\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckJ]}\ \[GothicCapitalD]\_{\[DoubleStruckL]} \
- \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckJ]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckL]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckL]})\) + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL]})\)\ \
\[GothicR]\_\({\[DoubleStruckK], \[DoubleStruckM]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckL]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckK], \[DoubleStruckM]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckK]}\ \
\[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \[GothicCapitalD]\
\_{\[DoubleStruckL]} - \[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckJ]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ]})\) - \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckL]})\) - \[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckL]})\) + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckL]})\)\ \((\[GothicR]\_\({\[DoubleStruckK]}, \
{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\[DoubleStruckK], \
\[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckK]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckJ]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckM]})\)\ \((\(-\(\(\[GothicR]\_\({\[DoubleStruckL]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\)\ \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckJ]}, {\[DoubleStruckK], \
\[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \[DoubleStruckM]}\
\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckM]}\)\)\)\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckJ]}, {\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckK], \[DoubleStruckM]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckL]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ]}\
\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \[DoubleStruckM]}\) + \
\[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckL]})\)\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckM]})\)\ \((\(-\(\(\[GothicR]\_\({\[DoubleStruckJ]}, {\
\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\ \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckL]}, {\[DoubleStruckK], \
\[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckL]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \[DoubleStruckM]}\
\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\)\)\)\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckL]}, {\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckK], \[DoubleStruckM]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckJ]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckL]}\
\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \[DoubleStruckM]}\) + \
\[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckI]}\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckL]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckL]})\)\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckK]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckK], \
\[DoubleStruckM]})\)\ \((\(-\(\(\[GothicR]\_\({\[DoubleStruckI]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\ \
\[GothicR]\_\({\[DoubleStruckJ], \[DoubleStruckL]}, {\[DoubleStruckK], \
\[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckL]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \[DoubleStruckM]}\
\) + \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\)\)\)\) + \[GothicR]\_\({\[DoubleStruckJ], \
\[DoubleStruckL]}, {\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckK], \[DoubleStruckM]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckL]}\
\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \[DoubleStruckM]}\) + \
\[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \((\[GothicCapitalD]\_{\
\[DoubleStruckI]}\ \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \
\[GothicCapitalD]\_{\[DoubleStruckL]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckK]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckK], \[DoubleStruckM]})\)\ \((\(-\(\(\
\[GothicR]\_\({\[DoubleStruckL]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckJ]}, {\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckJ]}, {\[DoubleStruckK], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckK], \
\[DoubleStruckM]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\)\)\)\) + \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckJ]}, {\[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\) - \(\[GothicR]\_\({\[DoubleStruckJ]}, {\
\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\ \
\((\[GothicR]\_\({\[DoubleStruckI]}, {\[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckL]}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckL]}, {\[DoubleStruckK], \[DoubleStruckM]}\))\)\)\/\(\(-\
\[GothicR]\_\({}, {\[DoubleStruckK], \[DoubleStruckM]}\)\) + \
\[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\)\) + \[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckL]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\) - \(\[GothicR]\_\({\
\[DoubleStruckI]}, {\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\)\ \((\[GothicR]\_\({\[DoubleStruckJ]}, {\[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckL]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckJ], \[DoubleStruckL]}, {\[DoubleStruckK], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckK], \
\[DoubleStruckM]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \[GothicR]\_\({\
\[DoubleStruckJ], \[DoubleStruckL]}, {\[DoubleStruckI], \[DoubleStruckK], \
\[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckK], \[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckL]}\))\))\)/\((\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\ \[GothicR]\_\({}, \
{\[DoubleStruckL]}\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\))\) + \((\
\[GothicCapitalD]\_{\[DoubleStruckI]}\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \
\[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckL]})\)\ \((\(-\(\(\
\[GothicR]\_\({\[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckK]}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL]}\) + \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckK]}, {\[DoubleStruckJ], \
\[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckL]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\)\)\)\) + \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckK]}, {\[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\) - \(\[GothicR]\_\({\[DoubleStruckK]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL], \[DoubleStruckM]}\)\ \
\((\[GothicR]\_\({\[DoubleStruckI]}, {\[DoubleStruckJ], \[DoubleStruckL], \
\[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckM]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckL]}\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckM]}, {\[DoubleStruckJ], \[DoubleStruckL]}\))\)\)\/\(\(-\
\[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckL]}\)\) + \
\[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL], \
\[DoubleStruckM]}\)\) + \[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckM]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\) - \(\[GothicR]\_\({\
\[DoubleStruckI]}, {\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\)\ \((\[GothicR]\_\({\[DoubleStruckK]}, {\[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckM]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckJ], \[DoubleStruckL]}, {\[DoubleStruckK], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckL]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \[GothicR]\_\({\
\[DoubleStruckJ], \[DoubleStruckL]}, {\[DoubleStruckI], \[DoubleStruckK], \
\[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckK], \[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckL]}\))\))\)/\((\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckK]}\)\ \[GothicR]\_\({}, \
{\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\))\) + \((\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\ \[GothicCapitalD]\_{\[DoubleStruckK]}\ \
\[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckL]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckL]})\)\ \((\(-\(\(\
\[GothicR]\_\({\[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\)\ \((\[GothicR]\_\({\[DoubleStruckJ]}, {\
\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckK]}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL]}\) + \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckL]}, {\[DoubleStruckJ], \
\[DoubleStruckK]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckL]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\)\)\)\) - \
\(\[GothicR]\_\({\[DoubleStruckK]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\)\ \((\[GothicR]\_\({\[DoubleStruckJ]}, {\
\[DoubleStruckI], \[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL]}\) + \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckL]}, {\[DoubleStruckJ], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckL]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckL], \[DoubleStruckM]}\)\) - \(\[GothicR]\_\({\
\[DoubleStruckJ]}, {\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\)\ \((\[GothicR]\_\({\[DoubleStruckK]}, {\[DoubleStruckI], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckL]}, {\[DoubleStruckK], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckL]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckL]}, {\[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckJ], \[DoubleStruckK]}, {\
\[DoubleStruckI], \[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckJ], \[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckK], \
\[DoubleStruckL]}\) + \[GothicR]\_\({\[DoubleStruckK], \[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckL]}\))\))\)/\((\(-\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckK]}\)\ \[GothicR]\_\({}, \
{\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\))\) + \(\((\(-\
\[GothicCapitalD]\_{\[DoubleStruckL]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckL], \
\[DoubleStruckM]})\)\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckJ]}\ \[GothicCapitalD]\_{\[DoubleStruckK]} \
- \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckJ]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckK]})\) - \
\[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]} + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckK]})\) + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]})\)\ \
\[GothicR]\_\({\[DoubleStruckL], \[DoubleStruckM]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckL], \[DoubleStruckM]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckL]}\ \
\[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \[GothicCapitalD]\
\_{\[DoubleStruckK]} - \[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckJ]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ]})\) - \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckK]})\) - \[GothicCapitalD]\_{\[DoubleStruckI]}\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]})\) + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK]})\)\ \((\[GothicR]\_\({\[DoubleStruckL]}, \
{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\[DoubleStruckL], \
\[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckL]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckJ]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ]})\)\ \((\(-\
\[GothicCapitalD]\_{\[DoubleStruckL]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckL], \
\[DoubleStruckM]})\)\ \((\(-\(\(\[GothicR]\_\({\[DoubleStruckK]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL], \[DoubleStruckM]}\)\ \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckJ]}, {\[DoubleStruckL], \
\[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckL], \[DoubleStruckM]}\
\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL], \
\[DoubleStruckM]}\)\)\)\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckJ]}, {\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckL], \[DoubleStruckM]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckK]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ]}\
\)\ \[GothicR]\_\({}, {\[DoubleStruckL], \[DoubleStruckM]}\) + \
\[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckI]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckK]})\)\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckL]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckL], \
\[DoubleStruckM]})\)\ \((\(-\(\(\[GothicR]\_\({\[DoubleStruckJ]}, {\
\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\ \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckK]}, {\[DoubleStruckL], \
\[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckK]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckL], \[DoubleStruckM]}\
\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\)\)\)\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckK]}, {\[DoubleStruckJ], \[DoubleStruckL], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckL], \[DoubleStruckM]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckJ]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckK]}\
\)\ \[GothicR]\_\({}, {\[DoubleStruckL], \[DoubleStruckM]}\) + \
\[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \(\[GothicCapitalD]\_{\
\[DoubleStruckI]}\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckJ]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckK]} + \[GothicCapitalD]\_{\[DoubleStruckJ], \
\[DoubleStruckK]})\)\ \((\(-\[GothicCapitalD]\_{\[DoubleStruckL]}\)\ \
\[GothicCapitalD]\_{\[DoubleStruckM]} + \[GothicCapitalD]\_{\[DoubleStruckL], \
\[DoubleStruckM]})\)\ \((\(-\(\(\[GothicR]\_\({\[DoubleStruckI]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\ \
\[GothicR]\_\({\[DoubleStruckJ], \[DoubleStruckK]}, {\[DoubleStruckL], \
\[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckK]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckL], \[DoubleStruckM]}\
\) + \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\)\)\)\) + \[GothicR]\_\({\[DoubleStruckJ], \
\[DoubleStruckK]}, {\[DoubleStruckI], \[DoubleStruckL], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckL], \[DoubleStruckM]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckK]}\
\)\ \[GothicR]\_\({}, {\[DoubleStruckL], \[DoubleStruckM]}\) + \
\[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\) + \((\[GothicCapitalD]\_{\
\[DoubleStruckI]}\ \[GothicCapitalD]\_{\[DoubleStruckJ]}\ \
\[GothicCapitalD]\_{\[DoubleStruckK]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckL]}\)\ \[GothicCapitalD]\_{\[DoubleStruckM]} + \
\[GothicCapitalD]\_{\[DoubleStruckL], \[DoubleStruckM]})\)\ \((\(-\(\(\
\[GothicR]\_\({\[DoubleStruckK]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, {\
\[DoubleStruckJ], \[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckJ]}, {\[DoubleStruckI], \[DoubleStruckL], \[DoubleStruckM]}\) + \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckJ]}, {\[DoubleStruckL], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckL], \
\[DoubleStruckM]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckL], \[DoubleStruckM]}\)\)\)\) + \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckJ]}, {\[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\) - \(\[GothicR]\_\({\[DoubleStruckJ]}, {\
\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\ \
\((\[GothicR]\_\({\[DoubleStruckI]}, {\[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckK]}, {\[DoubleStruckI], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckK]}, {\[DoubleStruckL], \[DoubleStruckM]}\))\)\)\/\(\(-\
\[GothicR]\_\({}, {\[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\)\) + \[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckK]}, {\
\[DoubleStruckJ], \[DoubleStruckL], \[DoubleStruckM]}\) - \(\[GothicR]\_\({\
\[DoubleStruckI]}, {\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\)\ \((\[GothicR]\_\({\[DoubleStruckJ]}, {\[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckK]}, {\
\[DoubleStruckJ], \[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckJ], \[DoubleStruckK]}, {\[DoubleStruckL], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckL], \
\[DoubleStruckM]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \[GothicR]\_\({\
\[DoubleStruckJ], \[DoubleStruckK]}, {\[DoubleStruckI], \[DoubleStruckL], \
\[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckL], \[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK]}\))\))\)/\((\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\ \[GothicR]\_\({}, \
{\[DoubleStruckK]}\)\ \[GothicR]\_\({}, {\[DoubleStruckL], \
\[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\))\) + \((\
\[GothicCapitalD]\_{\[DoubleStruckI]}\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \
\[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckJ]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]} + \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckK]})\)\ \((\(-\(\(\
\[GothicR]\_\({\[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\)\ \((\[GothicR]\_\({\[DoubleStruckI]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckL]}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]}\) + \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckL]}, {\[DoubleStruckJ], \
\[DoubleStruckK]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckK]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\)\)\)\) + \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckL]}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\) - \(\[GothicR]\_\({\[DoubleStruckL]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\)\ \
\((\[GothicR]\_\({\[DoubleStruckI]}, {\[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckM]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK]}\) + \[GothicR]\_\({\[DoubleStruckI], \
\[DoubleStruckM]}, {\[DoubleStruckJ], \[DoubleStruckK]}\))\)\)\/\(\(-\
\[GothicR]\_\({}, {\[DoubleStruckJ], \[DoubleStruckK]}\)\) + \
\[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckM]}\)\) + \[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckM]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\) - \(\[GothicR]\_\({\
\[DoubleStruckI]}, {\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\)\ \((\[GothicR]\_\({\[DoubleStruckL]}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckM]}, {\
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckJ], \[DoubleStruckK]}, {\[DoubleStruckL], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckK]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \[GothicR]\_\({\
\[DoubleStruckJ], \[DoubleStruckK]}, {\[DoubleStruckI], \[DoubleStruckL], \
\[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckL], \[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK]}\))\))\)/\((\(-\[GothicR]\_\({}, {\[DoubleStruckI]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckL]}\)\ \[GothicR]\_\({}, \
{\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckK]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\))\) + \((\
\[GothicCapitalD]\_{\[DoubleStruckJ]}\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \
\[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckK]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckK]})\)\ \((\(-\(\(\
\[GothicR]\_\({\[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\)\ \((\[GothicR]\_\({\[DoubleStruckJ]}, {\
\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckL]}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]}\) + \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckK]}, {\[DoubleStruckJ], \
\[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckK]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\)\)\)\) - \
\(\[GothicR]\_\({\[DoubleStruckL]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\)\ \((\[GothicR]\_\({\[DoubleStruckJ]}, {\
\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]}\) + \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckK]}, {\[DoubleStruckJ], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckK]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\)\) - \(\[GothicR]\_\({\
\[DoubleStruckJ]}, {\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\)\ \((\[GothicR]\_\({\[DoubleStruckL]}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckK]}, {\[DoubleStruckL], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckK]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckK]}, {\[DoubleStruckJ], \[DoubleStruckL], \
\[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckJ], \[DoubleStruckL]}, {\
\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckJ], \[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckK], \
\[DoubleStruckL]}\) + \[GothicR]\_\({\[DoubleStruckL], \[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK]}\))\))\)/\((\(-\[GothicR]\_\({}, {\[DoubleStruckJ]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckL]}\)\ \[GothicR]\_\({}, \
{\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckK]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\))\) + \((\
\[GothicCapitalD]\_{\[DoubleStruckK]}\ \[GothicCapitalD]\_{\[DoubleStruckL]}\ \
\[GothicCapitalD]\_{\[DoubleStruckM]}\ \((\(-\[GothicCapitalD]\_{\
\[DoubleStruckI]}\)\ \[GothicCapitalD]\_{\[DoubleStruckJ]} + \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ]})\)\ \((\(-\(\(\
\[GothicR]\_\({\[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\)\ \((\[GothicR]\_\({\[DoubleStruckK]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckL]}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]}\) + \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckJ]}, {\[DoubleStruckK], \
\[DoubleStruckL]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\)\)\)\) - \
\(\[GothicR]\_\({\[DoubleStruckL]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\)\ \((\[GothicR]\_\({\[DoubleStruckK]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]}\) + \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckJ]}, {\[DoubleStruckK], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\)\) - \(\[GothicR]\_\({\
\[DoubleStruckK]}, {\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL], \
\[DoubleStruckM]}\)\ \((\[GothicR]\_\({\[DoubleStruckL]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL]}\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckJ]}, {\[DoubleStruckL], \
\[DoubleStruckM]}\))\)\)\/\(\(-\[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ]}\)\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \[GothicR]\_\({\
\[DoubleStruckI], \[DoubleStruckJ]}, {\[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\) + \[GothicR]\_\({\[DoubleStruckK], \[DoubleStruckL]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckM]}\) + \[GothicR]\_\({\
\[DoubleStruckK], \[DoubleStruckM]}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckL]}\) + \[GothicR]\_\({\[DoubleStruckL], \[DoubleStruckM]}, {\
\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK]}\))\))\)/\((\(-\[GothicR]\_\({}, {\[DoubleStruckK]}\)\)\ \
\[GothicR]\_\({}, {\[DoubleStruckL]}\)\ \[GothicR]\_\({}, \
{\[DoubleStruckM]}\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\))\)\)], "Output",
  CellLabel->"Out[68]="]
}, Closed]],

Cell[TextData[{
  "Bennett's measures are complicated functions of the recombination rates.  \
They simplify somewhat if disequilibria are defined relative to current \
allele frequencies, so that ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_{i} = 0\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. \[GothicCapitalD]\_{_} \[RuleDelayed] 0\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]} + \
\(\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ]}\ \
\[GothicCapitalD]\_{\[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\ \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckJ]}, {\[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI], \[DoubleStruckJ]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckK]}\ \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckL], \[DoubleStruckM]}\ \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckK]}, {\[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI], \[DoubleStruckK]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckL]}\ \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckM]}\ \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckL]}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI], \[DoubleStruckL]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckM]}\ \
\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}\ \
\[GothicR]\_\({\[DoubleStruckI], \[DoubleStruckM]}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckI], \[DoubleStruckM]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckJ], \
\[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckK]}\ \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckL], \[DoubleStruckM]}\ \
\[GothicR]\_\({\[DoubleStruckJ], \[DoubleStruckK]}, {\[DoubleStruckI], \
\[DoubleStruckL], \[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckJ], \[DoubleStruckK]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckL], \[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckL]}\ \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckM]}\ \
\[GothicR]\_\({\[DoubleStruckJ], \[DoubleStruckL]}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckJ], \[DoubleStruckL]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckJ], \[DoubleStruckM]}\ \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckK], \[DoubleStruckL]}\ \
\[GothicR]\_\({\[DoubleStruckJ], \[DoubleStruckM]}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckL]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckJ], \[DoubleStruckM]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckK], \[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckK], \[DoubleStruckL]}\ \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckM]}\ \
\[GothicR]\_\({\[DoubleStruckK], \[DoubleStruckL]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckM]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckK], \[DoubleStruckL]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckM]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckK], \[DoubleStruckM]}\ \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckL]}\ \
\[GothicR]\_\({\[DoubleStruckK], \[DoubleStruckM]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckL]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckK], \[DoubleStruckM]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckL]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \[DoubleStruckM]}\)\) + \
\(\[GothicCapitalD]\_{\[DoubleStruckL], \[DoubleStruckM]}\ \
\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK]}\ \
\[GothicR]\_\({\[DoubleStruckL], \[DoubleStruckM]}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK]}\)\)\/\(\(-\[GothicR]\_\({}, {\
\[DoubleStruckL], \[DoubleStruckM]}\)\)\ \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK]}\) + \[GothicR]\_\({}, {\[DoubleStruckI], \
\[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL], \
\[DoubleStruckM]}\)\)\)], "Output",
  CellLabel->"Out[69]="]
}, Open  ]],

Cell["The transformation can be reversed:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(% /. ToBennett[]\) /. \[GothicB]\_{_} \[RuleDelayed] 0 // 
      Expand\)], "Input",
  CellLabel->"In[72]:="],

Cell[BoxData[
    \(\[GothicB]\_{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL], \[DoubleStruckM]}\)], "Output",
  CellLabel->"Out[72]="]
}, Open  ]],

Cell[TextData[{
  "NOTE:",
  StyleBox[" Confusingly, the recombination rates in the=is section  are \
taken to include ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[GothicR]\_\(A, B\)\)],
    FontWeight->"Plain"],
  StyleBox[" and ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[GothicR]\_\(B, A\)\)],
    FontWeight->"Plain"],
  StyleBox[" and so differ by a factor 2 from those elsewhere",
    FontWeight->"Plain"],
  StyleBox[" ",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            FormBox[\(d\_\[DoubleStruckCapitalU] /. ToBennett[d, b, r]\),
              "TraditionalForm"], \(transforms\ linkage\ disequilibria, \ 
            d, \ to\ Bennett' s\ measure, \ b, \ 
            using\ arbitrary\ symbols\)},
          {
            FormBox[\(b\_\[DoubleStruckCapitalU] /. FromBennett[b, d, r]\),
              "TraditionalForm"], \(transforms\ Bennett' s\ measure, \ b, \ 
            to\ linkage\ disequilibria, \ d, \ using\ arbitrary\ symbols\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(b\_{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL]} /. FromBennett[b, d, r]\) /. 
      d[{_}] \[RuleDelayed] 0\)], "Input",
  CellLabel->"In[82]:="],

Cell[BoxData[
    \(d[{\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL]}] + \(d[{\[DoubleStruckI], \[DoubleStruckJ]}]\ d[{\
\[DoubleStruckK], \[DoubleStruckL]}]\ r[{\[DoubleStruckI], \[DoubleStruckJ]}, \
{\[DoubleStruckK], \[DoubleStruckL]}]\)\/\(\(-r[{}, {\[DoubleStruckI], \
\[DoubleStruckJ]}]\)\ r[{}, {\[DoubleStruckK], \[DoubleStruckL]}] + r[{}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}]\) + \
\(d[{\[DoubleStruckI], \[DoubleStruckK]}]\ d[{\[DoubleStruckJ], \
\[DoubleStruckL]}]\ r[{\[DoubleStruckI], \[DoubleStruckK]}, \
{\[DoubleStruckJ], \[DoubleStruckL]}]\)\/\(\(-r[{}, {\[DoubleStruckI], \
\[DoubleStruckK]}]\)\ r[{}, {\[DoubleStruckJ], \[DoubleStruckL]}] + r[{}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \[DoubleStruckL]}]\) + \
\(d[{\[DoubleStruckI], \[DoubleStruckL]}]\ d[{\[DoubleStruckJ], \
\[DoubleStruckK]}]\ r[{\[DoubleStruckI], \[DoubleStruckL]}, \
{\[DoubleStruckJ], \[DoubleStruckK]}]\)\/\(\(-r[{}, {\[DoubleStruckI], \
\[DoubleStruckL]}]\)\ r[{}, {\[DoubleStruckJ], \[DoubleStruckK]}] + r[{}, {\
\[DoubleStruckI], \[DoubleStruckJ], \[DoubleStruckK], \
\[DoubleStruckL]}]\)\)], "Output",
  CellLabel->"Out[82]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Checking that Bennett's measures decay exponentially", \
"SubsubsectionIcon"],

Cell[TextData[{
  "In order to apply recombination to Bennett's disequilibrium measure, we \
must define ",
  ButtonBox["stages",
    ButtonData:>{"Life cycle", None},
    ButtonStyle->"AddOnsLink"],
  " in the life cycle:"
}], "Text"],

Cell[BoxData[{
    \(\(DefineContext[\[GothicCapitalG], {Sex}];\)\), "\[IndentingNewLine]", 
    \(\(DefineContext[\[GothicCapitalZ], {Sex, 
          SexOfOrigin}];\)\), "\[IndentingNewLine]", 
    \(\(DefineContext[\[GothicCapitalA], {Sex, 
          SexOfOrigin}];\)\), "\[IndentingNewLine]", 
    \(\(DefineContext[\(\[GothicCapitalG]\^*\), {Sex}];\)\)}], "Input",
  CellLabel->"In[61]:="],

Cell[TextData[{
  "These rules convert ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicB]\_\[DoubleStruckCapitalU]\)]],
  " into an expression involving ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_\[DoubleStruckCapitalV]\)]],
  "(FromBennett[]); apply Recombination[] and UnionOfGametes[]; simplify \
reference points; and finally convert back to an expression in terms of the \
",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicB]\_\[DoubleStruckCapitalU]\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sr = {r[{}, {}] \[Rule] 1, r[{_}, {}] \[Rule] 1, r[{}, {_}] \[Rule] 1, 
        r[A_, B_] \[RuleDelayed] r @@ Sort[Sort /@ {A, B}]}; 
    xx = \(\(\(\(\(\(\(\(\(\(\[GothicB]\_{i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}} /. 
                            FromBennett[BennettB, Disequilibrium, r]\) /. 
                          Recombination[{\[GothicCapitalZ], \(\
\[GothicCapitalG]\^*\)}, 
                            RecombinationRate]\) /. \[GothicR]\_\(A_, B_\) \
\[RuleDelayed] r[A, B]\/2\) /. sr\) /. UnionOfGametes[]\) /. 
                  RandomUnion[\[GothicCapitalG]]\) /. 
                ReferencePointSame[\(\[GothicCapitalG]\^*\), {\
\[GothicCapitalZ], \[GothicCapitalG]}]\) /. 
              ReferencePointZero[\(\[GothicCapitalG]\^*\)]\) /. 
            SymmetricSexes[]\) /. 
          ToBennett[Disequilibrium\ , BennettB, 
            r]\) /. {i_\_{\[GothicCapitalG], \[GothicCapitalF]} \
\[RuleDelayed] i}\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(1\/2\ \((\[GothicB]\_{i}\ \[GothicB]\_{j}\ \[GothicB]\_{k} + \[GothicB]\
\_{k}\ \[GothicB]\_{i, j} + \[GothicB]\_{j}\ \[GothicB]\_{i, k} + \
\[GothicB]\_{i}\ \[GothicB]\_{j, k} + \[GothicB]\_{i, j, k})\)\ r[{}, {i, j, 
            k}] + 1\/2\ \[GothicB]\_{i}\ \((\[GothicB]\_{j}\ \[GothicB]\_{k} \
+ \[GothicB]\_{j, k})\)\ r[{i}, {j, k}] + 
      1\/2\ \[GothicB]\_{j}\ \((\[GothicB]\_{i}\ \[GothicB]\_{k} + \[GothicB]\
\_{i, k})\)\ r[{j}, {i, k}] - \((1\/2\ \[GothicB]\_{i}\ r[{}, {i}] + 
            1\/2\ \[GothicB]\_{i}\ r[{i}, {}])\)\ \((1\/2\ \[GothicB]\_{j}\ \
r[{}, {j}] + 
            1\/2\ \[GothicB]\_{j}\ r[{j}, {}])\)\ \((1\/2\ \[GothicB]\_{k}\ \
r[{}, {k}] + 1\/2\ \[GothicB]\_{k}\ r[{k}, {}])\) + 
      1\/2\ \[GothicB]\_{k}\ \((\[GothicB]\_{i}\ \[GothicB]\_{j} + \[GothicB]\
\_{i, j})\)\ r[{k}, {i, j}] - \((1\/2\ \[GothicB]\_{k}\ r[{}, {k}] + 
            1\/2\ \[GothicB]\_{k}\ r[{k}, {}])\)\ \((1\/2\ \((\[GothicB]\_{i}\
\ \[GothicB]\_{j} + \[GothicB]\_{i, j})\)\ r[{}, {i, j}] + 
            1\/2\ \[GothicB]\_{i}\ \[GothicB]\_{j}\ r[{i}, {j}] - \((1\/2\ \
\[GothicB]\_{i}\ r[{}, {i}] + 
                  1\/2\ \[GothicB]\_{i}\ r[{i}, {}])\)\ \((1\/2\ \
\[GothicB]\_{j}\ r[{}, {j}] + 1\/2\ \[GothicB]\_{j}\ r[{j}, {}])\) + 
            1\/2\ \[GothicB]\_{i}\ \[GothicB]\_{j}\ r[{j}, {i}] + 
            1\/2\ \((\[GothicB]\_{i}\ \[GothicB]\_{j} + \[GothicB]\_{i, j})\)\
\ r[{i, j}, {}])\) + 
      1\/2\ \[GothicB]\_{k}\ \((\[GothicB]\_{i}\ \[GothicB]\_{j} + \[GothicB]\
\_{i, j})\)\ r[{i, j}, {k}] - \((1\/2\ \[GothicB]\_{j}\ r[{}, {j}] + 
            1\/2\ \[GothicB]\_{j}\ r[{j}, {}])\)\ \((1\/2\ \((\[GothicB]\_{i}\
\ \[GothicB]\_{k} + \[GothicB]\_{i, k})\)\ r[{}, {i, k}] + 
            1\/2\ \[GothicB]\_{i}\ \[GothicB]\_{k}\ r[{i}, {k}] - \((1\/2\ \
\[GothicB]\_{i}\ r[{}, {i}] + 
                  1\/2\ \[GothicB]\_{i}\ r[{i}, {}])\)\ \((1\/2\ \
\[GothicB]\_{k}\ r[{}, {k}] + 1\/2\ \[GothicB]\_{k}\ r[{k}, {}])\) + 
            1\/2\ \[GothicB]\_{i}\ \[GothicB]\_{k}\ r[{k}, {i}] + 
            1\/2\ \((\[GothicB]\_{i}\ \[GothicB]\_{k} + \[GothicB]\_{i, k})\)\
\ r[{i, k}, {}])\) + 
      1\/2\ \[GothicB]\_{j}\ \((\[GothicB]\_{i}\ \[GothicB]\_{k} + \[GothicB]\
\_{i, k})\)\ r[{i, k}, {j}] - \((1\/2\ \[GothicB]\_{i}\ r[{}, {i}] + 
            1\/2\ \[GothicB]\_{i}\ r[{i}, {}])\)\ \((1\/2\ \((\[GothicB]\_{j}\
\ \[GothicB]\_{k} + \[GothicB]\_{j, k})\)\ r[{}, {j, k}] + 
            1\/2\ \[GothicB]\_{j}\ \[GothicB]\_{k}\ r[{j}, {k}] - \((1\/2\ \
\[GothicB]\_{j}\ r[{}, {j}] + 
                  1\/2\ \[GothicB]\_{j}\ r[{j}, {}])\)\ \((1\/2\ \
\[GothicB]\_{k}\ r[{}, {k}] + 1\/2\ \[GothicB]\_{k}\ r[{k}, {}])\) + 
            1\/2\ \[GothicB]\_{j}\ \[GothicB]\_{k}\ r[{k}, {j}] + 
            1\/2\ \((\[GothicB]\_{j}\ \[GothicB]\_{k} + \[GothicB]\_{j, k})\)\
\ r[{j, k}, {}])\) + 
      1\/2\ \[GothicB]\_{i}\ \((\[GothicB]\_{j}\ \[GothicB]\_{k} + \[GothicB]\
\_{j, k})\)\ r[{j, k}, {i}] + 
      1\/2\ \((\[GothicB]\_{i}\ \[GothicB]\_{j}\ \[GothicB]\_{k} + \[GothicB]\
\_{k}\ \[GothicB]\_{i, j} + \[GothicB]\_{j}\ \[GothicB]\_{i, k} + \
\[GothicB]\_{i}\ \[GothicB]\_{j, k} + \[GothicB]\_{i, j, k})\)\ r[{i, j, 
            k}, {}]\)], "Output",
  CellLabel->"Out[66]="]
}, Closed]],

Cell[TextData[{
  "The subscripts have been collapsed for convenience.  The ",
  StyleBox["symmetric",
    FontSlant->"Italic"],
  " recombination rates have been written as ",
  Cell[BoxData[
      \(TraditionalForm\`r[A, 
          B] \[Congruent] \[GothicR]\_\(A, B\) + \[GothicR]\_\(B, A\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " FromBennett and ToBennett do not handle genes-in-context: they treat \
structures such as ",
  Cell[BoxData[
      \(TraditionalForm\`i\_{\[GothicCapitalG], \[Ellipsis]}\)]],
  " as single entities."
}], "Text"],

Cell["\<\
This expression can be simplified by invoking relations among \
recombination rates:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(yy = \((\(\(xx /. 
                r[A_, B_] \[RuleDelayed] 
                  If[Length[A\[Vee]B] < 3, 
                    y = Complement[{i, j, k}, 
                        A\[Vee]B]; \[Sum]\+\(x \[SubsetEqual] y\)r[A\[Vee]x, 
                        B\[Vee]\((y\[Backslash]x)\)], r[A, B]]\) /. sr\) /. 
            r[{}, {i, j, k}] \[RuleDelayed] 
              1 - \((r[{i}, {j, k}] + \ r[{j}, {i, k}] + \ r[{k}, {i, j}])\) // 
          Simplify)\)\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(\(-\[GothicB]\_{i, j, k}\)\ \((\(-1\) + r[{i}, {j, k}] + 
          r[{j}, {i, k}] + r[{k}, {i, j}])\)\)], "Output",
  CellLabel->"Out[67]="]
}, Open  ]],

Cell["This does the same for the four-way association:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(xx = 
      Collect[\(\(\(\(\(\(\(\(\(\[GothicB]\_{i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}, l\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}} /. FromBennett[BennettB, Disequilibrium, r]\) /. 
                          Recombination[{\[GothicCapitalZ], \(\
\[GothicCapitalG]\^*\)}, 
                            RecombinationRate]\) /. \[GothicR]\_\(A_, B_\) \
\[RuleDelayed] r[A, B]\/2\) /. sr\) /. UnionOfGametes[]\) /. 
                  RandomUnion[\[GothicCapitalG]]\) /. 
                ReferencePointSame[\(\[GothicCapitalG]\^*\), {\
\[GothicCapitalZ], \[GothicCapitalG]}]\) /. 
              ReferencePointZero[\(\[GothicCapitalG]\^*\)]\) /. 
            SymmetricSexes[]\) /. {i_\_{_, _} \[RuleDelayed] 
              i}, \[GothicCapitalD]\__]\)], "Input"],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i, j, k, l}\ r[{}, {i, j, k, 
            l}] + \[GothicCapitalD]\_{l}\ \[GothicCapitalD]\_{i, j, k}\ \
\((\(-r[{}, {i, j, k}]\) + 
            r[{l}, {i, j, 
                k}])\) + \[GothicCapitalD]\_{i, j}\ \[GothicCapitalD]\_{k, l}\
\ \((r[{i, j}, {k, 
                l}] + \(r[{}, {i, j}]\ r[{}, {k, l}]\ r[{i, j}, {k, l}]\)\/\(\
\(-r[{}, {i, j}]\)\ r[{}, {k, l}] + r[{}, {i, j, k, l}]\))\) + \
\[GothicCapitalD]\_{k}\ \((\[GothicCapitalD]\_{i, j, l}\ \((\(-r[{}, {i, j, 
                        l}]\) + 
                  r[{k}, {i, j, 
                      l}])\) + \[GothicCapitalD]\_{l}\ \[GothicCapitalD]\_{i, \
j}\ \((2\ r[{}, {i, j}] - r[{k}, {i, j}] - 
                  r[{l}, {i, 
                      j}] - \(r[{}, {i, j}]\ r[{i, j}, {k, l}]\)\/\(\(-r[{}, \
{i, j}]\)\ r[{}, {k, l}] + r[{}, {i, j, k, l}]\) + \(r[{}, {i, j}]\ r[{k}, \
{l}]\ r[{i, j}, {k, l}]\)\/\(\(-r[{}, {i, j}]\)\ r[{}, {k, l}] + r[{}, {i, j, \
k, l}]\) + \(r[{}, {i, j}]\ \((r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + r[{i, \
j}, {k, l}])\)\)\/\(\(-r[{}, {i, j}]\) + r[{}, {i, j, k, l}]\))\))\) + \
\[GothicCapitalD]\_{i, k}\ \[GothicCapitalD]\_{j, l}\ \((r[{i, k}, {j, 
                l}] + \(r[{}, {i, k}]\ r[{}, {j, l}]\ r[{i, k}, {j, l}]\)\/\(\
\(-r[{}, {i, k}]\)\ r[{}, {j, l}] + r[{}, {i, j, k, l}]\))\) + \
\[GothicCapitalD]\_{i, l}\ \[GothicCapitalD]\_{j, k}\ \((r[{i, l}, {j, 
                k}] + \(r[{}, {i, l}]\ r[{}, {j, k}]\ r[{i, l}, {j, k}]\)\/\(\
\(-r[{}, {i, l}]\)\ r[{}, {j, k}] + r[{}, {i, j, k, l}]\))\) + \
\[GothicCapitalD]\_{j}\ \((\[GothicCapitalD]\_{i, k, l}\ \((\(-r[{}, {i, k, 
                        l}]\) + 
                  r[{j}, {i, k, 
                      l}])\) + \[GothicCapitalD]\_{l}\ \[GothicCapitalD]\_{i, \
k}\ \((2\ r[{}, {i, k}] - r[{j}, {i, k}] - 
                  r[{l}, {i, 
                      k}] - \(r[{}, {i, k}]\ r[{i, k}, {j, l}]\)\/\(\(-r[{}, \
{i, k}]\)\ r[{}, {j, l}] + r[{}, {i, j, k, l}]\) + \(r[{}, {i, k}]\ r[{j}, \
{l}]\ r[{i, k}, {j, l}]\)\/\(\(-r[{}, {i, k}]\)\ r[{}, {j, l}] + r[{}, {i, j, \
k, l}]\) + \(r[{}, {i, k}]\ \((r[{j}, {i, k, l}] + r[{l}, {i, j, k}] + r[{i, \
k}, {j, l}])\)\)\/\(\(-r[{}, {i, k}]\) + r[{}, {i, j, k, l}]\))\) + \
\[GothicCapitalD]\_{k}\ \[GothicCapitalD]\_{i, l}\ \((2\ r[{}, {i, l}] - 
                  r[{j}, {i, l}] - 
                  r[{k}, {i, 
                      l}] - \(r[{}, {i, l}]\ r[{i, l}, {j, k}]\)\/\(\(-r[{}, \
{i, l}]\)\ r[{}, {j, k}] + r[{}, {i, j, k, l}]\) + \(r[{}, {i, l}]\ r[{j}, \
{k}]\ r[{i, l}, {j, k}]\)\/\(\(-r[{}, {i, l}]\)\ r[{}, {j, k}] + r[{}, {i, j, \
k, l}]\) + \(r[{}, {i, l}]\ \((r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + r[{i, \
l}, {j, k}])\)\)\/\(\(-r[{}, {i, l}]\) + r[{}, {i, j, k, l}]\))\))\) + \
\[GothicCapitalD]\_{i}\ \((\[GothicCapitalD]\_{j, k, l}\ \((\(-r[{}, {j, k, 
                        l}]\) + 
                  r[{i}, {j, k, 
                      l}])\) + \[GothicCapitalD]\_{k}\ \[GothicCapitalD]\_{j, \
l}\ \((2\ r[{}, {j, l}] - r[{i}, {j, l}] - 
                  r[{k}, {j, 
                      l}] - \(r[{}, {j, l}]\ r[{i, k}, {j, l}]\)\/\(\(-r[{}, \
{i, k}]\)\ r[{}, {j, l}] + r[{}, {i, j, k, l}]\) + \(r[{}, {j, l}]\ r[{i}, \
{k}]\ r[{i, k}, {j, l}]\)\/\(\(-r[{}, {i, k}]\)\ r[{}, {j, l}] + r[{}, {i, j, \
k, l}]\) + \(r[{}, {j, l}]\ \((r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + r[{i, \
k}, {j, l}])\)\)\/\(\(-r[{}, {j, l}]\) + r[{}, {i, j, k, l}]\))\) + \
\[GothicCapitalD]\_{l}\ \[GothicCapitalD]\_{j, k}\ \((2\ r[{}, {j, k}] - 
                  r[{i}, {j, k}] - 
                  r[{l}, {j, 
                      k}] - \(r[{}, {j, k}]\ r[{i, l}, {j, k}]\)\/\(\(-r[{}, \
{i, l}]\)\ r[{}, {j, k}] + r[{}, {i, j, k, l}]\) + \(r[{}, {j, k}]\ r[{i}, \
{l}]\ r[{i, l}, {j, k}]\)\/\(\(-r[{}, {i, l}]\)\ r[{}, {j, k}] + r[{}, {i, j, \
k, l}]\) + \(r[{}, {j, k}]\ \((r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + r[{i, \
l}, {j, k}])\)\)\/\(\(-r[{}, {j, k}]\) + r[{}, {i, j, k, l}]\))\) + \
\[GothicCapitalD]\_{j}\ \((\[GothicCapitalD]\_{k, l}\ \((2\ r[{}, {k, l}] - 
                        r[{i}, {k, l}] - 
                        r[{j}, {k, 
                            l}] - \(r[{}, {k, l}]\ r[{i, j}, {k, \
l}]\)\/\(\(-r[{}, {i, j}]\)\ r[{}, {k, l}] + r[{}, {i, j, k, l}]\) + \(r[{}, \
{k, l}]\ r[{i}, {j}]\ r[{i, j}, {k, l}]\)\/\(\(-r[{}, {i, j}]\)\ r[{}, {k, \
l}] + r[{}, {i, j, k, l}]\) + \(r[{}, {k, l}]\ \((r[{i}, {j, k, l}] + r[{j}, \
{i, k, l}] + r[{i, j}, {k, l}])\)\)\/\(\(-r[{}, {k, l}]\) + r[{}, {i, j, k, \
l}]\))\) + \[GothicCapitalD]\_{k}\ \[GothicCapitalD]\_{l}\ \((\(-9\) + 
                        2\ r[{i}, {j}] + 2\ r[{i}, {k}] + 2\ r[{i}, {l}] + 
                        2\ r[{j}, {k}] + 2\ r[{j}, {l}] + 2\ r[{k}, {l}] + 
                        r[{i, j}, {k, l}]\/\(\(-r[{}, {i, j}]\)\ r[{}, {k, \
l}] + r[{}, {i, j, k, l}]\) - \(r[{i}, {j}]\ r[{i, j}, {k, l}]\)\/\(\(-r[{}, \
{i, j}]\)\ r[{}, {k, l}] + r[{}, {i, j, k, l}]\) - \(r[{k}, {l}]\ r[{i, j}, \
{k, l}]\)\/\(\(-r[{}, {i, j}]\)\ r[{}, {k, l}] + r[{}, {i, j, k, l}]\) + \
\(r[{i}, {j}]\ r[{k}, {l}]\ r[{i, j}, {k, l}]\)\/\(\(-r[{}, {i, j}]\)\ r[{}, \
{k, l}] + r[{}, {i, j, k, l}]\) - \(r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + \
r[{i, j}, {k, l}]\)\/\(\(-r[{}, {k, l}]\) + r[{}, {i, j, k, l}]\) + \(r[{k}, \
{l}]\ \((r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + r[{i, j}, {k, \
l}])\)\)\/\(\(-r[{}, {k, l}]\) + r[{}, {i, j, k, l}]\) - \(r[{k}, {i, j, l}] \
+ r[{l}, {i, j, k}] + r[{i, j}, {k, l}]\)\/\(\(-r[{}, {i, j}]\) + r[{}, {i, \
j, k, l}]\) + \(r[{i}, {j}]\ \((r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + r[{i, \
j}, {k, l}])\)\)\/\(\(-r[{}, {i, j}]\) + r[{}, {i, j, k, l}]\) + 
                        r[{i, k}, {j, l}]\/\(\(-r[{}, {i, k}]\)\ r[{}, {j, \
l}] + r[{}, {i, j, k, l}]\) - \(r[{i}, {k}]\ r[{i, k}, {j, l}]\)\/\(\(-r[{}, \
{i, k}]\)\ r[{}, {j, l}] + r[{}, {i, j, k, l}]\) - \(r[{j}, {l}]\ r[{i, k}, \
{j, l}]\)\/\(\(-r[{}, {i, k}]\)\ r[{}, {j, l}] + r[{}, {i, j, k, l}]\) + \
\(r[{i}, {k}]\ r[{j}, {l}]\ r[{i, k}, {j, l}]\)\/\(\(-r[{}, {i, k}]\)\ r[{}, \
{j, l}] + r[{}, {i, j, k, l}]\) - \(r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + \
r[{i, k}, {j, l}]\)\/\(\(-r[{}, {j, l}]\) + r[{}, {i, j, k, l}]\) + \(r[{j}, \
{l}]\ \((r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + r[{i, k}, {j, \
l}])\)\)\/\(\(-r[{}, {j, l}]\) + r[{}, {i, j, k, l}]\) - \(r[{j}, {i, k, l}] \
+ r[{l}, {i, j, k}] + r[{i, k}, {j, l}]\)\/\(\(-r[{}, {i, k}]\) + r[{}, {i, \
j, k, l}]\) + \(r[{i}, {k}]\ \((r[{j}, {i, k, l}] + r[{l}, {i, j, k}] + r[{i, \
k}, {j, l}])\)\)\/\(\(-r[{}, {i, k}]\) + r[{}, {i, j, k, l}]\) + 
                        
                        r[{i, l}, {j, k}]\/\(\(-r[{}, {i, l}]\)\ r[{}, {j, \
k}] + r[{}, {i, j, k, l}]\) - \(r[{i}, {l}]\ r[{i, l}, {j, k}]\)\/\(\(-r[{}, \
{i, l}]\)\ r[{}, {j, k}] + r[{}, {i, j, k, l}]\) - \(r[{j}, {k}]\ r[{i, l}, \
{j, k}]\)\/\(\(-r[{}, {i, l}]\)\ r[{}, {j, k}] + r[{}, {i, j, k, l}]\) + \
\(r[{i}, {l}]\ r[{j}, {k}]\ r[{i, l}, {j, k}]\)\/\(\(-r[{}, {i, l}]\)\ r[{}, \
{j, k}] + r[{}, {i, j, k, l}]\) - \(r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + \
r[{i, l}, {j, k}]\)\/\(\(-r[{}, {i, l}]\) + r[{}, {i, j, k, l}]\) + \(r[{i}, \
{l}]\ \((r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + r[{i, l}, {j, \
k}])\)\)\/\(\(-r[{}, {i, l}]\) + r[{}, {i, j, k, l}]\) - \(r[{i}, {j, k, l}] \
+ r[{l}, {i, j, k}] + r[{i, l}, {j, k}]\)\/\(\(-r[{}, {j, k}]\) + r[{}, {i, \
j, k, l}]\) + \(r[{j}, {k}]\ \((r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + r[{i, \
l}, {j, k}])\)\)\/\(\(-r[{}, {j, k}]\) + r[{}, {i, j, k, l}]\))\))\))\)\)], \
"Output",
  CellLabel->"Out[88]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(zz = 
      Collect[xx /. 
          ToBennett[Disequilibrium\ , BennettB, r], \[GothicB]\__]\)], "Input",\

  CellLabel->"In[90]:="],

Cell[BoxData[
    \(\[GothicB]\_{i, j, k, l}\ r[{}, {i, j, k, 
            l}] + \[GothicB]\_{l}\ \[GothicB]\_{i, j, k}\ \((\(-r[{}, {i, j, 
                  k}]\) + r[{}, {i, j, k, l}] + 
            r[{l}, {i, j, 
                k}])\) + \[GothicB]\_{i, j}\ \[GothicB]\_{k, l}\ \((r[{i, 
                j}, {k, 
                l}] + \(r[{}, {i, j}]\ r[{}, {k, l}]\ r[{i, j}, {k, l}]\)\/\(\
\(-r[{}, {i, j}]\)\ r[{}, {k, l}] + r[{}, {i, j, k, l}]\) - \(r[{}, {i, j, k, \
l}]\ r[{i, j}, {k, l}]\)\/\(\(-r[{}, {i, j}]\)\ r[{}, {k, l}] + r[{}, {i, j, \
k, l}]\))\) + \[GothicB]\_{k}\ \((\[GothicB]\_{i, j, l}\ \((\(-r[{}, {i, j, 
                        l}]\) + r[{}, {i, j, k, l}] + 
                  r[{k}, {i, j, 
                      l}])\) + \[GothicB]\_{l}\ \[GothicB]\_{i, j}\ \((2\ \
r[{}, {i, j}] - r[{}, {i, j, k}] - r[{}, {i, j, l}] - r[{k}, {i, j}] + 
                  r[{k}, {i, j, l}] - r[{l}, {i, j}] + r[{l}, {i, j, k}] + 
                  r[{i, j}, {k, 
                      l}] - \(r[{}, {i, j}]\ r[{i, j}, {k, l}]\)\/\(\(-r[{}, \
{i, j}]\)\ r[{}, {k, l}] + r[{}, {i, j, k, l}]\) + \(r[{}, {i, j}]\ r[{}, {k, \
l}]\ r[{i, j}, {k, l}]\)\/\(\(-r[{}, {i, j}]\)\ r[{}, {k, l}] + r[{}, {i, j, \
k, l}]\) + \(r[{}, {i, j}]\ r[{k}, {l}]\ r[{i, j}, {k, l}]\)\/\(\(-r[{}, {i, \
j}]\)\ r[{}, {k, l}] + r[{}, {i, j, k, l}]\) + \(r[{}, {i, j}]\ \((r[{k}, {i, \
j, l}] + r[{l}, {i, j, k}] + r[{i, j}, {k, l}])\)\)\/\(\(-r[{}, {i, j}]\) + \
r[{}, {i, j, k, l}]\) - \(r[{}, {i, j, k, l}]\ \((r[{k}, {i, j, l}] + r[{l}, \
{i, j, k}] + r[{i, j}, {k, l}])\)\)\/\(\(-r[{}, {k}]\)\ r[{}, {l}]\ r[{}, {i, \
j}] + r[{}, {i, j, k, l}]\))\))\) + \[GothicB]\_{i, k}\ \[GothicB]\_{j, l}\ \
\((r[{i, k}, {j, 
                l}] + \(r[{}, {i, k}]\ r[{}, {j, l}]\ r[{i, k}, {j, l}]\)\/\(\
\(-r[{}, {i, k}]\)\ r[{}, {j, l}] + r[{}, {i, j, k, l}]\) - \(r[{}, {i, j, k, \
l}]\ r[{i, k}, {j, l}]\)\/\(\(-r[{}, {i, k}]\)\ r[{}, {j, l}] + r[{}, {i, j, \
k, l}]\))\) + \[GothicB]\_{i, l}\ \[GothicB]\_{j, k}\ \((r[{i, l}, {j, 
                k}] + \(r[{}, {i, l}]\ r[{}, {j, k}]\ r[{i, l}, {j, k}]\)\/\(\
\(-r[{}, {i, l}]\)\ r[{}, {j, k}] + r[{}, {i, j, k, l}]\) - \(r[{}, {i, j, k, \
l}]\ r[{i, l}, {j, k}]\)\/\(\(-r[{}, {i, l}]\)\ r[{}, {j, k}] + r[{}, {i, j, \
k, l}]\))\) + \[GothicB]\_{j}\ \((\[GothicB]\_{i, k, l}\ \((\(-r[{}, {i, k, 
                        l}]\) + r[{}, {i, j, k, l}] + 
                  r[{j}, {i, k, 
                      l}])\) + \[GothicB]\_{l}\ \[GothicB]\_{i, k}\ \((2\ \
r[{}, {i, k}] - r[{}, {i, j, k}] - r[{}, {i, k, l}] - r[{j}, {i, k}] + 
                  r[{j}, {i, k, l}] - r[{l}, {i, k}] + r[{l}, {i, j, k}] + 
                  r[{i, k}, {j, 
                      l}] - \(r[{}, {i, k}]\ r[{i, k}, {j, l}]\)\/\(\(-r[{}, \
{i, k}]\)\ r[{}, {j, l}] + r[{}, {i, j, k, l}]\) + \(r[{}, {i, k}]\ r[{}, {j, \
l}]\ r[{i, k}, {j, l}]\)\/\(\(-r[{}, {i, k}]\)\ r[{}, {j, l}] + r[{}, {i, j, \
k, l}]\) + \(r[{}, {i, k}]\ r[{j}, {l}]\ r[{i, k}, {j, l}]\)\/\(\(-r[{}, {i, \
k}]\)\ r[{}, {j, l}] + r[{}, {i, j, k, l}]\) + \(r[{}, {i, k}]\ \((r[{j}, {i, \
k, l}] + r[{l}, {i, j, k}] + r[{i, k}, {j, l}])\)\)\/\(\(-r[{}, {i, k}]\) + \
r[{}, {i, j, k, l}]\) - \(r[{}, {i, j, k, l}]\ \((r[{j}, {i, k, l}] + r[{l}, \
{i, j, k}] + r[{i, k}, {j, l}])\)\)\/\(\(-r[{}, {j}]\)\ r[{}, {l}]\ r[{}, {i, \
k}] + r[{}, {i, j, k, l}]\))\) + \[GothicB]\_{k}\ \[GothicB]\_{i, l}\ \((2\ \
r[{}, {i, l}] - r[{}, {i, j, l}] - r[{}, {i, k, l}] - r[{j}, {i, l}] + 
                  r[{j}, {i, k, l}] - r[{k}, {i, l}] + r[{k}, {i, j, l}] + 
                  r[{i, l}, {j, 
                      k}] - \(r[{}, {i, l}]\ r[{i, l}, {j, k}]\)\/\(\(-r[{}, \
{i, l}]\)\ r[{}, {j, k}] + r[{}, {i, j, k, l}]\) + \(r[{}, {i, l}]\ r[{}, {j, \
k}]\ r[{i, l}, {j, k}]\)\/\(\(-r[{}, {i, l}]\)\ r[{}, {j, k}] + r[{}, {i, j, \
k, l}]\) + \(r[{}, {i, l}]\ r[{j}, {k}]\ r[{i, l}, {j, k}]\)\/\(\(-r[{}, {i, \
l}]\)\ r[{}, {j, k}] + r[{}, {i, j, k, l}]\) + \(r[{}, {i, l}]\ \((r[{j}, {i, \
k, l}] + r[{k}, {i, j, l}] + r[{i, l}, {j, k}])\)\)\/\(\(-r[{}, {i, l}]\) + \
r[{}, {i, j, k, l}]\) - \(r[{}, {i, j, k, l}]\ \((r[{j}, {i, k, l}] + r[{k}, \
{i, j, l}] + r[{i, l}, {j, k}])\)\)\/\(\(-r[{}, {j}]\)\ r[{}, {k}]\ r[{}, {i, \
l}] + r[{}, {i, j, k, l}]\))\))\) + \[GothicB]\_{i}\ \((\[GothicB]\_{j, k, l}\
\ \((\(-r[{}, {j, k, l}]\) + r[{}, {i, j, k, l}] + 
                  r[{i}, {j, k, 
                      l}])\) + \[GothicB]\_{k}\ \[GothicB]\_{j, l}\ \((2\ \
r[{}, {j, l}] - r[{}, {i, j, l}] - r[{}, {j, k, l}] - r[{i}, {j, l}] + 
                  r[{i}, {j, k, l}] - r[{k}, {j, l}] + r[{k}, {i, j, l}] + 
                  r[{i, k}, {j, 
                      l}] - \(r[{}, {j, l}]\ r[{i, k}, {j, l}]\)\/\(\(-r[{}, \
{i, k}]\)\ r[{}, {j, l}] + r[{}, {i, j, k, l}]\) + \(r[{}, {i, k}]\ r[{}, {j, \
l}]\ r[{i, k}, {j, l}]\)\/\(\(-r[{}, {i, k}]\)\ r[{}, {j, l}] + r[{}, {i, j, \
k, l}]\) + \(r[{}, {j, l}]\ r[{i}, {k}]\ r[{i, k}, {j, l}]\)\/\(\(-r[{}, {i, \
k}]\)\ r[{}, {j, l}] + r[{}, {i, j, k, l}]\) + \(r[{}, {j, l}]\ \((r[{i}, {j, \
k, l}] + r[{k}, {i, j, l}] + r[{i, k}, {j, l}])\)\)\/\(\(-r[{}, {j, l}]\) + \
r[{}, {i, j, k, l}]\) - \(r[{}, {i, j, k, l}]\ \((r[{i}, {j, k, l}] + r[{k}, \
{i, j, l}] + r[{i, k}, {j, l}])\)\)\/\(\(-r[{}, {i}]\)\ r[{}, {k}]\ r[{}, {j, \
l}] + r[{}, {i, j, k, l}]\))\) + \[GothicB]\_{l}\ \[GothicB]\_{j, k}\ \((2\ \
r[{}, {j, k}] - r[{}, {i, j, k}] - r[{}, {j, k, l}] - r[{i}, {j, k}] + 
                  r[{i}, {j, k, l}] - r[{l}, {j, k}] + r[{l}, {i, j, k}] + 
                  r[{i, l}, {j, 
                      k}] - \(r[{}, {j, k}]\ r[{i, l}, {j, k}]\)\/\(\(-r[{}, \
{i, l}]\)\ r[{}, {j, k}] + r[{}, {i, j, k, l}]\) + \(r[{}, {i, l}]\ r[{}, {j, \
k}]\ r[{i, l}, {j, k}]\)\/\(\(-r[{}, {i, l}]\)\ r[{}, {j, k}] + r[{}, {i, j, \
k, l}]\) + \(r[{}, {j, k}]\ r[{i}, {l}]\ r[{i, l}, {j, k}]\)\/\(\(-r[{}, {i, \
l}]\)\ r[{}, {j, k}] + r[{}, {i, j, k, l}]\) + \(r[{}, {j, k}]\ \((r[{i}, {j, \
k, l}] + r[{l}, {i, j, k}] + r[{i, l}, {j, k}])\)\)\/\(\(-r[{}, {j, k}]\) + \
r[{}, {i, j, k, l}]\) - \(r[{}, {i, j, k, l}]\ \((r[{i}, {j, k, l}] + r[{l}, \
{i, j, k}] + r[{i, l}, {j, k}])\)\)\/\(\(-r[{}, {i}]\)\ r[{}, {l}]\ r[{}, {j, \
k}] + r[{}, {i, j, k, l}]\))\) + \[GothicB]\_{j}\ \((\[GothicB]\_{k, l}\ \((2\
\ r[{}, {k, l}] - r[{}, {i, k, l}] - r[{}, {j, k, l}] - r[{i}, {k, l}] + 
                        r[{i}, {j, k, l}] - r[{j}, {k, l}] + 
                        r[{j}, {i, k, l}] + 
                        r[{i, j}, {k, 
                            l}] - \(r[{}, {k, l}]\ r[{i, j}, {k, \
l}]\)\/\(\(-r[{}, {i, j}]\)\ r[{}, {k, l}] + r[{}, {i, j, k, l}]\) + \(r[{}, \
{i, j}]\ r[{}, {k, l}]\ r[{i, j}, {k, l}]\)\/\(\(-r[{}, {i, j}]\)\ r[{}, {k, \
l}] + r[{}, {i, j, k, l}]\) + \(r[{}, {k, l}]\ r[{i}, {j}]\ r[{i, j}, {k, l}]\
\)\/\(\(-r[{}, {i, j}]\)\ r[{}, {k, l}] + r[{}, {i, j, k, l}]\) + \(r[{}, {k, \
l}]\ \((r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + r[{i, j}, {k, \
l}])\)\)\/\(\(-r[{}, {k, l}]\) + r[{}, {i, j, k, l}]\) - \(r[{}, {i, j, k, \
l}]\ \((r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + r[{i, j}, {k, \
l}])\)\)\/\(\(-r[{}, {i}]\)\ r[{}, {j}]\ r[{}, {k, l}] + r[{}, {i, j, k, \
l}]\))\) + \[GothicB]\_{k}\ \[GothicB]\_{l}\ \((\(-9\) + 2\ r[{}, {i, j}] + 
                        2\ r[{}, {i, k}] + 2\ r[{}, {i, l}] + 
                        2\ r[{}, {j, k}] + 2\ r[{}, {j, l}] + 
                        2\ r[{}, {k, l}] - r[{}, {i, j, k}] - 
                        r[{}, {i, j, l}] - r[{}, {i, k, l}] - 
                        r[{}, {j, k, l}] + r[{}, {i, j, k, l}] + 
                        2\ r[{i}, {j}] + 2\ r[{i}, {k}] + 2\ r[{i}, {l}] - 
                        r[{i}, {j, k}] - r[{i}, {j, l}] - r[{i}, {k, l}] + 
                        r[{i}, {j, k, l}] + 2\ r[{j}, {k}] + 2\ r[{j}, {l}] - 
                        r[{j}, {i, k}] - r[{j}, {i, l}] - r[{j}, {k, l}] + 
                        r[{j}, {i, k, l}] + 2\ r[{k}, {l}] - r[{k}, {i, j}] - 
                        r[{k}, {i, l}] - r[{k}, {j, l}] + r[{k}, {i, j, l}] - 
                        r[{l}, {i, j}] - r[{l}, {i, k}] - r[{l}, {j, k}] + 
                        r[{l}, {i, j, k}] + r[{i, j}, {k, l}] + 
                        r[{i, j}, {k, l}]\/\(\(-r[{}, {i, j}]\)\ r[{}, {k, \
l}] + r[{}, {i, j, k, l}]\) - \(r[{}, {i, j}]\ r[{i, j}, {k, \
l}]\)\/\(\(-r[{}, {i, j}]\)\ r[{}, {k, l}] + r[{}, {i, j, k, l}]\) - \(r[{}, \
{k, l}]\ r[{i, j}, {k, l}]\)\/\(\(-r[{}, {i, j}]\)\ r[{}, {k, l}] + r[{}, {i, \
j, k, l}]\) + \(r[{}, {i, j}]\ r[{}, {k, l}]\ r[{i, j}, {k, l}]\)\/\(\(-r[{}, \
{i, j}]\)\ r[{}, {k, l}] + r[{}, {i, j, k, l}]\) - \(r[{i}, {j}]\ r[{i, j}, \
{k, l}]\)\/\(\(-r[{}, {i, j}]\)\ r[{}, {k, l}] + r[{}, {i, j, k, l}]\) + \
\(r[{}, {k, l}]\ r[{i}, {j}]\ r[{i, j}, {k, l}]\)\/\(\(-r[{}, {i, j}]\)\ \
r[{}, {k, l}] + r[{}, {i, j, k, l}]\) - \(r[{k}, {l}]\ r[{i, j}, {k, \
l}]\)\/\(\(-r[{}, {i, j}]\)\ r[{}, {k, l}] + r[{}, {i, j, k, l}]\) + \(r[{}, \
{i, j}]\ r[{k}, {l}]\ r[{i, j}, {k, l}]\)\/\(\(-r[{}, {i, j}]\)\ r[{}, {k, \
l}] + r[{}, {i, j, k, l}]\) + \(r[{i}, {j}]\ r[{k}, {l}]\ r[{i, j}, {k, l}]\)\
\/\(\(-r[{}, {i, j}]\)\ r[{}, {k, l}] + r[{}, {i, j, k, l}]\) - \(r[{i}, {j, \
k, l}] + r[{j}, {i, k, l}] + r[{i, j}, {k, l}]\)\/\(\(-r[{}, {k, l}]\) + \
r[{}, {i, j, k, l}]\) + \(r[{}, {k, l}]\ \((r[{i}, {j, k, l}] + r[{j}, {i, k, \
l}] + r[{i, j}, {k, l}])\)\)\/\(\(-r[{}, {k, l}]\) + r[{}, {i, j, k, l}]\) + \
\(r[{k}, {l}]\ \((r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + r[{i, j}, {k, \
l}])\)\)\/\(\(-r[{}, {k, l}]\) + r[{}, {i, j, k, l}]\) - \(r[{k}, {i, j, l}] \
+ r[{l}, {i, j, k}] + r[{i, j}, {k, l}]\)\/\(\(-r[{}, {i, j}]\) + r[{}, {i, \
j, k, l}]\) + \(r[{}, {i, j}]\ \((r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + \
r[{i, j}, {k, l}])\)\)\/\(\(-r[{}, {i, j}]\) + r[{}, {i, j, k, l}]\) + \
\(r[{i}, {j}]\ \((r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + r[{i, j}, {k, \
l}])\)\)\/\(\(-r[{}, {i, j}]\) + r[{}, {i, j, k, l}]\) + r[{i, k}, {j, l}] + 
                        r[{i, k}, {j, l}]\/\(\(-r[{}, {i, k}]\)\ r[{}, {j, \
l}] + r[{}, {i, j, k, l}]\) - \(r[{}, {i, k}]\ r[{i, k}, {j, \
l}]\)\/\(\(-r[{}, {i, k}]\)\ r[{}, {j, l}] + r[{}, {i, j, k, l}]\) - \(r[{}, \
{j, l}]\ r[{i, k}, {j, l}]\)\/\(\(-r[{}, {i, k}]\)\ r[{}, {j, l}] + r[{}, {i, \
j, k, l}]\) + \(r[{}, {i, k}]\ r[{}, {j, l}]\ r[{i, k}, {j, l}]\)\/\(\(-r[{}, \
{i, k}]\)\ r[{}, {j, l}] + r[{}, {i, j, k, l}]\) - \(r[{i}, {k}]\ r[{i, k}, \
{j, l}]\)\/\(\(-r[{}, {i, k}]\)\ r[{}, {j, l}] + r[{}, {i, j, k, l}]\) + \
\(r[{}, {j, l}]\ r[{i}, {k}]\ r[{i, k}, {j, l}]\)\/\(\(-r[{}, {i, k}]\)\ \
r[{}, {j, l}] + r[{}, {i, j, k, l}]\) - \(r[{j}, {l}]\ r[{i, k}, {j, \
l}]\)\/\(\(-r[{}, {i, k}]\)\ r[{}, {j, l}] + r[{}, {i, j, k, l}]\) + \(r[{}, \
{i, k}]\ r[{j}, {l}]\ r[{i, k}, {j, l}]\)\/\(\(-r[{}, {i, k}]\)\ r[{}, {j, \
l}] + r[{}, {i, j, k, l}]\) + \(r[{i}, {k}]\ r[{j}, {l}]\ r[{i, k}, {j, l}]\)\
\/\(\(-r[{}, {i, k}]\)\ r[{}, {j, l}] + r[{}, {i, j, k, l}]\) - \(r[{i}, {j, \
k, l}] + r[{k}, {i, j, l}] + r[{i, k}, {j, l}]\)\/\(\(-r[{}, {j, l}]\) + \
r[{}, {i, j, k, l}]\) + \(r[{}, {j, l}]\ \((r[{i}, {j, k, l}] + r[{k}, {i, j, \
l}] + r[{i, k}, {j, l}])\)\)\/\(\(-r[{}, {j, l}]\) + r[{}, {i, j, k, l}]\) + \
\(r[{j}, {l}]\ \((r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + r[{i, k}, {j, \
l}])\)\)\/\(\(-r[{}, {j, l}]\) + r[{}, {i, j, k, l}]\) - \(r[{j}, {i, k, l}] \
+ r[{l}, {i, j, k}] + r[{i, k}, {j, l}]\)\/\(\(-r[{}, {i, k}]\) + r[{}, {i, \
j, k, l}]\) + \(r[{}, {i, k}]\ \((r[{j}, {i, k, l}] + r[{l}, {i, j, k}] + \
r[{i, k}, {j, l}])\)\)\/\(\(-r[{}, {i, k}]\) + r[{}, {i, j, k, l}]\) + \
\(r[{i}, {k}]\ \((r[{j}, {i, k, l}] + r[{l}, {i, j, k}] + r[{i, k}, {j, \
l}])\)\)\/\(\(-r[{}, {i, k}]\) + r[{}, {i, j, k, l}]\) + r[{i, l}, {j, k}] + 
                        r[{i, l}, {j, k}]\/\(\(-r[{}, {i, l}]\)\ r[{}, {j, \
k}] + r[{}, {i, j, k, l}]\) - \(r[{}, {i, l}]\ r[{i, l}, {j, \
k}]\)\/\(\(-r[{}, {i, l}]\)\ r[{}, {j, k}] + r[{}, {i, j, k, l}]\) - \(r[{}, \
{j, k}]\ r[{i, l}, {j, k}]\)\/\(\(-r[{}, {i, l}]\)\ r[{}, {j, k}] + r[{}, {i, \
j, k, l}]\) + \(r[{}, {i, l}]\ r[{}, {j, k}]\ r[{i, l}, {j, k}]\)\/\(\(-r[{}, \
{i, l}]\)\ r[{}, {j, k}] + r[{}, {i, j, k, l}]\) - \(r[{i}, {l}]\ r[{i, l}, \
{j, k}]\)\/\(\(-r[{}, {i, l}]\)\ r[{}, {j, k}] + r[{}, {i, j, k, l}]\) + \
\(r[{}, {j, k}]\ r[{i}, {l}]\ r[{i, l}, {j, k}]\)\/\(\(-r[{}, {i, l}]\)\ \
r[{}, {j, k}] + r[{}, {i, j, k, l}]\) - \(r[{j}, {k}]\ r[{i, l}, {j, \
k}]\)\/\(\(-r[{}, {i, l}]\)\ r[{}, {j, k}] + r[{}, {i, j, k, l}]\) + \(r[{}, \
{i, l}]\ r[{j}, {k}]\ r[{i, l}, {j, k}]\)\/\(\(-r[{}, {i, l}]\)\ r[{}, {j, \
k}] + r[{}, {i, j, k, l}]\) + \(r[{i}, {l}]\ r[{j}, {k}]\ r[{i, l}, {j, k}]\)\
\/\(\(-r[{}, {i, l}]\)\ r[{}, {j, k}] + r[{}, {i, j, k, l}]\) - \(r[{j}, {i, \
k, l}] + r[{k}, {i, j, l}] + r[{i, l}, {j, k}]\)\/\(\(-r[{}, {i, l}]\) + \
r[{}, {i, j, k, l}]\) + \(r[{}, {i, l}]\ \((r[{j}, {i, k, l}] + r[{k}, {i, j, \
l}] + r[{i, l}, {j, k}])\)\)\/\(\(-r[{}, {i, l}]\) + r[{}, {i, j, k, l}]\) + \
\(r[{i}, {l}]\ \((r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + r[{i, l}, {j, \
k}])\)\)\/\(\(-r[{}, {i, l}]\) + r[{}, {i, j, k, l}]\) - \(r[{i}, {j, k, l}] \
+ r[{l}, {i, j, k}] + r[{i, l}, {j, k}]\)\/\(\(-r[{}, {j, k}]\) + r[{}, {i, \
j, k, l}]\) + \(r[{}, {j, k}]\ \((r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + \
r[{i, l}, {j, k}])\)\)\/\(\(-r[{}, {j, k}]\) + r[{}, {i, j, k, l}]\) + \
\(r[{j}, {k}]\ \((r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + r[{i, l}, {j, \
k}])\)\)\/\(\(-r[{}, {j, k}]\) + r[{}, {i, j, k, l}]\))\))\))\)\)], "Output",
  CellLabel->"Out[90]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(yy = \((\(zz /. 
            r[A_, B_] \[RuleDelayed] 
              If[Length[A\[Vee]B] < 4, 
                y = Complement[{i, j, k, l}, 
                    A\[Vee]B]; \[Sum]\+\(x \[SubsetEqual] y\)r[A\[Vee]x, 
                    B\[Vee]\((y\[Backslash]x)\)], r[A, B]]\) /. 
          sr)\)\)], "Input",
  CellLabel->"In[91]:="],

Cell[BoxData[
    \(\[GothicB]\_{i, j, k, l}\ r[{}, {i, j, k, 
            l}] + \[GothicB]\_{i, j}\ \[GothicB]\_{k, l}\ \((r[{i, j}, {k, 
                l}] - \((r[{}, {i, j, k, l}]\ r[{i, j}, {k, 
                      l}])\)/\((r[{}, {i, j, k, 
                      l}] - \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                        r[{j}, {i, k, l}] + 
                        r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, l}] + 
                        r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + 
                        r[{i, j}, {k, l}])\))\) + \((r[{i, j}, {k, 
                      l}]\ \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                      r[{j}, {i, k, l}] + 
                      r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, l}] + 
                      r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + 
                      r[{i, j}, {k, l}])\))\)/\((r[{}, {i, j, k, 
                      l}] - \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                        r[{j}, {i, k, l}] + 
                        r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, l}] + 
                        r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + 
                        r[{i, j}, {k, 
                            l}])\))\))\) + \[GothicB]\_{i, k}\ \
\[GothicB]\_{j, l}\ \((r[{i, k}, {j, 
                l}] - \((r[{}, {i, j, k, l}]\ r[{i, k}, {j, 
                      l}])\)/\((r[{}, {i, j, k, 
                      l}] - \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                        r[{k}, {i, j, l}] + 
                        r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, l}] + 
                        r[{j}, {i, k, l}] + r[{l}, {i, j, k}] + 
                        r[{i, k}, {j, l}])\))\) + \((r[{i, k}, {j, 
                      l}]\ \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                      r[{k}, {i, j, l}] + 
                      r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, l}] + 
                      r[{j}, {i, k, l}] + r[{l}, {i, j, k}] + 
                      r[{i, k}, {j, l}])\))\)/\((r[{}, {i, j, k, 
                      l}] - \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                        r[{k}, {i, j, l}] + 
                        r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, l}] + 
                        r[{j}, {i, k, l}] + r[{l}, {i, j, k}] + 
                        r[{i, k}, {j, 
                            l}])\))\))\) + \[GothicB]\_{i, l}\ \
\[GothicB]\_{j, k}\ \((r[{i, l}, {j, 
                k}] - \((r[{}, {i, j, k, l}]\ r[{i, l}, {j, 
                      k}])\)/\((r[{}, {i, j, k, 
                      l}] - \((r[{}, {i, j, k, l}] + r[{j}, {i, k, l}] + 
                        r[{k}, {i, j, l}] + 
                        r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, l}] + 
                        r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + 
                        r[{i, l}, {j, k}])\))\) + \((r[{i, l}, {j, 
                      k}]\ \((r[{}, {i, j, k, l}] + r[{j}, {i, k, l}] + 
                      r[{k}, {i, j, l}] + 
                      r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, l}] + 
                      r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + 
                      r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                      l}] - \((r[{}, {i, j, k, l}] + r[{j}, {i, k, l}] + 
                        r[{k}, {i, j, l}] + 
                        r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, l}] + 
                        r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + 
                        r[{i, l}, {j, 
                            k}])\))\))\) + \[GothicB]\_{k}\ \[GothicB]\_{l}\ \
\[GothicB]\_{i, j}\ \((\(-2\)\ r[{}, {i, j, k, l}] - r[{k}, {i, j, l}] - 
            r[{l}, {i, j, k}] - r[{i, j}, {k, l}] + 
            2\ \((r[{}, {i, j, k, l}] + r[{k}, {i, j, l}] + 
                  r[{l}, {i, j, k}] + 
                  r[{i, j}, {k, 
                      l}])\) + \(\((r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + \
r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, l}] + r[{k}, {i, j, l}] + r[{l}, {i, \
j, k}] + r[{i, j}, {k, l}])\)\)\/\(\(-r[{k}, {i, j, l}]\) - r[{l}, {i, j, k}] \
- r[{i, j}, {k, l}]\) - \((r[{i, j}, {k, l}]\ \((r[{}, {i, j, k, l}] + 
                      r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + 
                      r[{i, j}, {k, l}])\))\)/\((r[{}, {i, j, k, 
                      l}] - \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                        r[{j}, {i, k, l}] + 
                        r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, l}] + 
                        r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + 
                        r[{i, j}, {k, l}])\))\) + \((r[{i, j}, {k, 
                      l}]\ \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                      r[{j}, {i, k, l}] + 
                      r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, l}] + 
                      r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + 
                      r[{i, j}, {k, l}])\))\)/\((r[{}, {i, j, k, 
                      l}] - \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                        r[{j}, {i, k, l}] + 
                        r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, l}] + 
                        r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + 
                        r[{i, j}, {k, l}])\))\) + \((r[{i, j}, {k, 
                      l}]\ \((r[{}, {i, j, k, l}] + r[{k}, {i, j, l}] + 
                      r[{l}, {i, j, k}] + 
                      r[{i, j}, {k, l}])\)\ \((r[{k}, {i, j, l}] + 
                      r[{l}, {i, j, k}] + r[{i, k}, {j, l}] + 
                      r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                      l}] - \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                        r[{j}, {i, k, l}] + 
                        r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, l}] + 
                        r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + 
                        r[{i, j}, {k, l}])\))\) - \((r[{}, {i, j, k, 
                      l}]\ \((r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + 
                      r[{i, j}, {k, l}])\))\)/\((r[{}, {i, j, k, 
                      l}] - \((r[{}, {i, j, k, l}] + r[{k}, {i, j, l}] + 
                        r[{l}, {i, j, k}] + 
                        r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, l}] + 
                          r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                          r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + 
                          r[{i, j}, {k, l}] + r[{i, k}, {j, l}] + 
                          r[{i, l}, {j, 
                              k}])\)^2)\))\) + \[GothicB]\_{j}\ \((\[GothicB]\
\_{l}\ \[GothicB]\_{i, k}\ \((\(-2\)\ r[{}, {i, j, k, l}] - 
                  r[{j}, {i, k, l}] - r[{l}, {i, j, k}] - r[{i, k}, {j, l}] + 
                  2\ \((r[{}, {i, j, k, l}] + r[{j}, {i, k, l}] + 
                        r[{l}, {i, j, k}] + 
                        r[{i, k}, {j, 
                            l}])\) + \(\((r[{j}, {i, k, l}] + r[{l}, {i, j, \
k}] + r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, l}] + r[{j}, {i, k, l}] + \
r[{l}, {i, j, k}] + r[{i, k}, {j, l}])\)\)\/\(\(-r[{j}, {i, k, l}]\) - r[{l}, \
{i, j, k}] - r[{i, k}, {j, l}]\) - \((r[{i, k}, {j, 
                            l}]\ \((r[{}, {i, j, k, l}] + r[{j}, {i, k, l}] + 
                            r[{l}, {i, j, k}] + 
                            r[{i, k}, {j, l}])\))\)/\((r[{}, {i, j, k, 
                            l}] - \((r[{}, {i, j, k, l}] + 
                              r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + 
                              r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, l}] + 
                              r[{j}, {i, k, l}] + r[{l}, {i, j, k}] + 
                              r[{i, k}, {j, l}])\))\) + \((r[{i, k}, {j, 
                            l}]\ \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                            r[{k}, {i, j, l}] + 
                            r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, l}] + 
                            r[{j}, {i, k, l}] + r[{l}, {i, j, k}] + 
                            r[{i, k}, {j, l}])\))\)/\((r[{}, {i, j, k, 
                            l}] - \((r[{}, {i, j, k, l}] + 
                              r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + 
                              r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, l}] + 
                              r[{j}, {i, k, l}] + r[{l}, {i, j, k}] + 
                              r[{i, k}, {j, l}])\))\) + \((r[{i, k}, {j, 
                            l}]\ \((r[{}, {i, j, k, l}] + r[{j}, {i, k, l}] + 
                            r[{l}, {i, j, k}] + 
                            r[{i, k}, {j, l}])\)\ \((r[{j}, {i, k, l}] + 
                            r[{l}, {i, j, k}] + r[{i, j}, {k, l}] + 
                            r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                            l}] - \((r[{}, {i, j, k, l}] + 
                              r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + 
                              r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, l}] + 
                              r[{j}, {i, k, l}] + r[{l}, {i, j, k}] + 
                              r[{i, k}, {j, l}])\))\) - \((r[{}, {i, j, k, 
                            l}]\ \((r[{j}, {i, k, l}] + r[{l}, {i, j, k}] + 
                            r[{i, k}, {j, l}])\))\)/\((r[{}, {i, j, k, 
                            l}] - \((r[{}, {i, j, k, l}] + 
                              r[{j}, {i, k, l}] + r[{l}, {i, j, k}] + 
                              r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, l}] + 
                                r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + 
                                r[{i, j}, {k, l}] + r[{i, k}, {j, l}] + 
                                r[{i, l}, {j, 
                                    k}])\)^2)\))\) + \[GothicB]\_{k}\ \
\[GothicB]\_{i, l}\ \((\(-2\)\ r[{}, {i, j, k, l}] - r[{j}, {i, k, l}] - 
                  r[{k}, {i, j, l}] - r[{i, l}, {j, k}] + 
                  2\ \((r[{}, {i, j, k, l}] + r[{j}, {i, k, l}] + 
                        r[{k}, {i, j, l}] + 
                        r[{i, l}, {j, 
                            k}])\) + \(\((r[{j}, {i, k, l}] + r[{k}, {i, j, \
l}] + r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, l}] + r[{j}, {i, k, l}] + \
r[{k}, {i, j, l}] + r[{i, l}, {j, k}])\)\)\/\(\(-r[{j}, {i, k, l}]\) - r[{k}, \
{i, j, l}] - r[{i, l}, {j, k}]\) - \((r[{i, l}, {j, 
                            k}]\ \((r[{}, {i, j, k, l}] + r[{j}, {i, k, l}] + 
                            r[{k}, {i, j, l}] + 
                            r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                            l}] - \((r[{}, {i, j, k, l}] + 
                              r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                              r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, l}] + 
                              r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + 
                              r[{i, l}, {j, k}])\))\) + \((\((r[{j}, {i, k, 
                                l}] + r[{k}, {i, j, l}] + r[{i, j}, {k, l}] + 
                            r[{i, k}, {j, l}])\)\ r[{i, l}, {j, 
                            k}]\ \((r[{}, {i, j, k, l}] + r[{j}, {i, k, l}] + 
                            r[{k}, {i, j, l}] + 
                            r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                            l}] - \((r[{}, {i, j, k, l}] + 
                              r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                              r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, l}] + 
                              r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + 
                              r[{i, l}, {j, k}])\))\) + \((r[{i, l}, {j, 
                            k}]\ \((r[{}, {i, j, k, l}] + r[{j}, {i, k, l}] + 
                            r[{k}, {i, j, l}] + 
                            r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, l}] + 
                            r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + 
                            r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                            l}] - \((r[{}, {i, j, k, l}] + 
                              r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                              r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, l}] + 
                              r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + 
                              r[{i, l}, {j, k}])\))\) - \((r[{}, {i, j, k, 
                            l}]\ \((r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                            r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                            l}] - \((r[{}, {i, j, k, l}] + 
                              r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                              r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, l}] + 
                                r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + 
                                r[{i, j}, {k, l}] + r[{i, k}, {j, l}] + 
                                r[{i, l}, {j, 
                                    k}])\)^2)\))\))\) + \[GothicB]\_{i}\ \((\
\[GothicB]\_{k}\ \[GothicB]\_{j, l}\ \((\(-2\)\ r[{}, {i, j, k, l}] - 
                  r[{i}, {j, k, l}] - r[{k}, {i, j, l}] - r[{i, k}, {j, l}] + 
                  2\ \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                        r[{k}, {i, j, l}] + 
                        r[{i, k}, {j, 
                            l}])\) + \(\((r[{i}, {j, k, l}] + r[{k}, {i, j, \
l}] + r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + \
r[{k}, {i, j, l}] + r[{i, k}, {j, l}])\)\)\/\(\(-r[{i}, {j, k, l}]\) - r[{k}, \
{i, j, l}] - r[{i, k}, {j, l}]\) - \((r[{i, k}, {j, 
                            l}]\ \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                            r[{k}, {i, j, l}] + 
                            r[{i, k}, {j, l}])\))\)/\((r[{}, {i, j, k, 
                            l}] - \((r[{}, {i, j, k, l}] + 
                              r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + 
                              r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, l}] + 
                              r[{j}, {i, k, l}] + r[{l}, {i, j, k}] + 
                              r[{i, k}, {j, l}])\))\) + \((r[{i, k}, {j, 
                            l}]\ \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                            r[{k}, {i, j, l}] + 
                            r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, l}] + 
                            r[{j}, {i, k, l}] + r[{l}, {i, j, k}] + 
                            r[{i, k}, {j, l}])\))\)/\((r[{}, {i, j, k, 
                            l}] - \((r[{}, {i, j, k, l}] + 
                              r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + 
                              r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, l}] + 
                              r[{j}, {i, k, l}] + r[{l}, {i, j, k}] + 
                              r[{i, k}, {j, l}])\))\) + \((r[{i, k}, {j, 
                            l}]\ \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                            r[{k}, {i, j, l}] + 
                            r[{i, k}, {j, l}])\)\ \((r[{i}, {j, k, l}] + 
                            r[{k}, {i, j, l}] + r[{i, j}, {k, l}] + 
                            r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                            l}] - \((r[{}, {i, j, k, l}] + 
                              r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + 
                              r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, l}] + 
                              r[{j}, {i, k, l}] + r[{l}, {i, j, k}] + 
                              r[{i, k}, {j, l}])\))\) - \((r[{}, {i, j, k, 
                            l}]\ \((r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + 
                            r[{i, k}, {j, l}])\))\)/\((r[{}, {i, j, k, 
                            l}] - \((r[{}, {i, j, k, l}] + 
                              r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + 
                              r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, l}] + 
                                r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + 
                                r[{i, j}, {k, l}] + r[{i, k}, {j, l}] + 
                                r[{i, l}, {j, 
                                    k}])\)^2)\))\) + \[GothicB]\_{l}\ \
\[GothicB]\_{j, k}\ \((\(-2\)\ r[{}, {i, j, k, l}] - r[{i}, {j, k, l}] - 
                  r[{l}, {i, j, k}] - r[{i, l}, {j, k}] + 
                  2\ \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                        r[{l}, {i, j, k}] + 
                        r[{i, l}, {j, 
                            k}])\) + \(\((r[{i}, {j, k, l}] + r[{l}, {i, j, \
k}] + r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + \
r[{l}, {i, j, k}] + r[{i, l}, {j, k}])\)\)\/\(\(-r[{i}, {j, k, l}]\) - r[{l}, \
{i, j, k}] - r[{i, l}, {j, k}]\) - \((r[{i, l}, {j, 
                            k}]\ \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                            r[{l}, {i, j, k}] + 
                            r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                            l}] - \((r[{}, {i, j, k, l}] + 
                              r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                              r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, l}] + 
                              r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + 
                              r[{i, l}, {j, k}])\))\) + \((\((r[{i}, {j, k, 
                                l}] + r[{l}, {i, j, k}] + r[{i, j}, {k, l}] + 
                            r[{i, k}, {j, l}])\)\ r[{i, l}, {j, 
                            k}]\ \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                            r[{l}, {i, j, k}] + 
                            r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                            l}] - \((r[{}, {i, j, k, l}] + 
                              r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                              r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, l}] + 
                              r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + 
                              r[{i, l}, {j, k}])\))\) + \((r[{i, l}, {j, 
                            k}]\ \((r[{}, {i, j, k, l}] + r[{j}, {i, k, l}] + 
                            r[{k}, {i, j, l}] + 
                            r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, l}] + 
                            r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + 
                            r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                            l}] - \((r[{}, {i, j, k, l}] + 
                              r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                              r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, l}] + 
                              r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + 
                              r[{i, l}, {j, k}])\))\) - \((r[{}, {i, j, k, 
                            l}]\ \((r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + 
                            r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                            l}] - \((r[{}, {i, j, k, l}] + 
                              r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + 
                              r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, l}] + 
                                r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + 
                                r[{i, j}, {k, l}] + r[{i, k}, {j, l}] + 
                                r[{i, l}, {j, 
                                    k}])\)^2)\))\) + \[GothicB]\_{j}\ \((\
\[GothicB]\_{k}\ \[GothicB]\_{l}\ \((\(-9\) - 3\ r[{}, {i, j, k, l}] - 
                        3\ r[{i}, {j, k, l}] - 3\ r[{j}, {i, k, l}] - 
                        3\ r[{k}, {i, j, l}] - 3\ r[{l}, {i, j, k}] - 
                        3\ r[{i, j}, {k, 
                              l}] - \(r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + \
r[{i, j}, {k, l}]\)\/\(\(-r[{i}, {j, k, l}]\) - r[{j}, {i, k, l}] - r[{i, j}, \
{k, l}]\) + 2\ \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                              r[{j}, {i, k, l}] + 
                              r[{i, j}, {k, 
                                  l}])\) + \(\((r[{i}, {j, k, l}] + r[{j}, \
{i, k, l}] + r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] \
+ r[{j}, {i, k, l}] + r[{i, j}, {k, l}])\)\)\/\(\(-r[{i}, {j, k, l}]\) - \
r[{j}, {i, k, l}] - r[{i, j}, {k, l}]\) - \(r[{k}, {i, j, l}] + r[{l}, {i, j, \
k}] + r[{i, j}, {k, l}]\)\/\(\(-r[{k}, {i, j, l}]\) - r[{l}, {i, j, k}] - \
r[{i, j}, {k, l}]\) + 2\ \((r[{}, {i, j, k, l}] + r[{k}, {i, j, l}] + 
                              r[{l}, {i, j, k}] + 
                              r[{i, j}, {k, 
                                  l}])\) + \(\((r[{k}, {i, j, l}] + r[{l}, \
{i, j, k}] + r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, l}] + r[{k}, {i, j, l}] \
+ r[{l}, {i, j, k}] + r[{i, j}, {k, l}])\)\)\/\(\(-r[{k}, {i, j, l}]\) - \
r[{l}, {i, j, k}] - r[{i, j}, {k, l}]\) + 
                        r[{i, j}, {k, 
                              l}]/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                    r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{k}, {i, j, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, j}, {k, l}])\))\) - \((r[{i, 
                                  j}, {k, l}]\ \((r[{}, {i, j, k, l}] + 
                                  r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                  r[{i, j}, {k, l}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                    r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{k}, {i, j, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, j}, {k, l}])\))\) - \((r[{i, 
                                  j}, {k, l}]\ \((r[{}, {i, j, k, l}] + 
                                  r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + 
                                  r[{i, j}, {k, l}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                    r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{k}, {i, j, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, j}, {k, l}])\))\) + \((r[{i, 
                                  j}, {k, l}]\ \((r[{}, {i, j, k, l}] + 
                                  r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                  r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, 
                                      l}] + r[{k}, {i, j, l}] + 
                                  r[{l}, {i, j, k}] + 
                                  r[{i, j}, {k, l}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                    r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{k}, {i, j, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, j}, {k, l}])\))\) - 
                        3\ r[{i, k}, {j, 
                              l}] - \(r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + \
r[{i, k}, {j, l}]\)\/\(\(-r[{i}, {j, k, l}]\) - r[{k}, {i, j, l}] - r[{i, k}, \
{j, l}]\) + 2\ \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                              r[{k}, {i, j, l}] + 
                              r[{i, k}, {j, 
                                  l}])\) + \(\((r[{i}, {j, k, l}] + r[{k}, \
{i, j, l}] + r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] \
+ r[{k}, {i, j, l}] + r[{i, k}, {j, l}])\)\)\/\(\(-r[{i}, {j, k, l}]\) - \
r[{k}, {i, j, l}] - r[{i, k}, {j, l}]\) - \(r[{j}, {i, k, l}] + r[{l}, {i, j, \
k}] + r[{i, k}, {j, l}]\)\/\(\(-r[{j}, {i, k, l}]\) - r[{l}, {i, j, k}] - \
r[{i, k}, {j, l}]\) + 2\ \((r[{}, {i, j, k, l}] + r[{j}, {i, k, l}] + 
                              r[{l}, {i, j, k}] + 
                              r[{i, k}, {j, 
                                  l}])\) + \(\((r[{j}, {i, k, l}] + r[{l}, \
{i, j, k}] + r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, l}] + r[{j}, {i, k, l}] \
+ r[{l}, {i, j, k}] + r[{i, k}, {j, l}])\)\)\/\(\(-r[{j}, {i, k, l}]\) - \
r[{l}, {i, j, k}] - r[{i, k}, {j, l}]\) + 
                        2\ \((r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                              r[{i, j}, {k, l}] + r[{i, k}, {j, l}])\) + 
                        2\ \((r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + 
                              r[{i, j}, {k, l}] + r[{i, k}, {j, l}])\) + 
                        r[{i, k}, {j, 
                              l}]/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + 
                                    r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{j}, {i, k, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, k}, {j, l}])\))\) - \((r[{i, 
                                  k}, {j, l}]\ \((r[{}, {i, j, k, l}] + 
                                  r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + 
                                  r[{i, k}, {j, l}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + 
                                    r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{j}, {i, k, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, k}, {j, l}])\))\) - \((r[{i, 
                                  k}, {j, l}]\ \((r[{}, {i, j, k, l}] + 
                                  r[{j}, {i, k, l}] + r[{l}, {i, j, k}] + 
                                  r[{i, k}, {j, l}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + 
                                    r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{j}, {i, k, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, k}, {j, l}])\))\) + \((r[{i, 
                                  k}, {j, l}]\ \((r[{}, {i, j, k, l}] + 
                                  r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + 
                                  r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, 
                                      l}] + r[{j}, {i, k, l}] + 
                                  r[{l}, {i, j, k}] + 
                                  r[{i, k}, {j, l}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + 
                                    r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{j}, {i, k, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, k}, {j, l}])\))\) - 
                        3\ r[{i, l}, {j, 
                              k}] - \(r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + \
r[{i, l}, {j, k}]\)\/\(\(-r[{j}, {i, k, l}]\) - r[{k}, {i, j, l}] - r[{i, l}, \
{j, k}]\) + \(\((r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + r[{i, j}, {k, l}] + \
r[{i, k}, {j, l}])\)\ \((r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + r[{i, l}, \
{j, k}])\)\)\/\(\(-r[{j}, {i, k, l}]\) - r[{k}, {i, j, l}] - r[{i, l}, {j, \
k}]\) + 2\ \((r[{}, {i, j, k, l}] + r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                              r[{i, l}, {j, 
                                  k}])\) + \(\((r[{j}, {i, k, l}] + r[{k}, \
{i, j, l}] + r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, l}] + r[{j}, {i, k, l}] \
+ r[{k}, {i, j, l}] + r[{i, l}, {j, k}])\)\)\/\(\(-r[{j}, {i, k, l}]\) - \
r[{k}, {i, j, l}] - r[{i, l}, {j, k}]\) - \(r[{i}, {j, k, l}] + r[{l}, {i, j, \
k}] + r[{i, l}, {j, k}]\)\/\(\(-r[{i}, {j, k, l}]\) - r[{l}, {i, j, k}] - \
r[{i, l}, {j, k}]\) + \(\((r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + r[{i, j}, \
{k, l}] + r[{i, k}, {j, l}])\)\ \((r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + \
r[{i, l}, {j, k}])\)\)\/\(\(-r[{i}, {j, k, l}]\) - r[{l}, {i, j, k}] - r[{i, \
l}, {j, k}]\) + 2\ \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                              r[{l}, {i, j, k}] + 
                              r[{i, l}, {j, 
                                  k}])\) + \(\((r[{i}, {j, k, l}] + r[{l}, \
{i, j, k}] + r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] \
+ r[{l}, {i, j, k}] + r[{i, l}, {j, k}])\)\)\/\(\(-r[{i}, {j, k, l}]\) - \
r[{l}, {i, j, k}] - r[{i, l}, {j, k}]\) + 
                        2\ \((r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + 
                              r[{i, j}, {k, l}] + 
                              r[{i, l}, {j, 
                                  k}])\) + \(\((r[{j}, {i, k, l}] + r[{l}, \
{i, j, k}] + r[{i, k}, {j, l}])\)\ \((r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + \
r[{i, j}, {k, l}] + r[{i, l}, {j, k}])\)\)\/\(\(-r[{j}, {i, k, l}]\) - r[{l}, \
{i, j, k}] - r[{i, k}, {j, l}]\) - \((r[{i, k}, {j, 
                                  l}]\ \((r[{i}, {j, k, l}] + 
                                  r[{k}, {i, j, l}] + r[{i, j}, {k, l}] + 
                                  r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + 
                                    r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{j}, {i, k, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, k}, {j, l}])\))\) + \((r[{i, 
                                  k}, {j, l}]\ \((r[{}, {i, j, k, l}] + 
                                  r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + 
                                  r[{i, k}, {j, l}])\)\ \((r[{i}, {j, k, 
                                      l}] + r[{k}, {i, j, l}] + 
                                  r[{i, j}, {k, l}] + 
                                  r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + 
                                    r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{j}, {i, k, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, k}, {j, l}])\))\) + 
                        2\ \((r[{j}, {i, k, l}] + r[{l}, {i, j, k}] + 
                              r[{i, j}, {k, l}] + 
                              r[{i, l}, {j, 
                                  k}])\) + \(\((r[{i}, {j, k, l}] + r[{k}, \
{i, j, l}] + r[{i, k}, {j, l}])\)\ \((r[{j}, {i, k, l}] + r[{l}, {i, j, k}] + \
r[{i, j}, {k, l}] + r[{i, l}, {j, k}])\)\)\/\(\(-r[{i}, {j, k, l}]\) - r[{k}, \
{i, j, l}] - r[{i, k}, {j, l}]\) - \((r[{i, k}, {j, 
                                  l}]\ \((r[{j}, {i, k, l}] + 
                                  r[{l}, {i, j, k}] + r[{i, j}, {k, l}] + 
                                  r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + 
                                    r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{j}, {i, k, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, k}, {j, l}])\))\) + \((r[{i, 
                                  k}, {j, l}]\ \((r[{}, {i, j, k, l}] + 
                                  r[{j}, {i, k, l}] + r[{l}, {i, j, k}] + 
                                  r[{i, k}, {j, l}])\)\ \((r[{j}, {i, k, 
                                      l}] + r[{l}, {i, j, k}] + 
                                  r[{i, j}, {k, l}] + 
                                  r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + 
                                    r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{j}, {i, k, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, k}, {j, l}])\))\) + \((r[{i, 
                                  k}, {j, l}]\ \((r[{i}, {j, k, l}] + 
                                  r[{k}, {i, j, l}] + r[{i, j}, {k, l}] + 
                                  r[{i, l}, {j, k}])\)\ \((r[{j}, {i, k, 
                                      l}] + r[{l}, {i, j, k}] + 
                                  r[{i, j}, {k, l}] + 
                                  r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{k}, {i, j, l}] + 
                                    r[{i, k}, {j, l}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{j}, {i, k, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, k}, {j, l}])\))\) + 
                        2\ \((r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                              r[{i, k}, {j, l}] + 
                              r[{i, l}, {j, 
                                  
                                  k}])\) + \(\((r[{k}, {i, j, l}] + r[{l}, \
{i, j, k}] + r[{i, j}, {k, l}])\)\ \((r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + \
r[{i, k}, {j, l}] + r[{i, l}, {j, k}])\)\)\/\(\(-r[{k}, {i, j, l}]\) - r[{l}, \
{i, j, k}] - r[{i, j}, {k, l}]\) - \((r[{i, j}, {k, 
                                  l}]\ \((r[{i}, {j, k, l}] + 
                                  r[{j}, {i, k, l}] + r[{i, k}, {j, l}] + 
                                  r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                    r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{k}, {i, j, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, j}, {k, l}])\))\) + \((r[{i, 
                                  j}, {k, l}]\ \((r[{}, {i, j, k, l}] + 
                                  r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                  r[{i, j}, {k, l}])\)\ \((r[{i}, {j, k, 
                                      l}] + r[{j}, {i, k, l}] + 
                                  r[{i, k}, {j, l}] + 
                                  r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                    r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{k}, {i, j, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, j}, {k, l}])\))\) + 
                        2\ \((r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + 
                              r[{i, k}, {j, l}] + 
                              r[{i, l}, {j, 
                                  k}])\) + \(\((r[{i}, {j, k, l}] + r[{j}, \
{i, k, l}] + r[{i, j}, {k, l}])\)\ \((r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + \
r[{i, k}, {j, l}] + r[{i, l}, {j, k}])\)\)\/\(\(-r[{i}, {j, k, l}]\) - r[{j}, \
{i, k, l}] - r[{i, j}, {k, l}]\) - \((r[{i, j}, {k, 
                                  l}]\ \((r[{k}, {i, j, l}] + 
                                  r[{l}, {i, j, k}] + r[{i, k}, {j, l}] + 
                                  r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                    r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{k}, {i, j, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, j}, {k, l}])\))\) + \((r[{i, 
                                  j}, {k, l}]\ \((r[{}, {i, j, k, l}] + 
                                  r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + 
                                  r[{i, j}, {k, l}])\)\ \((r[{k}, {i, j, 
                                      l}] + r[{l}, {i, j, k}] + 
                                  r[{i, k}, {j, l}] + 
                                  r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                    r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{k}, {i, j, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, j}, {k, l}])\))\) + \((r[{i, 
                                  j}, {k, l}]\ \((r[{i}, {j, k, l}] + 
                                  r[{j}, {i, k, l}] + r[{i, k}, {j, l}] + 
                                  r[{i, l}, {j, k}])\)\ \((r[{k}, {i, j, 
                                      l}] + r[{l}, {i, j, k}] + 
                                  r[{i, k}, {j, l}] + 
                                  r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                    r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{k}, {i, j, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, j}, {k, l}])\))\) + 
                        r[{i, l}, {j, 
                              k}]/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                                    r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{i}, {j, k, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, l}, {j, 
                                        k}])\))\) - \((\((r[{j}, {i, k, l}] + 
                                  r[{k}, {i, j, l}] + r[{i, j}, {k, l}] + 
                                  r[{i, k}, {j, l}])\)\ r[{i, l}, {j, 
                                  k}])\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                                    r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{i}, {j, k, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, l}, {j, 
                                        k}])\))\) - \((\((r[{i}, {j, k, l}] + 
                                  r[{l}, {i, j, k}] + r[{i, j}, {k, l}] + 
                                  r[{i, k}, {j, l}])\)\ r[{i, l}, {j, 
                                  k}])\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                                    r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{i}, {j, k, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, l}, {j, 
                                        k}])\))\) + \((\((r[{j}, {i, k, l}] + 
                                  r[{k}, {i, j, l}] + r[{i, j}, {k, l}] + 
                                  r[{i, k}, {j, l}])\)\ \((r[{i}, {j, k, 
                                      l}] + r[{l}, {i, j, k}] + 
                                  r[{i, j}, {k, l}] + 
                                  r[{i, k}, {j, l}])\)\ r[{i, l}, {j, 
                                  k}])\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                                    r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{i}, {j, k, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, l}, {j, k}])\))\) - \((r[{i, 
                                  l}, {j, k}]\ \((r[{}, {i, j, k, l}] + 
                                  r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                                  r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                                    r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{i}, {j, k, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, l}, {j, 
                                        k}])\))\) + \((\((r[{j}, {i, k, l}] + 
                                  r[{k}, {i, j, l}] + r[{i, j}, {k, l}] + 
                                  r[{i, k}, {j, l}])\)\ r[{i, l}, {j, 
                                  k}]\ \((r[{}, {i, j, k, l}] + 
                                  r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                                  r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                                    r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{i}, {j, k, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, l}, {j, k}])\))\) - \((r[{i, 
                                  l}, {j, k}]\ \((r[{}, {i, j, k, l}] + 
                                  r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + 
                                  r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                                    r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{i}, {j, k, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, l}, {j, 
                                        k}])\))\) + \((\((r[{i}, {j, k, l}] + 
                                  r[{l}, {i, j, k}] + r[{i, j}, {k, l}] + 
                                  r[{i, k}, {j, l}])\)\ r[{i, l}, {j, 
                                  k}]\ \((r[{}, {i, j, k, l}] + 
                                  r[{i}, {j, k, l}] + r[{l}, {i, j, k}] + 
                                  r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                                    r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{i}, {j, k, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, l}, {j, k}])\))\) + \((r[{i, 
                                  l}, {j, k}]\ \((r[{}, {i, j, k, l}] + 
                                  r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                                  r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, 
                                      l}] + r[{i}, {j, k, l}] + 
                                  r[{l}, {i, j, k}] + 
                                  r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + 
                                    r[{i, l}, {j, k}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{i}, {j, k, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, l}, {j, 
                                        k}])\))\))\) + \[GothicB]\_{k, l}\ \
\((\(-2\)\ r[{}, {i, j, k, l}] - r[{i}, {j, k, l}] - r[{j}, {i, k, l}] - 
                        r[{i, j}, {k, l}] + 
                        2\ \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] + 
                              r[{j}, {i, k, l}] + 
                              r[{i, j}, {k, 
                                  l}])\) + \(\((r[{i}, {j, k, l}] + r[{j}, \
{i, k, l}] + r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, l}] + r[{i}, {j, k, l}] \
+ r[{j}, {i, k, l}] + r[{i, j}, {k, l}])\)\)\/\(\(-r[{i}, {j, k, l}]\) - \
r[{j}, {i, k, l}] - r[{i, j}, {k, l}]\) - \((r[{i, j}, {k, 
                                  l}]\ \((r[{}, {i, j, k, l}] + 
                                  r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                  r[{i, j}, {k, l}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                    r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{k}, {i, j, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, j}, {k, l}])\))\) + \((r[{i, 
                                  j}, {k, l}]\ \((r[{}, {i, j, k, l}] + 
                                  r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                  r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, 
                                      l}] + r[{k}, {i, j, l}] + 
                                  r[{l}, {i, j, k}] + 
                                  r[{i, j}, {k, l}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                    r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{k}, {i, j, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, j}, {k, l}])\))\) + \((r[{i, 
                                  j}, {k, l}]\ \((r[{}, {i, j, k, l}] + 
                                  r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                  r[{i, j}, {k, l}])\)\ \((r[{i}, {j, k, 
                                      l}] + r[{j}, {i, k, l}] + 
                                  r[{i, k}, {j, l}] + 
                                  r[{i, l}, {j, k}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                    r[{i, j}, {k, l}])\)\ \((r[{}, {i, j, k, 
                                        l}] + r[{k}, {i, j, l}] + 
                                    r[{l}, {i, j, k}] + 
                                    r[{i, j}, {k, l}])\))\) - \((r[{}, {i, j, 
                                  k, l}]\ \((r[{i}, {j, k, l}] + 
                                  r[{j}, {i, k, l}] + 
                                  r[{i, j}, {k, l}])\))\)/\((r[{}, {i, j, k, 
                                  l}] - \((r[{}, {i, j, k, l}] + 
                                    r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                    r[{i, j}, {k, 
                                        l}])\)\ \((r[{}, {i, j, k, l}] + 
                                      r[{i}, {j, k, l}] + r[{j}, {i, k, l}] + 
                                      r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + 
                                      r[{i, j}, {k, l}] + r[{i, k}, {j, l}] + 
                                      r[{i, l}, {j, 
                                        k}])\)^2)\))\))\))\)\)], "Output",
  CellLabel->"Out[91]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(yy /. 
        r[{}, {i, j, k, l}] -> 
          1 - \((\[Sum]\+\(x \[Element] Subsets[{i, j, k, l}, 1, 3]\)r[x, {i, \
j, k, l}\[Backslash]x]\/2 /. sr)\) // Simplify\)], "Input",
  CellLabel->"In[95]:="],

Cell[BoxData[
    \(\(-\[GothicB]\_{i, j, k, l}\)\ \((\(-1\) + r[{i}, {j, k, l}] + 
          r[{j}, {i, k, l}] + r[{k}, {i, j, l}] + r[{l}, {i, j, k}] + 
          r[{i, j}, {k, l}] + r[{i, k}, {j, l}] + 
          r[{i, l}, {j, k}])\)\)], "Output",
  CellLabel->"Out[95]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["The algorithm", "SubsubsectionIcon",
  CellTags->"Algorithm"],

Cell[TextData[{
  "The leading term in each ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[GothicB]\_U\)\(\ \)\)\)]],
  "is just ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_U\)]],
  ", and the rate of decay of ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicB]\_U\)]],
  " is the probability that there is no recombination among any of the loci \
U.  This is denoted by ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicR]\_U \[Congruent] \
\[GothicR]\_\(\[EmptySet], U\)\)]],
  ".  It is also convenient to define ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(r\_P\)\(\[Congruent]\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Product]\+\(U \[Element] P\)r\_U\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Product]\+\(U \[Element] P\)r\_U\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_P \[Congruent] \[Product]\+\(U \
\[Element] P\)\[GothicCapitalD]\_U\)]],
  ". Denote the set of all partition of U by \[DoubleStruckCapitalP][U]. Let \
Bennett's coefficient be:"
}], "Text"],

Cell[BoxData[
    \(TextForm\`b\_U = \[GothicCapitalD]\_U + \[Sum]\+\(P \[Element] \
\[DoubleStruckCapitalP][U]\[IndentingNewLine] | P | \(\(>\)\(1\)\)\)\(c\_P\) 
            b\_P\)], "NumberedEquation"],

Cell[TextData[{
  "We have ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_U\%*\) = \(r\_U\) b\_U\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c\_P = 1\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(P\)\(|\)\) = 1\)]],
  ".  Separating out the leading term:"
}], "Text"],

Cell[BoxData[
    \(TextForm\`\(b\_U\%*\) = \(\(\[GothicCapitalD]\_U\%*\) + \[Sum]\+\(P \
\[Element] \[DoubleStruckCapitalP][U]\[IndentingNewLine] | P | \(\(>\)\(1\)\)\
\)\(c\_P\) \(r\_P\) 
              b\_P\[IndentingNewLine] = \(\(r\_U\) \[GothicCapitalD]\_U + \
\[Sum]\+\(A \[SubsetEqual] U\)\(r\_\(A, 
                    U\[Backslash]
                      A\)\) \(\[GothicCapitalD]\_A\) \[GothicCapitalD]\_\(U\
\[Backslash]A\) + \[Sum]\+\(P \[Element] \[DoubleStruckCapitalP][U]\
\[IndentingNewLine] | P | \(\(>\)\(1\)\)\)\(c\_P\) \(r\_P\) 
                b\_P\[IndentingNewLine] = \(\(r\_U\) \((b\_U - \[Sum]\+\(P \
\[Element] \[DoubleStruckCapitalP][U]\[IndentingNewLine] | P | \(\(>\)\(1\)\)\
\)\(c\_P\) b\_P)\) + \[Sum]\+\(A \[SubsetEqual] U\)\(r\_\(A, 
                      U\[Backslash]
                        A\)\) \(\[GothicCapitalD]\_A\) \[GothicCapitalD]\_\(U\
\[Backslash]A\) + \[Sum]\+\(P \[Element] \[DoubleStruckCapitalP][U]\
\[IndentingNewLine] | P | \(\(>\)\(1\)\)\)\(c\_P\) \(r\_P\) 
                  b\_P\[IndentingNewLine] = \(\(r\_U\) 
                  b\_U + \[Sum]\+\(A \[SubsetEqual] U\)\(r\_\(A, 
                        U\[Backslash]
                          A\)\) \(\[GothicCapitalD]\_A\) \
\[GothicCapitalD]\_\(U\[Backslash]A\) - \[Sum]\+\(P \[Element] \
\[DoubleStruckCapitalP][U]\[IndentingNewLine] | P | \(\(>\)\(1\)\)\)\(c\_P\) \
\((r\_U - r\_P)\) b\_P\[IndentingNewLine] = \(r\_U\) 
                  b\_U + \[Sum]\+\(A \[SubsetEqual] U\)\(r\_\(A, 
                        U\[Backslash]A\)\) \((\(b\_A\) 
                          b\_\(U\[Backslash]A\) - \(b\_A\) \(\[Sum]\+\(P\_2 \
\[Element] \[DoubleStruckCapitalP][U\[Backslash]A]\[IndentingNewLine] | P\_2 \
| \(\(>\)\(1\)\)\)\(c\_\(P\_2\)\) 
                              b\_\(P\_2\)\) - \(b\_\(U\[Backslash]
                                A\)\) \(\[Sum]\+\(P\_1 \[Element] \
\[DoubleStruckCapitalP][A]\[IndentingNewLine] | P\_1 | \
\(\(>\)\(1\)\)\)\(c\_\(P\_1\)\) 
                              b\_\(P\_1\)\) + \[Sum]\+\(P\_1 \[Element] \
\[DoubleStruckCapitalP][A]\[IndentingNewLine]
                            P\_2 \[Element] \[DoubleStruckCapitalP][U\
\[Backslash]A]\[IndentingNewLine] | P\_1 | \(\(>\)\(1\)\), \(\(|\)\(P\_2\)\(|\
\)\(\(>\)\(1\)\)\)\)\(c\_\(P\_1\)\) \(b\_\(P\_1\)\) \(c\_\(P\_2\)\) 
                            
                            b\_\(P\_2\))\) - \[Sum]\+\(P \[Element] \
\[DoubleStruckCapitalP][U]\[IndentingNewLine] | P | \(\(>\)\(1\)\)\)\(c\_P\) \
\((r\_U - r\_P)\) b\_P\)\)\)\)\)], "NumberedEquation"],

Cell["\<\
 In order to construct the coefficients, we classify terms in the \
sum according to the partition to which they contribute.\
\>", "Text"],

Cell[TextData[{
  "We have ",
  Cell[BoxData[
      \(TraditionalForm\`b\_{1} \[Congruent] \[GothicCapitalD]\_{1}\)]],
  ", which allows for non-central \[GothicCapitalD]. The two way equation \
is:"
}], "Text"],

Cell[BoxData[
    \(TextForm\`\(b\_{1, 2}\%*\) = \(r\_{1, 2}\) 
          b\_{1, 2} + \(r\_\({1}, {2}\)\) \(b\_{1}\) 
          b\_{2} - \(c\_{{1}, {2}}\) \((r\_{1, 2} - \(r\_{1}\) 
                r\_{2})\) \(b\_{1}\) b\_{2}\)], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`r\_{1} = 1\)]],
  ".  Setting this to ",
  Cell[BoxData[
      \(\(r\_{1, 2}\) b\_{1, 2}\)]],
  " and identifying coefficients:"
}], "Text"],

Cell[BoxData[
    \(TextForm\`c\_{{1}, {2}} = \(r\_\({1}, {2}\)\/\(r\_{1, 2} - \(r\_{1}\) r\
\_{2}\) = \(\(-1\)\ \ \ and\ b\_{1, 2} = \(\[GothicCapitalD]\_{1, 2} - \
\(b\_{1}\) 
                b\_{2} = \[GothicCapitalD]\_{1, 2} - \(\[GothicCapitalD]\_{1}\
\) \[GothicCapitalD]\_{2}\)\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "This does decay geometrically under recombination; in general, .",
  Cell[BoxData[
      \(c\_{{1}, {2, \[Ellipsis]}} = \(\(-1\)\(\ \)\)\)]],
  ".  "
}], "Text"],

Cell["Similarly:", "Text"],

Cell[BoxData[
    \(TextForm\`b\_{1, 2, 3} = \[GothicCapitalD]\_{1, 2, 3} - \(\
\[GothicCapitalD]\_{1}\) \[GothicCapitalD]\_{2, 3} - \(\[GothicCapitalD]\_{2}\
\) \[GothicCapitalD]\_{1, 3} - \(\[GothicCapitalD]\_{3}\) \
\[GothicCapitalD]\_{1, 2} + 
        2 \( \[GothicCapitalD]\_{1}\) \(\[GothicCapitalD]\_{2}\) \
\[GothicCapitalD]\_{3}\)], "NumberedEquation"],

Cell["\<\
Deviations from the cumulant measures only appear at fourth order \
and above.\
\>", "Text"],

Cell[TextData[{
  "More generally, consider coefficients of the form ",
  Cell[BoxData[
      \(TraditionalForm\`c\_{{i}, A}\)]],
  ".  Such partitions with two elements can only include a contribution from \
",
  Cell[BoxData[
      \(TraditionalForm\`r\_\({i}, A\)\)]],
  ", with value ",
  Cell[BoxData[
      FormBox[
        FractionBox[
          FormBox[\(r\_\({i}, A\)\),
            "TraditionalForm"], \(r\_\(A\[Vee]{i}\) - \(r\_A\) r\_{i}\)], 
        TraditionalForm]]],
  ".  However, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(r\_A = r\_\(A\[Vee]{i}\)\),
            "TraditionalForm"], "+", \(r\_\(A, {i}\)\)}], TraditionalForm]]],
  ", so this is in general -1.  Coefficients of the form ",
  Cell[BoxData[
      \(TraditionalForm\`c\_{{1}, {2}, {3}, \[Ellipsis]}\)]],
  " also are -1 in general."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Technicalities", "SubsubsectionIcon"],

Cell["\<\
The following functions are used to construct ToBennett[] and \
FromBennett[], and are not usually needed.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(BennettC[
              P]\), \(gives\ the\ coefficient\ c\_P\ in\ an\ expression\ for\ \
Bennett' s\ measure\ of\ \(\(disequilibrium\)\(.\)\)\)},
          {\(BennettExpansion[
              U]\), \(generates\ and\ stores\ the\ expression\ used\ to\ \
calculate\ the\ BennettC[P]\)},
          {\(ToBennettExpression[
              U]\), \(gives\ \[GothicCapitalD]\_U\ in\ terms\ of\ \
\[GothicB]\_U\)},
          {\(FromBennettExpression[
              U]\), \(gives\ \[GothicB]\_U\ in\ terms\ of\ \[GothicD]\_U\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{
  "BennettC", "BennettExpansion", "ToBennettExpression", 
    "FromBennettExpression"}],

Cell[TextData[{
  "As explained ",
  ButtonBox["above",
    ButtonData:>"Algorithm",
    ButtonStyle->"AddOnsLink"],
  ", the ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicB]\_U\)]],
  " are expressed as a sum of terms ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_P\) \(\[Product]\+\(A \[Element] \
P\)\[GothicB]\_A\)\)]],
  ", where P is a ",
  ButtonBox["partition",
    ButtonData:>{"Set partitions", "PartitionSet"},
    ButtonStyle->"AddOnsLink"],
  " of the set U. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BennettC[{{i, j}, {k, l}}]\)], "Input",
  CellLabel->"In[85]:="],

Cell[BoxData[
    \(\[GothicR]\_\({i, j}, {k, l}\)\/\(\(-\[GothicR]\_\({}, {i, j}\)\)\ \
\[GothicR]\_\({}, {k, l}\) + \[GothicR]\_\({}, {i, j, k, l}\)\)\)], "Output",
  CellLabel->"Out[85]="]
}, Open  ]],

Cell[TextData[{
  "The coefficients are stored for ",
  ButtonBox["standard partitions",
    ButtonData:>{"Set partitions", "StandardPartition"},
    ButtonStyle->"AddOnsLink"],
  ", such as {{1},{2,3},{4,5,6}}, and partitions with the same structure \
(e.g. {{i,j},{k},{l,m,n}}) are derived from these stored forms.  The \
coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c\_P\)\(\ \)\)\)]],
  "is the coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Product]\+\(A \[Element] P\)\[GothicB]\_A\)]],
  " in BennettExpansion[U]."
}], "Text"]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowSize->{1075, 690},
WindowMargins->{{6, Automatic}, {14, Automatic}},
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\[Placeholder]", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", 
                BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->Utilities`Notation`Private`DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Baake"->{
    Cell[2659, 78, 62, 1, 36, "SubsectionIcon",
      CellTags->"Baake"]},
  "ToBaake"->{
    Cell[2724, 81, 698, 16, 54, "DefinitionBox",
      CellTags->{"ToBaake", "FromBaake"}]},
  "FromBaake"->{
    Cell[2724, 81, 698, 16, 54, "DefinitionBox",
      CellTags->{"ToBaake", "FromBaake"}]},
  "Bennett"->{
    Cell[14708, 399, 79, 1, 26, "SubsectionIcon",
      CellTags->"Bennett"]},
  "ToBennett"->{
    Cell[15349, 416, 710, 16, 56, "DefinitionBox",
      CellTags->{"ToBennett", "FromBennett"}]},
  "FromBennett"->{
    Cell[15349, 416, 710, 16, 56, "DefinitionBox",
      CellTags->{"ToBennett", "FromBennett"}]},
  "Algorithm"->{
    Cell[233125, 3738, 67, 1, 20, "SubsubsectionIcon",
      CellTags->"Algorithm"]},
  "BennettC"->{
    Cell[240184, 3927, 733, 16, 94, "DefinitionBox",
      CellTags->{
      "BennettC", "BennettExpansion", "ToBennettExpression", 
        "FromBennettExpression"}]},
  "BennettExpansion"->{
    Cell[240184, 3927, 733, 16, 94, "DefinitionBox",
      CellTags->{
      "BennettC", "BennettExpansion", "ToBennettExpression", 
        "FromBennettExpression"}]},
  "ToBennettExpression"->{
    Cell[240184, 3927, 733, 16, 94, "DefinitionBox",
      CellTags->{
      "BennettC", "BennettExpansion", "ToBennettExpression", 
        "FromBennettExpression"}]},
  "FromBennettExpression"->{
    Cell[240184, 3927, 733, 16, 94, "DefinitionBox",
      CellTags->{
      "BennettC", "BennettExpansion", "ToBennettExpression", 
        "FromBennettExpression"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Baake", 313693, 6560},
  {"ToBaake", 313783, 6563},
  {"FromBaake", 313893, 6566},
  {"Bennett", 314001, 6569},
  {"ToBennett", 314097, 6572},
  {"FromBennett", 314215, 6575},
  {"Algorithm", 314331, 6578},
  {"BennettC", 314433, 6581},
  {"BennettExpansion", 314626, 6586},
  {"ToBennettExpression", 314822, 6591},
  {"FromBennettExpression", 315020, 6596}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 57, 0, 36, "Subsection"],
Cell[1777, 51, 717, 17, 38, "Text"],
Cell[2497, 70, 46, 0, 28, "MathCaption"],
Cell[2546, 72, 88, 2, 26, "Input"],

Cell[CellGroupData[{
Cell[2659, 78, 62, 1, 36, "SubsectionIcon",
  CellTags->"Baake"],
Cell[2724, 81, 698, 16, 54, "DefinitionBox",
  CellTags->{"ToBaake", "FromBaake"}],
Cell[3425, 99, 433, 9, 37, "Text"],
Cell[3861, 110, 441, 12, 24, "Text"],
Cell[4305, 124, 112, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4442, 131, 163, 3, 27, "Input"],
Cell[4608, 136, 948, 14, 22, "Output"]
}, Open  ]],
Cell[5571, 153, 395, 11, 22, "Text"],
Cell[5969, 166, 59, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6053, 170, 85, 2, 26, "Input"],
Cell[6141, 174, 151, 3, 22, "Output"]
}, Open  ]],
Cell[6307, 180, 590, 15, 56, "DefinitionBox"],
Cell[6900, 197, 65, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6990, 201, 139, 3, 26, "Input"],
Cell[7132, 206, 337, 5, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7506, 216, 90, 2, 26, "Input"],
Cell[7599, 220, 116, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7752, 227, 79, 0, 24, "SubsubsectionIcon"],
Cell[7834, 229, 233, 7, 23, "Text"],
Cell[8070, 238, 392, 7, 74, "Input"],
Cell[8465, 247, 265, 6, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[8755, 257, 107, 2, 26, "Input"],
Cell[8865, 261, 91, 2, 36, "Output"]
}, Open  ]],
Cell[8971, 266, 533, 13, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[9529, 283, 822, 13, 66, "Input"],
Cell[10354, 298, 445, 7, 27, "Output"]
}, Open  ]],
Cell[10814, 308, 223, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[11062, 316, 169, 4, 26, "Input"],
Cell[11234, 322, 243, 4, 27, "Output"]
}, Open  ]],
Cell[11492, 329, 71, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[11588, 333, 874, 14, 66, "Input"],
Cell[12465, 349, 1666, 27, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[14168, 381, 169, 4, 22, "Input"],
Cell[14340, 387, 307, 5, 27, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[14708, 399, 79, 1, 26, "SubsectionIcon",
  CellTags->"Bennett"],
Cell[14790, 402, 556, 12, 37, "Text"],
Cell[15349, 416, 710, 16, 56, "DefinitionBox",
  CellTags->{"ToBennett", "FromBennett"}],
Cell[16062, 434, 94, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[16181, 441, 160, 3, 27, "Input"],
Cell[16344, 446, 558, 9, 22, "Output"]
}, Open  ]],
Cell[16917, 458, 64, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[17006, 462, 158, 3, 27, "Input"],
Cell[17167, 467, 558, 9, 22, "Output"]
}, Open  ]],
Cell[17740, 479, 69, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[17834, 483, 179, 3, 27, "Input"],
Cell[18016, 488, 127252, 1826, 4091, "Output"]
}, Closed]],
Cell[145283, 2317, 290, 7, 18, "Text"],

Cell[CellGroupData[{
Cell[145598, 2328, 102, 2, 27, "Input"],
Cell[145703, 2332, 5342, 74, 123, "Output"]
}, Open  ]],
Cell[151060, 2409, 58, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[151143, 2413, 131, 3, 27, "Input"],
Cell[151277, 2418, 163, 3, 22, "Output"]
}, Open  ]],
Cell[151455, 2424, 542, 18, 24, "Text"],
Cell[152000, 2444, 595, 11, 54, "DefinitionBox"],

Cell[CellGroupData[{
Cell[152620, 2459, 197, 4, 27, "Input"],
Cell[152820, 2465, 1207, 18, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[154064, 2488, 83, 1, 24, "SubsubsectionIcon"],
Cell[154150, 2491, 235, 7, 23, "Text"],
Cell[154388, 2500, 393, 7, 74, "Input"],
Cell[154784, 2509, 511, 13, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[155320, 2526, 1092, 19, 104, "Input"],
Cell[156415, 2547, 3225, 51, 342, "Output"]
}, Closed]],
Cell[159655, 2601, 318, 9, 20, "Text"],
Cell[159976, 2612, 276, 8, 24, "Text"],
Cell[160255, 2622, 115, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[160395, 2629, 512, 10, 98, "Input"],
Cell[160910, 2641, 161, 3, 22, "Output"]
}, Open  ]],
Cell[161086, 2647, 71, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[161182, 2651, 899, 15, 104, "Input"],
Cell[162084, 2668, 7545, 113, 1098, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[169666, 2786, 153, 5, 23, "Input"],
Cell[169822, 2793, 13414, 185, 2159, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[183273, 2983, 353, 8, 48, "Input"],
Cell[183629, 2993, 48909, 722, 4037, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[232575, 3720, 223, 5, 48, "Input"],
Cell[232801, 3727, 275, 5, 22, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[233125, 3738, 67, 1, 20, "SubsubsectionIcon",
  CellTags->"Algorithm"],
Cell[233195, 3741, 1040, 28, 37, "Text"],
Cell[234238, 3771, 203, 3, 59, "NumberedEquation"],
Cell[234444, 3776, 302, 11, 22, "Text"],
Cell[234749, 3789, 2538, 41, 305, "NumberedEquation"],
Cell[237290, 3832, 148, 3, 22, "Text"],
Cell[237441, 3837, 211, 6, 22, "Text"],
Cell[237655, 3845, 249, 4, 31, "NumberedEquation"],
Cell[237907, 3851, 209, 8, 22, "Text"],
Cell[238119, 3861, 312, 5, 47, "NumberedEquation"],
Cell[238434, 3868, 180, 5, 22, "Text"],
Cell[238617, 3875, 26, 0, 70, "Text"],
Cell[238646, 3877, 361, 6, 70, "NumberedEquation"],
Cell[239010, 3885, 102, 3, 70, "Text"],
Cell[239115, 3890, 853, 25, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[240005, 3920, 43, 0, 20, "SubsubsectionIcon"],
Cell[240051, 3922, 130, 3, 22, "Text"],
Cell[240184, 3927, 733, 16, 94, "DefinitionBox",
  CellTags->{
  "BennettC", "BennettExpansion", "ToBennettExpression", 
    "FromBennettExpression"}],
Cell[240920, 3945, 494, 17, 23, "Text"],

Cell[CellGroupData[{
Cell[241439, 3966, 84, 2, 26, "Input"],
Cell[241526, 3970, 191, 3, 39, "Output"]
}, Open  ]],
Cell[241732, 3976, 562, 14, 37, "Text"]
}, Closed]]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

