(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12108,        326]*)
(*NotebookOutlinePosition[     13698,        372]*)
(*  CellTagsIndexPosition[     13483,        363]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Changing contexts", "SubsectionIcon"],

Cell[TextData[{
  "During meiosis, a gamete is produced which contains some genes from the \
paternal genome (SexOfOrigin\[Equal]\[GothicCapitalM]), and some from the \
maternal genome (SexOfOrigin\[Equal]\[GothicCapitalF]).  As a result of \
migration of juvenile diploids, genes in adults are derived from zygotes in a \
different deme.  As a result of random union of gametes, a gene in a zygote \
is derived from one in the gamete pool.  All these changes in contexts are \
described by ",
  StyleBox["rules",
    FontSlant->"Italic"],
  " or ",
  StyleBox["families of rules",
    FontSlant->"Italic"],
  ".  Transmission of genes between stages is then described by coefficients \
which give the probability of each kind of rule."
}], "Text"],

Cell[TextData[{
  "Defining these rules is complicated by two requirements.  First, sets of \
genes-in-context might in principle contain a mixture of kinds of context: \
for example, genes in two different individuals (\[Alpha], \[Beta]) might be \
represented by ",
  Cell[BoxData[
      \(TraditionalForm\`{i\_{\[GothicCapitalZ], t, \[Alpha], \
\[GothicCapitalM], \[GothicCapitalF]}, \ 
        j\_{\[GothicCapitalZ], t, \[Beta], \[GothicCapitalM], \
\[GothicCapitalM]}}\)]],
  "; genes in an adult individual \[Alpha], and in a gamete produced by that \
individual, might be represented as ",
  Cell[BoxData[
      \(TraditionalForm\`{i\_{\[GothicCapitalG], t, \[Alpha], \
\[GothicCapitalM]}, \ 
        j\_{\[GothicCapitalZ], t, \[Alpha], \[GothicCapitalM], \
\[GothicCapitalF]}}\)]],
  ".  Usually, genes-in-context will be in the same individual, and at the \
same stage.  However, that might not be the case in general."
}], "Text"],

Cell["\<\
A second complication is that at meiosis, one set of genes comes \
from the maternal genome, and another set of genes from the paternal genome.  \
Thus, we need to define composite rules, such that one rule applies to one \
set of genes, and another to the other set.\
\>", "Text"],

Cell[BoxData[
    StyleBox[GridBox[{
          {
            RowBox[{
              StyleBox[\(present\ context\),
                FontSlant->"Italic"], "\[LeftArrow]", 
              RowBox[{
                StyleBox["previous",
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  FontSlant->"Italic"], 
                StyleBox["context",
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  FontSlant->"Italic"], "or", " ", 
                RowBox[{"TransmissionRule", "[", 
                  RowBox[{
                    StyleBox[\(present\ context\),
                      FontSlant->"Italic"], ",", " ", 
                    StyleBox[\(previous\ context\),
                      FontSlant->"Italic"]}], "]"}]}]}], 
            RowBox[{
            "specifies", " ", "that", " ", "genes", " ", "in", " ", "the", 
              " ", 
              StyleBox["present",
                FontSlant->"Italic"], 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["context",
                FontSlant->"Italic"], 
              StyleBox[" ",
                FontSlant->"Italic"], "derive", " ", "from", " ", "those", 
              " ", "in", " ", "the", " ", 
              StyleBox["previous",
                FontSlant->"Italic"], 
              StyleBox[" ",
                FontSlant->"Italic"], 
              RowBox[{
                StyleBox["context",
                  FontSlant->"Italic"], ".", "  ", "The"}], " ", 
              StyleBox["present",
                FontSlant->"Italic"], 
              StyleBox[" ",
                FontSlant->"Italic"], 
              StyleBox["context",
                FontSlant->"Italic"], " ", "can", " ", "include", " ", 
              "pattern", " ", \(\(elements\)\(.\)\)}]},
          {\(\({\[GothicCapitalG], t_, 
                sex_}\)\(\[LeftArrow]\)\({\[GothicCapitalZ], t - 1, 
                
                sex, \[GothicCapitalF]}\)\(\ \)\), \(specifies\ that\ gametes\
\ at\ time\ t\ derive\ from\ the\ maternal\ zygotes\ at\ time\ t - 1\)},
          {
            RowBox[{
              RowBox[{"\[DoubleStruckCapitalU]", "\[CirclePlus]", 
                RowBox[{
                  StyleBox["rule",
                    FontSlant->"Italic"], " ", "or"}]}], "\n", 
              RowBox[{"ChangeContext", "[", 
                RowBox[{"\[DoubleStruckCapitalU]", ",", 
                  StyleBox["rule",
                    FontSlant->"Italic"]}], 
                "]"}]}], \(applies\ the\ transmission\ rule\ to\ the\ set\ of\
\ genes - in - context\ \[DoubleStruckCapitalU]\)}
          },
        ColumnAlignments->{Left},
        GridFrame->False],
      FontFamily->"Times"]], "DefinitionBox",
  CellTags->{"TransmissionRule", "ChangeContext"}],

Cell["\<\
This defines a rule by which the maternal gene in a diploid zygote \
descends from the female gamete, and the paternal gene from the male gamete: \
\
\>", "MathCaption"],

Cell[BoxData[
    \(\(union = {{\[GothicCapitalZ], t_, sex_, 
              soo_} \[LeftArrow] {\[GothicCapitalG], t, soo}};\)\)], "Input",
  CellLabel->"In[6]:="],

Cell["This applies the rule to a set of three genes in the zygote:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({i\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalM]}, 
        j\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalM]}, 
        k\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalF]}}\
\[CirclePlus]union\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \({i\_{\[GothicCapitalG], t, \[GothicCapitalM]}, 
      j\_{\[GothicCapitalG], t, \[GothicCapitalM]}, 
      k\_{\[GothicCapitalG], t, \[GothicCapitalF]}}\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell[BoxData[
    StyleBox[GridBox[{
          {
            RowBox[{"\[DoubleStruckCapitalU]", "\[CirclePlus]", 
              RowBox[{"{", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["rule",
                      FontSlant->"Italic"], "1"], "\[Ellipsis]"}], 
                "}"}]}], \(applies\ a\ list\ of\ transmission\ rules\ to\ the\
\ set\ of\ genes - in - context\ \[DoubleStruckCapitalU]\)},
          {
            RowBox[{
              RowBox[{
                StyleBox["present",
                  FontSlant->"Italic"], \( \[LeftArrow] \+A\), 
                RowBox[{
                  StyleBox["previous",
                    FontSlant->"Italic"], 
                  StyleBox[" ",
                    FontSlant->"Italic"], "or"}]}], " ", "\n", 
              RowBox[{"TransmissionRule", "[", 
                RowBox[{
                  StyleBox["present",
                    FontSlant->"Italic"], ",", " ", 
                  StyleBox["previous",
                    FontSlant->"Italic"], ",", "A"}], 
                "]"}]}], \(applies\ the\ rule\ only\ to\ genes\ in\ the\ set\ \
A\)},
          {
            RowBox[{"{", 
              
              RowBox[{\({\[GothicCapitalG], t_, 
                    sex_}\( \[LeftArrow] \+A\){\[GothicCapitalZ], t - 1, 
                    sex, \[GothicCapitalF]}\), " ", 
                StyleBox[",",
                  
                  FontSlant->"Italic"], \({\[GothicCapitalG], t_, 
                    sex_}\( \[LeftArrow] \+B\){\[GothicCapitalZ], t - 1, 
                    sex, \[GothicCapitalM]}\)}], " ", 
              "}"}], \(specifies\ that\ genes\ in\ the\ set\ A\ derive\ from\ \
maternal\ genes\ in\ the\ zygote, \ 
            and\ those\ in\ B\ derive\ from\ the\ paternal\ genes\)}
          },
        ColumnAlignments->{Left},
        GridFrame->False],
      FontFamily->"Times"]], "DefinitionBox",
  CellTags->"Applying transmission rules"],

Cell["\<\
Transmission rules can be restricted to certain sets of genes.  \
\
\>", "Text"],

Cell["\<\
At meiosis, a set A of genes derive from the maternal genome, and a \
set B from the paternal genome:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(meiosis[A_List, 
          B_List] := {{\[GothicCapitalG], t_, 
              sex_}\( \[LeftArrow] \+A\){\[GothicCapitalZ], t - 1, 
              sex, \[GothicCapitalF]}, {\[GothicCapitalG], t_, 
              sex_}\( \[LeftArrow] \+B\){\[GothicCapitalZ], t - 1, 
              sex, \[GothicCapitalM]}};\)\)], "Input",
  CellLabel->"In[4]:="],

Cell["\<\
This gives the origin of a set of three genes in a gamete, assuming \
that {i,j} came from the maternal genome, and {k} from the paternal:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({i\_{\[GothicCapitalG], t, \[GothicCapitalM]}, 
        j\_{\[GothicCapitalG], t, \[GothicCapitalM]}, 
        k\_{\[GothicCapitalG], t, \[GothicCapitalM]}}\[CirclePlus]meiosis[{i, 
          j}, {k}]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \({i\_{\[GothicCapitalZ], \(-1\) + t, \[GothicCapitalM], \
\[GothicCapitalF]}, 
      j\_{\[GothicCapitalZ], \(-1\) + t, \[GothicCapitalM], \
\[GothicCapitalF]}, 
      k\_{\[GothicCapitalZ], \(-1\) + t, \[GothicCapitalM], \
\[GothicCapitalF]}}\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell["\<\
Note that union of gametes and meiosis are implemented by the \
pre-defined rules UnionOfGametes and Meiosis (see below); these are similar \
to the examples defined above.\
\>", "Text"],

Cell[TextData[{
  "Note:  ",
  StyleBox["UnionOfGametes[], Meiosis[] etc. are ordinary ",
    FontWeight->"Plain"],
  StyleBox["Mathematica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" rules, and can be applied using /.  Internally, they apply the \
transmission rule ",
    FontWeight->"Plain"],
  "{\[GothicCapitalZ],sex_,soo_}\[LeftArrow]{\[GothicCapitalG],soo} ",
  StyleBox["using the special operator \[CirclePlus] or ChangeContext.  Thus, \
\[CirclePlus] appears within the special rules defined for (say) selection on \
diploids.  In general, transmission rules ",
    FontWeight->"Plain"],
  "must",
  StyleBox[" be applied using \[CirclePlus], but may be incorporated within \
ordinary ",
    FontWeight->"Plain"],
  StyleBox["Mathematica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[" rules that can be applied using /.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold",
  CellTags->"Transmission vs Mathematica rules"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "TransmissionRule"->{
    Cell[3773, 98, 2823, 68, 106, "DefinitionBox",
      CellTags->{"TransmissionRule", "ChangeContext"}]},
  "ChangeContext"->{
    Cell[3773, 98, 2823, 68, 106, "DefinitionBox",
      CellTags->{"TransmissionRule", "ChangeContext"}]},
  "Applying transmission rules"->{
    Cell[7575, 198, 1969, 47, 114, "DefinitionBox",
      CellTags->"Applying transmission rules"]},
  "Transmission vs Mathematica rules"->{
    Cell[11112, 297, 980, 26, 56, "Text",
      CellTags->"Transmission vs Mathematica rules"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"TransmissionRule", 12947, 347},
  {"ChangeContext", 13076, 350},
  {"Applying transmission rules", 13219, 353},
  {"Transmission vs Mathematica rules", 13361, 356}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 43, 0, 36, "SubsectionIcon"],
Cell[1785, 53, 748, 15, 52, "Text"],
Cell[2536, 70, 940, 19, 50, "Text"],
Cell[3479, 91, 291, 5, 36, "Text"],
Cell[3773, 98, 2823, 68, 106, "DefinitionBox",
  CellTags->{"TransmissionRule", "ChangeContext"}],
Cell[6599, 168, 179, 4, 28, "MathCaption"],
Cell[6781, 174, 163, 3, 27, "Input"],
Cell[6947, 179, 85, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7057, 184, 290, 5, 28, "Input"],
Cell[7350, 191, 210, 4, 21, "Output"]
}, Open  ]],
Cell[7575, 198, 1969, 47, 114, "DefinitionBox",
  CellTags->"Applying transmission rules"],
Cell[9547, 247, 90, 3, 22, "Text"],
Cell[9640, 252, 132, 3, 28, "MathCaption"],
Cell[9775, 257, 364, 7, 35, "Input"],
Cell[10142, 266, 171, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[10338, 274, 257, 5, 28, "Input"],
Cell[10598, 281, 300, 7, 21, "Output"]
}, Open  ]],
Cell[10913, 291, 196, 4, 22, "Text"],
Cell[11112, 297, 980, 26, 56, "Text",
  CellTags->"Transmission vs Mathematica rules"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

