(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     19926,        412]*)
(*NotebookOutlinePosition[     20954,        446]*)
(*  CellTagsIndexPosition[     20874,        440]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["A complete life cycle", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["rules",
                FontSlant->"Italic"], 
              "=", \((Recombination[]\[Vee]SymmetricRecombination[]\[Vee]\
ReferencePointSame[\[GothicCapitalG], {\[GothicCapitalA], \[GothicCapitalZ]}]\
\[Vee]ReferencePointZero[{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalG]}]\[Vee]Selection[{Sex}]\[Vee]UnionOfGametes[]\[Vee]\
RandomUnion[\[GothicCapitalG]])\)}], \(the\ complete\ set\ of\ rules\ \
required\ to\ relate\ the\ new\ gamete\ pool\ \(\[GothicCapitalG]\^*\) 
              to\ the\ old\ gamete\ pool\ \[GothicCapitalG]\)},
          {
            
            RowBox[{\(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}, k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}}\), "//.",
               
              StyleBox["rules",
                
                FontSlant->
                  "Italic"]}], \(applying\ the\ rules\ repeatedly\ gives\ an\ \
expression\ in\ terms\ of\ the\ linkage\ disequilibria\ in\ the\ initial\ \
gamete\ pool\ \(\[GothicCapitalG]\^*\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"Complete rules"],

Cell["The set of loci that affect fitness must be specified.  ", "Text"],

Cell[TextData[{
  "Here, only locus ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " is selected:"
}], "MathCaption"],

Cell[BoxData[
    \(\(\[DoubleStruckCapitalW]\_sex_ := {i\_{\[GothicCapitalZ], sex, \
\[GothicCapitalM]}, 
          i\_{\[GothicCapitalZ], sex, \[GothicCapitalF]}};\)\)], "Input",
  CellLabel->"In[242]:="],

Cell[TextData[{
  "Different sets ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\((\[DoubleStruckCapitalW]\_\[GothicCapitalM], \ \
\[DoubleStruckCapitalW]\_\[GothicCapitalF]\)\(}\)\)\(\ \)\(are\)\(\ \
\)\(defined\)\(\ \)\)\)]],
  "for the two sexes."
}], "Text"],

Cell[TextData[{
  "Different rules can be joined to give a set of rules that transforms the \
",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicM]\_\[DoubleStruckI]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_\[DoubleStruckCapitalU]\)]],
  " at any stage to expressions involving only genotype frequencies in the \
initial gamete pool, \[GothicCapitalG]:"
}], "Text"],

Cell[BoxData[
    \(\(rules = \
\((Recombination[]\[Vee]SymmetricRecombination[]\[Vee]ReferencePointSame[\
\[GothicCapitalG], {\[GothicCapitalA], \
\[GothicCapitalZ]}]\[Vee]ReferencePointZero[{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalG]}]\[Vee]Selection[{Sex}]\[Vee]UnionOfGametes[]\[Vee]\
RandomUnion[\[GothicCapitalG]])\);\)\)], "Input",
  CellLabel->"In[224]:="],

Cell[TextData[{
  "The rules are joined using \[Vee] (entered as \[AliasIndicator]v\
\[AliasIndicator]).  Recombination is assumed to be symmetric \
(SymmetricRecombination[]); the reference points in zygotes and adults are \
the same as in the initial  gamete pool \
(ReferencePointSame[\[GothicCapitalG],{\[GothicCapitalA],\[GothicCapitalZ]}]);\
 the reference point in the gamete pools is equal to the local mean, so that \
single-locus ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[Ellipsis]}} = 0\)]],
  " (",
  Cell[BoxData[
      \(ReferencePointZero[{\(\[GothicCapitalG]\^*\), \[GothicCapitalG]}]\)],
    FontFamily->"Times"],
  "); selection coefficients depend on sex (Selection[{Sex}]); and there is \
random union of gametes (UnionOfGametes[], RandomUnion[\[GothicCapitalG]])."
}], "Text"],

Cell["\<\
The rules must be applied repeatedly until there is no further \
change (//.). \
\>", "Text"],

Cell[" The within-genome association is:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}, k\
\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}} //. rules // 
      Simplify\)], "Input",
  CellLabel->"In[243]:="],

Cell[BoxData[
    \(1\/2\ \((2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicR]\_\({}, {i, k}\) + 
          2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, k\
\_{\[GothicCapitalG], \[GothicCapitalM]}}\ \[GothicR]\_\({}, {i, k}\) + \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[GothicM]\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalF]}\)\ \[GothicR]\_\({}, {i, k}\) - \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\)\ \[GothicM]\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalF]}\)\ \[GothicR]\_\({}, {i, k}\) - \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[GothicM]\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalM]}\)\ \[GothicR]\_\({}, {i, k}\) + \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\)\ \[GothicM]\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalM]}\)\ \[GothicR]\_\({}, {i, k}\) - \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[GothicM]\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalF]}\)\ \[GothicR]\_\({i}, {k}\) + \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\)\ \[GothicM]\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalF]}\)\ \[GothicR]\_\({i}, {k}\) + \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[GothicM]\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalM]}\)\ \[GothicR]\_\({i}, {k}\) - \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\)\ \[GothicM]\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalM]}\)\ \[GothicR]\_\({i}, {k}\) + 
          2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, k\
\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicR]\_\({}, {i, k}\)\ \[GothicA]\_\(\
\[GothicCapitalF], {i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\) + \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[GothicR]\_\({}, \
{i, k}\)\ \[GothicA]\_\(\[GothicCapitalF], {i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}}\) - \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\)\ \[GothicR]\_\({}, {i, k}\)\ \[GothicA]\_\(\
\[GothicCapitalF], {i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicM]\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[GothicR]\_\({}, \
{i, k}\)\ \[GothicA]\_\(\[GothicCapitalF], {i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}}\) - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicM]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalM]}\)\ \[GothicR]\_\({}, {i, k}\)\ \[GothicA]\_\(\
\[GothicCapitalF], {i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\) - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[GothicR]\_\({i}, \
{k}\)\ \[GothicA]\_\(\[GothicCapitalF], {i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}}\) + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\)\ \[GothicR]\_\({i}, {k}\)\ \[GothicA]\_\(\
\[GothicCapitalF], {i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\) - \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicM]\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[GothicR]\_\({i}, \
{k}\)\ \[GothicA]\_\(\[GothicCapitalF], {i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}}\) + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicM]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalM]}\)\ \[GothicR]\_\({i}, {k}\)\ \[GothicA]\_\(\
\[GothicCapitalF], {i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\) - \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \[GothicR]\_\({}, {i, k}\)\ \
\[GothicA]\_\(\[GothicCapitalF], {i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\)\%2 - \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \[GothicR]\_\({i}, {k}\)\ \
\[GothicA]\_\(\[GothicCapitalF], {i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\)\%2 + 
          2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, k\
\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicR]\_\({}, {i, k}\)\ \[GothicA]\_\(\
\[GothicCapitalF], {i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}}\) - \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[GothicR]\_\({}, \
{i, k}\)\ \[GothicA]\_\(\[GothicCapitalF], {i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}}\) + \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\)\ \[GothicR]\_\({}, {i, k}\)\ \[GothicA]\_\(\
\[GothicCapitalF], {i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}}\) - \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ \
\[GothicM]\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[GothicR]\_\({}, \
{i, k}\)\ \[GothicA]\_\(\[GothicCapitalF], {i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}}\) + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicM]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalM]}\)\ \[GothicR]\_\({}, {i, k}\)\ \[GothicA]\_\(\
\[GothicCapitalF], {i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}}\) + \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[GothicR]\_\({i}, \
{k}\)\ \[GothicA]\_\(\[GothicCapitalF], {i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}}\) - \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\)\ \[GothicR]\_\({i}, {k}\)\ \[GothicA]\_\(\
\[GothicCapitalF], {i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}}\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ \
\[GothicM]\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\)\ \[GothicR]\_\({i}, \
{k}\)\ \[GothicA]\_\(\[GothicCapitalF], {i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}}\) - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicM]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalM]}\)\ \[GothicR]\_\({i}, {k}\)\ \[GothicA]\_\(\
\[GothicCapitalF], {i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}}\) - \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ \
\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \[GothicR]\_\({}, {i, k}\)\ \
\[GothicA]\_\(\[GothicCapitalF], {i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\)\ \[GothicA]\_\(\[GothicCapitalF], \
{i\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}}\) - \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicR]\_\({}, {i, k}\)\ \[GothicA]\_\(\
\[GothicCapitalF], {i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\)\ \[GothicA]\_\(\[GothicCapitalF], \
{i\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}}\) - \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicR]\_\({i}, {k}\)\ \
\[GothicA]\_\(\[GothicCapitalF], {i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\)\ \[GothicA]\_\(\[GothicCapitalF], \
{i\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}}\) - \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicR]\_\({i}, {k}\)\ \
\[GothicA]\_\(\[GothicCapitalF], {i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\)\ \[GothicA]\_\(\[GothicCapitalF], \
{i\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}}\) - \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicR]\_\({}, {i, k}\)\ \[GothicA]\_\(\
\[GothicCapitalF], {i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}}\)\%2 - \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ \
\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ \[GothicR]\_\({i}, {k}\)\ \
\[GothicA]\_\(\[GothicCapitalF], {i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}}\)\%2 + 
          2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, i\
\_{\[GothicCapitalG], \[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicR]\_\({i}, {k}\)\ \
\[GothicA]\_\(\[GothicCapitalF], {i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}}\) + 
          2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, i\
\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicR]\_\({i}, {k}\)\ \
\[GothicA]\_\(\[GothicCapitalF], {i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}}\))\)\)], "Output",
  CellLabel->"Out[243]="]
}, Closed]],

Cell["With no selection, the expression is still non-trivial:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}, \
k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}} //. 
          rules\) /. \[GothicA]\___ \[Rule] 0 // Simplify\)], "Input",
  CellLabel->"In[225]:="],

Cell[BoxData[
    \(1\/2\ \((2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicR]\_\({}, {i, k}\) + 
          2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, k\
\_{\[GothicCapitalG], \[GothicCapitalM]}}\ \[GothicR]\_\({}, {i, k}\) + \((\
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\) - \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \((\[GothicM]\_\
\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\) - \[GothicM]\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \((\[GothicR]\_\({}, {i, k}\) - \
\[GothicR]\_\({i}, {k}\))\))\)\)], "Output",
  CellLabel->"Out[171]="]
}, Closed]],

Cell["\<\
Disequilibria are generated by differences in mean between the \
sexes (last term).\
\>", "Text"],

Cell["The cross-genome association in adult females is simple:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}} //. rules // Simplify\)], "Input",
  CellLabel->"In[245]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ \[GothicCapitalD]\_{k\_{\
\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicA]\_\(\[GothicCapitalF], {i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}}\)\)], "Output",
  CellLabel->"Out[245]="]
}, Open  ]],

Cell["This is the change in mean:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\) //. 
        rules // Simplify\)], "Input",
  CellLabel->"In[231]:="],

Cell[BoxData[
    \(1\/2\ \((\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\) + \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\) + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \[GothicA]\_\(\[GothicCapitalF], {i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}}\) + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\ \[GothicA]\_\(\[GothicCapitalF], {i\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}}\))\)\)], "Output",
  CellLabel->"Out[231]="]
}, Open  ]],

Cell[TextData[{
  "Note: ",
  StyleBox["If a list of rules of this sort is not applied as expected, see ",
    
    FontWeight->"Plain"],
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Applying rules"},
    ButtonStyle->"AddOnsLink"],
  StyleBox[".",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{944, 645},
WindowMargins->{{14, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Complete rules"->{
    Cell[1789, 53, 1192, 25, 98, "DefinitionBox",
      CellTags->"Complete rules"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Complete rules", 20763, 433}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 47, 0, 36, "SubsectionIcon"],
Cell[1789, 53, 1192, 25, 98, "DefinitionBox",
  CellTags->"Complete rules"],
Cell[2984, 80, 72, 0, 22, "Text"],
Cell[3059, 82, 123, 5, 28, "MathCaption"],
Cell[3185, 89, 206, 4, 28, "Input"],
Cell[3394, 95, 264, 7, 22, "Text"],
Cell[3661, 104, 401, 10, 22, "Text"],
Cell[4065, 116, 367, 7, 42, "Input"],
Cell[4435, 125, 846, 17, 55, "Text"],
Cell[5284, 144, 103, 3, 22, "Text"],
Cell[5390, 149, 57, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5472, 153, 209, 4, 34, "Input"],
Cell[5684, 159, 11084, 166, 262, "Output"]
}, Closed]],
Cell[16783, 328, 78, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[16886, 332, 245, 4, 34, "Input"],
Cell[17134, 338, 686, 11, 36, "Output"]
}, Closed]],
Cell[17835, 352, 107, 3, 18, "Text"],
Cell[17945, 357, 79, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[18049, 361, 228, 4, 33, "Input"],
Cell[18280, 367, 443, 7, 26, "Output"]
}, Open  ]],
Cell[18738, 377, 50, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[18813, 381, 154, 3, 32, "Input"],
Cell[18970, 386, 617, 9, 36, "Output"]
}, Open  ]],
Cell[19602, 398, 308, 11, 24, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

