(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     28299,        697]*)
(*NotebookOutlinePosition[    101069,       3295]*)
(*  CellTagsIndexPosition[    100728,       3282]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Cytoplasmic inheritance", "SubsectionIcon"],

Cell[TextData[{
  "The rules defined for Mendelian inheritance extend almost unchanged to \
other kinds of inheritance. The only differences are that i) ",
  ButtonBox["reference points",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"reference points"],
  " may need to be set differently for loci that are inherited in different \
ways, and ii) recombination rates may be ",
  ButtonBox["asymmetric",
    ButtonData:>{"Non-Mendelian inheritance", "NonMendelian"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"asymmetric"],
  ".  For example, for a cytoplasmically-inherited locus, i, ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicR]\_\({i}, {}\)\)]],
  "=1 and ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicR]\_\({}, {i}\) = 0\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell["Setting up\[Ellipsis]", "SubsubsectionIcon",
  CellTags->"Setting up"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Multilocus`Multilocus`;\)\)], "Input",
  CellLabel->"In[1]:="],

Cell["The simplest life cycle is defined using:", "MathCaption"],

Cell[BoxData[{
    \(\(DefineContext[\[GothicCapitalG], {\ Sex}];\)\), "\n", 
    \(\(DefineContext[\[GothicCapitalZ], {Sex, SexOfOrigin}];\)\), "\n", 
    \(\(DefineContext[\[GothicCapitalA], {Sex, SexOfOrigin}];\)\), "\n", 
    \(\(DefineContext[\(\[GothicCapitalG]\^*\), {\ Sex}];\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
Assume no selection by specifying that no genes affect \
fitness:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(\[DoubleStruckCapitalW] = {};\)\)], "Input",
  CellLabel->"In[6]:="],

Cell[TextData[{
  "One could just drop the stage \[GothicCapitalA], and go directly from \
\[GothicCapitalZ] to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[GothicCapitalG]\^*\) . \ \ However, \ 
      the\ default\ rules\ assume\ that\ there\ is\ selection, \ \(\(and\)\(\ \
\)\(so\)\(\ \)\(it\)\(\ \)\(is\)\(\ \)\(easier\)\(\ \)\(just\)\(\ \)\(to\)\(\ \
\)\)\)]],
  "keep the extra stage."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simplifying recombination", "SubsubsectionIcon",
  CellTags->"Simplifying recombination"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(NonMendelian[
              CytoplasmicLoci -> {i}]\), \(is\ a\ rule\ which\ simplifies\ \
recombination\ rates\ \[GothicR]\_\(A, B\)\ on\ the\ assumption\ that\ locus\ \
i\ is\ cytoplasmically\ inherited\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{
  "NonMendelian", "PaternalLoci", "MaternalLoci", "CytoplasmicLoci"}],

Cell[TextData[{
  "In general, the association between loci i and j in the new gamete pool, \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\[GothicCapitalG]\^*\), \ is\)]],
  " written as a sum over all possible recombination events:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}, j\
\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}} /. 
      Recombination[]\)], "Input",
  CellLabel->"In[12]:=  (6:30:53 on 3/7/01)"],

Cell[BoxData[
    \(\[GothicR]\_\({i, j}, {}\)\ \
\((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\({j}, {i}\)\ \
\((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\)\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\({i}, {j}\)\ \
\((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\))\) + \[GothicR]\_\({}, {i, j}\)\ \((\[GothicCapitalD]\
\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}, j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\))\)\)], "Output",
  CellLabel->"Out[12]=  (6:30:53 on 3/7/01)"]
}, Closed]],

Cell[TextData[{
  "If locus i is cytoplasmically inherited, then it cannot be inherited from \
the father; ",
  Cell[BoxData[
      \(\[GothicR]\_\({j}, {i}\)\)]],
  "=",
  Cell[BoxData[
      \(\[GothicR]\_\({}, {i, j}\)\)]],
  "=0:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}, \
j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}} /. Recombination[]\) /. 
      NonMendelian[CytoplasmicLoci -> {i}]\)], "Input",
  CellLabel->"In[13]:=  (6:30:57 on 3/7/01)"],

Cell[BoxData[
    \(\[GothicR]\_\({j}, {}\)\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}, j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\({}, {j}\)\ \
\((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\))\)\)], "Output",
  CellLabel->"Out[13]=  (6:30:57 on 3/7/01)"]
}, Closed]],

Cell[TextData[{
  "This further simplifies if the autosomal locus j is inherited in a \
Mendelian way; ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicR]\_\({j}, {}\) = \(\[GothicR]\_\({}, {j}\) \
= \(\(1\/2\)\(:\)\)\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}, j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}} /. 
            Recombination[]\) /. NonMendelian[CytoplasmicLoci -> {i}]\) /. 
        SymmetricRecombination[] // Simplify\)], "Input",
  CellLabel->"In[14]:=  (6:31:00 on 3/7/01)"],

Cell[BoxData[
    \(1\/2\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}, j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \((\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\) - \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\)\ \((\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\) - \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\) + \((\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\) - \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}\))\)\ \((\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\) - \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}\))\))\)\)], "Output",
  CellLabel->"Out[14]=  (6:31:01 on 3/7/01)"]
}, Open  ]],

Cell[TextData[{
  "Note: ",
  StyleBox["SymmetricRecombination[] ",
    FontWeight->"Plain"],
  "must",
  StyleBox[" be applied ",
    FontWeight->"Plain"],
  "after",
  StyleBox[" NonMendelian[\[Ellipsis]]",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The complete life cycle", "SubsubsectionIcon",
  CellTags->"Complete life cycle"],

Cell[TextData[{
  "This expression still involves the (arbitrary) changes in reference points \
between stages.  As above, we can assume that the reference points in the \
gamete pools equal the local means (",
  Cell[BoxData[
      \(ReferencePointZero[{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalG]}]\)]],
  "); that the reference points in the diploid stages are inherited from the \
initial gamete pool (ReferencePointSame[\[GothicCapitalG],{\[GothicCapitalA],\
\[GothicCapitalZ]}]); and that gametes unite at random \
(UnionOfGametes[]\[Vee]RandomUnion[\[GothicCapitalG]])."
}], "Text"],

Cell["\<\
This is the set of rules that describes the complete life \
cycle:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(rules = \((Recombination[]\[Vee]NonMendelian[
              CytoplasmicLoci -> \
{i}]\[Vee]SymmetricRecombination[]\[Vee]Selection[]\[Vee]UnionOfGametes[]\
\[Vee]RandomUnion[\[GothicCapitalG]]\[Vee]ReferencePointSame[\[GothicCapitalG]\
, {\[GothicCapitalA], \[GothicCapitalZ]}]\[Vee]ReferencePointZero[{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalG]}])\);\)\)], "Input",
  CellLabel->"In[83]:=  (8:27:16 on 3/11/01)"],

Cell[TextData[{
  "Note: ",
  StyleBox["NonMendelian[] ",
    FontWeight->"Plain"],
  "must",
  StyleBox[" be applied before SymmetricRecombination[], and UnionOfGametes[] \
before RandomUnion[\[GothicCapitalG]]",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "The cytonuclear association in female gametes decreases by ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\ in\ each\ \(\(generation\)\(:\)\)\)]],
  " "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}, j\
\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}} //. rules\)], "Input",
  CellLabel->"In[84]:=  (8:27:21 on 3/11/01)"],

Cell[BoxData[
    \(1\/2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, \
j\_{\[GothicCapitalG], \[GothicCapitalF]}}\)], "Output",
  CellLabel->"Out[84]=  (8:27:21 on 3/11/01)"]
}, Open  ]],

Cell[TextData[{
  "In contrast, the association between two autosomal loci in female gametes \
is the average association across both sexes, deflated by ",
  Cell[BoxData[
      \(\((1 - r\_\(j, k\))\)\)]],
  ", plus a contribution from differences in mean between the sexes:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[GothicCapitalD]\_{j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}, \
k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}} //. 
          rules\) /. {\[GothicR]\_\({}, {j, k}\) -> \(1 - r\_\(j, k\)\)\/2, \
\[GothicR]\_\({j}, {k}\) -> r\_\(j, k\)\/2} // Simplify\)], "Input",
  CellLabel->"In[87]:=  (8:29:18 on 3/11/01)"],

Cell[BoxData[
    \(\((1 - 
            r\_\(j, k\))\)\ \ \(\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}}\  + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, k\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\)\/2 + \(1\/4\) \((\[GothicM]\_\(j\_{\
\[GothicCapitalG], \[GothicCapitalF]}\) - \
\[GothicM]\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \((\[GothicM]\_\
\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\) - \[GothicM]\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \((1 - 
            2\ r\_\(j, k\))\)\)], "Output",
  CellLabel->"Out[10]=  (6:25:41 on 3/7/01)"]
}, Open  ]],

Cell[TextData[{
  ButtonBox["Recall",
    ButtonData:>{"Recombination", "Factors of two"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Recall"],
  " that ",
  Cell[BoxData[
      \(\[GothicR]\_\({}, {j, k}\)\)]],
  "is the probability that both j and k come from the father, which has \
probability ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(1 - 
              r\_\(j, k\)\)\/2\) \((r\_\(j, k\)\ being\ the\ usual\ \
recombination\ rate)\) . \ \ Remember\ to\ include\ the\ factor\ of\ \(\(1\/2\
\)\(.\)\)\)]]
}], "Text"],

Cell["\<\
This is the three-way association between two autosomal loci and a \
cytoplasmic locus:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ff = \(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, k\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}} //. 
            rules\) /. {\[GothicR]\_\({}, {j, k}\) -> \(1 - r\_\(j, k\)\)\/2, \
\[GothicR]\_\({j}, {k}\) -> r\_\(j, k\)\/2} // Simplify\)], "Input",
  CellLabel->"In[90]:=  (8:31:31 on 3/11/01)"],

Cell[BoxData[
    \(\(1\/2\) \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, \
j\_{\[GothicCapitalG], \[GothicCapitalF]}, k\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \((1 - r\_\(j, k\))\) + 
      1\/4\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, \
k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \((\[GothicM]\_\(j\_{\
\[GothicCapitalG], \[GothicCapitalF]}\) - \
\[GothicM]\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \
\((\[GothicM]\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\) - \
\[GothicM]\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\))\))\)\ \((1 - 
            2\ r\_\(j, k\))\)\)], "Output",
  CellLabel->"Out[161]=  (19:23:32 on 3/6/01)"]
}, Open  ]],

Cell["\<\
Again, this depends on the initial difference in mean between the \
sexes.\
\>", "Text"],

Cell["\<\
With random mating, there is no association in a diploid between \
two homologous autosomal loci, and a cytoplasmic locus:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}} //. rules\)], "Input",
  CellLabel->"In[93]:=  (8:33:08 on 3/11/01)"],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[93]=  (8:33:08 on 3/11/01)"]
}, Open  ]],

Cell["\<\
After one generation, the mean contributions in the two sexes are \
the same.  Therefore, the contributions from differences in mean between the \
sexes seen above can only contribute if there is selection, migration, or \
some other process that generates them.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(\[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\), \(\[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\)},
                {\(\[GothicM]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\), \(\[GothicM]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\)}
                }], ")"}], "//.", "rules"}], "//", "Simplify"}], "//", 
      "MatrixForm"}]], "Input",
  CellLabel->"In[94]:=  (8:33:22 on 3/11/01)"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\), \
\(\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\)},
            {\(1\/2\ \((\[GothicM]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \[GothicM]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\), \(1\/2\ \((\[GothicM]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \[GothicM]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[94]//MatrixForm=  (8:33:22 on 3/11/01)"]
}, Open  ]],

Cell["\<\
Paternal inheritance is dealt with in the same way, using \
PaternalLoci->{i, j\[Ellipsis]}\
\>", "Text"],

Cell[TextData[{
  "Note: ",
  StyleBox["MaternalLoci is a synonym for CytoplasmicLoci",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reference points at the mean of the two sexes", "SubsubsectionIcon",
  CellTags->"ReferencePointMean"],

Cell[TextData[{
  "Associations among autosomal loci could be defined with respect to \
reference points at the mean of the two sexes of gamete, and at the mean of \
the two sexes-of-origin.  (Note that reference points could still differ \
between the two diploid sexes).  It is then natural to define the reference \
point for cytoplasmically inherited loci equal to the mean in females.  This \
can be done by specifying the set of CytoplasmicLoci in ",
  " ",
  ButtonBox["ReferencePointMean[]",
    ButtonData:>{"Reference points", "CytoplasmicLoci"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"reference points"],
  "."
}], "Text"],

Cell["\<\
This is the set of rules that describes the complete life \
cycle:\
\>", "MathCaption"],

Cell[BoxData[
    \(rules = \((Recombination[]\[Vee]NonMendelian[
            CytoplasmicLoci -> \
{i}]\[Vee]SymmetricRecombination[]\[Vee]Selection[]\[Vee]UnionOfGametes[]\
\[Vee]RandomUnion[\[GothicCapitalG]]\[Vee]ReferencePointMean[{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalA], \[GothicCapitalZ], \
\[GothicCapitalG]}, CytoplasmicLoci -> {i}])\); \)], "Input",
  CellLabel->"In[98]:=  (8:35:33 on 3/11/01)"],

Cell[TextData[{
  "The cytonuclear association in female gametes again decreases by ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\ in\ each\ \(\(generation\)\(:\)\)\)]],
  " "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}, j\
\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}} //. rules\)], "Input",
  CellLabel->"In[113]:=  (8:45:25 on 3/11/01)"],

Cell[BoxData[
    \(1\/2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, \
j\_{\[GothicCapitalG], \[GothicCapitalF]}}\)], "Output",
  CellLabel->"Out[113]=  (8:45:25 on 3/11/01)"]
}, Open  ]],

Cell["\<\
This is unaffected, because the reference point for the cytoplasmic \
loci is still defined with respect to the female gametes only.\
\>", "Text"],

Cell["\<\
In contrast, the association between two autosomal loci in female \
gametes contains a different contribution from the difference between the \
sexes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[GothicCapitalD]\_{j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}, \
k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}} //. 
          rules\) /. {\[GothicR]\_\({}, {j, k}\) -> \(1 - r\_\(j, k\)\)\/2, \
\[GothicR]\_\({j}, {k}\) -> r\_\(j, k\)\/2} // Simplify\)], "Input",
  CellLabel->"In[112]:=  (8:44:48 on 3/11/01)"],

Cell[BoxData[
    \(\((1 - 
            r\_\(j, k\))\)\ \(\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, k\_{\[GothicCapitalG], \[GothicCapitalF]}} + \
\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \[GothicCapitalM]}, k\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\)\/2 - \(1\/4\) \((\[GothicM]\_\(j\_{\
\[GothicCapitalG], \[GothicCapitalF]}\) - \
\[GothicM]\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \((\[GothicM]\_\
\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\) - \[GothicM]\_\(k\_{\
\[GothicCapitalG], \[GothicCapitalM]}\))\)\ r\_\(j, k\)\)], "Output",
  CellLabel->"Out[112]=  (8:44:50 on 3/11/01)"]
}, Open  ]],

Cell["\<\
With respect to the new reference point, there is now an \
association between two homologous autosomal loci, and a cytoplasmic locus:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}} //. rules // Simplify\)], "Input",
  CellLabel->"In[115]:=  (8:48:13 on 3/11/01)"],

Cell[BoxData[
    \(\(-\(1\/2\)\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \((\[GothicM]\
\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) - \[GothicM]\_\(j\_{\
\[GothicCapitalG], \[GothicCapitalM]}\))\)\)], "Output",
  CellLabel->"Out[115]=  (8:48:13 on 3/11/01)"]
}, Open  ]],

Cell["\<\
The means necessarily change in the same way, since they are not \
affected by reference points:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(\[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\), \(\[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\)},
                {\(\[GothicM]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\), \(\[GothicM]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\)}
                }], ")"}], "//.", "rules"}], "//", "Simplify"}], "//", 
      "MatrixForm"}]], "Input",
  CellLabel->"In[116]:=  (8:49:17 on 3/11/01)"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\), \
\(\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\)},
            {\(1\/2\ \((\[GothicM]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \[GothicM]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\), \(1\/2\ \((\[GothicM]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \[GothicM]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[116]//MatrixForm=  (8:49:17 on 3/11/01)"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{884, 665},
WindowMargins->{{Automatic, 122}, {Automatic, 12}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\[Placeholder]", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->Utilities`Notation`Private`DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\nThe item above is horizontal 0.5 pt line", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\nThe item above is a ProgramTop line\n", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\nThe item above is a ProgramBottom line\n", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Setting up"->{
    Cell[2642, 77, 76, 1, 24, "SubsubsectionIcon",
      CellTags->"Setting up"]},
  "Simplifying recombination"->{
    Cell[3888, 118, 95, 1, 24, "SubsubsectionIcon",
      CellTags->"Simplifying recombination"]},
  "NonMendelian"->{
    Cell[3986, 121, 406, 8, 54, "DefinitionBox",
      CellTags->{
      "NonMendelian", "PaternalLoci", "MaternalLoci", "CytoplasmicLoci"}]},
  "PaternalLoci"->{
    Cell[3986, 121, 406, 8, 54, "DefinitionBox",
      CellTags->{
      "NonMendelian", "PaternalLoci", "MaternalLoci", "CytoplasmicLoci"}]},
  "MaternalLoci"->{
    Cell[3986, 121, 406, 8, 54, "DefinitionBox",
      CellTags->{
      "NonMendelian", "PaternalLoci", "MaternalLoci", "CytoplasmicLoci"}]},
  "CytoplasmicLoci"->{
    Cell[3986, 121, 406, 8, 54, "DefinitionBox",
      CellTags->{
      "NonMendelian", "PaternalLoci", "MaternalLoci", "CytoplasmicLoci"}]},
  "Complete life cycle"->{
    Cell[14890, 332, 87, 1, 24, "SubsubsectionIcon",
      CellTags->"Complete life cycle"]},
  "ReferencePointMean"->{
    Cell[22777, 550, 108, 1, 24, "SubsubsectionIcon",
      CellTags->"ReferencePointMean"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Setting up", 99592, 3250},
  {"Simplifying recombination", 99708, 3253},
  {"NonMendelian", 99827, 3256},
  {"PaternalLoci", 99990, 3260},
  {"MaternalLoci", 100153, 3264},
  {"CytoplasmicLoci", 100319, 3268},
  {"Complete life cycle", 100489, 3272},
  {"ReferencePointMean", 100609, 3275}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 49, 0, 36, "SubsectionIcon"],
Cell[1791, 53, 826, 20, 38, "Text"],

Cell[CellGroupData[{
Cell[2642, 77, 76, 1, 24, "SubsubsectionIcon",
  CellTags->"Setting up"],
Cell[2721, 80, 46, 0, 28, "MathCaption"],
Cell[2770, 82, 87, 2, 26, "Input"],
Cell[2860, 86, 64, 0, 28, "MathCaption"],
Cell[2927, 88, 323, 5, 74, "Input"],
Cell[3253, 95, 96, 3, 28, "MathCaption"],
Cell[3352, 100, 90, 2, 26, "Input"],
Cell[3445, 104, 406, 9, 22, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3888, 118, 95, 1, 24, "SubsubsectionIcon",
  CellTags->"Simplifying recombination"],
Cell[3986, 121, 406, 8, 54, "DefinitionBox",
  CellTags->{
  "NonMendelian", "PaternalLoci", "MaternalLoci", "CytoplasmicLoci"}],
Cell[4395, 131, 254, 6, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4674, 141, 226, 4, 45, "Input"],
Cell[4903, 147, 4245, 62, 183, "Output"]
}, Closed]],
Cell[9163, 212, 253, 9, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[9441, 225, 270, 4, 45, "Input"],
Cell[9714, 231, 2157, 32, 111, "Output"]
}, Closed]],
Cell[11886, 266, 245, 6, 24, "MathCaption"],

Cell[CellGroupData[{
Cell[12156, 276, 329, 5, 61, "Input"],
Cell[12488, 283, 2083, 30, 97, "Output"]
}, Open  ]],
Cell[14586, 316, 267, 11, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14890, 332, 87, 1, 24, "SubsubsectionIcon",
  CellTags->"Complete life cycle"],
Cell[14980, 335, 591, 11, 50, "Text"],
Cell[15574, 348, 97, 3, 28, "MathCaption"],
Cell[15674, 353, 438, 7, 54, "Input"],
Cell[16115, 362, 272, 9, 24, "Text"],
Cell[16390, 373, 191, 5, 34, "MathCaption"],

Cell[CellGroupData[{
Cell[16606, 382, 211, 3, 45, "Input"],
Cell[16820, 387, 194, 3, 48, "Output"]
}, Open  ]],
Cell[17029, 393, 295, 6, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[17349, 403, 342, 5, 54, "Input"],
Cell[17694, 410, 653, 11, 54, "Output"]
}, Open  ]],
Cell[18362, 424, 530, 15, 54, "Text"],
Cell[18895, 441, 118, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[19038, 448, 401, 6, 54, "Input"],
Cell[19442, 456, 804, 13, 48, "Output"]
}, Open  ]],
Cell[20261, 472, 98, 3, 22, "Text"],
Cell[20362, 477, 153, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[20540, 484, 301, 5, 42, "Input"],
Cell[20844, 491, 82, 2, 32, "Output"]
}, Open  ]],
Cell[20941, 496, 293, 5, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[21259, 505, 565, 13, 64, "Input"],
Cell[21827, 520, 634, 12, 61, "Output"]
}, Open  ]],
Cell[22476, 535, 115, 3, 22, "Text"],
Cell[22594, 540, 146, 5, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22777, 550, 108, 1, 24, "SubsubsectionIcon",
  CellTags->"ReferencePointMean"],
Cell[22888, 553, 642, 13, 51, "Text"],
Cell[23533, 568, 97, 3, 28, "MathCaption"],
Cell[23633, 573, 412, 7, 54, "Input"],
Cell[24048, 582, 197, 5, 34, "MathCaption"],

Cell[CellGroupData[{
Cell[24270, 591, 212, 3, 45, "Input"],
Cell[24485, 596, 195, 3, 48, "Output"]
}, Open  ]],
Cell[24695, 602, 156, 3, 22, "Text"],
Cell[24854, 607, 181, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[25060, 615, 343, 5, 54, "Input"],
Cell[25406, 622, 625, 10, 54, "Output"]
}, Open  ]],
Cell[26046, 635, 167, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[26238, 643, 314, 5, 42, "Input"],
Cell[26555, 650, 333, 5, 48, "Output"]
}, Open  ]],
Cell[26903, 658, 127, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[27055, 665, 566, 13, 64, "Input"],
Cell[27624, 680, 635, 12, 61, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

