(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     16421,        372]*)
(*NotebookOutlinePosition[     17582,        410]*)
(*  CellTagsIndexPosition[     17472,        403]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Disequilibrium", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            FormBox[
              
              RowBox[{\(\[GothicCapitalD]\_\[DoubleStruckCapitalU]\), 
                "\[CirclePlus]", 
                StyleBox["rule",
                  FontSlant->"Italic"]}],
              "TraditionalForm"], 
            RowBox[{
            "gives", " ", "the", " ", "value", " ", "of", 
              " ", \(\[GothicCapitalD]\_\[DoubleStruckCapitalU]\), " ", 
              "after", " ", "transmission", " ", "according", " ", "to", " ", 
              "a", " ", "particular", " ", 
              RowBox[{
                StyleBox["rule",
                  "SmallText",
                  FontSlant->"Italic"], ".", "  ", "Allows"}], " ", "for", 
              " ", "the", " ", "change", " ", "in", " ", "reference", " ", 
              "point", " ", "associated", " ", "with", " ", "the", " ", 
              "change", " ", "in", " ", "context"}]},
          {
            RowBox[{\(\[Sum]\+\(r \[Element] R\)\), 
              RowBox[{\(t\_R\), 
                RowBox[{"(", 
                  
                  RowBox[{\(\[GothicCapitalD]\_\[DoubleStruckCapitalU]\), 
                    "\[CirclePlus]", 
                    StyleBox["r",
                      FontSlant->"Italic"]}], 
                  StyleBox[")",
                    
                    FontSlant->
                      "Italic"]}]}]}], \(gives\ the\ value\ of\ \
\[GothicCapitalD]\_\[DoubleStruckCapitalU]\ after\ transmission, \ 
            as\ a\ sum\ over\ the\ set\ of\ transmission\ rules, \ 
            R . \ t\_r  
                is\ the\ probability\ of\ rule\ r \[Element] \
\(\(R\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"Disequilibrium"],

Cell[TextData[{
  "Linkage disequilibria ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_\(\(\[DoubleStruckCapitalU]\)\(\ \
\)\)\)]],
  "are defined relative to reference points ",
  Cell[BoxData[
      \(TraditionalForm\`\[WeierstrassP]\_\[DoubleStruckI]\)]],
  ", which may differ between contexts.  Therefore, changes in context will \
involve changes in reference point, which in turn change the linkage \
disequilibria."
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`Meiosis[A, B]\)]],
  " is a rule which describes a particular meiotic segregation, in which a \
set A of genes derive from the maternal genome, and a set B from the paternal \
genome (see below)."
}], "Text"],

Cell[TextData[{
  "This is the effect of the rule on a set of genes-in-context; genes in the \
new gamete pool ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[GothicCapitalG]\^*\)\(\ \)\(derive\)\(\ \
\)\(from\)\(\ \)\)\)]],
  "genes in the adult diploid \[GothicCapitalA]:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, 
        j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, 
        k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}}\[CirclePlus]Meiosis[{i, j}, {k}]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \({i\_{\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}, 
      j\_{\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}, 
      k\_{\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}}\)], \
"Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[TextData[{
  "(For this to work, the stages ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[GothicCapitalG]\^*\)\)]],
  " and \[GothicCapitalA] must have been defined; ",
  ButtonBox["see above",
    ButtonData:>{"Stages in the life cycle", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"see above"],
  ").  "
}], "Text"],

Cell["This is the corresponding change in linkage disequilibrium:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, j\
\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}}\[CirclePlus]Meiosis[{i, 
          j}, {k}]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\)\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell["\<\
There are extra terms involving changes in reference point between \
the contexts.  In general:\
\>", "Text"],

Cell[BoxData[
    \(\[GothicCapitalD]\_\[DoubleStruckCapitalA]\[CirclePlus]{\
\[DoubleStruckCapitalA] \[LeftArrow] \[DoubleStruckCapitalB]} = \[Sum]\+\(\
\[DoubleStruckCapitalC] \[Subset] \
\[DoubleStruckCapitalB]\)\(\[GothicCapitalD]\_\(\[DoubleStruckCapitalB]\
\[Backslash]\[DoubleStruckCapitalC]\)\) \(\[Product]\+\(\[DoubleStruckJ] \
\[Element] \[DoubleStruckCapitalC]\)\((\[WeierstrassP]\_\[DoubleStruckJ] - \
\[WeierstrassP]\_\[DoubleStruckI])\)\)\)], "NumberedEquation"],

Cell["\<\
where \[DoubleStruckI]\[Element]\[DoubleStruckCapitalA] is the \
present gene-in-context corresponding to the previous \[DoubleStruckJ]\
\[Element]\[DoubleStruckCapitalB].  \
\>", "Text"],

Cell["\<\
The net change in disequilibrium is a sum over all possible modes \
of transmission.  \
\>", "Text"],

Cell["For example, after meiosis we have:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(A \[Element] Subsets[{i, \
j}]\)\((\((\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}}\
\[CirclePlus]Meiosis[A, {i, j}\[Backslash]A])\) 
          r\_\(A, {i, j}\[Backslash]A\))\)\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(\((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\))\)\ r\_\({}, {i, j}\) + \((\[GothicCapitalD]\_{i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\))\)\ r\_\({i}, {j}\) + \((\[GothicCapitalD]\_{i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\))\)\ r\_\({j}, {i}\) + \((\[GothicCapitalD]\_{i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\))\)\ r\_\({i, j}, {}\)\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell["\<\
This simplifies if we assume no meiotic drive, and write the \
difference in reference point between contexts as \[CapitalDelta]:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(% /. {r\_\({}, {i, j}\) \[Rule] \(1 - \[Rho]\)\/2, 
            r\_\({i, j}, {}\) \[Rule] \(1 - \[Rho]\)\/2, 
            r\_\({i}, {j}\) \[Rule] \[Rho]\/2, 
            r\_\({j}, {i}\) \[Rule] \[Rho]\/2}\) /. {\[WeierstrassP]\_\(i_\_{\
\[GothicCapitalA], s_, so_}\) \[RuleDelayed] \[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), s}\) - \[CapitalDelta]\_\(i\_{s, so}\)} // 
      Simplify\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(1\/2\ \((\((1 - \[Rho])\)\ \
\((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}}\ \[CapitalDelta]\_\(i\_{\
\[GothicCapitalM], \[GothicCapitalF]}\) + \((\(-\[GothicCapitalD]\_{i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}}\) + \[CapitalDelta]\
\_\(i\_{\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \[CapitalDelta]\_\(j\_{\
\[GothicCapitalF], \[GothicCapitalF]}\))\) + \[Rho]\ \((\[GothicCapitalD]\_{i\
\_{\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}}\ \
\[CapitalDelta]\_\(i\_{\[GothicCapitalM], \[GothicCapitalM]}\) + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \[CapitalDelta]\_\(i\_{\[GothicCapitalM], \
\[GothicCapitalM]}\))\)\ \[CapitalDelta]\_\(j\_{\[GothicCapitalF], \
\[GothicCapitalF]}\))\) + \[Rho]\ \
\((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}}\ \[CapitalDelta]\_\(i\_{\
\[GothicCapitalM], \[GothicCapitalF]}\) + \((\(-\[GothicCapitalD]\_{i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}}\) + \[CapitalDelta]\
\_\(i\_{\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \[CapitalDelta]\_\(j\_{\
\[GothicCapitalF], \[GothicCapitalM]}\))\) + \((1 - \[Rho])\)\ \((\
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}}\ \[CapitalDelta]\_\(i\_{\
\[GothicCapitalM], \[GothicCapitalM]}\) + \((\(-\[GothicCapitalD]\_{i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}}\) + \[CapitalDelta]\
\_\(i\_{\[GothicCapitalM], \[GothicCapitalM]}\))\)\ \[CapitalDelta]\_\(j\_{\
\[GothicCapitalF], \[GothicCapitalM]}\))\))\)\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell["These sums are implemented by Recombination[].", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{GridBox[{
            {\(Symmetrise[
                Disequilibrium]\), \(is\ a\ rule\ which\ converts\ the\ \
arguments\ of\ \ \[GothicCapitalD]\_\[DoubleStruckCapitalU]\ into\ the\ \
standard\ \(\(order\)\(.\)\)\)}
            }], " "}], TraditionalForm]]]], "DefinitionBox",
  CellTags->"Symmetrise"],

Cell["\<\
Linkage disequilibria are independent of the order of their \
arguments.  However, that is not imposed as an attribute of \[GothicCapitalD] \
(doing so would lead to obscure problems in pattern matching).  Thus, if an \
expression contains equivalent forms, the rule Symmetrise[Disequilibrium] \
must be invoked:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{\[DoubleStruckK], \[DoubleStruckJ], \
\[DoubleStruckI]} /. Symmetrise[Disequilibrium]\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{\[DoubleStruckI], \[DoubleStruckJ], \
\[DoubleStruckK]}\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{245, Automatic}, {Automatic, 46}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Disequilibrium"->{
    Cell[1760, 51, 1770, 41, 118, "DefinitionBox",
      CellTags->"Disequilibrium"]},
  "Symmetrise"->{
    Cell[15383, 341, 358, 8, 70, "DefinitionBox",
      CellTags->"Symmetrise"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Disequilibrium", 17260, 393},
  {"Symmetrise", 17365, 396}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 40, 0, 36, "SubsectionIcon"],
Cell[1760, 51, 1770, 41, 118, "DefinitionBox",
  CellTags->"Disequilibrium"],
Cell[3533, 94, 452, 11, 50, "Text"],
Cell[3988, 107, 265, 6, 36, "Text"],
Cell[4256, 115, 295, 7, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[4576, 126, 260, 5, 28, "Input"],
Cell[4839, 133, 260, 5, 22, "Output"]
}, Open  ]],
Cell[5114, 141, 334, 10, 23, "Text"],
Cell[5451, 153, 84, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5560, 158, 222, 4, 33, "Input"],
Cell[5785, 164, 1062, 16, 75, "Output"]
}, Open  ]],
Cell[6862, 183, 119, 3, 22, "Text"],
Cell[6984, 188, 477, 7, 54, "NumberedEquation"],
Cell[7464, 197, 197, 4, 22, "Text"],
Cell[7664, 203, 110, 3, 22, "Text"],
Cell[7777, 208, 58, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7860, 212, 319, 6, 72, "Input"],
Cell[8182, 220, 4185, 61, 70, "Output"]
}, Open  ]],
Cell[12382, 284, 162, 4, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[12569, 292, 451, 8, 70, "Input"],
Cell[13023, 302, 2280, 34, 70, "Output"]
}, Open  ]],
Cell[15318, 339, 62, 0, 70, "Text"],
Cell[15383, 341, 358, 8, 70, "DefinitionBox",
  CellTags->"Symmetrise"],
Cell[15744, 351, 336, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[16105, 361, 163, 3, 70, "Input"],
Cell[16271, 366, 134, 3, 70, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

