(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11187,        301]*)
(*NotebookOutlinePosition[     12502,        343]*)
(*  CellTagsIndexPosition[     12355,        335]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Alternative methods", "SubsectionIcon"],

Cell["Naive maximum likelihood estimation", "SubsubsectionIcon",
  CellTags->"Naive MLE"],

Cell[TextData[{
  "\tThe key difficulties arise because of the very large number of possible \
genotypes.  For example, with two alleles at each of five loci, there are ",
  Cell[BoxData[
      \(TraditionalForm\`2\^5\)]],
  "= 32 haplotypes and ",
  Cell[BoxData[
      \(TraditionalForm\`3\^5\)]],
  "= 243 distinguishable diploid genotypes.  Unless samples are extremely \
large, one cannot estimate even haplotype frequencies.  Moreover, if gametes \
are not combined at random, the genetic structure is determined by the much \
larger number of diploid genotypes; yet, these cannot be distinguished \
without knowing which gene came from which parent.  The very large number of \
genotypes rules out the most obvious method: to make a maximum likelihood \
estimate (MLE) of the genotype frequencies.  Even in large samples, most \
diplotypes, and even most haplotypes, may be missing. Therefore, the MLE \
would be that only observed genotypes are actually present, implying complete \
associations between certain gene combinations.  This can raise serious \
difficulties.  For example, suppose that we wish to find whether some family \
was sired by a known male, or by some unknown father.  If we suppose that \
genotypes that are absent in our sample are absent in the rest of the \
population, then there will be an undue tendency to assign paternity to \
implausible parental genotypes represented amongst the known individuals."
}], "Text"],

Cell["Maximum entropy", "SubsubsectionIcon",
  CellTags->"Maximum entropy"],

Cell[TextData[{
  "\tThe problem, therefore, is to describe the genotype frequencies in terms \
of a small number of parameters; the description must be simple enough to \
make calculations tractable, and must include the structure of the actual \
populations under study.  A popular solution to this kind of problem has been \
to use the method of \"maximum entropy\" (Guiasu & Shenitzer, ",
  Cell[BoxData[
      FormBox[
        ButtonBox["1985",
          ButtonData:>{"References", "Guiasu & Shenitzer 1985"},
          ButtonStyle->"AddOnsLink",
          ButtonNote->"1985"], TraditionalForm]]],
  "; Phipps & Brill,",
  Cell[BoxData[
      FormBox[
        ButtonBox[\(\(\ \)\(1995\)\),
          ButtonData:>{"References", "Phipps & Brill 1995"},
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  ").  The entropy of a sample is defined as S = ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["\[Sum]", 
            StyleBox["X",
              FontWeight->"Bold"]], 
          RowBox[{
            RowBox[{"g", "[", 
              StyleBox["X",
                FontWeight->"Bold"], "]"}], 
            RowBox[{"log", "[", 
              RowBox[{"g", "[", 
                StyleBox["X",
                  FontWeight->"Bold"], "]"}], "]"}]}]}], TraditionalForm]]],
  ", where g[",
  StyleBox["X",
    FontWeight->"Bold"],
  "] is the frequency of genotype ",
  StyleBox["X",
    FontWeight->"Bold"],
  ".  Given the constraint ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["\[Sum]", 
            StyleBox["X",
              FontWeight->"Bold"]], 
          RowBox[{"g", "[", 
            StyleBox["X",
              FontWeight->"Bold"], "]"}]}], TraditionalForm]]],
  "=1, entropy is maximised when all genotypes are equally common.  Given \
further constraints on allele frequencies, the maximum entropy is at linkage \
equilibrium.  With constraints on pairwise linkage disequilibria, the maximum \
entropy solution defines the genotype frequencies in terms of the small \
number of pairwise coefficients.  In the haploid case, the solution is g[",
  StyleBox["X",
    FontWeight->"Bold"],
  "]= ",
  Cell[BoxData[
      \(TraditionalForm\`Exp[\[Sum]\_i\( \[Lambda]\_i\) 
                X\_i + \[Sum]\_\(i, j\)\(\[Lambda]\_\(i, j\)\) \(X\_i\) X\_j]/
        Z\)]],
  ", where Z is a normalising constant, and ",
  Cell[BoxData[
      \(TraditionalForm\`X\_i\)]],
  "= 0 or 1 defines the state of the ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  "'th locus.  The \[Lambda]'s are determined by the equations \[PartialD]",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(ln \((Z)\)\)/\[PartialD]\[Lambda]\_i\),
            "TraditionalForm"], "=", \(p\_i\)}], TraditionalForm]]],
  ", \[PartialD]",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(ln \((Z)\)\)/\[PartialD]\[Lambda]\_\(i, j\)\),
            "TraditionalForm"], "=", \(\(p\_i\) p\_j + C\_\(i, j\)\)}], 
        TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`p\_i\)]],
  "is the allele frequency, and ",
  Cell[BoxData[
      \(TraditionalForm\`C\_\(i, j\)\)]],
  "is the covariance (equivalent to the linkage disequilibrium) between loci \
",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ".  This method has a tempting generality, but suffers two drawbacks.  \
First, numerical solutions involve complicated transecendental equations, \
which become intractable in the diploid case.  Second, there is no reason why \
evolutionary processes should lead populations to have \"maximum entropy\".  \
The method has been justifed as reflecting our ignorance of unknown \
frequencies (analogous to arguments justifying parsimony in phylogeny \
reconstruction).  However, even though we may not know actual genotype \
frequencies, we may know the patterns of genotype frequencies likely to be \
produced by evolution: estimation procedures should be based on these \
patterns.  Moreover, the parameter estimates are not interesting in \
themselves: they can only be interpreted in the light of some evolutionary \
model."
}], "Text"],

Cell["Log-linear models", "SubsubsectionIcon",
  CellTags->"Log-linear models"],

Cell[TextData[{
  "\tA related approach is that taken by Haber (",
  Cell[BoxData[
      FormBox[
        ButtonBox["1984",
          ButtonData:>{"References", "Haber 1984"},
          ButtonStyle->"AddOnsLink",
          ButtonNote->"1984"], TraditionalForm]]],
  ") where a log-linear model is used to parameterize genotype frequencies.  \
For two loci (labelled ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  "), the frequency of the diploid combination ",
  Cell[BoxData[
      \(TraditionalForm\`{{P\_i, P\_j\)]],
  "}, ",
  Cell[BoxData[
      \(TraditionalForm\`{P\_\(i\^*\), P\_\(j\^*\)\)]],
  "}} (where ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " label the alleles inherited from the mother, and ",
  Cell[BoxData[
      \(TraditionalForm\`\(i\^*\), \ \(j\^*\)\)]],
  "those from the mother), is given as log[",
  Cell[BoxData[
      \(p\_\(\(iji\^*\) \(j\^*\)\)\)],
    FontFamily->"Times"],
  "] = \[Mu]+",
  Cell[BoxData[
      \(\[Alpha]\_i\)],
    FontFamily->"Times"],
  "+",
  Cell[BoxData[
      \(\[Alpha]\_j\)],
    FontFamily->"Times"],
  "+",
  Cell[BoxData[
      \(\[Alpha]\_\(i\^*\)\)],
    FontFamily->"Times"],
  "+",
  Cell[BoxData[
      \(\[Alpha]\_\(j\^*\)\)],
    FontFamily->"Times"],
  "+",
  Cell[BoxData[
      \(\[Beta]\_ij\)],
    FontFamily->"Times"],
  "+",
  Cell[BoxData[
      \(\[Beta]\_\(\(i\^*\) \(j\^*\)\)\)],
    FontFamily->"Times"],
  "+",
  Cell[BoxData[
      \(\[Beta]\_\(i\ \(i\^*\)\)\)],
    FontFamily->"Times"],
  "+",
  Cell[BoxData[
      \(\[Beta]\_\(j\ \(j\^*\)\)\)],
    FontFamily->"Times"],
  "+",
  Cell[BoxData[
      \(\(\(\[Beta]\_\(i\ \(j\^*\)\)\)\(+\)\)\)],
    FontFamily->"Times"],
  Cell[BoxData[
      \(\[Beta]\_\(ji\^*\)\)],
    FontFamily->"Times"],
  ".  Only first and second order interactions are considered, but the method \
could be extended to include higher order interactions and multiple loci.  A \
difficulty with this method is that, in order to uniquely determine the \
parameters, some arbitrary reference point needs to be assigned, which will \
not necessarily have a biological interpretation. For example, Haber (1984) \
suggests setting the sums over the indices to zero.  With no higher order \
interactions,the allele frequencies for locus ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " are then ",
  Cell[BoxData[
      \(p\_1 = \(p = exp[\[Mu] + \[Alpha]\_1]\)\)],
    FontFamily->"Times"],
  " and ",
  Cell[BoxData[
      \(p\_2 = \(q = exp[\[Mu] - \[Alpha]\_1]\)\)],
    FontFamily->"Times"],
  "; however, the parameters \[Mu], \[Alpha] do not bear a simple relation to \
allele frequencies in the presence of interactions. Another problem is that \
the parameters of the log-linear model measure net effects; the parameter ",
  Cell[BoxData[
      \(\[Beta]\_\(j\ \(j\^*\)\)\)],
    FontFamily->"Times"],
  " which measures deviations from random mating with respect to locus ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " could be zero, but if some of the other 5 sets of 2-way parameters, \
\[Beta], are nonzero, the covariance between alleles at locus ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " will not be zero.  Finally, there is still the problem of estimating a \
large number of parameters; simply setting parameters for higher order \
interactions to zero may cause erroneous estimates of lower order \
interactions."
}], "Text"]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{245, Automatic}, {Automatic, 46}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Naive MLE"->{
    Cell[1765, 51, 89, 1, 24, "SubsubsectionIcon",
      CellTags->"Naive MLE"]},
  "Maximum entropy"->{
    Cell[3312, 79, 75, 1, 24, "SubsubsectionIcon",
      CellTags->"Maximum entropy"]},
  "Log-linear models"->{
    Cell[7597, 189, 79, 1, 24, "SubsubsectionIcon",
      CellTags->"Log-linear models"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Naive MLE", 12021, 322},
  {"Maximum entropy", 12126, 325},
  {"Log-linear models", 12239, 328}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 45, 0, 36, "SubsectionIcon"],
Cell[1765, 51, 89, 1, 24, "SubsubsectionIcon",
  CellTags->"Naive MLE"],
Cell[1857, 54, 1452, 23, 191, "Text"],
Cell[3312, 79, 75, 1, 24, "SubsubsectionIcon",
  CellTags->"Maximum entropy"],
Cell[3390, 82, 4204, 105, 308, "Text"],
Cell[7597, 189, 79, 1, 24, "SubsubsectionIcon",
  CellTags->"Log-linear models"],
Cell[7679, 192, 3504, 107, 235, "Text"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

