(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     25238,        764]*)
(*NotebookOutlinePosition[     26983,        819]*)
(*  CellTagsIndexPosition[     26751,        808]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Estimating the matrix of moments from genotype \
frequencies", "SubsectionIcon"]], "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(EstimateMoments[
              g, {p\_1, \[Ellipsis]}]\), \(estimates\ the\ matrix\ of\ \
moments\ from\ the\ 3\^n\ diploid\ genotype\ frequencies, \ 
            assuming\ allele\ frequencies\ p\_i; \ 
            divergences\ \[Delta]p\_i\ are\ assumed\ 1, \ 
            so\ that\ all\ loci\ are\ \(\(equivalent\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"EstimateMoments"],

Cell[TextData[{
  "This sets up a list of three-locus genotype frequencies, in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`p\_i, \ c\_\(j, k\)\)]],
  ":"
}], "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"gv", "=", 
        RowBox[{"GenotypeFrequencyConvert", "[", 
          RowBox[{
            RowBox[{"DiploidGenotypeFrequencyList", "[", 
              RowBox[{\({p\_1, p\_2, p\_3}\), ",", 
                RowBox[{"(", GridBox[{
                      {"1", "0", \(c\_\(0, 2\)\), \(c\_\(0, 3\)\)},
                      {
                        "0", \(c\_\(1, 1\)\), \(c\_\(1, 2\)\), \(c\_\(1, 
                            3\)\)},
                      {\(c\_\(0, 2\)\), \(c\_\(1, 2\)\), \(c\_\(2, 
                            2\)\), \(c\_\(2, 3\)\)},
                      {\(c\_\(0, 3\)\), \(c\_\(1, 3\)\), \(c\_\(2, 
                            3\)\), \(c\_\(3, 3\)\)}
                      }], ")"}]}], "]"}], ",", "3"}], "]"}]}], ";", 
      "\n", \(gv = \(\((Together /@ \((Collect[#, c\___])\))\) &\) /@ gv\), 
      ";"}]], "Input",
  CellLabel->"In[45]:="],

Cell["This is the frequency of the homozygous genotype {2,2,2}:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gv[\([\(-1\)]\)]\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(p\_1\%2\ p\_2\%2\ p\_3\%2 + 
      2\ p\_1\ p\_2\ p\_3\ \((p\_1 + p\_2 + p\_3)\)\ c\_\(0, 2\) + 
      2\ p\_1\ p\_2\ p\_3\ c\_\(0, 3\) + \((p\_1\ p\_2 + p\_1\ p\_3 + p\_2\ p\
\_3)\)\^2\ c\_\(1, 1\) + 
      2\ \((p\_1 + p\_2 + p\_3)\)\ \((p\_1\ p\_2 + p\_1\ p\_3 + 
            p\_2\ p\_3)\)\ c\_\(1, 2\) + 
      2\ \((p\_1\ p\_2 + p\_1\ p\_3 + 
            p\_2\ p\_3)\)\ c\_\(1, 3\) + \((p\_1 + p\_2 + p\_3)\)\^2\ c\_\(2, \
2\) + 2\ \((p\_1 + p\_2 + p\_3)\)\ c\_\(2, 3\) + c\_\(3, 3\)\)], "Output",
  CellLabel->"Out[48]="]
}, Open  ]],

Cell["\<\
This estimates the matrix of moments, for given allele frequencies:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cc = 
        EstimateMoments[
          gv /. {p\_1 -> 0.2, p\_2 -> 0.1, p\_3 -> 0.3}, {0.2, 0.1, 
            0.3}];\)\), "\n", 
    \(Chop[Expand /@ cc] // MatrixForm\)}], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.`", 
              "0", \(1.`\ c\_\(0, 2\)\), \(0.9999999999999999`\ c\_\(0, \
3\)\)},
            {
              "0", \(1.`\ c\_\(1, 1\)\), \(1.0000000000000002`\ c\_\(1, \
2\)\), \(1.`\ c\_\(1, 3\)\)},
            {\(1.`\ c\_\(0, 2\)\), \(1.0000000000000002`\ c\_\(1, 2\)\), \
\(1.0000000000000002`\ c\_\(2, 2\)\), \(1.`\ c\_\(2, 3\)\)},
            {\(0.9999999999999999`\ c\_\(0, 3\)\), \(1.`\ c\_\(1, 3\)\), \
\(1.`\ c\_\(2, 3\)\), \(1.0000000000000002`\ c\_\(3, 3\)\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[59]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "After some simplification, this reduces to the correct form.  If the \
genotype frequencies are of the symmetrical form, such that ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(U, V\)\)]],
  "is ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(~\[Delta]p\_U\) \(\[Delta]p\_V\) 
        c\_\(\( | U | \), \( | V | \)\)\)]],
  ", then the exact answer will be given.  For other genotype frequencies, \
however, this algorithm does not return the maximum likelihood estimate of \
the moments."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(EstimateMoments[
              g, {p\_1, \[Ellipsis]}, {\[Delta]p\_1, \[Ellipsis]}]\), \
\(allows\ the\ effects\ of\ each\ locus, \ 
            represented\ by\ the\ divergences\ \[Delta]p\_i, \ 
            to\ \(\(vary\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"Varying divergence"],

Cell[TextData[{
  "This sets up a list of three-locus genotype frequencies, in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`p\_i, \ c\_\(j, k\)\)]],
  ":"
}], "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"gv", "=", 
        RowBox[{"GenotypeFrequencyConvert", "[", 
          RowBox[{
            RowBox[{"DiploidGenotypeFrequencyList", "[", 
              
              RowBox[{\({p\_1, p\_2, p\_3}\), 
                ",", \({\[Delta]p\_1, \[Delta]p\_2, \[Delta]p\_3}\), ",", 
                RowBox[{"(", GridBox[{
                      {"1", "0", \(c\_\(0, 2\)\), \(c\_\(0, 3\)\)},
                      {
                        "0", \(c\_\(1, 1\)\), \(c\_\(1, 2\)\), \(c\_\(1, 
                            3\)\)},
                      {\(c\_\(0, 2\)\), \(c\_\(1, 2\)\), \(c\_\(2, 
                            2\)\), \(c\_\(2, 3\)\)},
                      {\(c\_\(0, 3\)\), \(c\_\(1, 3\)\), \(c\_\(2, 
                            3\)\), \(c\_\(3, 3\)\)}
                      }], ")"}]}], "]"}], ",", "3"}], "]"}]}], ";", 
      "\n", \(gv = \(\((Together /@ \((Collect[#, c\___])\))\) &\) /@ gv\), 
      ";"}]], "Input",
  CellLabel->"In[60]:="],

Cell["This is the frequency of the homozygous genotype {2,2,2}:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gv[\([\(-1\)]\)]\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \(p\_1\%2\ p\_2\%2\ p\_3\%2 + 
      2\ p\_1\ p\_2\ p\_3\ \((p\_3\ \[Delta]p\_1\ \[Delta]p\_2 + 
            p\_2\ \[Delta]p\_1\ \[Delta]p\_3 + 
            p\_1\ \[Delta]p\_2\ \[Delta]p\_3)\)\ c\_\(0, 2\) + 
      2\ p\_1\ p\_2\ p\_3\ \[Delta]p\_1\ \[Delta]p\_2\ \[Delta]p\_3\ c\_\(0, \
3\) + \((p\_2\ p\_3\ \[Delta]p\_1 + p\_1\ p\_3\ \[Delta]p\_2 + p\_1\ p\_2\ \
\[Delta]p\_3)\)\^2\ c\_\(1, 1\) + 
      2\ \((p\_2\ p\_3\ \[Delta]p\_1 + p\_1\ p\_3\ \[Delta]p\_2 + 
            p\_1\ p\_2\ \[Delta]p\_3)\)\ \((p\_3\ \[Delta]p\_1\ \[Delta]p\_2 \
+ p\_2\ \[Delta]p\_1\ \[Delta]p\_3 + 
            p\_1\ \[Delta]p\_2\ \[Delta]p\_3)\)\ c\_\(1, 2\) + 
      2\ \[Delta]p\_1\ \[Delta]p\_2\ \[Delta]p\_3\ \((p\_2\ p\_3\ \
\[Delta]p\_1 + p\_1\ p\_3\ \[Delta]p\_2 + 
            p\_1\ p\_2\ \[Delta]p\_3)\)\ c\_\(1, 3\) + \((p\_3\ \[Delta]p\_1\ \
\[Delta]p\_2 + p\_2\ \[Delta]p\_1\ \[Delta]p\_3 + p\_1\ \[Delta]p\_2\ \
\[Delta]p\_3)\)\^2\ c\_\(2, 2\) + 
      2\ \[Delta]p\_1\ \[Delta]p\_2\ \[Delta]p\_3\ \((p\_3\ \[Delta]p\_1\ \
\[Delta]p\_2 + p\_2\ \[Delta]p\_1\ \[Delta]p\_3 + 
            p\_1\ \[Delta]p\_2\ \[Delta]p\_3)\)\ c\_\(2, 3\) + \
\[Delta]p\_1\%2\ \[Delta]p\_2\%2\ \[Delta]p\_3\%2\ c\_\(3, 3\)\)], "Output",
  CellLabel->"Out[61]="]
}, Open  ]],

Cell["\<\
This estimates the matrix of moments, for given allele frequencies:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cc = 
        EstimateMoments[
          gv /. {p\_1 -> 0.2, p\_2 -> 0.1, 
              p\_3 -> 0.3, \[Delta]p\_1 -> 0.8, \[Delta]p\_2 -> 
                1, \[Delta]p\_3 -> 1.1}, {0.2, 0.1, 0.3}, {0.8, 1, 
            1.1}];\)\), "\n", 
    \(Chop[Expand /@ cc] // MatrixForm\)}], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.`", 
              "0", \(0.9999999999999998`\ c\_\(0, 2\)\), \
\(1.0000000000000002`\ c\_\(0, 3\)\)},
            {
              "0", \(0.9999999999999999`\ c\_\(1, 1\)\), \(1.`\ c\_\(1, \
2\)\), \(1.`\ c\_\(1, 3\)\)},
            {\(0.9999999999999998`\ c\_\(0, 2\)\), \(1.`\ c\_\(1, 2\)\), \
\(1.`\ c\_\(2, 2\)\), \(1.`\ c\_\(2, 3\)\)},
            {\(1.0000000000000002`\ c\_\(0, 3\)\), \(1.`\ c\_\(1, 3\)\), \
\(1.`\ c\_\(2, 3\)\), \(1.0000000000000002`\ c\_\(3, 3\)\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[63]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "This gives the correct value, taking into account the varying \[Delta]p.  \
It is important that no \[Delta]p be zero, since the function works simply by \
rescaling ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_i\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_i/\[Delta]p\_i\)]],
  ". This suggests that the method may give a poor estimate for varying ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]p\_i\)]],
  ", since it gives greater weight to less important loci.\nBecause \
EstimateMoments[] describes the ",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(2  n\)\)]],
  "genotype frequencies in terms of a much smaller number of parameters, it \
may fit a model which cannot be realised because it predicts negative \
genotype frequencies.  For example, suppose that genotype frequencies are \
sampled from a population which does satisfy the form of the admixture model \
with \[Delta]p=1 and equal allele frequencies.  Because sampled allele \
frequencies may vary, EstimateMoments[] may predict negative genptype \
frequencies.  This is clearly inadmissible if one regards EstimateMoments[] \
as estimating the full genotypic structure; nevertheless, EstimateMoments[] \
may give satisfactory estimates of individual coefficients."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MToC[m, c, \ nloci]\), \(gives\ the\ moments, \ c\_\(j, k\), \ 
            in\ terms\ of\ m[j, k], \ 
            where\ m[j, 
                k]\ is\ the\ average\ expectation\ of\ terms\ \ consisting\ \
of\ \((\[Zeta] + \(\[Zeta]\^*\))\)\ for\ j\ distinct\ loci, \ \(\(and\)\(\ \)\
\(\[Zeta]\)\(\[VeryThinSpace]\)\(\[Zeta]\^*\)\(\ \)\(for\)\(\ \)\(k\)\(\ \
\)\(distinct\)\(\ \)\(\(loci\)\(.\)\)\(\ \ \)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"MToC"],

Cell["This is the three locus solution:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MToC[m, c, 3]\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \({c[0, 0] \[Rule] m[0, 0], c[0, 1] \[Rule] 1\/2\ m[1, 0], 
      c[0, 2] \[Rule] \(-m[0, 1]\) + 1\/2\ m[2, 0], 
      c[0, 3] \[Rule] 1\/2\ \((\(-3\)\ m[1, 1] + m[3, 0])\), 
      c[1, 1] \[Rule] m[0, 1], c[1, 2] \[Rule] 1\/2\ m[1, 1], 
      c[1, 3] \[Rule] \(-m[0, 2]\) + 1\/2\ m[2, 1], c[2, 2] \[Rule] m[0, 2], 
      c[2, 3] \[Rule] 1\/2\ m[1, 2], c[3, 3] \[Rule] m[0, 3]}\)], "Output",
  CellLabel->"Out[41]="]
}, Open  ]],

Cell["This shows the solution as a matrix of moments:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Array[c, {4, 4}, 0] /. c[i_, j_] \[RuleDelayed] c @@ Sort[{i, j}]\) /. 
        MToC[m, c, 3] // MatrixForm\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(m[0, 0]\), \(1\/2\ m[1, 0]\), \(\(-m[0, 1]\) + 
                1\/2\ m[2, 0]\), \(1\/2\ \((\(-3\)\ m[1, 1] + m[3, 0])\)\)},
            {\(1\/2\ m[1, 0]\), \(m[0, 
                1]\), \(1\/2\ m[1, 1]\), \(\(-m[0, 2]\) + 1\/2\ m[2, 1]\)},
            {\(\(-m[0, 1]\) + 1\/2\ m[2, 0]\), \(1\/2\ m[1, 1]\), \(m[0, 
                2]\), \(1\/2\ m[1, 2]\)},
            {\(1\/2\ \((\(-3\)\ m[1, 1] + m[3, 0])\)\), \(\(-m[0, 2]\) + 
                1\/2\ m[2, 1]\), \(1\/2\ m[1, 2]\), \(m[0, 3]\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[40]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "Suppose that genotypes are defined by the contributions of maternal and \
paternal alleles, ",
  Cell[BoxData[
      \(TraditionalForm\`X\_i, \ \(X\_i\%*\) = 0, \ 1. \)]],
  " Let the deviations of these be ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_i \[Congruent] X\_i - p\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Zeta]\_i\%*\) \[Congruent] \(X\_i\%*\) - 
          p\_i\)]],
  "(assume here that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(p\_i\),
            "TraditionalForm"], "=", \(p\_i\%*\)}], TraditionalForm]]],
  ").  Then, E[",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{
                  RowBox[{
                    RowBox[{
                      RowBox[{
                        RowBox[{
                          RowBox[{
                            FormBox[\((\(\[Zeta]\_1\)\(+\)\),
                              "TraditionalForm"], \(\[Zeta]\_1\%*\)}], ")"}], 
                        
                        FormBox[\((\(\[Zeta]\_2\)\(+\)\),
                          "TraditionalForm"], \(\[Zeta]\_2\%*\)}], ")"}], 
                    FormBox[\((\[Zeta]\_3\),
                      "TraditionalForm"], \(\[Zeta]\_3\%*\)}], ")"}], 
                FormBox[\((\[Zeta]\_4\),
                  "TraditionalForm"], \(\[Zeta]\_4\%*\)}], ")"}], "]"}], 
          "=", \(c\_\(4, 2\) + 2  c\_\(3, 3\) + c\_\(2, 4\)\)}], 
        TraditionalForm]]],
  " (assuming that \[Delta]p=1).  In general, if ",
  Cell[BoxData[
      \(TraditionalForm\`m[j, k]\)]],
  " is the expectation of ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " factors ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Zeta] + \(\[Zeta]\^*\))\)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " factors ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\[VeryThinSpace]\(\[Zeta]\^*\)\)]],
  ", all with distinct indices, then ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(m[j, k]\), "=", 
          RowBox[{\(\[Sum]\+\(u + v = j\)\), 
            RowBox[{
              RowBox[{"(", GridBox[{
                    {"j"},
                    {"u"}
                    }], ")"}], \(c\_\(k + u, k + v\)\)}]}]}], 
        TraditionalForm]]],
  ".  There are ",
  Cell[BoxData[
      \(TraditionalForm\`\(n!\)\/\(\(j!\) \(k!\) \(\((n - j - k)\)!\)\)\)]],
  "terms which contribute to m[j,k].  MToC[] solves for the ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(j, k\)\)]],
  " in terms of the ",
  Cell[BoxData[
      \(TraditionalForm\`m[j, k]\)]],
  " .  EstimateMoments[] calculates the ",
  Cell[BoxData[
      \(TraditionalForm\`m[j, k]\)]],
  " from the genotype frequencies, and then uses MToC[] to find the matrix of \
moments."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions used by EstimateMoments[]", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MVariables[
              n]\), \(lists\ all\ the\ coefficients\ m[S, 
                H]\ needed\ to\ describe\ an\ n\ locus\ diploid\ \(\(genotype\
\)\(.\)\)\)},
          {\(MVariables[j, \ n]\), \(lists\ those\ of\ order\ j \[LessEqual] 
              2 \( \(n\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"MVariables"],

Cell[TextData[{
  "In order to describe all the moments among 3 biallelic loci in a diploid, \
moments ",
  Cell[BoxData[
      \(TraditionalForm\`E[\(\((\[Zeta] + \(\[Zeta]\^*\))\)\_S\) \((\[Zeta]\
\[VeryThinSpace]\(\[Zeta]\^*\))\)\_H]\)]],
  " are required.  Here, S and H are sets of distinct and non-overlapping \
indices.  In the symmetric model, only the number of elements in S and H is \
important,  MVariables gives the set of {|S|,|H|} required for a full \
description.  "
}], "Text"],

Cell[TextData[{
  "With three loci the most complex moment would be ",
  Cell[BoxData[
      \(TraditionalForm\`M\_\(0, 3\)\)]],
  "=E[",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_1\[VeryThinSpace]\(\[Zeta]\_1\%*\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_2\[VeryThinSpace]\(\[Zeta]\_2\%*\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_3\[VeryThinSpace]\(\[Zeta]\_3\%*\)\)]],
  "]:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MVariables[3]\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \({{0, 0}, {0, 1}, {0, 2}, {0, 3}, {1, 0}, {1, 1}, {1, 2}, {2, 0}, {2, 
        1}, {3, 0}}\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell["This picks out those elements of order 3:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MVariables[3, 3]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \({{1, 1}, {3, 0}}\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell[TextData[{
  "Thus, moments like E[",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Zeta]\_1\[VeryThinSpace] + \(\[Zeta]\_1\%*\))\)\
\)]],
  Cell[BoxData[
      \(TraditionalForm\`\((\[Zeta]\_2\[VeryThinSpace]\(\[Zeta]\_2\%*\))\)\)]]\
,
  "] and E[",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Zeta]\_1\[VeryThinSpace] + \(\[Zeta]\_1\%*\))\)\
\)]],
  Cell[BoxData[
      \(TraditionalForm\`\((\[Zeta]\_2 + \[VeryThinSpace]\(\[Zeta]\_2\%*\))\)\
\)]],
  Cell[BoxData[
      \(TraditionalForm\`\((\[Zeta]\_3\[VeryThinSpace] + \(\[Zeta]\_3\%*\))\)\
\)]],
  "] involve only 3 genes."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MFromC[
              c, {S, H}]\), \(gives\ the\ expression\ for\ M[S, 
                H]\ in\ terms\ of\ the\ c[i, j]\)},
          {\(MToCEquations[m, c, 
              n]\), \(gives\ the\ set\ of\ equations\ for\ m[S, 
                H]\ in\ terms\ of\ the\ c[j, 
                k]\ for\ n\ \(\(loci\)\(.\)\)\)},
          {\(MToCEquations[m, c, j, 
              n]\), \(gives\ the\ set\ of\ equations\ of\ order\ \(\(j\)\(.\)\
\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"MFromC", "MToCEquations"}],

Cell[TextData[{
  "For example, ",
  Cell[BoxData[
      \(TraditionalForm\`M[3, 0] = E[\((\[Zeta] + \(\[Zeta]\^*\))\)\_S]\)]],
  " for S containing 3 distinct indices.  Expanding, ",
  Cell[BoxData[
      \(TraditionalForm\`M[3, 0] = 
        2  E[\[Zeta]\_S] + 6  E[\(\[Zeta]\_U\) \(\[Zeta]\_V\%*\)]\)]],
  " where |S|=3, |U|=1, |V|=2, and we assume ",
  Cell[BoxData[
      \(TraditionalForm\`E[\(\[Zeta]\_U\) \(\[Zeta]\_V\%*\)]\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`E[\(\[Zeta]\_U\%*\) \[Zeta]\_V]\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MFromC[c, {3, 0}]\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \(2\ c[0, 3] + 6\ c[1, 2]\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell["\<\
These are the equations needed to describe the 3 locus \
system:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MToCEquations[m, c, 3] // TableForm\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(m[0, 0] == c[0, 0]\)},
          {\(m[0, 1] == c[1, 1]\)},
          {\(m[0, 2] == c[2, 2]\)},
          {\(m[0, 3] == c[3, 3]\)},
          {\(m[1, 0] == 2\ c[0, 1]\)},
          {\(m[1, 1] == 2\ c[1, 2]\)},
          {\(m[1, 2] == 2\ c[2, 3]\)},
          {\(m[2, 0] == 2\ c[0, 2] + 2\ c[1, 1]\)},
          {\(m[2, 1] == 2\ c[1, 3] + 2\ c[2, 2]\)},
          {\(m[3, 0] == 2\ c[0, 3] + 6\ c[1, 2]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          m[ 0, 0], 
          c[ 0, 0]], 
        Equal[ 
          m[ 0, 1], 
          c[ 1, 1]], 
        Equal[ 
          m[ 0, 2], 
          c[ 2, 2]], 
        Equal[ 
          m[ 0, 3], 
          c[ 3, 3]], 
        Equal[ 
          m[ 1, 0], 
          Times[ 2, 
            c[ 0, 1]]], 
        Equal[ 
          m[ 1, 1], 
          Times[ 2, 
            c[ 1, 2]]], 
        Equal[ 
          m[ 1, 2], 
          Times[ 2, 
            c[ 2, 3]]], 
        Equal[ 
          m[ 2, 0], 
          Plus[ 
            Times[ 2, 
              c[ 0, 2]], 
            Times[ 2, 
              c[ 1, 1]]]], 
        Equal[ 
          m[ 2, 1], 
          Plus[ 
            Times[ 2, 
              c[ 1, 3]], 
            Times[ 2, 
              c[ 2, 2]]]], 
        Equal[ 
          m[ 3, 0], 
          Plus[ 
            Times[ 2, 
              c[ 0, 3]], 
            Times[ 6, 
              c[ 1, 2]]]]}]]], "Output",
  CellLabel->"Out[17]//TableForm="]
}, Open  ]],

Cell["These are those equations that involve just 3 loci:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MToCEquations[m, c, 3, 3] // TableForm\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(m[1, 1] == 2\ c[1, 2]\)},
          {\(m[3, 0] == 2\ c[0, 3] + 6\ c[1, 2]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          m[ 1, 1], 
          Times[ 2, 
            c[ 1, 2]]], 
        Equal[ 
          m[ 3, 0], 
          Plus[ 
            Times[ 2, 
              c[ 0, 3]], 
            Times[ 6, 
              c[ 1, 2]]]]}]]], "Output",
  CellLabel->"Out[18]//TableForm="]
}, Open  ]],

Cell["The solution to the full set is just MToC[m,c,3]:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MToC[m, c, 3]\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \({{c[0, 0] \[Rule] m[0, 0], c[0, 1] \[Rule] 1\/2\ m[1, 0], 
        c[0, 2] \[Rule] \(-m[0, 1]\) + 1\/2\ m[2, 0], 
        c[0, 3] \[Rule] 1\/2\ \((\(-3\)\ m[1, 1] + m[3, 0])\), 
        c[1, 1] \[Rule] m[0, 1], c[1, 2] \[Rule] 1\/2\ m[1, 1], 
        c[1, 3] \[Rule] \(-m[0, 2]\) + 1\/2\ m[2, 1], 
        c[2, 2] \[Rule] m[0, 2], c[2, 3] \[Rule] 1\/2\ m[1, 2], 
        c[3, 3] \[Rule] m[0, 3]}}\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell["\<\
This is acheived using Solve[eqns,vars] where \
vars=Union[Extract[eqns,Position[eqns,c[__]]]], \
eqns=MToCEquations[m,c,jn,opts].\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eqns = MToCEquations[m, c, 3]; 
    vars = Union[Extract[eqns, Position[eqns, c[__]]]]\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \({c[0, 0], c[0, 1], c[0, 2], c[0, 3], c[1, 1], c[1, 2], c[1, 3], 
      c[2, 2], c[2, 3], c[3, 3]}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[eqns, vars]\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \({{c[0, 0] \[Rule] m[0, 0], c[0, 1] \[Rule] 1\/2\ m[1, 0], 
        c[0, 2] \[Rule] \(-m[0, 1]\) + 1\/2\ m[2, 0], 
        c[0, 3] \[Rule] 1\/2\ \((\(-3\)\ m[1, 1] + m[3, 0])\), 
        c[1, 1] \[Rule] m[0, 1], c[1, 2] \[Rule] 1\/2\ m[1, 1], 
        c[1, 3] \[Rule] \(-m[0, 2]\) + 1\/2\ m[2, 1], 
        c[2, 2] \[Rule] m[0, 2], c[2, 3] \[Rule] 1\/2\ m[1, 2], 
        c[3, 3] \[Rule] m[0, 3]}}\)], "Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell["One can just solve for the third order terms:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(eqns = MToCEquations[m, c, 3, 3]; 
    vars = Union[
        Extract[eqns, Position[eqns, c[__]]]];\), "\[IndentingNewLine]", 
    \(Solve[eqns, vars]\)}], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({{c[0, 3] \[Rule] 1\/2\ \((\(-3\)\ m[1, 1] + m[3, 0])\), 
        c[1, 2] \[Rule] 1\/2\ m[1, 1]}}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["This is done using:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MToC[m, c, 3, 3]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \({{c[0, 3] \[Rule] 1\/2\ \((\(-3\)\ m[1, 1] + m[3, 0])\), 
        c[1, 2] \[Rule] 1\/2\ m[1, 1]}}\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{550, 692},
WindowMargins->{{Automatic, -16}, {Automatic, -2}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "EstimateMoments"->{
    Cell[1869, 54, 472, 9, 64, "DefinitionBox",
      CellTags->"EstimateMoments"]},
  "Varying divergence"->{
    Cell[5760, 163, 382, 8, 52, "DefinitionBox",
      CellTags->"Varying divergence"]},
  "MToC"->{
    Cell[11236, 298, 545, 10, 64, "DefinitionBox",
      CellTags->"MToC"]},
  "MVariables"->{
    Cell[16289, 442, 417, 9, 70, "DefinitionBox",
      CellTags->"MVariables"]},
  "MFromC"->{
    Cell[18755, 525, 597, 13, 88, "DefinitionBox",
      CellTags->{"MFromC", "MToCEquations"}]},
  "MToCEquations"->{
    Cell[18755, 525, 597, 13, 88, "DefinitionBox",
      CellTags->{"MFromC", "MToCEquations"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"EstimateMoments", 26106, 786},
  {"Varying divergence", 26217, 789},
  {"MToC", 26318, 792},
  {"MVariables", 26413, 795},
  {"MFromC", 26509, 798},
  {"MToCEquations", 26628, 801}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 127, 1, 26, "SubsubsectionIcon"],
Cell[1869, 54, 472, 9, 64, "DefinitionBox",
  CellTags->"EstimateMoments"],
Cell[2344, 65, 181, 5, 28, "MathCaption"],
Cell[2528, 72, 907, 19, 117, "Input"],
Cell[3438, 93, 82, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3545, 98, 74, 2, 27, "Input"],
Cell[3622, 102, 547, 10, 56, "Output"]
}, Open  ]],
Cell[4184, 115, 100, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4309, 122, 231, 6, 42, "Input"],
Cell[4543, 130, 671, 15, 75, "Output"]
}, Open  ]],
Cell[5229, 148, 528, 13, 50, "Text"],
Cell[5760, 163, 382, 8, 52, "DefinitionBox",
  CellTags->"Varying divergence"],
Cell[6145, 173, 181, 5, 28, "MathCaption"],
Cell[6329, 180, 992, 21, 117, "Input"],
Cell[7324, 203, 82, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7431, 208, 74, 2, 27, "Input"],
Cell[7508, 212, 1257, 21, 100, "Output"]
}, Open  ]],
Cell[8780, 236, 100, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[8905, 243, 339, 8, 73, "Input"],
Cell[9247, 253, 671, 15, 75, "Output"]
}, Open  ]],
Cell[9933, 271, 1300, 25, 156, "Text"],
Cell[11236, 298, 545, 10, 64, "DefinitionBox",
  CellTags->"MToC"],
Cell[11784, 310, 56, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[11865, 314, 71, 2, 27, "Input"],
Cell[11939, 318, 434, 7, 120, "Output"]
}, Open  ]],
Cell[12388, 328, 70, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[12483, 332, 167, 3, 27, "Input"],
Cell[12653, 337, 690, 13, 103, "Output"]
}, Open  ]],
Cell[13358, 353, 2827, 82, 147, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16222, 440, 64, 0, 24, "SubsubsectionIcon"],
Cell[16289, 442, 417, 9, 70, "DefinitionBox",
  CellTags->"MVariables"],
Cell[16709, 453, 495, 10, 64, "Text"],
Cell[17207, 465, 433, 12, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[17665, 481, 70, 2, 27, "Input"],
Cell[17738, 485, 147, 3, 20, "Output"]
}, Open  ]],
Cell[17900, 491, 64, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[17989, 495, 73, 2, 27, "Input"],
Cell[18065, 499, 74, 2, 20, "Output"]
}, Open  ]],
Cell[18154, 504, 598, 19, 22, "Text"],
Cell[18755, 525, 597, 13, 88, "DefinitionBox",
  CellTags->{"MFromC", "MToCEquations"}],
Cell[19355, 540, 546, 15, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[19926, 559, 75, 2, 27, "Input"],
Cell[20004, 563, 82, 2, 20, "Output"]
}, Open  ]],
Cell[20101, 568, 95, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[20221, 575, 93, 2, 27, "Input"],
Cell[20317, 579, 1608, 63, 163, "Output"]
}, Open  ]],
Cell[21940, 645, 74, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[22039, 649, 96, 2, 27, "Input"],
Cell[22138, 653, 572, 21, 35, "Output"]
}, Open  ]],
Cell[22725, 677, 72, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[22822, 681, 71, 2, 27, "Input"],
Cell[22896, 685, 455, 8, 120, "Output"]
}, Open  ]],
Cell[23366, 696, 154, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[23545, 704, 144, 3, 27, "Input"],
Cell[23692, 709, 156, 3, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23885, 717, 75, 2, 27, "Input"],
Cell[23963, 721, 455, 8, 120, "Output"]
}, Open  ]],
Cell[24433, 732, 68, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[24526, 736, 210, 5, 57, "Input"],
Cell[24739, 743, 156, 3, 36, "Output"]
}, Open  ]],
Cell[24910, 749, 42, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[24977, 753, 74, 2, 27, "Input"],
Cell[25054, 757, 156, 3, 36, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

