(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     46061,       1156]*)
(*NotebookOutlinePosition[     47532,       1202]*)
(*  CellTagsIndexPosition[     47344,       1193]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Estimating the matrix of moments", "SubsectionIcon",
  CellTags->"Estimating the matrix"],

Cell[CellGroupData[{

Cell["A simple method", "SubsubsectionIcon",
  CellTags->"simple method"],

Cell[TextData[{
  "\tThere is a simple way of estimating the matrix of moments, ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(j, k\)\)]],
  ", from a set of ",
  Cell[BoxData[
      \(TraditionalForm\`3\^n\)]],
  " diploid genotype frequencies.  Each locus is described by the value ",
  Cell[BoxData[
      \(TraditionalForm\`X\_i + \(X\_i\%*\) = 
        0, \ \(\(1\)\(\ \)\(or\)\(\ \)\(2.\)\(\ \ \)\)\)]],
  "However, the underlying genotypes {0, 1} and {1, 0} cannot be \
distinguished in heterozygotes: this makes it impossible to directly estimate \
all the multilocus moments.  Nevertheless, provided that allele frequencies \
are known, and are the same amongst male and female gametes, two useful \
quantities can be defined for each locus.  First, the additive effect is \
given by  ",
  Cell[BoxData[
      \(TraditionalForm\`z\_i \[Congruent] \[Zeta]\_i + \
\(\[Zeta]\_i\%*\)\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`X\_i + \(X\_i\%*\) - 2  p\_i\)]],
  ".  Second, the deviation from Hardy-Weinberg proportions is described by \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_i \[Congruent] \(\[Zeta]\_i\) \
\(\[Zeta]\_i\%*\)\)]],
  ", which takes values ",
  Cell[BoxData[
      \(TraditionalForm\`\(\({p\_i\%2, \ \(-p\_i\) q\_i, 
        q\_i\%2}\)\(\ \)\)\)]],
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`X\_i + \(X\_i\%*\) = \ \(\({0, \ 1, \ 
            2}\)\(.\)\)\)]],
  "  Next, find the average value of all those terms ",
  Cell[BoxData[
      \(TraditionalForm\`M\_\(a, b\)\)]],
  "which contain ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " factors ",
  Cell[BoxData[
      \(TraditionalForm\`z\_i\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " factors ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_i\)]],
  ", all with distinct indices: ",
  Cell[BoxData[
      \(TraditionalForm\`M\_\(a, b\) \[Congruent]  < \[Product]\+\(i \
\[Element] A\)\((\[Zeta]\_i + \(\[Zeta]\_i\%*\))\) \(\[Product]\+\(j \
\[Element] B\)\((\(\[Zeta]\_j\) \(\[Zeta]\_j\%*\))\)\) > \)]],
  " , where A, B are sets of distinct and non-overlapping indices, and <> \
indicates an average over all ",
  Cell[BoxData[
      \(TraditionalForm\`\(n!\)\/\(\(a!\) \(b!\) \(\((n - a - b)\)!\)\)\)]],
  "such terms.  If the genotype frequencies have the form given by the \
admixture model, with \[Delta]p=1, then ",
  Cell[BoxData[
      \(TraditionalForm\`M\_\(a, b\)\)]],
  "= ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Sum]\_\(j + k = a\)\), 
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"a"},
                  {"j"}
                  }], ")"}], \(c\_\(j + b, k + b\)\)}]}], TraditionalForm]]],
  ".  Taking all possible ",
  Cell[BoxData[
      \(TraditionalForm\`M\_\(a, b\)\)]],
  " provides a set of linear equations which uniquely determine all possible \
",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(j, k\)\)]],
  ".  If the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]p\_i\)]],
  "vary across loci, the same method can be used, provided that ",
  Cell[BoxData[
      \(TraditionalForm\`z\_i\)]],
  " is scaled relative to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]p\_i\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_i\)]],
  " relative to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]p\_i\%2\)]],
  ": ",
  Cell[BoxData[
      \(TraditionalForm\`M\_\(a, b\) \[Congruent]  < \[Product]\+\(i \
\[Element] A\)\(\((\[Zeta]\_i + \(\[Zeta]\_i\%*\))\)\/\[Delta]p\_i\) \(\
\[Product]\+\(j \[Element] B\)\((\(\[Zeta]\_j\) \
\(\[Zeta]\_j\%*\))\)\/\[Delta]p\_i\%2\) > \)]],
  ".  None of the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]p\_i\)]],
  "can be zero; the method may be statistically inefficient if there is wide \
variation in the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Delta]p\_i\)\(.\)\)\)]]
}], "Text"],

Cell[TextData[{
  "\tThis is a straightforward extension of the obvious method for estimating \
pairwise associations: to estimate the sum ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(0, 2\) + c\_\(1, 1\)\)]],
  "from the variance of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+i\((X\_i + \(X\_i\%*\))\)\)]],
  " (roughly, ",
  Cell[BoxData[
      \(TraditionalForm\`M\_\(2, 0\)\)]],
  "), and to estimate ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(1, 1\)\)]],
  "from deviations from Hardy-Weinberg at each locus (here, ",
  Cell[BoxData[
      \(TraditionalForm\`M\_\(0, 1\)\)]],
  ").  It may give satisfactory estimates of individual coefficients.  \
However, it is unsatisfactory as an estimator of the overall genotypic \
structure, described by the full set of moments, since individual genotype \
frequencies may be negative."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extension to estimation from families", "SubsubsectionIcon",
  CellTags->"Extension to families"],

Cell[TextData[{
  "This method extends to estimates about the parental population based on \
families of offspring.   The population allele frequencies can be estimated \
simply from the mean across families, weighting each family equally; however, \
it is impossible to distinguish maternal and paternal allele frequencies from \
observations of autosomal loci in offspring.  Let ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_i, \ \(\[Zeta]\_i\%*\)\)]],
  " be the mother's genotype, and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Zeta]\_i\%'\), \ \[Zeta]\_i\%\(\('\)\(*\)\)\)]],
  " the father's.  These states are measured relative to the overall \
population allele frequencies.    Let the states in the offspring be \[Phi], \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\^*\)\)]],
  "; we observe these \[Phi], ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\^*\)\)]],
  ", and wish to infer moments of the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_i, \ \(\[Zeta]\_i\%*\), \ \
\(\[Zeta]\_i\%'\), \ \[Zeta]\_i\%\(\('\)\(*\)\)\)]],
  " from them."
}], "Text"],

Cell[TextData[{
  "First, consider a single  family derived from a pair of diploid parents.  \
Then, the mean of the maternal allele in the offspring is ",
  Cell[BoxData[
      \(TraditionalForm\`E[\[Phi]] = \(1\/2\) \((\[Zeta]\_i + \(\[Zeta]\_i\%*\
\))\)\)]],
  ", and the variance of that allele is ",
  Cell[BoxData[
      \(TraditionalForm\`var[\[Phi]] = \(1\/4\) \((\[Zeta]\_i - \
\(\[Zeta]\_i\%*\))\)\^2\)]],
  "; ",
  Cell[BoxData[
      \(TraditionalForm\`E\_f\)]],
  "denotes an expectation over a particular family.  Hence, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\[VeryThinSpace]\(\[Zeta]\^*\)\)]],
  " is estimated by ",
  Cell[BoxData[
      \(TraditionalForm\`E[\[Phi]]\^2 - var[\[Phi]]\)]],
  ".  We cannot observe \[Phi] directly.  However, we do have the following \
relations:"
}], "Text"],

Cell[BoxData[{
    RowBox[{\(E\_f[\[Phi] + \(\[Phi]\^*\)] = \(1\/2\) \((S + S')\)\), 
      "        "}], "\[IndentingNewLine]", \(var[\[Phi] + \(\[Phi]\^*\)] = \
\(1\/4\) \((\[CapitalDelta]\^2 + \[CapitalDelta]'\^2\ )\)\), "\
\[IndentingNewLine]", 
    RowBox[{\(E\_f[\[Phi]\ \(\[Phi]\^*\)] = \(1\/4\) S\[VeryThinSpace]S'\), 
      "       "}], "\[IndentingNewLine]", \(cov[\[Phi] + \(\[Phi]\^*\), \
\[Phi]\[VeryThinSpace]\(\[Phi]\^*\)] = \(1\/8\) \((\(\[CapitalDelta]\^2\) 
              S' + \(\[CapitalDelta]'\^2\) 
              S)\)\), "\[IndentingNewLine]", \(K[\[Phi] + \(\[Phi]\^*\)] = \
\(1\/16\) \((\[CapitalDelta]\^4 + \[CapitalDelta]'\^4\ )\)\), "\
\[IndentingNewLine]", \(var[\[Phi]\ \(\[Phi]\^*\)] = \(1\/16\) \((\(S\^2\) \
\[CapitalDelta]'\^2 + \(S'\^2\) \[CapitalDelta]\^2 + \(\[CapitalDelta]\^2\) \
\[CapitalDelta]'\^2)\)\), "\[IndentingNewLine]", 
    RowBox[{"\t\t", 
      RowBox[{\(where\ S = \[Zeta]\_i + \(\[Zeta]\_i\%*\)\), ",", " ", 
        RowBox[{\(S'\), "=", 
          FormBox[\(\(\[Zeta]\_i\%'\) + \ \[Zeta]\_i\%\(\('\)\(*\)\)\),
            "TraditionalForm"]}], ",", 
        " ", \(\[CapitalDelta] = \[Zeta]\_i - \(\[Zeta]\_i\%*\)\), ",", 
        " ", \(\[CapitalDelta]' = \(\[Zeta]\_i\%'\) - \ \
\[Zeta]\_i\%\(\('\)\(*\)\)\)}]}]}], "NumberedEquation"],

Cell[BoxData[
    \(\(\(Hence\)\(:\)\)\)], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{\(S\_i \[Congruent] 2\ E\_f[\[Phi] + \(\[Phi]\^*\)]\), "=", 
        RowBox[{"(", 
          RowBox[{\(\[Zeta]\_i\), "+", \(\[Zeta]\_i\%*\), "+", 
            FormBox[\(\(\[Zeta]\_i\%'\) + \ \[Zeta]\_i\%\(\('\)\(*\)\)\),
              "TraditionalForm"]}], ")"}]}], 
      " "}], "\[IndentingNewLine]", \(H\_i \[Congruent] 
        E\_f[\[Phi] + \(\[Phi]\^*\)]\^2 - 2  E\_f[\[Phi]\ \(\[Phi]\^*\)] - \ 
          var[\[Phi] + \(\[Phi]\^*\)] = \((\(\[Zeta]\_i\) \(\[Zeta]\_i\%*\) + \
\(\[Zeta]\_i\%'\) \[Zeta]\_i\%\(\('\)\(*\)\))\)\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(SS\_i \[Congruent] 4  E\_f[\[Phi]\ \(\[Phi]\^*\)]\), "=", 
        RowBox[{\((\[Zeta]\_i + \(\[Zeta]\_i\%*\))\), 
          RowBox[{"(", 
            FormBox[\(\(\[Zeta]\_i\%'\) + \ \[Zeta]\_i\%\(\('\)\(*\)\)\),
              "TraditionalForm"], ")"}]}]}], " "}], "\[IndentingNewLine]", 
    RowBox[{\(SH\_i \[Congruent] 
        2  E\_f[\[Phi] + \(\[Phi]\^*\)] E\_f[\[Phi]\ \(\[Phi]\^*\)] - 
          2  cov[\[Phi] + \(\[Phi]\^*\), \[Phi]\[VeryThinSpace]\(\[Phi]\^*\)]\
\), "=", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              FormBox[\(\(\[Zeta]\_i\%'\) + \ \[Zeta]\_i\%\(\('\)\(*\)\)\),
                "TraditionalForm"], 
              ")"}], \(\[Zeta]\_i\), \(\[Zeta]\_i\%*\)}], 
          "+", \(\((\[Zeta]\_i + \(\[Zeta]\_i\%*\))\) \(\[Zeta]\_i\%'\) \
\[Zeta]\_i\%\(\('\)\(*\)\)\)}], 
        ")"}]}], "\[IndentingNewLine]", \(HH\_i \[Congruent] 
        var[\[Phi]\ \(\[Phi]\^*\)] + E\_f[\[Phi]\ \(\[Phi]\^*\)]\^2 - 
          2\ E\_f[\[Phi] + \(\[Phi]\^*\)] 
            cov[\[Phi] + \(\[Phi]\^*\), \[Phi]\[VeryThinSpace]\(\[Phi]\^*\)] \
+ 2  E\_f[\[Phi]\ \(\[Phi]\^*\)] 
            var[\[Phi] + \(\[Phi]\^*\)] = \(\[Zeta]\_i\) \(\[Zeta]\_i\%*\) \(\
\[Zeta]\_i\%'\) \[Zeta]\_i\%\(\('\)\(*\)\)\)}], "NumberedEquation"],

Cell[TextData[{
  "There is an alternative expression for ",
  Cell[BoxData[
      \(TraditionalForm\`H\[VeryThinSpace]H\_i\)]],
  "in terms of K[], the fourth cumulant; however, this seems more \
complicated.  I should really find the minimal variance estimator.  "
}], "Text"],

Cell["\<\
Thus, we calculate the additive effect directly; the heterozygosity \
of the parents from the variance in additive effect among offspring; the \
correlation betwen additive effects across parents from the heterozygosity of \
offspring; the correlation between additive effects and heterozygosity from \
the variance of heterozygosity in the offspring; and the correlation between \
heterozygosity in the parents from a combination of these.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Calculating unbiased estimates", "SubsubsectionIcon"],

Cell[TextData[{
  "To make unbiased estimates of {S,H,\[Ellipsis]} from families of size ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", we need to know the expectations of the quantities in Eq.2.  These \
expressions will involve moments of the joint expression for (",
  Cell[BoxData[
      \(\(\(\[Phi] + \(\[Phi]\^*\)\)\(,\)\(\ \)\)\)]],
  Cell[BoxData[
      \(\(\[Phi]\[Phi]\^*\)\)]],
  ").  We have:"
}], "Text"],

Cell[BoxData[{
    \(\[LeftAngleBracket]E\_f[\[Phi] + \(\[Phi]\^*\)]\[RightAngleBracket] = \ \
\[Kappa]\_1[\[Phi] + \(\[Phi]\^*\)]\), "\n", 
    \(\[LeftAngleBracket]E\_f[\[Phi] + \(\[Phi]\^*\)]\^2\[RightAngleBracket]\ \
 = \[Kappa]\_1[\[Phi] + \(\[Phi]\^*\)]\^2 + \[Kappa]\_2[\[Phi] + \
\(\[Phi]\^*\)]\/n\), "\n", 
    \(\[LeftAngleBracket]E\_f[\[Phi]\ \(\[Phi]\^*\)]\[RightAngleBracket]\  = \
\[Kappa]\_1[\(\[Phi]\[Phi]\^*\)]\), "\n", 
    \(\[LeftAngleBracket]var[\[Phi] + \(\[Phi]\^*\)]\[RightAngleBracket] = \
\((1 - 1\/\(\(n\)\(\ \)\))\) \[Kappa]\_2[\[Phi] + \(\[Phi]\^*\)]\), "\n", 
    \(\[LeftAngleBracket]E\_f[\[Phi] + \(\[Phi]\^*\)] 
          E\_f[\[Phi]\ \(\[Phi]\^*\)]\[RightAngleBracket] = \ \[Kappa]\_1[\
\[Phi] + \(\[Phi]\^*\)]\ \[Kappa]\_1[\[Phi]\[VeryThinSpace]\(\[Phi]\^*\)] + \
\[Kappa]\_2[\[Phi] + \(\[Phi]\^*\), \(\[Phi]\[Phi]\^*\)]\/n\), "\n", 
    \(\[LeftAngleBracket]cov[\[Phi] + \(\[Phi]\^*\), \[Phi]\[VeryThinSpace]\(\
\[Phi]\^*\)]\[RightAngleBracket] = \((1 - 
            1\/\(\(n\)\(\ \)\))\) \[Kappa]\_2[\[Phi] + \(\[Phi]\^*\), \
\(\[Phi]\[Phi]\^*\)]\), "\n", 
    \(\[LeftAngleBracket]var[\[Phi]\ \(\[Phi]\^*\)]\[RightAngleBracket] = \
\((1 - 1\/\(\(n\)\(\ \)\))\) \[Kappa]\_2[\(\[Phi]\[Phi]\^*\)]\), "\n", 
    \(\[LeftAngleBracket]E\_f[\[Phi]\ \(\[Phi]\^*\)]\^2\[RightAngleBracket] = \
\[Kappa]\_1[\[Phi]\[VeryThinSpace]\(\[Phi]\^*\)]\^2 + \[Kappa]\_2[\[Phi]\
\[VeryThinSpace]\(\[Phi]\^*\)]\/n\), "\n", 
    \(\[LeftAngleBracket]E\_f[\[Phi] + \(\[Phi]\^*\)] 
          cov[\[Phi] + \(\[Phi]\^*\), \[Phi]\[VeryThinSpace]\(\[Phi]\^*\)]\
\[RightAngleBracket] = \(\(\((n - 1)\) \((n - 
                    2)\)\)\/n\^2\) \[Kappa]\_1[\[Phi] + \(\[Phi]\^*\)] \
\[Kappa]\_2[\[Phi] + \(\[Phi]\^*\), \[Phi]\[VeryThinSpace]\(\[Phi]\^*\)] + \(\
\((n - 1)\)\/n\^2\) \[Kappa]\_2[\((\[Phi] + \(\[Phi]\^*\))\)\^2, \[Phi]\
\[VeryThinSpace]\(\[Phi]\^*\)]\), "\n", 
    \(\[LeftAngleBracket]E\_f[\[Phi]\ \(\[Phi]\^*\)] 
          var[\[Phi] + \(\[Phi]\^*\)]\[RightAngleBracket] = \
\[IndentingNewLine]\(\((n - 
                  1)\)\/n\) \[Kappa]\_1[\(\[Phi]\[Phi]\^*\)] \[Kappa]\_2[\
\[Phi] + \(\[Phi]\^*\)] + \(\((n - 
                  1)\)\/n\^2\) \((\[Kappa]\_2[\((\[Phi] + \
\(\[Phi]\^*\))\)\^2, \[Phi]\[VeryThinSpace]\(\[Phi]\^*\)] - 
              2  \[Kappa]\_1[\[Phi] + \(\[Phi]\^*\)] \[Kappa]\_2[\((\[Phi] + \
\(\[Phi]\^*\))\), \[Phi]\[VeryThinSpace]\(\[Phi]\^*\)])\)\), "\
\[IndentingNewLine]", 
    \(\[LeftAngleBracket]cov[\((\[Phi] + \(\[Phi]\^*\))\)\^2, \[Phi]\
\[VeryThinSpace]\(\[Phi]\^*\)]\[RightAngleBracket] = \((1 - 
            1\/\(\(n\)\(\ \)\))\) \[Kappa]\_2[\((\[Phi] + \
\(\[Phi]\^*\))\)\^2, \(\[Phi]\[Phi]\^*\)]\)}], "NumberedEquation"],

Cell[TextData[{
  "where the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\_2\)]],
  " denote true variances and covariances, and the \[LeftAngleBracket]\
\[RightAngleBracket] are expectations over the means and variances calculated \
naively from families of size ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ".  (I assume variances var() are estimated with ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " in the denominator, not ",
  Cell[BoxData[
      \(TraditionalForm\`\((n - 1)\)\)]],
  ")"
}], "Text"],

Cell[TextData[{
  "We can invert these linear expressions so as to get unbiased estimators; \
variances and covariances are simply multiplied by ",
  Cell[BoxData[
      \(TraditionalForm\`n\/\(n - 1\)\)]],
  " in the usual way, but quantities such as ",
  Cell[BoxData[
      \(E\_f[\[Phi] + \(\[Phi]\^*\)] 
        cov[\[Phi] + \(\[Phi]\^*\), \[Phi]\[VeryThinSpace]\(\[Phi]\^*\)]\)]],
  "need to be corrected in a more complicated way.  From Eq. 2, then:"
}], "Text"],

Cell[BoxData[{
    \(S\_i = 2  E\_f[\[Phi] + \(\[Phi]\^*\)]\), "\[IndentingNewLine]", 
    \(H\_i \[Congruent] 
      E\_f[\[Phi] + \(\[Phi]\^*\)]\^2 - 
        2  E\_f[\[Phi]\ \(\[Phi]\^*\)] - \ \(\(n + 1\)\/\(n - 1\)\) 
          var[\[Phi] + \(\[Phi]\^*\)]\), "\[IndentingNewLine]", 
    \(SS\_i \[Congruent] 
      4  E\_f[\[Phi]\ \(\[Phi]\^*\)]\), "\[IndentingNewLine]", 
    \(SH\_i \[Congruent] 
      2  E\_f[\[Phi] + \(\[Phi]\^*\)] E\_f[\[Phi]\ \(\[Phi]\^*\)] - 
        2 \(\( n + 1\)\/\(n - 1\)\) 
          cov[\[Phi] + \(\[Phi]\^*\), \[Phi]\[VeryThinSpace]\(\[Phi]\^*\)]\), \
"\[IndentingNewLine]", 
    \(HH\_i \[Congruent] 
      var[\[Phi]\ \(\[Phi]\^*\)] + 
        E\_f[\[Phi]\ \(\[Phi]\^*\)]\^2 + \(\(2  n\)\/\(n - 
                1\)\) \((E\_f[\[Phi]\ \(\[Phi]\^*\)] 
                var[\[Phi] + \(\[Phi]\^*\)] - 
              E\_f[\[Phi] + \(\[Phi]\^*\)] 
                cov[\[Phi] + \(\[Phi]\^*\), \
\[Phi]\[VeryThinSpace]\ \(\[Phi]\^*\)])\)\)}], "NumberedEquation"]
}, Closed]],

Cell[CellGroupData[{

Cell["Calculating moments", "SubsubsectionIcon"],

Cell["\tNow, consider the quantity:", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox[
            RowBox[{\(M\_\(S, H, SS, SH, HH\)\), "\[Congruent]", 
              RowBox[{"E", "[", "\[IndentingNewLine]", 
                RowBox[{\(\[Product]\_\(i \[Element] S\)\), 
                  RowBox[{"(", 
                    RowBox[{\(\[Zeta]\_i\), "+", \(\[Zeta]\_i\%*\), "+", 
                      
                      FormBox[\(\(\[Zeta]\_i\%'\) + \ \
\[Zeta]\_i\%\(\('\)\(*\)\)\),
                        "TraditionalForm"]}], ")"}]}]}]}],
            "TraditionalForm"], 
          RowBox[{\(\[Product]\_\(i \[Element] H\)\), 
            
            RowBox[{\((\(\[Zeta]\_i\) \(\[Zeta]\_i\%*\) + \(\[Zeta]\_i\%'\) \
\[Zeta]\_i\%\(\('\)\(*\)\))\), 
              FormBox[
                RowBox[{\(\[Product]\_\(i \[Element] SS\)\), 
                  RowBox[{"(", 
                    
                    RowBox[{\(\(\[Zeta]\_i\) \(\[Zeta]\_i\%'\)\), 
                      "+", \(\(\[Zeta]\_i\%*\) \(\[Zeta]\_i\%'\)\), "+", 
                      RowBox[{\(\[Zeta]\_i\), 
                        
                        FormBox[\(\[Zeta]\_i\%\(\('\)\(*\)\) + \
\(\[Zeta]\_i\%*\)\ \[Zeta]\_i\%\(\('\)\(*\)\)\),
                          "TraditionalForm"]}]}], ")"}]}],
                "TraditionalForm"], 
              RowBox[{\(\[Product]\_\(i \[Element] SH\)\), 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{\(\[Zeta]\_i\), \(\[Zeta]\_i\%*\), 
                        
                        FormBox[\(\(\[Zeta]\_i\%'\) + \(\[Zeta]\_i\) \
\(\[Zeta]\_i\%*\)\ \[Zeta]\_i\%\(\('\)\(*\)\)\),
                          "TraditionalForm"]}], 
                      "+", \(\(\[Zeta]\_i\) \(\[Zeta]\_i\%'\) \
\[Zeta]\_i\%\(\('\)\(*\)\)\), 
                      "+", \(\(\[Zeta]\_i\%*\) \(\[Zeta]\_i\%'\) \[Zeta]\_i\%\
\(\('\)\(*\)\)\)}], 
                    ")"}], \(\[Product]\_\(i \[Element] HH\)\(\[Zeta]\_i\) \(\
\[Zeta]\_i\%*\) \(\[Zeta]\_i\%'\) \[Zeta]\_i\%\(\('\)\(*\)\)\)}]}]}]}]}], 
        "]"}], TraditionalForm]], "NumberedEquation",
  FormatType->StandardForm],

Cell["\<\
where the expectation is over all the families.  This can be \
calculated from the product over loci of the various quantities defined in \
Eq. 4.  Only sets involving distinct sets of loci will be required.\
\>", \
"Text"],

Cell["\<\
This can be rewritten as a sum over moments:\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`M\_\(S, H, SS, SH, HH\) = \[Sum]\+\(S\_1 + S\_2 + S\_3 \
+ S\_4\)\(\[Sum]\+\(H\_1 + H\_2\)\(\[Sum]\+\(SS\_1 + SS\_2 + SS\_3 + \
SS\_4\)\(\[Sum]\+\(SH\_1 + SH\_2 + SH\_3 + SH\_4\)C\_\({\(S\_1\) \(H\_1\) \
\(SS\_\(1, 3\)\) \(SH\_\(1, 2, 3\)\) HH}, {\(S\_2\) \(H\_1\) \(SS\_\(2, 4\)\) \
\(SH\_\(1, 2, 4\)\) HH}, {\(S\_3\) \(H\_2\) \(SS\_\(1, 2\)\) \(SH\_\(1, 3, \
4\)\) HH}, {\(S\_4\) \(H\_2\) \(SS\_\(3, 4\)\) \(SH\_\(2, 3, 4\)\) \
HH}\)\)\)\)\)], "NumberedEquation",
  FormatType->StandardForm],

Cell[TextData[{
  "where the sum is over components of SS etc. as ordered in Eq. 4.  Thus, \
the ",
  Cell[BoxData[
      \(TraditionalForm\`M\_\[Aleph]\)]],
  "are sums of moments ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(C\_\(A, B, C, D\)\),
            "TraditionalForm"], 
          "\[Congruent]", \(E[\(\[Zeta]\_A\) \(\[Zeta]\_B\%*\) \
\(\[Zeta]\_C\%'\) \[Zeta]\_D\%\(\('\)\(*\)\)]\)}], TraditionalForm]]],
  " involving simpler sets of loci.  For example:"
}], "Text"],

Cell[BoxData[
    \(M\_\({i, j}, {}, {}, {}, {}\) = 
      C\_\({i, j}, {}, {}, {}\) + 
        C\_\({i}, {j}, {}, {}\) + \[Ellipsis]C\_\({}, {}, {i}, {j}\) + 
        C\_\({}, {}, {}, {i, j}\)\)], "NumberedEquation"],

Cell[TextData[{
  "By making some symmetry assumptions, one can solve for the C's in terms of \
the ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  "'s.  Suppose now that we just count classes of moments.  Eq. 6 then \
becomes a sum over integer partitions:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(M\_\(S, H, SS, SH, HH\)\), "=", 
        RowBox[{\(\[Sum]\+\(S = S\_1 + S\_2 + S\_3 + S\_4\)\), 
          RowBox[{\(\[Sum]\+\(H = H\_1 + H\_2\)\), 
            RowBox[{\(\[Sum]\+\(SS = SS\_1 + SS\_2 + SS\_3 + SS\_4\)\), 
              RowBox[{\(\[Sum]\+\(SH = SH\_1 + SH\_2 + SH\_3 + SH\_4\)\), 
                RowBox[{
                  RowBox[{"(", GridBox[{
                        {"S"},
                        {\(S\+_\)}
                        }], ")"}], 
                  RowBox[{"(", GridBox[{
                        {"H"},
                        {\(H\+_\)}
                        }], ")"}], 
                  RowBox[{"(", GridBox[{
                        {"SS"},
                        {\(SS\+_\)}
                        }], ")"}], 
                  RowBox[{"(", GridBox[{
                        {"SH"},
                        {\(SH\+_\)}
                        }], 
                    ")"}], \(C\_\(S\_1 + H\_1 + SS\_1 + SS\_3 + SH\_1 + 
                        SH\_2 + SH\_3 + HH, 
                      S\_2 + H\_1 + SS\_2 + SS\_4 + SH\_1 + SH\_2 + SH\_4 + 
                        HH, S\_3 + H\_2 + SS\_1 + SS\_2 + SH\_1 + SH\_3 + 
                        SH\_4 + HH, 
                      S\_4 + H\_2 + SS\_3 + SS\_4 + SH\_2 + SH\_3 + SH\_4 + 
                        HH\)\)}]}]}]}]}]}], 
      TraditionalForm]], "NumberedEquation",
  FormatType->StandardForm],

Cell[TextData[{
  "This set of equations has peculiar properties.  For 2 loci, the full set \
of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  "'s gives 21 equations for the 21 ",
  Cell[BoxData[
      \(TraditionalForm\`c' s\)]],
  ".  However, for 3 loci there are 56 equations for 55 distinct c's; for 4 \
loci, 126 equations for 120 loci.  Eliminating the ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  "'s leaves a necessary relation among the sixth-order M's which is not in \
fact satisfied by the numerical estimates of the M's.  (Since those are only \
estimates, that may be reasonable).  For example, with 3 loci the relevant \
equations are:"
}], "Text"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(m[0, 0, 1, 0, 1] == 4\ c[1, 2, 1, 2]\)},
          {\(m[0, 2, 1, 0, 0] == 8\ c[0, 1, 2, 3] + 8\ c[1, 2, 1, 2]\)},
          {\(m[1, 1, 0, 1, 0] == 
              8\ c[0, 1, 2, 3] + 4\ c[0, 2, 2, 2] + 4\ c[1, 1, 1, 3] + 
                8\ c[1, 1, 2, 2] + 8\ c[1, 2, 1, 2]\)},
          {\(m[2, 0, 0, 0, 1] == 
              4\ c[1, 1, 1, 3] + 4\ c[1, 1, 2, 2] + 8\ c[1, 2, 1, 2]\)},
          {\(m[0, 0, 0, 2, 0] == 
              4\ c[0, 2, 2, 2] + 4\ c[1, 1, 2, 2] + 8\ c[1, 2, 1, 2]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          m[ 0, 0, 1, 0, 1], 
          Times[ 4, 
            c[ 1, 2, 1, 2]]], 
        Equal[ 
          m[ 0, 2, 1, 0, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 1, 2, 3]], 
            Times[ 8, 
              c[ 1, 2, 1, 2]]]], 
        Equal[ 
          m[ 1, 1, 0, 1, 0], 
          Plus[ 
            Times[ 8, 
              c[ 0, 1, 2, 3]], 
            Times[ 4, 
              c[ 0, 2, 2, 2]], 
            Times[ 4, 
              c[ 1, 1, 1, 3]], 
            Times[ 8, 
              c[ 1, 1, 2, 2]], 
            Times[ 8, 
              c[ 1, 2, 1, 2]]]], 
        Equal[ 
          m[ 2, 0, 0, 0, 1], 
          Plus[ 
            Times[ 4, 
              c[ 1, 1, 1, 3]], 
            Times[ 4, 
              c[ 1, 1, 2, 2]], 
            Times[ 8, 
              c[ 1, 2, 1, 2]]]], 
        Equal[ 
          m[ 0, 0, 0, 2, 0], 
          Plus[ 
            Times[ 4, 
              c[ 0, 2, 2, 2]], 
            Times[ 4, 
              c[ 1, 1, 2, 2]], 
            Times[ 8, 
              c[ 1, 2, 1, 2]]]]}]]], "Output",
  CellLabel->"Out[303]//TableForm="],

Cell[TextData[{
  "These define a relation between the ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  "'s which should be satisfied given the symmetry assumptions among the ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  "/s, but which will not be exactly satisfied in any sample. It is not \
obvious to me how best to deal with this problem of overdetermination.  \
However, it only arises for higher-order coefficients which may not be of \
much interest in any case."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Maximum likelihood estimation using the Metropolis algorithm", \
"SubsubsectionIcon",
  CellTags->"MLE"],

Cell[TextData[{
  "\tThe Metropolis algorithm (Metropolis ",
  StyleBox["et al.",
    FontSlant->"Italic"],
  ", 1954) generates a random walk with density proportional to the \
likelihood.  This can be used either to find the likelihood surface, or to \
search for maximum likelihood estimates.  The algorithm makes a random change \
to a set of parameters ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            FormBox[\(x\+_\),
              "TraditionalForm"], "\[Rule]", \(x\+_\^*\)}], ")"}], 
        TraditionalForm]]],
  "; if this increases the likelihood, it is accepted, whilst if it decreases \
the likelihood, it is accepted with probability ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(L\^*\)\/L)\)\^T\)]],
  ".  This generates a random sequence with density ",
  Cell[BoxData[
      \(TraditionalForm\`L\^T\)]],
  ". The parameter ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " is referred to as a \"temperature\".  If it is large, a wide range of \
parameter space is explored: this is appropriate in the initial stages of a \
search, where regions of high likelihood are to be found, and local peaks \
avoided.  If ",
  Cell[BoxData[
      \(TraditionalForm\`T = 1\)]],
  ", then the random walk follows the likelihood surface, and can be used to \
construct support surfaces for arbitrary functions of the parameters. If ",
  Cell[BoxData[
      \(TraditionalForm\`T = 0\)]],
  ", the sequence climbs uphill to a nearby peak. "
}], "Text"],

Cell[TextData[{
  "\t If the temperature is decreased towards zero sufficiently slowly, a \
global optimum will be reached; this is known as \"simulated annealing\" \
(Kirkpatrick ",
  StyleBox["et al",
    FontSlant->"Italic"],
  "., 1984).  However, there is no easy way to know what is \"sufficiently \
slow\".   From a Bayesian point of view, the distribution of random changes \
determines a prior probability for the parameters.  Here, a uniform \
distribution is used, with a certain step size.  The step size is chosen \
initially on the basis of the bounds on the parameter values, such that \
impossible parameter combinations are avoided.  (This is a difficult \
calculation).  It is then adjusted by decreasing by a factor \
$MetropolisAdjustment (by default, 0.95) when changes are rejected, and \
increasing by 1/$MetropolisAdjustment when changes are rejected.  Random \
changes are tried for each parameter in turn."
}], "Text"],

Cell["\<\
\tA set of parameters can be held fixed by setting the step size to \
zero: it will then remain zero throughout.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Checks", "SubsubsectionIcon"],

Cell[TextData[StyleBox["Checking algebra in Eq 2:",
  FontWeight->"Bold"]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{\({2  E\_f[\[Phi] + \(\[Phi]\^*\)], 
            E\_f[\[Phi] + \(\[Phi]\^*\)]\^2 - 
              2  E\_f[\[Phi]\ \(\[Phi]\^*\)] - \ var[\[Phi] + \(\[Phi]\^*\)], 
            4  E\_f[\[Phi]\ \(\[Phi]\^*\)], 
            2  E\_f[\[Phi] + \(\[Phi]\^*\)] E\_f[\[Phi]\ \(\[Phi]\^*\)] - 
              2  cov[\[Phi] + \(\[Phi]\^*\), \
\[Phi]\[VeryThinSpace]\(\[Phi]\^*\)], 
            var[\[Phi]\ \(\[Phi]\^*\)] + E\_f[\[Phi]\ \(\[Phi]\^*\)]\^2 - 
              2\ E\_f[\[Phi] + \(\[Phi]\^*\)] 
                cov[\[Phi] + \(\[Phi]\^*\), \[Phi]\[VeryThinSpace]\(\[Phi]\^*\
\)] + 2  E\_f[\[Phi]\ \(\[Phi]\^*\)] 
                var[\[Phi] + \(\[Phi]\^*\)]} /. {E\_f[\[Phi] + \(\[Phi]\^*\)] \
-> \(1\/2\) \((S + S')\)\ , 
            E\_f[\[Phi]\ \(\[Phi]\^*\)] -> \(1\/4\) 
                S\[VeryThinSpace]S'\ \ , \[IndentingNewLine]\ 
            var[\[Phi] + \(\[Phi]\^*\)] -> \(1\/4\) \((\[CapitalDelta]\^2 + \
\[CapitalDelta]'\^2\ )\), 
            cov[\[Phi] + \(\[Phi]\^*\), \[Phi]\[VeryThinSpace]\(\[Phi]\^*\)] -> \
\(1\/8\) \((\(\[CapitalDelta]\^2\) S' + \(\[CapitalDelta]'\^2\) S)\), 
            K[\[Phi] + \(\[Phi]\^*\)] -> \(1\/16\) \((\[CapitalDelta]\^4 + \
\[CapitalDelta]'\^4\ )\), 
            var[\[Phi]\ \(\[Phi]\^*\)] -> \(1\/16\) \((\(S\^2\) \
\[CapitalDelta]'\^2 + \(S'\^2\) \[CapitalDelta]\^2 + \(\[CapitalDelta]\^2\) \
\[CapitalDelta]'\^2)\)}\), "/.", 
        RowBox[{"{", 
          
          RowBox[{\(\[CapitalDelta]\^2 \[Rule] S\^2 - 4  \[CapitalPi]\), ",", 
            
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  SuperscriptBox["\[CapitalDelta]", "\[Prime]",
                    MultilineFunction->None], ")"}], "2"], 
              "\[Rule]", \(S'\^2 - 4  \[CapitalPi]'\)}], 
            ",", \(\[CapitalDelta]\^4 -> \((S\^2 - 4  \[CapitalPi])\)\^2\), 
            ",", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  SuperscriptBox["\[CapitalDelta]", "\[Prime]",
                    MultilineFunction->None], ")"}], "4"], 
              "->", \(\((S'\^2 - 4  \[CapitalPi]')\)\^2\)}]}], "}"}]}], "//", 
      "Simplify"}]], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"S", "+", 
          SuperscriptBox["S", "\[Prime]",
            MultilineFunction->None]}], ",", 
        RowBox[{"\[CapitalPi]", "+", 
          SuperscriptBox["\[CapitalPi]", "\[Prime]",
            MultilineFunction->None]}], ",", 
        RowBox[{"S", " ", 
          SuperscriptBox["S", "\[Prime]",
            MultilineFunction->None]}], ",", 
        RowBox[{
          RowBox[{"\[CapitalPi]", " ", 
            SuperscriptBox["S", "\[Prime]",
              MultilineFunction->None]}], "+", 
          RowBox[{"S", " ", 
            SuperscriptBox["\[CapitalPi]", "\[Prime]",
              MultilineFunction->None]}]}], ",", 
        RowBox[{"\[CapitalPi]", " ", 
          SuperscriptBox["\[CapitalPi]", "\[Prime]",
            MultilineFunction->None]}]}], "}"}]], "Output",
  CellLabel->"Out[61]="]
}, Open  ]],

Cell[TextData[{
  "where \[CapitalPi] represents ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\[VeryThinSpace]\(\[Zeta]\^*\)\)]]
}], "Text"],

Cell[TextData[StyleBox["Checking individual moments etc:",
  FontWeight->"Bold"]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[{ex = \({\(z1 + z2 + z3 + z4\)\/2, \(\((z1 - z2)\)\^2 + \((z3 \
- z4)\)\^2\)\/4, \(\((z1 + z2)\) \((z3 + z4)\)\)\/4, \(\(\((z1 + z2)\)\^2\) \
\((z3 - z4)\)\^2 + \(\((z3 + z4)\)\^2\) \((z1 - z2)\)\^2 + \(\((z3 - z4)\)\^2\
\) \((z1 - z2)\)\^2\)\/16, \(\((z1 + z2)\) \((z3 - z4)\)\^2 + \((z3 + z4)\) \
\((z1 - z2)\)\^2\)\/8} /. {z1 \[Rule] \(-p\), z2 \[Rule] 1 - p, 
                  z3 \[Rule] \(-p\), z4 \[Rule] 1 - p}\) /. 
              p \[Rule] 0.4, \[IndentingNewLine]mn = 
            Mean /@ Transpose[\(Flatten[FE[List /@ #, {0.4}]] &\) /@ rfs3 // 
                  Chop], se = 
            StandardErrorOfSampleMean /@ 
              Transpose[\(Flatten[FE[List /@ #, {0.4}]] &\) /@ rfs3 // 
                  Chop], \[IndentingNewLine]\(ex - mn\)\/se}] // 
      MatrixForm\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.19999999999999996`", "0.2105999999999999`", 
              "0.006965353986421367`", \(-1.5218178459650649`\)},
            {\(1\/2\), "0.4984666666666655`", "0.005554809826493159`", 
              "0.2760370527936714`"},
            {"0.009999999999999995`", "0.009659999999999997`", 
              "0.002602971352101254`", "0.13061995466278667`"},
            {"0.0675`", "0.06803688888888866`", 
              "0.00047712194068660966`", \(-1.1252655623341032`\)},
            {"0.04999999999999999`", "0.05246888888888906`", 
              "0.0019302250200137674`", \(-1.2790679134764606`\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[53]//MatrixForm="]
}, Open  ]],

Cell["Checking method for each genotype: 1000 replicates", "Text",
  FontWeight->"Bold"],

Cell["\<\
This generates 1000 replicate families from each type of cross.  \
When there is no segregation )ie no heterozygous parents) there is an exact \
match.  With segregation, the last row gives t tests for deviations from \
expectations. None are significant.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\((rfs3 = 
              RandomFamilySet[#\[LeftDoubleBracket]1\[RightDoubleBracket], #\
\[LeftDoubleBracket]2\[RightDoubleBracket], 10, 1000]; 
            ef = ExpectedFamilyEffects[#\[LeftDoubleBracket]1\
\[RightDoubleBracket], #\[LeftDoubleBracket]2\[RightDoubleBracket], 
                0.4]; \[IndentingNewLine]mf = 
              MeanFamilyEffects[rfs3, 0.4]; \[IndentingNewLine]se = 
              StandardDeviationFamilyEffects[rfs3, 0.4]\/\@1000; \
\[IndentingNewLine]tt = \((mf - ef)\)/
                se; \[IndentingNewLine]Print["\<Testing \>", #]; \
\[IndentingNewLine]Print[{ef, mf, se, tt} // 
                MatrixForm])\) &\) /@ {\[IndentingNewLine]{{0, 0}, {0, 
              0}}, \[IndentingNewLine]{{0, 0}, {0, 
              1}}, \[IndentingNewLine]{{0, 0}, {1, 
              1}}, \[IndentingNewLine]{{0, 1}, {0, 
              1}}, \[IndentingNewLine]{{0, 1}, {1, 
              1}}, \[IndentingNewLine]{{1, 1}, {1, 1}}};\)\)], "Input",
  CellLabel->"In[137]:="],

Cell[BoxData[
    InterpretationBox[\("Testing "\[InvisibleSpace]{{0, 0}, {0, 0}}\),
      SequenceForm[ "Testing ", {{0, 0}, {0, 0}}],
      Editable->False]], "Print",
  CellLabel->"From In[137]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-1.6`\), "0.32000000000000006`", 
              "0.6400000000000001`", \(-0.25600000000000006`\), 
              "0.02560000000000001`"},
            {\(-1.5999999999999774`\), "0.3199999999999946`", 
              "0.6399999999999892`", \(-0.25600000000000017`\), 
              "0.02560000000000047`"},
            {"7.095432210002707`*^-16", "1.633354444381811`*^-16", 
              "3.47746430094192`*^-16", "3.512590202971636`*^-18", 
              "1.4269897699572277`*^-17"},
            {
              "31.919901469038983`", \(-33.30626025095382`\), \
\(-31.287699023623286`\), \(-31.60696125855822`\), "32.093222200997566`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Print",
  CellLabel->"From In[137]:="],

Cell[BoxData[
    InterpretationBox[\("Testing "\[InvisibleSpace]{{0, 0}, {0, 1}}\),
      SequenceForm[ "Testing ", {{0, 0}, {0, 1}}],
      Editable->False]], "Print",
  CellLabel->"From In[137]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-0.6000000000000002`\), \(-0.07999999999999996`\), \
\(-0.15999999999999998`\), "0.224`", \(-0.038400000000000004`\)},
            {\(-0.5956000000000004`\), \(-0.07876000000000022`\), \
\(-0.16351999999999867`\), 
              "0.22371200000000108`", \(-0.03820159999999996`\)},
            {"0.010075820669412594`", "0.0025887522307448045`", 
              "0.008060656535530076`", "0.0020521610955045975`", 
              "0.0004142003569191711`"},
            {"0.436688994808833`", 
              "0.4789952415194959`", \(-0.43668899480868556`\), \
\(-0.14033985958987924`\), "0.4789952415196968`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Print",
  CellLabel->"From In[137]:="],

Cell[BoxData[
    InterpretationBox[\("Testing "\[InvisibleSpace]{{0, 0}, {1, 1}}\),
      SequenceForm[ "Testing ", {{0, 0}, {1, 1}}],
      Editable->False]], "Print",
  CellLabel->"From In[137]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.3999999999999999`", 
              "0.52`", \(-0.96`\), \(-0.09599999999999997`\), "0.0576`"},
            {"0.39999999999999436`", 
              "0.5199999999999929`", \(-0.9600000000000122`\), \
\(-0.09600000000000009`\), "0.057600000000000644`"},
            {"1.7562951014858182`*^-16", "2.2480577299018473`*^-16", 
              "3.793597419209367`*^-16", "2.6344426522287277`*^-18", 
              "1.9758319891715455`*^-17"},
            {\(-31.606961258558215`\), \(-31.60696125855822`\), \
\(-32.192275355938925`\), \(-42.14261501141095`\), "32.66052663384349`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Print",
  CellLabel->"From In[137]:="],

Cell[BoxData[
    InterpretationBox[\("Testing "\[InvisibleSpace]{{0, 1}, {0, 1}}\),
      SequenceForm[ "Testing ", {{0, 1}, {0, 1}}],
      Editable->False]], "Print",
  CellLabel->"From In[137]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.3999999999999999`", \(-0.48`\), 
              "0.03999999999999998`", \(-0.09599999999999997`\), 
              "0.05760000000000001`"},
            {"0.3893999999999995`", \(-0.48170444444444455`\), 
              "0.03608000000000002`", \(-0.0917457777777776`\), 
              "0.0588432888888888`"},
            {"0.013975799188703467`", "0.01111732730375089`", 
              "0.01055545599447281`", "0.003894406059946106`", 
              "0.0029549259765571743`"},
            {\(-0.7584539429107058`\), \(-0.15331422723063115`\), \
\(-0.3713719238707074`\), "1.0923930778500384`", "0.42075128065893697`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Print",
  CellLabel->"From In[137]:="],

Cell[BoxData[
    InterpretationBox[\("Testing "\[InvisibleSpace]{{0, 1}, {1, 1}}\),
      SequenceForm[ "Testing ", {{0, 1}, {1, 1}}],
      Editable->False]], "Print",
  CellLabel->"From In[137]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.4`", "0.12`", 
              "0.23999999999999994`", \(-0.216`\), \
\(-0.08639999999999999`\)},
            {"1.395400000000004`", "0.11689555555555607`", 
              "0.23448000000000005`", \(-0.22138133333333426`\), \
\(-0.08751759999999975`\)},
            {"0.009762896811610496`", "0.002370786782534403`", 
              "0.011715476173932595`", "0.005364754738150806`", 
              "0.0008534832417123897`"},
            {\(-0.47117162956443465`\), \(-1.3094574625244162`\), \
\(-0.4711716295648407`\), \(-1.003090280169858`\), \(-1.3094574625243478`\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Print",
  CellLabel->"From In[137]:="],

Cell[BoxData[
    InterpretationBox[\("Testing "\[InvisibleSpace]{{1, 1}, {1, 1}}\),
      SequenceForm[ "Testing ", {{1, 1}, {1, 1}}],
      Editable->False]], "Print",
  CellLabel->"From In[137]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"2.4`", "0.72`", "1.44`", "0.864`", "0.1296`"},
            {"2.400000000000045`", "0.7200000000000172`", 
              "1.4400000000000344`", "0.8640000000000071`", 
              "0.12959999999999744`"},
            {"1.447187163624314`*^-15", "5.620144324754618`*^-16", 
              "1.0959281433271506`*^-15", "2.3534354359909963`*^-16", 
              "7.903327956686182`*^-17"},
            {"31.30009755701882`", "30.619243719228272`", 
              "31.404352532541818`", 
              "30.19172418727949`", \(-32.309338175415064`\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Print",
  CellLabel->"From In[137]:="]
}, Open  ]],

Cell["\<\
Testing the double heterozygote more carefully, using 10000 \
replicate families\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(rfs3 = RandomFamilySet[{0, 1}, {0, 1}, 10, 10000]; 
    ef = ExpectedFamilyEffects[{0, 1}, {0, 1}, 
        0.4];\), "\[IndentingNewLine]", 
    \(\(mf = MeanFamilyEffects[rfs3, 0.4];\)\), "\[IndentingNewLine]", 
    \(\(se = 
        StandardDeviationFamilyEffects[rfs3, 0.4]\/\@10000;\)\), "\
\[IndentingNewLine]", 
    \(tt = \((mf - ef)\)/se; {ef, mf, se, tt} // MatrixForm\)}], "Input",
  CellLabel->"In[133]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.3999999999999999`", \(-0.48`\), 
              "0.03999999999999998`", \(-0.09599999999999997`\), 
              "0.05760000000000001`"},
            {"0.3957799999999991`", \(-0.48341088888888134`\), 
              "0.041656000000000123`", \(-0.0960949333333294`\), 
              "0.058523279999999706`"},
            {"0.004467909509103533`", "0.003534254946262415`", 
              "0.0032829504325765867`", "0.001268046270745876`", 
              "0.0009513848664074975`"},
            {\(-0.9445133101739026`\), \(-0.965094182718335`\), 
              "0.504424307954126`", \(-0.0748658274698323`\), 
              "0.9704589936206045`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[136]//MatrixForm="]
}, Open  ]],

Cell["There is no significant deviation.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Definitions used in  checks", "SubsubsectionIcon"],

Cell[BoxData[
    \(\(<< Multilocus`EstimatingD`;\)\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\(RandomFamilySet[p1 : {__Integer}, p2 : {__Integer}, n_Integer, 
          nreps_Integer] := 
        Table[RandomFamily[List /@ p1, List /@ p2, 
              n] /. {{x_Integer}, {y_Integer}} \[RuleDelayed] 
              x + y, {nreps}];\)\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \(\(MeanFamilyEffects[rfs_List, p_] := 
        Mean /@ Transpose[\(Flatten[FamilyEffects[List /@ #, {p}]] &\) /@ 
                rfs // Chop];\)\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(\(StandardDeviationFamilyEffects[rfs_List, p_] := 
        StandardDeviation /@ 
          Transpose[\(Flatten[FamilyEffects[List /@ #, {p}]] &\) /@ rfs // 
              Chop];\)\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(\(FE[f_, pp_] := \(FE[f, pp] = 
          Module[{z, y, mz, vz, czy, dz, dy, my, vy, 
              n = Length[f]}, \[IndentingNewLine]z = 
              Replace[\((\(\((# - 2  pp)\) &\) /@ 
                    f)\), {_?\((\((\(! FreeQ[#, \[EmptySet]]\))\) &)\) \
\[RuleDelayed] \[EmptySet]}, {2}]; \[IndentingNewLine]y = 
              Replace[\((\(\((#\^2 - # \((1 + 2  pp)\) + 2  pp\^2)\) &\) /@ 
                      f)\), {_?\((\((\(! FreeQ[#, \[EmptySet]]\))\) &)\) \
\[RuleDelayed] \[EmptySet]}, {2}]/2; \[IndentingNewLine]dz = 
              DeleteCases[Transpose[z], \[EmptySet], 2]; 
            dy = DeleteCases[Transpose[y], \[EmptySet], 
                2]; \[IndentingNewLine]mz = 
              Mean /@ dz; \[IndentingNewLine]vz = 
              VarianceMLE /@ dz; \[IndentingNewLine]my = 
              Mean /@ dy; \[IndentingNewLine]vy = 
              VarianceMLE /@ dy; \[IndentingNewLine]czy = 
              MapThread[
                CovarianceMLE[#1, #2] &, {dz, 
                  dy}]; \[IndentingNewLine]{mz, \(n\/\(n - 1\)\) vz, 
              my, \(n\/\(n - 1\)\) vy, \(n\/\(n - 1\)\) czy}]\);\)\)], "Input",\

  CellLabel->"In[51]:="],

Cell[BoxData[
    \(\(ExpectedFamilyEffects[{f1_, f2_}, {f3_, f4_}, 
          p_] := \[IndentingNewLine]Module[{\[Zeta]1 = f1 - p, \[Zeta]2 = 
              f2 - p, \[Zeta]3 = f3 - p, \[Zeta]4 = 
              f4 - p}, \[IndentingNewLine]{\[Zeta]1 + \[Zeta]2 + \[Zeta]3 + \
\[Zeta]4, \[IndentingNewLine]\[Zeta]1*\[Zeta]2 + \[Zeta]3*\[Zeta]4, \
\[IndentingNewLine]\((\[Zeta]1 + \[Zeta]2)\) \((\[Zeta]3 + \[Zeta]4)\), \
\[IndentingNewLine]\((\[Zeta]1 + \[Zeta]2)\) \[Zeta]3*\[Zeta]4 + \[Zeta]1*\
\[Zeta]2 \((\[Zeta]3 + \[Zeta]4)\), \[IndentingNewLine]\[Zeta]1*\[Zeta]2*\
\[Zeta]3*\[Zeta]4}];\)\)], "Input",
  CellLabel->"In[7]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{851, 712},
WindowMargins->{{2, Automatic}, {Automatic, -12}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Estimating the matrix"->{
    Cell[1739, 51, 95, 1, 36, "SubsectionIcon",
      CellTags->"Estimating the matrix"]},
  "simple method"->{
    Cell[1859, 56, 73, 1, 24, "SubsubsectionIcon",
      CellTags->"simple method"]},
  "Extension to families"->{
    Cell[6714, 195, 103, 1, 24, "SubsubsectionIcon",
      CellTags->"Extension to families"]},
  "MLE"->{
    Cell[26556, 680, 110, 2, 20, "SubsubsectionIcon",
      CellTags->"MLE"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Estimating the matrix", 46906, 1177},
  {"simple method", 47018, 1180},
  {"Extension to families", 47133, 1183},
  {"MLE", 47240, 1186}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 95, 1, 36, "SubsectionIcon",
  CellTags->"Estimating the matrix"],

Cell[CellGroupData[{
Cell[1859, 56, 73, 1, 24, "SubsubsectionIcon",
  CellTags->"simple method"],
Cell[1935, 59, 3875, 108, 180, "Text"],
Cell[5813, 169, 864, 21, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6714, 195, 103, 1, 24, "SubsubsectionIcon",
  CellTags->"Extension to families"],
Cell[6820, 198, 1098, 24, 66, "Text"],
Cell[7921, 224, 819, 21, 62, "Text"],
Cell[8743, 247, 1288, 21, 233, "NumberedEquation"],
Cell[10034, 270, 50, 1, 22, "Text"],
Cell[10087, 273, 1906, 36, 103, "NumberedEquation"],
Cell[11996, 311, 278, 6, 22, "Text"],
Cell[12277, 319, 464, 7, 50, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[12778, 331, 59, 0, 20, "SubsubsectionIcon"],
Cell[12840, 333, 427, 11, 36, "Text"],
Cell[13270, 346, 2684, 43, 364, "NumberedEquation"],
Cell[15957, 391, 531, 16, 36, "Text"],
Cell[16491, 409, 469, 10, 40, "Text"],
Cell[16963, 421, 992, 20, 142, "NumberedEquation"]
}, Closed]],

Cell[CellGroupData[{
Cell[17992, 446, 48, 0, 20, "SubsubsectionIcon"],
Cell[18043, 448, 45, 0, 22, "Text"],
Cell[18091, 450, 2143, 47, 79, "NumberedEquation"],
Cell[20237, 499, 233, 5, 36, "Text"],
Cell[20473, 506, 68, 2, 22, "Text"],
Cell[20544, 510, 530, 8, 65, "NumberedEquation"],
Cell[21077, 520, 504, 14, 37, "Text"],
Cell[21584, 536, 217, 4, 30, "NumberedEquation"],
Cell[21804, 542, 275, 7, 36, "Text"],
Cell[22082, 551, 1435, 32, 72, "NumberedEquation"],
Cell[23520, 585, 679, 16, 50, "Text"],
Cell[24202, 603, 1821, 59, 95, "Output"],
Cell[26026, 664, 493, 11, 50, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[26556, 680, 110, 2, 20, "SubsubsectionIcon",
  CellTags->"MLE"],
Cell[26669, 684, 1501, 36, 102, "Text"],
Cell[28173, 722, 944, 16, 80, "Text"],
Cell[29120, 740, 136, 3, 22, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[29293, 748, 35, 0, 20, "SubsubsectionIcon"],
Cell[29331, 750, 83, 1, 24, "Text"],

Cell[CellGroupData[{
Cell[29439, 755, 2235, 45, 174, "Input"],
Cell[31677, 802, 872, 22, 20, "Output"]
}, Open  ]],
Cell[32564, 827, 146, 4, 22, "Text"],
Cell[32713, 833, 90, 1, 24, "Text"],

Cell[CellGroupData[{
Cell[32828, 838, 852, 14, 182, "Input"],
Cell[33683, 854, 789, 15, 103, "Output"]
}, Open  ]],
Cell[34487, 872, 88, 1, 24, "Text"],
Cell[34578, 875, 279, 5, 36, "Text"],

Cell[CellGroupData[{
Cell[34882, 884, 1013, 18, 279, "Input"],
Cell[35898, 904, 200, 4, 20, "Print"],
Cell[36101, 910, 823, 17, 69, "Print"],
Cell[36927, 929, 200, 4, 20, "Print"],
Cell[37130, 935, 792, 16, 67, "Print"],
Cell[37925, 953, 200, 4, 20, "Print"],
Cell[38128, 959, 761, 15, 69, "Print"],
Cell[38892, 976, 200, 4, 20, "Print"],
Cell[39095, 982, 802, 16, 67, "Print"],
Cell[39900, 1000, 200, 4, 20, "Print"],
Cell[40103, 1006, 754, 16, 67, "Print"],
Cell[40860, 1024, 200, 4, 20, "Print"],
Cell[41063, 1030, 732, 15, 69, "Print"]
}, Open  ]],
Cell[41810, 1048, 104, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[41939, 1055, 438, 9, 99, "Input"],
Cell[42380, 1066, 840, 17, 79, "Output"]
}, Open  ]],
Cell[43235, 1086, 50, 0, 22, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[43322, 1091, 56, 0, 20, "SubsubsectionIcon"],
Cell[43381, 1093, 88, 2, 26, "Input"],
Cell[43472, 1097, 299, 6, 42, "Input"],
Cell[43774, 1105, 201, 4, 42, "Input"],
Cell[43978, 1111, 236, 5, 42, "Input"],
Cell[44217, 1118, 1184, 22, 192, "Input"],
Cell[45404, 1142, 629, 10, 122, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

