(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     49748,       1011]*)
(*NotebookOutlinePosition[     50981,       1050]*)
(*  CellTagsIndexPosition[     50854,       1043]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Fast calculation of genotype frequencies from a matrix of moments\
\
\>", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(DiploidGenotypeFrequencyList[{p\_1, \[Ellipsis], 
                p\_n}, {{c\_\(0, 0\), \[Ellipsis]c\_\(0, n\)}, \
\[Ellipsis]}]\), \(calculates\ the\ matrix\ of\ 2\^n\[Times]\ 
              2\^n\ genotype\ frequnecies\ from\ the\ allele\ frequencies\ \
and\ a\ matrix\ of\ moments, \ assuming\ \[Delta]p = 1. \)},
          {\(DiploidGenotypeFrequencyList[{p\_1, \[Ellipsis]p\_n}, {\[Delta]p\
\_1, \[Ellipsis]\[Delta]p\_n}, \ {{c\_\(0, 0\), \[Ellipsis]c\_\(0, n\)}, \
\[Ellipsis]}]\), \(calculates\ the\ matrix\ of\ 2\^n\[Times]\ 
              2\^n\ genotype\ frequnecies\ from\ the\ allele\ frequencies\ \
and\ a\ matrix\ of\ \(\(moments\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"DiploidGenotypeFrequencyList"],

Cell[TextData[{
  "Suppose that the within- and between-genome moments are represented as ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(j, k\)\)]],
  ", where a set of ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " loci come from one genome, and ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "  loci from the other.  Necessarily, ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(0, 0\) = 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(0, 1\) = \(c\_\(0, 1\) = 0\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(j, k\) = c\_\(k, j\)\)]],
  ".  The moments can then be represented by a matrix, indexed from 0\
\[Ellipsis]n.  The simplest matrix is for a population in Hardy-Weinberg \
proportions and linkage equilibrium.  "
}], "Text"],

Cell["For four loci:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cc = Array[0&, {5, 5}]; 
    cc\[LeftDoubleBracket]1, 1\[RightDoubleBracket] = 1; cc // MatrixForm\)], 
  "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[3]//MatrixForm="]
}, Closed]],

Cell[TextData[{
  "These are the ",
  Cell[BoxData[
      \(TraditionalForm\`2\^4\[Times]2\^4\)]],
  "genotype frequencies for a population with allele frequencies ",
  "{0.2, 0.3, 0.4, 0.5}, and in HWLE:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{
        FormBox["DiploidGenotypeFrequencyList",
          "TraditionalForm"], "[", \({0.2, 0.3, 0.4, 0.5}, cc\), "]"}]}]], 
  "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \({{0.0282239999999999913`, 0.0282239999999999913`, 
        0.0188159999999999971`, 0.0188159999999999971`, 
        0.0120959999999999978`, 0.0120959999999999978`, 
        0.00806400000000000005`, 0.00806400000000000005`, 
        0.00705599999999999738`, 0.00705599999999999738`, 
        0.00470399999999999884`, 0.00470399999999999884`, 
        0.00302399999999999957`, 0.00302399999999999957`, 
        0.00201600000000000001`, 0.00201600000000000001`}, {
        0.0282239999999999913`, 0.0282239999999999913`, 
        0.0188159999999999971`, 0.0188159999999999971`, 
        0.0120959999999999978`, 0.0120959999999999978`, 
        0.00806400000000000005`, 0.00806400000000000005`, 
        0.00705599999999999738`, 0.00705599999999999738`, 
        0.00470399999999999884`, 0.00470399999999999884`, 
        0.00302399999999999957`, 0.00302399999999999957`, 
        0.00201600000000000001`, 0.00201600000000000001`}, {
        0.0188159999999999971`, 0.0188159999999999971`, 
        0.0125439999999999973`, 0.0125439999999999973`, 
        0.00806399999999999828`, 0.00806399999999999828`, 
        0.00537599999999999944`, 0.00537599999999999944`, 
        0.00470399999999999884`, 0.00470399999999999884`, 
        0.00313599999999999923`, 0.00313599999999999923`, 
        0.00201599999999999957`, 0.00201599999999999957`, 
        0.00134399999999999986`, 0.00134399999999999986`}, {
        0.0188159999999999971`, 0.0188159999999999971`, 
        0.0125439999999999973`, 0.0125439999999999973`, 
        0.00806399999999999828`, 0.00806399999999999828`, 
        0.00537599999999999944`, 0.00537599999999999944`, 
        0.00470399999999999884`, 0.00470399999999999884`, 
        0.00313599999999999923`, 0.00313599999999999923`, 
        0.00201599999999999957`, 0.00201599999999999957`, 
        0.00134399999999999986`, 0.00134399999999999986`}, {
        0.0120959999999999978`, 0.0120959999999999978`, 
        0.00806399999999999828`, 0.00806399999999999828`, 
        0.00518399999999999927`, 0.00518399999999999927`, 
        0.0034560000000000004`, 0.0034560000000000004`, 
        0.00302399999999999957`, 0.00302399999999999957`, 
        0.00201599999999999957`, 0.00201599999999999957`, 
        0.00129599999999999981`, 0.00129599999999999981`, 
        0.000864000000000000056`, 0.000864000000000000056`}, {
        0.0120959999999999978`, 0.0120959999999999978`, 
        0.00806399999999999828`, 0.00806399999999999828`, 
        0.00518399999999999927`, 0.00518399999999999927`, 
        0.0034560000000000004`, 0.0034560000000000004`, 
        0.00302399999999999957`, 0.00302399999999999957`, 
        0.00201599999999999957`, 0.00201599999999999957`, 
        0.00129599999999999981`, 0.00129599999999999981`, 
        0.000864000000000000056`, 0.000864000000000000056`}, {
        0.00806400000000000005`, 0.00806400000000000005`, 
        0.00537599999999999944`, 0.00537599999999999944`, 
        0.0034560000000000004`, 0.0034560000000000004`, 
        0.00230400000000000027`, 0.00230400000000000027`, 
        0.00201600000000000001`, 0.00201600000000000001`, 
        0.00134399999999999986`, 0.00134399999999999986`, 
        0.000864000000000000056`, 0.000864000000000000056`, 
        0.000576000000000000067`, 0.000576000000000000067`}, {
        0.00806400000000000005`, 0.00806400000000000005`, 
        0.00537599999999999944`, 0.00537599999999999944`, 
        0.0034560000000000004`, 0.0034560000000000004`, 
        0.00230400000000000027`, 0.00230400000000000027`, 
        0.00201600000000000001`, 0.00201600000000000001`, 
        0.00134399999999999986`, 0.00134399999999999986`, 
        0.000864000000000000056`, 0.000864000000000000056`, 
        0.000576000000000000067`, 0.000576000000000000067`}, {
        0.00705599999999999738`, 0.00705599999999999738`, 
        0.00470399999999999884`, 0.00470399999999999884`, 
        0.00302399999999999957`, 0.00302399999999999957`, 
        0.00201600000000000001`, 0.00201600000000000001`, 
        0.00176399999999999934`, 0.00176399999999999934`, 
        0.00117599999999999971`, 0.00117599999999999971`, 
        0.000755999999999999872`, 0.000755999999999999872`, 
        0.000504000000000000003`, 0.000504000000000000003`}, {
        0.00705599999999999738`, 0.00705599999999999738`, 
        0.00470399999999999884`, 0.00470399999999999884`, 
        0.00302399999999999957`, 0.00302399999999999957`, 
        0.00201600000000000001`, 0.00201600000000000001`, 
        0.00176399999999999934`, 0.00176399999999999934`, 
        0.00117599999999999971`, 0.00117599999999999971`, 
        0.000755999999999999872`, 0.000755999999999999872`, 
        0.000504000000000000003`, 0.000504000000000000003`}, {
        0.00470399999999999884`, 0.00470399999999999884`, 
        0.00313599999999999923`, 0.00313599999999999923`, 
        0.00201599999999999957`, 0.00201599999999999957`, 
        0.00134399999999999986`, 0.00134399999999999986`, 
        0.00117599999999999971`, 0.00117599999999999971`, 
        0.000783999999999999808`, 0.000783999999999999808`, 
        0.000503999999999999914`, 0.000503999999999999914`, 
        0.000335999999999999943`, 0.000335999999999999943`}, {
        0.00470399999999999884`, 0.00470399999999999884`, 
        0.00313599999999999923`, 0.00313599999999999923`, 
        0.00201599999999999957`, 0.00201599999999999957`, 
        0.00134399999999999986`, 0.00134399999999999986`, 
        0.00117599999999999971`, 0.00117599999999999971`, 
        0.000783999999999999808`, 0.000783999999999999808`, 
        0.000503999999999999914`, 0.000503999999999999914`, 
        0.000335999999999999943`, 0.000335999999999999943`}, {
        0.00302399999999999957`, 0.00302399999999999957`, 
        0.00201599999999999957`, 0.00201599999999999957`, 
        0.00129599999999999981`, 0.00129599999999999981`, 
        0.000864000000000000056`, 0.000864000000000000056`, 
        0.000755999999999999872`, 0.000755999999999999872`, 
        0.000503999999999999914`, 0.000503999999999999914`, 
        0.000323999999999999932`, 0.000323999999999999932`, 
        0.000216000000000000014`, 0.000216000000000000014`}, {
        0.00302399999999999957`, 0.00302399999999999957`, 
        0.00201599999999999957`, 0.00201599999999999957`, 
        0.00129599999999999981`, 0.00129599999999999981`, 
        0.000864000000000000056`, 0.000864000000000000056`, 
        0.000755999999999999872`, 0.000755999999999999872`, 
        0.000503999999999999914`, 0.000503999999999999914`, 
        0.000323999999999999932`, 0.000323999999999999932`, 
        0.000216000000000000014`, 0.000216000000000000014`}, {
        0.00201600000000000001`, 0.00201600000000000001`, 
        0.00134399999999999986`, 0.00134399999999999986`, 
        0.000864000000000000056`, 0.000864000000000000056`, 
        0.000576000000000000067`, 0.000576000000000000067`, 
        0.000504000000000000003`, 0.000504000000000000003`, 
        0.000335999999999999943`, 0.000335999999999999943`, 
        0.000216000000000000014`, 0.000216000000000000014`, 
        0.000144000000000000021`, 0.000144000000000000021`}, {
        0.00201600000000000001`, 0.00201600000000000001`, 
        0.00134399999999999986`, 0.00134399999999999986`, 
        0.000864000000000000056`, 0.000864000000000000056`, 
        0.000576000000000000067`, 0.000576000000000000067`, 
        0.000504000000000000003`, 0.000504000000000000003`, 
        0.000335999999999999943`, 0.000335999999999999943`, 
        0.000216000000000000014`, 0.000216000000000000014`, 
        0.000144000000000000021`, 0.000144000000000000021`}}\)], "Output",
  CellLabel->"Out[22]="]
}, Closed]],

Cell[TextData[{
  "GenotypeFrequencyConvert[] converts the ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\[Times]2\^n\)]],
  "matrix of genotype frequencies to the ",
  Cell[BoxData[
      \(TraditionalForm\`3\^\(\(n\)\(\ \ \)\)\)]],
  "observable diploid genotypes:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GenotypeFrequencyConvert[%, 4]\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \({0.0282239999999999913`, 0.0564479999999999826`, 
      0.0282239999999999913`, 0.0376319999999999943`, 0.0752639999999999886`, 
      0.0376319999999999943`, 0.0125439999999999973`, 0.0250879999999999947`, 
      0.0125439999999999973`, 0.0241919999999999957`, 0.0483839999999999914`, 
      0.0241919999999999957`, 0.0322559999999999957`, 0.0645119999999999915`, 
      0.0322559999999999957`, 0.0107519999999999993`, 0.0215039999999999986`, 
      0.0107519999999999993`, 0.00518399999999999927`, 
      0.0103679999999999994`, 0.00518399999999999927`, 
      0.00691200000000000081`, 0.0138240000000000007`, 
      0.00691200000000000081`, 0.00230400000000000027`, 
      0.00460800000000000054`, 0.00230400000000000027`, 
      0.0141119999999999956`, 0.0282239999999999913`, 0.0141119999999999956`, 
      0.0188159999999999971`, 0.0376319999999999943`, 0.0188159999999999971`, 
      0.00627199999999999846`, 0.0125439999999999973`, 
      0.00627199999999999846`, 0.0120959999999999978`, 
      0.0241919999999999957`, 0.0120959999999999978`, 0.0161279999999999983`, 
      0.0322560000000000002`, 0.0161279999999999983`, 
      0.00537599999999999944`, 0.0107519999999999993`, 
      0.00537599999999999944`, 0.00259199999999999963`, 
      0.00518399999999999927`, 0.00259199999999999963`, 
      0.0034560000000000004`, 0.00691200000000000081`, 
      0.0034560000000000004`, 0.00115200000000000013`, 
      0.00230400000000000027`, 0.00115200000000000013`, 
      0.00176399999999999934`, 0.00352799999999999869`, 
      0.00176399999999999934`, 0.00235199999999999942`, 
      0.00470399999999999884`, 0.00235199999999999942`, 
      0.000783999999999999808`, 0.00156799999999999961`, 
      0.000783999999999999808`, 0.00151199999999999974`, 
      0.00302399999999999957`, 0.00151199999999999974`, 
      0.00201599999999999957`, 0.00403199999999999914`, 
      0.00201599999999999957`, 0.000671999999999999886`, 
      0.00134399999999999986`, 0.000671999999999999886`, 
      0.000323999999999999932`, 0.000647999999999999864`, 
      0.000323999999999999932`, 0.000432000000000000028`, 
      0.000864000000000000056`, 0.000432000000000000028`, 
      0.000144000000000000021`, 0.000288000000000000042`, 
      0.000144000000000000021`}\)], "Output",
  CellLabel->"Out[39]="]
}, Closed]],

Cell[TextData[{
  "In general, the effect of each locus can be scaled by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]p\_i\)]],
  "; in admixture models, \[Delta]p represents the divergence in alelle \
frequency between source demes.  The divergence can be given explicitly by \
calling DiploidGenotypeFrequencyList[p,\[Delta]p,c].  "
}], "Text"],

Cell[TextData[{
  "This example is for 3 loci with allele frequencies {0.2, 0.3, 0.4}, \
divergence {0.9, 0.3,0 0.8}, and pairwise associations ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(1, 1\) = 0.01, \ 
      c\_\(0, 2\) = \(c\_\(2, 0\) = 0.02\)\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{
        RowBox[{
          FormBox["DiploidGenotypeFrequencyList",
            "TraditionalForm"], "[", 
          RowBox[{\({0.2, 0.3, 0.4}\), ",", \({0.9, 0.3, 0.8}\), ",", 
            RowBox[{"(", GridBox[{
                  {"1", "0", "0.02", "0"},
                  {"0", "0.01", "0", "0"},
                  {"0.02", "0", "0", "0"},
                  {"0", "0", "0", "0"}
                  }], ")"}]}], "]"}], "//", "MatrixForm"}]}]], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0.133836519999999992`", "0.0741864799999999924`", 
              "0.0519646799999999853`", "0.0312703200000000069`", 
              "0.0232814799999999921`", "0.0188175199999999982`", 
              "0.0105733199999999971`", "0.00922968000000000188`"},
            {"0.0741864799999999924`", "0.0450075199999999853`", 
              "0.0297343199999999985`", "0.01996368`", 
              "0.0152895199999999986`", "0.0137844799999999967`", 
              "0.00733367999999999753`", "0.00694031999999999982`"},
            {"0.0519646799999999853`", "0.0297343199999999896`", 
              "0.0203821199999999969`", "0.0128008799999999967`", 
              "0.00960131999999999763`", "0.0081976799999999983`", 
              "0.0044758799999999983`", "0.00408311999999999919`"},
            {"0.0312703199999999892`", "0.0199636799999999965`", 
              "0.0128008799999999967`", "0.00903311999999999848`", 
              "0.00706967999999999818`", "0.00650831999999999943`", 
              "0.0034351199999999995`", "0.00327888000000000001`"},
            {"0.0232814799999999921`", "0.0152895199999999986`", 
              "0.00960131999999999763`", "0.00706967999999999996`", 
              "0.00550851999999999897`", "0.00537847999999999881`", 
              "0.0027526799999999989`", "0.00275831999999999943`"},
            {"0.0188175199999999911`", "0.0137844799999999922`", 
              "0.0081976799999999983`", "0.00650831999999999943`", 
              "0.00537847999999999792`", "0.0050715199999999978`", 
              "0.00266231999999999979`", "0.00253967999999999927`"},
            {"0.0105733199999999993`", "0.00733367999999999753`", 
              "0.0044758799999999983`", "0.00343511999999999995`", 
              "0.00275267999999999979`", "0.00266231999999999935`", 
              "0.00137411999999999978`", "0.00135287999999999963`"},
            {"0.00922968000000000188`", "0.00694031999999999982`", 
              "0.00408312000000000008`", "0.00327888000000000001`", 
              "0.00275831999999999943`", "0.00253967999999999971`", 
              "0.00135287999999999986`", "0.00125712000000000023`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[8]//MatrixForm="]
}, Closed]],

Cell["\<\
DiploidGenotypeFrequencyList[] can give symbolic expressions.  This \
shows the frequency of genotype {{0,0,0},{0,0,0}}:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{
        RowBox[{
          RowBox[{
            FormBox["DiploidGenotypeFrequencyList",
              "TraditionalForm"], "[", 
            RowBox[{
            \({p\_1, p\_2, p\_3}\), ",", 
              \({\[Delta]p\_1, \[Delta]p\_2, \[Delta]p\_3}\), ",", 
              RowBox[{"(", GridBox[{
                    {"1", "0", \(c\_\(0, 2\)\), \(c\_\(0, 3\)\)},
                    {"0", \(c\_\(1, 1\)\), \(c\_\(1, 2\)\), \(c\_\(1, 3\)\)},
                    {\(c\_\(2, 0\)\), \(c\_\(2, 1\)\), \(c\_\(2, 2\)\), 
                      \(c\_\(2, 3\)\)},
                    {\(c\_\(3, 0\)\), \(c\_\(3, 1\)\), \(c\_\(3, 2\)\), 
                      \(c\_\(3, 3\)\)}
                    }], ")"}]}], "]"}], "\[LeftDoubleBracket]", \(1, 1\), 
          "\[RightDoubleBracket]"}], "/.", \({1 - p\_i_ :> q\_i}\)}]}]], 
  "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \(q\_1\ q\_2\ q\_3\ 
        \((q\_1\ q\_2\ q\_3 + \ 
            \((\[Delta]p\_1\ \(\[Delta]p\_2\) q\_3 + 
                  \(\[Delta]p\_1\) q\_2\ \[Delta]p\_3 + 
                  \(q\_1\) \[Delta]p\_2\ \[Delta]p\_3)\)\ c\_\(2, 0\) - 
            \[Delta]p\_1\ \[Delta]p\_2\ \[Delta]p\_3\ c\_\(3, 0\))\) - 
      \((\(\[Delta]p\_1\) q\_2\ q\_3 + \(q\_1\) \(\[Delta]p\_2\) q\_3 + 
            q\_1\ \(q\_2\) \[Delta]p\_3)\)\ 
        \((\(-\ \((
                  \(\[Delta]p\_1\) q\_2\ q\_3 + \(q\_1\) \[Delta]p\_2\ q\_3 + 
                    q\_1\ \(q\_2\) \[Delta]p\_3)\)\)\ c\_\(1, 1\) + \ 
            \((\[Delta]p\_1\ \(\[Delta]p\_2\) q\_3 + 
                  \(\[Delta]p\_1\) q\_2\ \[Delta]p\_3 + 
                  \(q\_1\) \[Delta]p\_2\ \[Delta]p\_3)\)\ c\_\(2, 1\) - 
            \[Delta]p\_1\ \[Delta]p\_2\ \[Delta]p\_3\ c\_\(3, 1\))\) + \ 
      \((\[Delta]p\_1\ \(\[Delta]p\_2\) q\_3 + 
            \[Delta]p\_1\ \(q\_2\) \[Delta]p\_3 + 
            \(q\_1\) \[Delta]p\_2\ \[Delta]p\_3)\)\ 
        \((q\_1\ q\_2\ q\_3\ c\_\(0, 2\) - \ 
            \((\(\[Delta]p\_1\) q\_2\ q\_3 + 
                  \(q\_1\) \(\[Delta]p\_2\) q\_3\  + 
                  q\_1\ \(q\_2\) \[Delta]p\_3)\)\ c\_\(1, 2\) + \ 
            \((\[Delta]p\_1\ \(\[Delta]p\_2\) q\_3 + 
                  \[Delta]p\_1\ \(q\_2\) \[Delta]p\_3 + 
                  \(q\_1\) \[Delta]p\_2\ \[Delta]p\_3)\)\ c\_\(2, 2\) - 
            \[Delta]p\_1\ \[Delta]p\_2\ \[Delta]p\_3\ c\_\(3, 2\))\) - 
      \[Delta]p\_1\ \[Delta]p\_2\ \[Delta]p\_3\ 
        \((q\_1\ q\_2\ q\_3\ c\_\(0, 3\) - \ 
            \((\(\[Delta]p\_1\) q\_2\ q\_3 + \(q\_1\) \[Delta]p\_2\ q\_3 + 
                  q\_1\ \(q\_2\) \[Delta]p\_3)\)\ c\_\(1, 3\) + \ 
            \((\[Delta]p\_1\ \(\[Delta]p\_2\) q\_3 + 
                  \[Delta]p\_1\ \(q\_2\) \[Delta]p\_3 + 
                  \(q\_1\) \[Delta]p\_2\ \[Delta]p\_3)\)\ c\_\(2, 3\) - 
            \[Delta]p\_1\ \[Delta]p\_2\ \[Delta]p\_3\ c\_\(3, 3\))\)\)], 
  "Output",
  CellLabel->"Out[19]="]
}, Closed]],

Cell[TextData[{
  "DiploidGenotypeFrequencyList[] calculates ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma] . c . \[CapitalGamma]\^T\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is the matrix of moments, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\)]],
  " is a matrix of permuted allele frequencies, calculated by Matrix\
\[CapitalGamma][].  If male and female gamete pools difer, this generalises \
to ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma] . c . \[CapitalGamma]\^\(*T\)\)]],
  ", where \[CapitalGamma] is calculated from the female allele frequencies & \
divergences, and \[CapitalGamma] from the male allele frequencies & \
divergences."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            \(DiploidGenotypeFrequencyList[{{p\_1, \[Ellipsis], p\_n}, {
                  \(p\_1\%*\), \(\[Ellipsis]p\_n\%*\)}}, 
              \ {{\[Delta]p\_1, \[Ellipsis], \[Delta]p\_n}, {
                  \(\[Delta]p\_1\%*\), \(\[Ellipsis]\[Delta]p\_n\%*\)}}, {{
                  c\_\(0, 0\), \[Ellipsis]c\_\(0, n\)}, \[Ellipsis]}, \ 
              Symmetric \[Rule] False]\), 
            \(allows\ for\ different\ allele\ frequencies\ and\ divergences\ 
              in\ the\ female\ and\ male\ gamete\ \(pools . \)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{
        RowBox[{
          FormBox["DiploidGenotypeFrequencyList",
            "TraditionalForm"], "[", 
          RowBox[{
          \({{0.2, 0.3, 0.4}, {0.3, 0.2, 0.4}}\), ",", 
            \({{0.9, 0.3, 0.8}, {1, 1, 1}}\), ",", 
            RowBox[{"(", GridBox[{
                  {"1", "0", "0.02", "0"},
                  {"0", "0.01", "0", "0"},
                  {"0.03", "0", "0", "0"},
                  {"0", "0", "0", "0"}
                  }], ")"}], ",", \(Symmetric \[Rule] False\)}], "]"}], "//", 
        "MatrixForm"}]}]], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0.149818639999999936`", "0.0740257599999999804`", 
              "0.0214421599999999923`", "0.017631439999999996`", 
              "0.0441165599999999891`", "0.0311310399999999942`", 
              "0.0113666399999999967`", "0.0122077599999999986`"},
            {"0.0772849599999999803`", "0.0412566399999999866`", 
              "0.0125662399999999996`", "0.0123441599999999995`", 
              "0.0248478399999999988`", "0.0206985599999999969`", 
              "0.00811695999999999884`", "0.00924463999999999863`"},
            {"0.0561069599999999901`", "0.0282446399999999933`", 
              "0.00824424000000000134`", "0.00740615999999999718`", 
              "0.0168458399999999963`", "0.0127905600000000019`", 
              "0.0048189599999999988`", "0.00540263999999999988`"},
            {"0.0323294399999999937`", "0.0184329599999999977`", 
              "0.00590735999999999705`", "0.0059582399999999982`", 
              "0.0112497599999999997`", "0.00981983999999999745`", 
              "0.0039374399999999996`", "0.00440495999999999998`"},
            {"0.0221645599999999953`", "0.0127230399999999965`", 
              "0.00401863999999999776`", "0.00461575999999999897`", 
              "0.00771623999999999643`", "0.00746415999999999879`", 
              "0.00307655999999999929`", "0.00368103999999999942`"},
            {"0.0197118399999999951`", "0.0135145599999999976`", 
              "0.00489296000000000042`", "0.00498863999999999929`", 
              "0.00853935999999999673`", "0.00798624000000000044`", 
              "0.00331983999999999923`", "0.00348655999999999988`"},
            {"0.0103898399999999968`", "0.00652655999999999814`", 
              "0.00221495999999999915`", "0.00242663999999999946`", 
              "0.00404135999999999917`", "0.00389423999999999956`", 
              "0.00161783999999999945`", "0.00182855999999999951`"},
            {"0.0101937599999999983`", "0.00727583999999999875`", 
              "0.00271343999999999985`", "0.00262895999999999974`", 
              "0.00464303999999999916`", "0.00421536000000000043`", 
              "0.00174575999999999957`", "0.00174383999999999979`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[29]//MatrixForm="]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            \(\(DiploidGenotypeFrequencyList[n]\)[{p\_1, \[Ellipsis]p\_n}, {
                \[Delta]p\_1, \[Ellipsis]\[Delta]p\_n}, 
              \ {{c\_\(0, 0\), \[Ellipsis]c\_\(0, n\)}, \[Ellipsis]}]\), 
            \(is\ a\ compiled\ \(version . \)\)},
          {
            \(\(DiploidGenotypeFrequencyList[n, \ Symmetric \[Rule] False]
                \)[{{p\_1, \[Ellipsis], p\_n}, {\(p\_1\%*\), 
                  \(\[Ellipsis]p\_n\%*\)}}, 
              \ {{\[Delta]p\_1, \[Ellipsis], \[Delta]p\_n}, {\ 
                  \(\[Delta]p\_1\%*\), \(\[Ellipsis]\[Delta]p\_n\%*\)}}, {{
                  c\_\(0, 0\), \[Ellipsis]c\_\(0, n\)}, \[Ellipsis]}]\), 
            \(is\ a\ compiled\ version\ which\ allows\ for\ different\ allele
              \ frequencies\ and\ divergences\ in\ the\ female\ and\ male\ 
              gamete\ \(pools . \)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["The compiled version is considerably faster:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{\(DiploidGenotypeFrequencyList[3]\), "[", 
        RowBox[{\({0.2, 0.3, 0.4}\), ",", \({0.9, 0.3, 0.8}\), ",", 
          RowBox[{"(", GridBox[{
                {"1", "0", "0.02", "0"},
                {"0", "0.01", "0", "0"},
                {"0.02", "0", "0", "0"},
                {"0", "0", "0", "0"}
                }], ")"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \({0.0166666666666515084`\ 
        Second, {{0.133836519999999992`, 0.0741864799999999924`, 
          0.0519646799999999853`, 0.0312703200000000069`, 
          0.0232814799999999921`, 0.0188175199999999982`, 
          0.0105733199999999971`, 0.00922968000000000188`}, {
          0.0741864799999999924`, 0.0450075199999999853`, 
          0.0297343199999999985`, 0.01996368`, 0.0152895199999999942`, 
          0.0137844799999999967`, 0.00733367999999999753`, 
          0.00694031999999999982`}, {0.0519646799999999853`, 
          0.0297343199999999896`, 0.0203821199999999969`, 
          0.0128008799999999967`, 0.00960131999999999763`, 
          0.00819767999999999652`, 0.0044758799999999983`, 
          0.00408311999999999919`}, {0.0312703199999999892`, 
          0.0199636799999999965`, 0.0128008799999999967`, 
          0.00903311999999999848`, 0.00706967999999999818`, 
          0.00650831999999999855`, 0.0034351199999999995`, 
          0.00327888000000000001`}, {0.0232814799999999921`, 
          0.0152895199999999986`, 0.00960131999999999763`, 
          0.00706967999999999996`, 0.00550851999999999897`, 
          0.00537847999999999881`, 0.0027526799999999989`, 
          0.00275831999999999943`}, {0.0188175199999999911`, 
          0.0137844799999999922`, 0.0081976799999999983`, 
          0.00650831999999999943`, 0.00537847999999999792`, 
          0.00507151999999999691`, 0.00266231999999999935`, 
          0.00253967999999999927`}, {0.0105733199999999993`, 
          0.00733367999999999753`, 0.0044758799999999983`, 
          0.00343511999999999995`, 0.00275267999999999979`, 
          0.00266231999999999935`, 0.00137411999999999956`, 
          0.00135287999999999963`}, {0.00922968000000000188`, 
          0.00694031999999999982`, 0.00408312000000000008`, 
          0.00327888000000000001`, 0.00275831999999999943`, 
          0.00253967999999999971`, 0.00135287999999999986`, 
          0.00125712000000000023`}}}\)], "Output",
  CellLabel->"Out[22]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", 
      RowBox[{"DiploidGenotypeFrequencyList", "[", 
        RowBox[{\({0.2, 0.3, 0.4}\), ",", \({0.9, 0.3, 0.8}\), ",", 
          RowBox[{"(", GridBox[{
                {"1", "0", "0.02", "0"},
                {"0", "0.01", "0", "0"},
                {"0.02", "0", "0", "0"},
                {"0", "0", "0", "0"}
                }], ")"}]}], "]"}], "]"}]], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \({0.0833333333334849157`\ 
        Second, {{0.133836519999999992`, 0.0741864799999999924`, 
          0.0519646799999999853`, 0.0312703200000000069`, 
          0.0232814799999999921`, 0.0188175199999999982`, 
          0.0105733199999999971`, 0.00922968000000000188`}, {
          0.0741864799999999924`, 0.0450075199999999853`, 
          0.0297343199999999985`, 0.01996368`, 0.0152895199999999986`, 
          0.0137844799999999967`, 0.00733367999999999753`, 
          0.00694031999999999982`}, {0.0519646799999999853`, 
          0.0297343199999999896`, 0.0203821199999999969`, 
          0.0128008799999999967`, 0.00960131999999999763`, 
          0.0081976799999999983`, 0.0044758799999999983`, 
          0.00408311999999999919`}, {0.0312703199999999892`, 
          0.0199636799999999965`, 0.0128008799999999967`, 
          0.00903311999999999848`, 0.00706967999999999818`, 
          0.00650831999999999943`, 0.0034351199999999995`, 
          0.00327888000000000001`}, {0.0232814799999999921`, 
          0.0152895199999999986`, 0.00960131999999999763`, 
          0.00706967999999999996`, 0.00550851999999999897`, 
          0.00537847999999999881`, 0.0027526799999999989`, 
          0.00275831999999999943`}, {0.0188175199999999911`, 
          0.0137844799999999922`, 0.0081976799999999983`, 
          0.00650831999999999943`, 0.00537847999999999792`, 
          0.0050715199999999978`, 0.00266231999999999979`, 
          0.00253967999999999927`}, {0.0105733199999999993`, 
          0.00733367999999999753`, 0.0044758799999999983`, 
          0.00343511999999999995`, 0.00275267999999999979`, 
          0.00266231999999999935`, 0.00137411999999999978`, 
          0.00135287999999999963`}, {0.00922968000000000188`, 
          0.00694031999999999982`, 0.00408312000000000008`, 
          0.00327888000000000001`, 0.00275831999999999943`, 
          0.00253967999999999971`, 0.00135287999999999986`, 
          0.00125712000000000023`}}}\)], "Output",
  CellLabel->"Out[23]="]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(Matrix\[CapitalGamma][{\(p\_1\) \[Ellipsis]}, {\[Delta]p\_1, \
\[Ellipsis]}, 
              n]\), \(gives\ the\ matrix\ of\ coefficients\ for\ the\ \
moments; \ Matrix\[CapitalGamma] . c . Matrix\[CapitalGamma]\^\(\(*\)\(T\)\) 
              is\ the\ matrix\ of\ diploid\ genotype\ \
\(\(frequencies\)\(.\)\)\)},
          {\(Matrix\[CapitalGamma][{\(p\_1\) \[Ellipsis]}, 
              n]\), \(assumes\ \[Delta]p = 1. \)},
          {\(\(Matrix\[CapitalGamma][
                n]\)[{\(p\_1\) \[Ellipsis]}, {\[Delta]p\_1, \[Ellipsis]}]\), \
\(is\ a\ compiled\ \(\(version\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"MatrixGamma"],

Cell["\<\
This matrix is calculated from the allele frequencies.  It is used \
by DiploidGenotypeFrequencyList[], LogLikelihoodDisequilibrium[], and other \
functions, to construct the table of genotype frequencies:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\ Matrix\[CapitalGamma][{0.2, 0.3, 0.4}, {1, 1, 1}, 3] // MatrixForm
      \)\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0.335999999999999943`", \(-1.45999999999999996`\), 
              "2.10000000000000053`", \(-1.00000000000000088`\)},
            {"0.223999999999999976`", \(-0.0400000000000000444`\), 
              \(-1.09999999999999985`\), "1.00000000000000022`"},
            {"0.143999999999999994`", "0.0600000000000000088`", 
              \(-1.10000000000000008`\), "1.`"},
            {"0.0959999999999999964`", "0.440000000000000035`", 
              "0.100000000000000111`", \(-0.999999999999999822`\)},
            {"0.0839999999999999857`", "0.159999999999999946`", 
              \(-1.10000000000000008`\), "0.999999999999999644`"},
            {"0.0559999999999999964`", "0.339999999999999946`", 
              "0.0999999999999997335`", \(-1.00000000000000111`\)},
            {"0.0359999999999999964`", "0.239999999999999991`", 
              "0.100000000000000022`", \(-0.999999999999999644`\)},
            {"0.0239999999999999991`", "0.260000000000000008`", 
              "0.900000000000000177`", "1.00000000000000066`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[18]//MatrixForm="]
}, Closed]],

Cell["\<\
The default assumption is to assume that \[Delta]p=1:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\ Matrix\[CapitalGamma][{0.2, 0.3, 0.4}, 3] // MatrixForm\)\)], 
  "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0.335999999999999943`", \(-1.45999999999999996`\), 
              "2.10000000000000053`", \(-1.00000000000000088`\)},
            {"0.223999999999999976`", \(-0.0400000000000000444`\), 
              \(-1.09999999999999985`\), "1.00000000000000022`"},
            {"0.143999999999999994`", "0.0600000000000000088`", 
              \(-1.10000000000000008`\), "1.`"},
            {"0.0959999999999999964`", "0.440000000000000035`", 
              "0.100000000000000111`", \(-0.999999999999999822`\)},
            {"0.0839999999999999857`", "0.159999999999999946`", 
              \(-1.10000000000000008`\), "0.999999999999999644`"},
            {"0.0559999999999999964`", "0.339999999999999946`", 
              "0.0999999999999997335`", \(-1.00000000000000111`\)},
            {"0.0359999999999999964`", "0.239999999999999991`", 
              "0.100000000000000022`", \(-0.999999999999999644`\)},
            {"0.0239999999999999991`", "0.260000000000000008`", 
              "0.900000000000000177`", "1.00000000000000066`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[19]//MatrixForm="]
}, Closed]],

Cell["This is a compiled version, which is much faster:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\ Timing[
      \(\(Matrix\[CapitalGamma][5]\)[{0.2, 0.3, 0.4, 0.5, 0.6}, {1, 1, 1, 1, 
              1}] // Chop\) // MatrixForm]\)\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(0.0500000000001818989`\ Second\), ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.0671999999999999886`", \(-0.594399999999999906`\), 
                  "2.06999999999999939`", \(-3.54999999999999893`\), 
                  "2.99999999999999857`", \(-0.999999999999997157`\)},
                {"0.100799999999999978`", \(-0.47159999999999993`\), 
                  "0.440000000000000035`", "0.95`", \(-2.`\), 
                  "1.00000000000000222`"},
                {"0.0671999999999999886`", \(-0.325600000000000022`\), 
                  "0.230000000000000204`", "1.0499999999999996`", 
                  \(-2.00000000000000044`\), "1.00000000000000133`"},
                {"0.100799999999999978`", \(-0.0684000000000000341`\), 
                  \(-0.640000000000000035`\), "0.550000000000000266`", 
                  "0.999999999999999822`", \(-0.999999999999999822`\)},
                {"0.0448000000000000042`", \(-0.209600000000000008`\), 
                  "0.0400000000000001332`", "1.14999999999999968`", \(-2.`\), 
                  "1.00000000000000266`"},
                {"0.0671999999999999886`", \(-0.0344000000000000083`\), 
                  \(-0.549999999999999911`\), "0.450000000000000088`", 
                  "0.999999999999999111`", \(-0.999999999999999644`\)},
                {"0.0448000000000000042`", \(-0.0304000000000000092`\), 
                  \(-0.439999999999999857`\), "0.350000000000000088`", 
                  "0.999999999999999467`", \(-0.999999999999999822`\)},
                {"0.0671999999999999886`", "0.234399999999999986`", 
                  \(-0.149999999999999911`\), \(-0.949999999999999644`\), 
                  "0", "0.999999999999998223`"},
                {"0.0287999999999999989`", \(-0.117599999999999971`\), 
                  \(-0.130000000000000115`\), "1.25000000000000022`", 
                  \(-1.99999999999999964`\), "0.999999999999999644`"},
                {"0.0431999999999999939`", "0.00360000000000000586`", 
                  \(-0.480000000000000071`\), "0.349999999999999911`", 
                  "1.00000000000000044`", \(-1.00000000000000088`\)},
                {"0.0287999999999999989`", \(-0.00239999999999999147`\), 
                  \(-0.370000000000000062`\), "0.25`", 
                  "0.999999999999999822`", \(-1.00000000000000088`\)},
                {"0.0431999999999999939`", "0.176400000000000005`", 
                  \(-0.120000000000000017`\), \(-0.85`\), "0", 
                  "0.999999999999998401`"},
                {"0.0191999999999999992`", "0.00160000000000001136`", 
                  \(-0.280000000000000071`\), "0.149999999999999893`", 
                  "1.00000000000000044`", \(-1.00000000000000044`\)},
                {"0.0287999999999999989`", "0.122400000000000019`", 
                  \(-0.109999999999999943`\), \(-0.750000000000000177`\), 
                  "0", "1.00000000000000111`"},
                {"0.0191999999999999992`", "0.0784000000000000252`", 
                  \(-0.120000000000000017`\), \(-0.650000000000000177`\), 
                  "0", "1.00000000000000066`"},
                {"0.0287999999999999989`", "0.237599999999999988`", 
                  "0.609999999999999875`", "0.249999999999999511`", 
                  \(-1.00000000000000044`\), \(-1.00000000000000111`\)},
                {"0.0167999999999999971`", \(-0.0436000000000000031`\), 
                  \(-0.279999999999999893`\), "1.35000000000000008`", 
                  \(-2.00000000000000177`\), "1.00000000000000532`"},
                {"0.0251999999999999957`", "0.0395999999999999907`", 
                  \(-0.429999999999999893`\), "0.250000000000000044`", 
                  "0.999999999999999289`", \(-0.99999999999999698`\)},
                {"0.0167999999999999971`", "0.0235999999999999854`", 
                  \(-0.319999999999999928`\), "0.150000000000000159`", 
                  "0.999999999999999111`", \(-0.999999999999998223`\)},
                {"0.0251999999999999957`", "0.140399999999999973`", 
                  \(-0.0700000000000000088`\), \(-0.75`\), "0", "1.`"},
                {"0.011200000000000001`", "0.0175999999999999978`", 
                  \(-0.230000000000000026`\), "0.0499999999999999822`", 
                  "1.`", \(-1.00000000000000111`\)},
                {"0.0167999999999999971`", "0.0964000000000000056`", 
                  \(-0.0600000000000000177`\), \(-0.650000000000000355`\), 
                  "0", "1.00000000000000222`"},
                {"0.011200000000000001`", "0.0624000000000000021`", 
                  \(-0.0700000000000000355`\), \(-0.550000000000000177`\), 
                  "0", "1.00000000000000222`"},
                {"0.0167999999999999971`", "0.163599999999999967`", 
                  "0.459999999999999786`", "0.149999999999998827`", 
                  \(-1.00000000000000244`\), \(-1.00000000000000222`\)},
                {"0.00719999999999999928`", "0.0156000000000000005`", 
                  \(-0.160000000000000008`\), \(-0.0500000000000000177`\), 
                  "0.999999999999999822`", \(-1.00000000000000111`\)},
                {"0.0107999999999999984`", "0.0684000000000000074`", 
                  \(-0.0299999999999999644`\), \(-0.549999999999999733`\), 
                  "0", "1.00000000000000088`"},
                {"0.00719999999999999928`", "0.0444000000000000039`", 
                  \(-0.0399999999999999555`\), \(-0.45`\), "0", 
                  "1.00000000000000111`"},
                {"0.0107999999999999984`", "0.111599999999999988`", 
                  "0.329999999999999982`", "0.0499999999999999822`", 
                  \(-1.00000000000000155`\), \(-1.00000000000000088`\)},
                {"0.00479999999999999982`", "0.0304000000000000047`", 
                  \(-0.0299999999999999822`\), \(-0.350000000000000044`\), 
                  "0", "1.00000000000000133`"},
                {"0.00719999999999999928`", "0.0756000000000000049`", 
                  "0.219999999999999973`", \(-0.0500000000000002842`\), 
                  \(-1.00000000000000088`\), \(-0.99999999999999769`\)},
                {"0.00479999999999999982`", "0.0496000000000000085`", 
                  "0.130000000000000026`", \(-0.150000000000000044`\), 
                  \(-1.00000000000000044`\), \(-0.999999999999998934`\)},
                {"0.00719999999999999928`", "0.104400000000000003`", 
                  "0.579999999999999982`", "1.54999999999999964`", 
                  "1.99999999999999857`", "0.999999999999992361`"}
                }], ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output",
  CellLabel->"Out[50]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\ Timing[
      Matrix\[CapitalGamma][{0.2, 0.3, 0.4, 0.5, 0.6}, {1, 1, 1, 1, 1}, 5] // 
        MatrixForm]\)\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(2.75`\ Second\), ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"0.0671999999999999886`", \(-0.594399999999999906`\), 
                  "2.06999999999999984`", \(-3.54999999999999937`\), 
                  "2.99999999999999964`", \(-1.`\)},
                {"0.100799999999999978`", \(-0.47159999999999993`\), 
                  "0.439999999999999857`", "0.95`", 
                  \(-1.99999999999999982`\), "0.999999999999999822`"},
                {"0.0671999999999999886`", \(-0.325600000000000022`\), 
                  "0.230000000000000071`", "1.05000000000000004`", \(-2.`\), 
                  "1.`"},
                {"0.100799999999999978`", \(-0.0684000000000000341`\), 
                  \(-0.640000000000000035`\), "0.549999999999999911`", 
                  "0.999999999999999822`", \(-0.999999999999999822`\)},
                {"0.0448000000000000042`", \(-0.209600000000000008`\), 
                  "0.0399999999999999822`", "1.15000000000000013`", \(-2.`\), 
                  "1.`"},
                {"0.0671999999999999886`", \(-0.0344000000000000083`\), 
                  \(-0.55`\), "0.45`", "1.`", \(-1.`\)},
                {"0.0448000000000000042`", \(-0.0304000000000000092`\), 
                  \(-0.440000000000000035`\), "0.350000000000000133`", 
                  "0.999999999999999822`", \(-1.`\)},
                {"0.0671999999999999886`", "0.234399999999999986`", 
                  \(-0.149999999999999955`\), \(-0.949999999999999822`\), 
                  \(-2.38742359215393662`*^-16\), "1.`"},
                {"0.0287999999999999989`", \(-0.117599999999999971`\), 
                  \(-0.130000000000000004`\), "1.25`", 
                  \(-2.00000000000000044`\), "1.00000000000000022`"},
                {"0.0431999999999999939`", "0.00360000000000000586`", 
                  \(-0.479999999999999893`\), "0.349999999999999911`", "1.`", 
                  \(-1.`\)},
                {"0.0287999999999999989`", \(-0.00239999999999999147`\), 
                  \(-0.369999999999999928`\), "0.250000000000000088`", 
                  "1.00000000000000022`", \(-1.00000000000000022`\)},
                {"0.0431999999999999939`", "0.176400000000000005`", 
                  \(-0.120000000000000062`\), \(-0.85`\), 
                  \(-7.67386154620908023`*^-17\), "1.`"},
                {"0.0191999999999999992`", "0.00160000000000001136`", 
                  \(-0.280000000000000035`\), "0.150000000000000017`", 
                  "1.00000000000000022`", \(-1.00000000000000022`\)},
                {"0.0287999999999999989`", "0.122400000000000019`", 
                  \(-0.110000000000000008`\), \(-0.750000000000000088`\), 
                  \(-1.02318153949454426`*^-16\), "1.00000000000000022`"},
                {"0.0191999999999999992`", "0.0784000000000000252`", 
                  \(-0.120000000000000062`\), \(-0.650000000000000177`\), 
                  \(-1.36424205265939257`*^-16\), "1.00000000000000022`"},
                {"0.0287999999999999989`", "0.237599999999999988`", 
                  "0.609999999999999964`", "0.250000000000000266`", 
                  \(-1.00000000000000022`\), \(-1.00000000000000022`\)},
                {"0.0167999999999999971`", \(-0.0436000000000000031`\), 
                  \(-0.280000000000000035`\), "1.35000000000000008`", 
                  \(-2.`\), "1.`"},
                {"0.0251999999999999957`", "0.0395999999999999907`", 
                  \(-0.429999999999999893`\), "0.250000000000000044`", 
                  "0.999999999999999822`", \(-0.999999999999999822`\)},
                {"0.0167999999999999971`", "0.0235999999999999854`", 
                  \(-0.319999999999999928`\), "0.149999999999999928`", "1.`", 
                  \(-1.`\)},
                {"0.0251999999999999957`", "0.140399999999999973`", 
                  \(-0.0700000000000000621`\), \(-0.749999999999999911`\), 
                  \(-8.95283847057726056`*^-17\), "0.999999999999999822`"},
                {"0.011200000000000001`", "0.0175999999999999978`", 
                  \(-0.229999999999999982`\), "0.0499999999999999644`", 
                  "1.`", \(-1.`\)},
                {"0.0167999999999999971`", "0.0964000000000000056`", 
                  \(-0.0599999999999999644`\), \(-0.65`\), 
                  \(-5.96855898038484156`*^-17\), "1.`"},
                {"0.011200000000000001`", "0.0624000000000000021`", 
                  \(-0.070000000000000071`\), \(-0.55`\), 
                  "7.95807864051312208`*^-17", "1.`"},
                {"0.0167999999999999971`", "0.163599999999999967`", 
                  "0.459999999999999964`", "0.149999999999999911`", \(-1.`\), 
                  \(-1.`\)},
                {"0.00719999999999999928`", "0.0156000000000000005`", 
                  \(-0.160000000000000008`\), \(-0.0499999999999999111`\), 
                  "1.00000000000000022`", \(-1.00000000000000022`\)},
                {"0.0107999999999999984`", "0.0684000000000000074`", 
                  \(-0.0299999999999999644`\), \(-0.55`\), 
                  "7.67386154620908023`*^-17", "1.`"},
                {"0.00719999999999999928`", "0.0444000000000000039`", 
                  \(-0.0400000000000000355`\), \(-0.450000000000000088`\), 
                  "5.11590769747272133`*^-17", "1.00000000000000022`"},
                {"0.0107999999999999984`", "0.111599999999999988`", 
                  "0.329999999999999982`", "0.04999999999999992`", \(-1.`\), 
                  \(-1.`\)},
                {"0.00479999999999999982`", "0.0304000000000000047`", 
                  \(-0.0299999999999999822`\), \(-0.350000000000000044`\), 
                  \(-1.36424205265939257`*^-16\), "1.00000000000000022`"},
                {"0.00719999999999999928`", "0.0756000000000000049`", 
                  "0.220000000000000017`", \(-0.0499999999999998845`\), 
                  \(-1.00000000000000022`\), \(-1.00000000000000022`\)},
                {"0.00479999999999999982`", "0.0496000000000000085`", 
                  "0.130000000000000026`", \(-0.150000000000000088`\), 
                  \(-1.00000000000000022`\), \(-1.00000000000000022`\)},
                {"0.00719999999999999928`", "0.104400000000000003`", 
                  "0.579999999999999982`", "1.55000000000000026`", 
                  "2.00000000000000044`", "1.00000000000000022`"}
                }], ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output",
  CellLabel->"Out[51]="]
}, Closed]],

Cell[TextData[{
  "Matrix\[CapitalGamma][] calls AlleleFrequencyPermutations[], \
\[Delta]AlleleFrequencyPermutations[] to construct the matrix.  The matrix of \
genotype frequencies is ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma] . c . \[CapitalGamma]\^\(*T\)\)]],
  "."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "DiploidGenotypeFrequencyList"->{
    Cell[1843, 56, 812, 13, 86, "DefinitionBox",
      CellTags->"DiploidGenotypeFrequencyList"]},
  "MatrixGamma"->{
    Cell[31916, 684, 725, 14, 88, "DefinitionBox",
      CellTags->"MatrixGamma"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"DiploidGenotypeFrequencyList", 50627, 1033},
  {"MatrixGamma", 50745, 1036}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 101, 3, 36, "SubsectionIcon"],
Cell[1843, 56, 812, 13, 86, "DefinitionBox",
  CellTags->"DiploidGenotypeFrequencyList"],
Cell[2658, 71, 778, 22, 36, "Text"],
Cell[3439, 95, 37, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3501, 99, 158, 4, 27, "Input"],
Cell[3662, 105, 344, 10, 94, "Output"]
}, Closed]],
Cell[4021, 118, 224, 6, 20, "MathCaption"],

Cell[CellGroupData[{
Cell[4270, 128, 206, 6, 27, "Input"],
Cell[4479, 136, 7678, 129, 365, "Output"]
}, Closed]],
Cell[12172, 268, 288, 8, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[12485, 280, 88, 2, 27, "Input"],
Cell[12576, 284, 2313, 38, 125, "Output"]
}, Closed]],
Cell[14904, 325, 353, 7, 32, "Text"],
Cell[15260, 334, 283, 7, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[15568, 345, 521, 13, 76, "Input"],
Cell[16092, 360, 2305, 37, 142, "Output"]
}, Closed]],
Cell[18412, 400, 151, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[18588, 407, 896, 20, 80, "Input"],
Cell[19487, 429, 2027, 36, 91, "Output"]
}, Closed]],
Cell[21529, 468, 733, 18, 36, "Text"],
Cell[22265, 488, 642, 11, 52, "DefinitionBox"],

Cell[CellGroupData[{
Cell[22932, 503, 621, 16, 76, "Input"],
Cell[23556, 521, 2318, 37, 142, "Output"]
}, Closed]],
Cell[25889, 561, 971, 17, 82, "DefinitionBox"],
Cell[26863, 580, 67, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[26955, 584, 438, 10, 76, "Input"],
Cell[27396, 596, 2017, 34, 125, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[29450, 635, 433, 10, 72, "Input"],
Cell[29886, 647, 2015, 34, 125, "Output"]
}, Closed]],
Cell[31916, 684, 725, 14, 88, "DefinitionBox",
  CellTags->"MatrixGamma"],
Cell[32644, 700, 236, 4, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[32905, 708, 137, 3, 27, "Input"],
Cell[33045, 713, 1190, 21, 142, "Output"]
}, Closed]],
Cell[34250, 737, 86, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[34361, 744, 122, 3, 27, "Input"],
Cell[34486, 749, 1190, 21, 142, "Output"]
}, Closed]],
Cell[35691, 773, 72, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[35788, 777, 192, 4, 27, "Input"],
Cell[35983, 783, 6699, 102, 514, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[42719, 890, 170, 4, 23, "Input"],
Cell[42892, 896, 6527, 102, 544, "Output"]
}, Closed]],
Cell[49434, 1001, 298, 7, 20, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

