(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     20891,        463]*)
(*NotebookOutlinePosition[     22150,        502]*)
(*  CellTagsIndexPosition[     22016,        495]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Genotype frequencies from moments", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(HaploidGenotypeFrequency[X, c, p, 
              S]\), \(gives\ an\ expression\ for\ g[
                X]\ in\ terms\ of\ the\ moments\ c[]\ and\ allele\ \
frequencies\ p[] . \ \ Stores\ \(\(results\)\(.\)\)\)},
          {\(HaploidGenotypeFrequency[X, c, 
              p]\), \(uses\ this\ to\ find\ the\ frequency\ of\ genotype\ X; \
\ c\ and\ p\ must\ then\ be\ given\ as\ lists\ of\ numbers\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"HaploidGenotypeFrequency"],

Cell["\<\
This is the frequency of genotype {0,0,1}in terms of moments c[] \
and allele frequencies p[]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gf = HaploidGenotypeFrequency[{0, 0, 1}, c, p, {i, j, k}]\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    \(c[{i, j, k}] - c[{j, k}]\ \((1 - p[i])\) - c[{i, k}]\ \((1 - p[j])\) + 
      c[{i, j}]\ p[k] + \((1 - p[i])\)\ \((1 - p[j])\)\ p[k]\)], "Output",
  CellLabel->"Out[55]="]
}, Closed]],

Cell[TextData[{
  "This is the frequency of {0,0,1}with linkage equilibrium and allele \
frequencies {0.2, 0.3, 0.4} at loci ",
  Cell[BoxData[
      \(TraditionalForm\`{i, \ j, \ k}\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gf /. {c[_] \[Rule] 0, p[i] \[Rule] 0.2, p[j] \[Rule] 0.3, 
        p[k] \[Rule] 0.4}\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \(0.223999999999999976`\)], "Output",
  CellLabel->"Out[56]="]
}, Closed]],

Cell["This gives the same, but using a compiled version:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(n = 3; 
    HaploidGenotypeFrequency[{0, 0, 1}, 
      Array[0&, 2\^n - n - 1], {0.2, 0.3, 0.4}]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \(0.223999999999999976`\)], "Output",
  CellLabel->"Out[57]="]
}, Closed]],

Cell["\<\
The moments and allele frequencies must be given as lists of \
numbers.  The moments are given in the same order as HaploidSubsets[]:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(HaploidSubsets[{i, j, k}]\)], "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    \({{i, j}, {i, k}, {j, k}, {i, j, k}}\)], "Output",
  CellLabel->"Out[80]="]
}, Closed]],

Cell["\<\
The first time the compiled version is called, it is slower, \
because the code has to be compiled:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(n = 8; pp = {0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9}; 
    \n{Timing[
        HaploidGenotypeFrequency[{0, 0, 1, 0, 0, 1, 0, 1}, 
          Array[0&, 2\^n - n - 1], pp]], \n\t
      Timing[HaploidGenotypeFrequency[{0, 0, 1, 0, 0, 1, 0, 1}, c, p, 
            Range[n]] /. {c[_] \[RuleDelayed] 0, 
            p[i_] \[RuleDelayed] 
              pp\[LeftDoubleBracket]i\[RightDoubleBracket]}]}\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \({{2.80000000000018189`\ Second, 0.00564479999999999826`}, {
        0.616666666666333185`\ Second, 0.00564479999999999826`}}\)], "Output",\

  CellLabel->"Out[64]="]
}, Closed]],

Cell["Thereafter, it is faster:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Timing[
        HaploidGenotypeFrequency[{0, 0, 1, 0, 0, 1, 0, 1}, 
          Array[0&, 2\^n - n - 1], pp]], \n\t
      Timing[HaploidGenotypeFrequency[{0, 0, 1, 0, 0, 1, 0, 1}, c, p, 
            Range[n]] /. {c[_] \[RuleDelayed] 0, 
            p[i_] \[RuleDelayed] 
              pp\[LeftDoubleBracket]i\[RightDoubleBracket]}]}\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \({{0.016666666666878882`\ Second, 0.00564479999999999826`}, {
        0.0333333333333030168`\ Second, 0.00564479999999999826`}}\)], "Output",\

  CellLabel->"Out[65]="]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            \(\(HaploidGenotypeFrequency[nloci]\)[p1, \( ..  pn\), 
              c[{1, 2}] ... ]\), 
            \(stores\ a\ compiled\ version\ of\ g[{1, \(1.  . \)},  .. ], \ 
            which\ takes\ as\ arguments\ the\ n\ allele\ frequencies\ and\ 
                2^n - n - 1\ \(moments . \)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell[TextData[{
  "This is the  compiled function which is called by ",
  "HaploidGenotypeFrequency",
  "[X,c,p].  Only the frequency of g[{1,1,1\[Ellipsis]}] is compiled: other \
genotype frequnecies are found by permutation."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(DiploidGenotypeFrequency[{0, 1, 0}, c, p, 
              S]\), \(uses\ HaploidGenotypeFrequency[]\ to\ express\ this\ in\
\ terms\ of\ c[], \ p[]; \ 
            S\ is\ the\ complete\ set\ of\ \(\(loci\)\(.\)\)\)},
          {\(DiploidGenotypeFrequency[{0, 1, 0}, c, 
              p]\), \(uses\ the\ compiled\ version, \ 
            where\ c\ and\ p\ are\ lists\ of\ numbers; 
            c\ lists\ the\ moments\ in\ the\ same\ order\ as\ \
DiploidSubsets[]\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"DiploidGenotypeFrequency"],

Cell[TextData[{
  "This is the frequency of the diploid genotype {1,1,2}, in symbolic form.  \
It depends on 3 allele frequencies defined for the female gamete pool ",
  Cell[BoxData[
      \(TraditionalForm\`\((p[i], \ p[j], \ p[k])\)\)]],
  ", three for the male gametes ",
  Cell[BoxData[
      \(TraditionalForm\`\((p[\(i\^*\)], \ p[\(j\^*\)], \ p[\(k\^*\)])\)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(2  n\) - 2  n - 1\)]],
  "= 57 within- and between genome associations:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DiploidGenotypeFrequency[{1, 1, 2}, c, p, {i, j, k}]\)], "Input",
  CellLabel->"In[109]:="],

Cell[BoxData[
    \(4\ c[{i, j, k, \(i\^*\), \(j\^*\), \(k\^*\)}] - 
      2\ c[{j, k, \(i\^*\), \(j\^*\), \(k\^*\)}]\ \((1 - p[i])\) + 
      2\ c[{j, k, \(i\^*\), \(j\^*\), \(k\^*\)}]\ p[i] - 
      2\ c[{i, k, \(i\^*\), \(j\^*\), \(k\^*\)}]\ \((1 - p[j])\) + 
      c[{k, \(i\^*\), \(j\^*\), \(k\^*\)}]\ \((1 - p[i])\)\ \((1 - p[j])\) - 
      c[{k, \(i\^*\), \(j\^*\), \(k\^*\)}]\ p[i]\ \((1 - p[j])\) + 
      2\ c[{i, k, \(i\^*\), \(j\^*\), \(k\^*\)}]\ p[j] - 
      c[{k, \(i\^*\), \(j\^*\), \(k\^*\)}]\ \((1 - p[i])\)\ p[j] + 
      c[{k, \(i\^*\), \(j\^*\), \(k\^*\)}]\ p[i]\ p[j] + 
      4\ c[{i, j, \(i\^*\), \(j\^*\), \(k\^*\)}]\ p[k] - 
      2\ c[{j, \(i\^*\), \(j\^*\), \(k\^*\)}]\ \((1 - p[i])\)\ p[k] + 
      2\ c[{j, \(i\^*\), \(j\^*\), \(k\^*\)}]\ p[i]\ p[k] - 
      2\ c[{i, \(i\^*\), \(j\^*\), \(k\^*\)}]\ \((1 - p[j])\)\ p[k] + 
      c[{\(i\^*\), \(j\^*\), \(k\^*\)}]\ \((1 - p[i])\)\ \((1 - p[j])\)\ 
        p[k] - c[{\(i\^*\), \(j\^*\), \(k\^*\)}]\ p[i]\ \((1 - p[j])\)\ 
        p[k] + 2\ c[{i, \(i\^*\), \(j\^*\), \(k\^*\)}]\ p[j]\ p[k] - 
      c[{\(i\^*\), \(j\^*\), \(k\^*\)}]\ \((1 - p[i])\)\ p[j]\ p[k] + 
      c[{\(i\^*\), \(j\^*\), \(k\^*\)}]\ p[i]\ p[j]\ p[k] - 
      2\ c[{i, j, k, \(j\^*\), \(k\^*\)}]\ \((1 - p[\(i\^*\)])\) - 
      2\ c[{j, k, \(j\^*\), \(k\^*\)}]\ p[i]\ \((1 - p[\(i\^*\)])\) + 
      c[{i, k, \(j\^*\), \(k\^*\)}]\ \((1 - p[j])\)\ \((1 - p[\(i\^*\)])\) + 
      c[{k, \(j\^*\), \(k\^*\)}]\ p[i]\ \((1 - p[j])\)\ 
        \((1 - p[\(i\^*\)])\) - 
      c[{i, k, \(j\^*\), \(k\^*\)}]\ p[j]\ \((1 - p[\(i\^*\)])\) - 
      c[{k, \(j\^*\), \(k\^*\)}]\ p[i]\ p[j]\ \((1 - p[\(i\^*\)])\) - 
      2\ c[{i, j, \(j\^*\), \(k\^*\)}]\ p[k]\ \((1 - p[\(i\^*\)])\) - 
      2\ c[{j, \(j\^*\), \(k\^*\)}]\ p[i]\ p[k]\ \((1 - p[\(i\^*\)])\) + 
      c[{i, \(j\^*\), \(k\^*\)}]\ \((1 - p[j])\)\ p[k]\ 
        \((1 - p[\(i\^*\)])\) + 
      c[{\(j\^*\), \(k\^*\)}]\ p[i]\ \((1 - p[j])\)\ p[k]\ 
        \((1 - p[\(i\^*\)])\) - 
      c[{i, \(j\^*\), \(k\^*\)}]\ p[j]\ p[k]\ \((1 - p[\(i\^*\)])\) - 
      c[{\(j\^*\), \(k\^*\)}]\ p[i]\ p[j]\ p[k]\ \((1 - p[\(i\^*\)])\) + 
      2\ c[{i, j, k, \(j\^*\), \(k\^*\)}]\ p[\(i\^*\)] - 
      2\ c[{j, k, \(j\^*\), \(k\^*\)}]\ \((1 - p[i])\)\ p[\(i\^*\)] - 
      c[{i, k, \(j\^*\), \(k\^*\)}]\ \((1 - p[j])\)\ p[\(i\^*\)] + 
      c[{k, \(j\^*\), \(k\^*\)}]\ \((1 - p[i])\)\ \((1 - p[j])\)\ 
        p[\(i\^*\)] + c[{i, k, \(j\^*\), \(k\^*\)}]\ p[j]\ p[\(i\^*\)] - 
      c[{k, \(j\^*\), \(k\^*\)}]\ \((1 - p[i])\)\ p[j]\ p[\(i\^*\)] + 
      2\ c[{i, j, \(j\^*\), \(k\^*\)}]\ p[k]\ p[\(i\^*\)] - 
      2\ c[{j, \(j\^*\), \(k\^*\)}]\ \((1 - p[i])\)\ p[k]\ p[\(i\^*\)] - 
      c[{i, \(j\^*\), \(k\^*\)}]\ \((1 - p[j])\)\ p[k]\ p[\(i\^*\)] + 
      c[{\(j\^*\), \(k\^*\)}]\ \((1 - p[i])\)\ \((1 - p[j])\)\ p[k]\ 
        p[\(i\^*\)] + c[{i, \(j\^*\), \(k\^*\)}]\ p[j]\ p[k]\ p[\(i\^*\)] - 
      c[{\(j\^*\), \(k\^*\)}]\ \((1 - p[i])\)\ p[j]\ p[k]\ p[\(i\^*\)] - 
      2\ c[{i, j, k, \(i\^*\), \(k\^*\)}]\ \((1 - p[\(j\^*\)])\) + 
      c[{j, k, \(i\^*\), \(k\^*\)}]\ \((1 - p[i])\)\ \((1 - p[\(j\^*\)])\) - 
      c[{j, k, \(i\^*\), \(k\^*\)}]\ p[i]\ \((1 - p[\(j\^*\)])\) - 
      2\ c[{i, k, \(i\^*\), \(k\^*\)}]\ p[j]\ \((1 - p[\(j\^*\)])\) + 
      c[{k, \(i\^*\), \(k\^*\)}]\ \((1 - p[i])\)\ p[j]\ 
        \((1 - p[\(j\^*\)])\) - 
      c[{k, \(i\^*\), \(k\^*\)}]\ p[i]\ p[j]\ \((1 - p[\(j\^*\)])\) - 
      2\ c[{i, j, \(i\^*\), \(k\^*\)}]\ p[k]\ \((1 - p[\(j\^*\)])\) + 
      c[{j, \(i\^*\), \(k\^*\)}]\ \((1 - p[i])\)\ p[k]\ 
        \((1 - p[\(j\^*\)])\) - 
      c[{j, \(i\^*\), \(k\^*\)}]\ p[i]\ p[k]\ \((1 - p[\(j\^*\)])\) - 
      2\ c[{i, \(i\^*\), \(k\^*\)}]\ p[j]\ p[k]\ \((1 - p[\(j\^*\)])\) + 
      c[{\(i\^*\), \(k\^*\)}]\ \((1 - p[i])\)\ p[j]\ p[k]\ 
        \((1 - p[\(j\^*\)])\) - 
      c[{\(i\^*\), \(k\^*\)}]\ p[i]\ p[j]\ p[k]\ \((1 - p[\(j\^*\)])\) + 
      c[{i, j, k, \(k\^*\)}]\ \((1 - p[\(i\^*\)])\)\ \((1 - p[\(j\^*\)])\) + 
      c[{j, k, \(k\^*\)}]\ p[i]\ \((1 - p[\(i\^*\)])\)\ 
        \((1 - p[\(j\^*\)])\) + 
      c[{i, k, \(k\^*\)}]\ p[j]\ \((1 - p[\(i\^*\)])\)\ 
        \((1 - p[\(j\^*\)])\) + 
      c[{k, \(k\^*\)}]\ p[i]\ p[j]\ \((1 - p[\(i\^*\)])\)\ 
        \((1 - p[\(j\^*\)])\) + 
      c[{i, j, \(k\^*\)}]\ p[k]\ \((1 - p[\(i\^*\)])\)\ 
        \((1 - p[\(j\^*\)])\) + 
      c[{j, \(k\^*\)}]\ p[i]\ p[k]\ \((1 - p[\(i\^*\)])\)\ 
        \((1 - p[\(j\^*\)])\) + 
      c[{i, \(k\^*\)}]\ p[j]\ p[k]\ \((1 - p[\(i\^*\)])\)\ 
        \((1 - p[\(j\^*\)])\) - 
      c[{i, j, k, \(k\^*\)}]\ p[\(i\^*\)]\ \((1 - p[\(j\^*\)])\) + 
      c[{j, k, \(k\^*\)}]\ \((1 - p[i])\)\ p[\(i\^*\)]\ 
        \((1 - p[\(j\^*\)])\) - 
      c[{i, k, \(k\^*\)}]\ p[j]\ p[\(i\^*\)]\ \((1 - p[\(j\^*\)])\) + 
      c[{k, \(k\^*\)}]\ \((1 - p[i])\)\ p[j]\ p[\(i\^*\)]\ 
        \((1 - p[\(j\^*\)])\) - 
      c[{i, j, \(k\^*\)}]\ p[k]\ p[\(i\^*\)]\ \((1 - p[\(j\^*\)])\) + 
      c[{j, \(k\^*\)}]\ \((1 - p[i])\)\ p[k]\ p[\(i\^*\)]\ 
        \((1 - p[\(j\^*\)])\) - 
      c[{i, \(k\^*\)}]\ p[j]\ p[k]\ p[\(i\^*\)]\ \((1 - p[\(j\^*\)])\) + 
      2\ c[{i, j, k, \(i\^*\), \(k\^*\)}]\ p[\(j\^*\)] - 
      c[{j, k, \(i\^*\), \(k\^*\)}]\ \((1 - p[i])\)\ p[\(j\^*\)] + 
      c[{j, k, \(i\^*\), \(k\^*\)}]\ p[i]\ p[\(j\^*\)] - 
      2\ c[{i, k, \(i\^*\), \(k\^*\)}]\ \((1 - p[j])\)\ p[\(j\^*\)] + 
      c[{k, \(i\^*\), \(k\^*\)}]\ \((1 - p[i])\)\ \((1 - p[j])\)\ 
        p[\(j\^*\)] - 
      c[{k, \(i\^*\), \(k\^*\)}]\ p[i]\ \((1 - p[j])\)\ p[\(j\^*\)] + 
      2\ c[{i, j, \(i\^*\), \(k\^*\)}]\ p[k]\ p[\(j\^*\)] - 
      c[{j, \(i\^*\), \(k\^*\)}]\ \((1 - p[i])\)\ p[k]\ p[\(j\^*\)] + 
      c[{j, \(i\^*\), \(k\^*\)}]\ p[i]\ p[k]\ p[\(j\^*\)] - 
      2\ c[{i, \(i\^*\), \(k\^*\)}]\ \((1 - p[j])\)\ p[k]\ p[\(j\^*\)] + 
      c[{\(i\^*\), \(k\^*\)}]\ \((1 - p[i])\)\ \((1 - p[j])\)\ p[k]\ 
        p[\(j\^*\)] - 
      c[{\(i\^*\), \(k\^*\)}]\ p[i]\ \((1 - p[j])\)\ p[k]\ p[\(j\^*\)] - 
      c[{i, j, k, \(k\^*\)}]\ \((1 - p[\(i\^*\)])\)\ p[\(j\^*\)] - 
      c[{j, k, \(k\^*\)}]\ p[i]\ \((1 - p[\(i\^*\)])\)\ p[\(j\^*\)] + 
      c[{i, k, \(k\^*\)}]\ \((1 - p[j])\)\ \((1 - p[\(i\^*\)])\)\ 
        p[\(j\^*\)] + 
      c[{k, \(k\^*\)}]\ p[i]\ \((1 - p[j])\)\ \((1 - p[\(i\^*\)])\)\ 
        p[\(j\^*\)] - 
      c[{i, j, \(k\^*\)}]\ p[k]\ \((1 - p[\(i\^*\)])\)\ p[\(j\^*\)] - 
      c[{j, \(k\^*\)}]\ p[i]\ p[k]\ \((1 - p[\(i\^*\)])\)\ p[\(j\^*\)] + 
      c[{i, \(k\^*\)}]\ \((1 - p[j])\)\ p[k]\ \((1 - p[\(i\^*\)])\)\ 
        p[\(j\^*\)] + c[{i, j, k, \(k\^*\)}]\ p[\(i\^*\)]\ p[\(j\^*\)] - 
      c[{j, k, \(k\^*\)}]\ \((1 - p[i])\)\ p[\(i\^*\)]\ p[\(j\^*\)] - 
      c[{i, k, \(k\^*\)}]\ \((1 - p[j])\)\ p[\(i\^*\)]\ p[\(j\^*\)] + 
      c[{k, \(k\^*\)}]\ \((1 - p[i])\)\ \((1 - p[j])\)\ p[\(i\^*\)]\ 
        p[\(j\^*\)] + c[{i, j, \(k\^*\)}]\ p[k]\ p[\(i\^*\)]\ p[\(j\^*\)] - 
      c[{j, \(k\^*\)}]\ \((1 - p[i])\)\ p[k]\ p[\(i\^*\)]\ p[\(j\^*\)] - 
      c[{i, \(k\^*\)}]\ \((1 - p[j])\)\ p[k]\ p[\(i\^*\)]\ p[\(j\^*\)] + 
      4\ c[{i, j, k, \(i\^*\), \(j\^*\)}]\ p[\(k\^*\)] - 
      2\ c[{j, k, \(i\^*\), \(j\^*\)}]\ \((1 - p[i])\)\ p[\(k\^*\)] + 
      2\ c[{j, k, \(i\^*\), \(j\^*\)}]\ p[i]\ p[\(k\^*\)] - 
      2\ c[{i, k, \(i\^*\), \(j\^*\)}]\ \((1 - p[j])\)\ p[\(k\^*\)] + 
      c[{k, \(i\^*\), \(j\^*\)}]\ \((1 - p[i])\)\ \((1 - p[j])\)\ 
        p[\(k\^*\)] - 
      c[{k, \(i\^*\), \(j\^*\)}]\ p[i]\ \((1 - p[j])\)\ p[\(k\^*\)] + 
      2\ c[{i, k, \(i\^*\), \(j\^*\)}]\ p[j]\ p[\(k\^*\)] - 
      c[{k, \(i\^*\), \(j\^*\)}]\ \((1 - p[i])\)\ p[j]\ p[\(k\^*\)] + 
      c[{k, \(i\^*\), \(j\^*\)}]\ p[i]\ p[j]\ p[\(k\^*\)] + 
      4\ c[{i, j, \(i\^*\), \(j\^*\)}]\ p[k]\ p[\(k\^*\)] - 
      2\ c[{j, \(i\^*\), \(j\^*\)}]\ \((1 - p[i])\)\ p[k]\ p[\(k\^*\)] + 
      2\ c[{j, \(i\^*\), \(j\^*\)}]\ p[i]\ p[k]\ p[\(k\^*\)] - 
      2\ c[{i, \(i\^*\), \(j\^*\)}]\ \((1 - p[j])\)\ p[k]\ p[\(k\^*\)] + 
      c[{\(i\^*\), \(j\^*\)}]\ \((1 - p[i])\)\ \((1 - p[j])\)\ p[k]\ 
        p[\(k\^*\)] - 
      c[{\(i\^*\), \(j\^*\)}]\ p[i]\ \((1 - p[j])\)\ p[k]\ p[\(k\^*\)] + 
      2\ c[{i, \(i\^*\), \(j\^*\)}]\ p[j]\ p[k]\ p[\(k\^*\)] - 
      c[{\(i\^*\), \(j\^*\)}]\ \((1 - p[i])\)\ p[j]\ p[k]\ p[\(k\^*\)] + 
      c[{\(i\^*\), \(j\^*\)}]\ p[i]\ p[j]\ p[k]\ p[\(k\^*\)] - 
      2\ c[{i, j, k, \(j\^*\)}]\ \((1 - p[\(i\^*\)])\)\ p[\(k\^*\)] - 
      2\ c[{j, k, \(j\^*\)}]\ p[i]\ \((1 - p[\(i\^*\)])\)\ p[\(k\^*\)] + 
      c[{i, k, \(j\^*\)}]\ \((1 - p[j])\)\ \((1 - p[\(i\^*\)])\)\ 
        p[\(k\^*\)] + 
      c[{k, \(j\^*\)}]\ p[i]\ \((1 - p[j])\)\ \((1 - p[\(i\^*\)])\)\ 
        p[\(k\^*\)] - 
      c[{i, k, \(j\^*\)}]\ p[j]\ \((1 - p[\(i\^*\)])\)\ p[\(k\^*\)] - 
      c[{k, \(j\^*\)}]\ p[i]\ p[j]\ \((1 - p[\(i\^*\)])\)\ p[\(k\^*\)] - 
      2\ c[{i, j, \(j\^*\)}]\ p[k]\ \((1 - p[\(i\^*\)])\)\ p[\(k\^*\)] - 
      2\ c[{j, \(j\^*\)}]\ p[i]\ p[k]\ \((1 - p[\(i\^*\)])\)\ p[\(k\^*\)] + 
      c[{i, \(j\^*\)}]\ \((1 - p[j])\)\ p[k]\ \((1 - p[\(i\^*\)])\)\ 
        p[\(k\^*\)] - 
      c[{i, \(j\^*\)}]\ p[j]\ p[k]\ \((1 - p[\(i\^*\)])\)\ p[\(k\^*\)] + 
      2\ c[{i, j, k, \(j\^*\)}]\ p[\(i\^*\)]\ p[\(k\^*\)] - 
      2\ c[{j, k, \(j\^*\)}]\ \((1 - p[i])\)\ p[\(i\^*\)]\ p[\(k\^*\)] - 
      c[{i, k, \(j\^*\)}]\ \((1 - p[j])\)\ p[\(i\^*\)]\ p[\(k\^*\)] + 
      c[{k, \(j\^*\)}]\ \((1 - p[i])\)\ \((1 - p[j])\)\ p[\(i\^*\)]\ 
        p[\(k\^*\)] + c[{i, k, \(j\^*\)}]\ p[j]\ p[\(i\^*\)]\ p[\(k\^*\)] - 
      c[{k, \(j\^*\)}]\ \((1 - p[i])\)\ p[j]\ p[\(i\^*\)]\ p[\(k\^*\)] + 
      2\ c[{i, j, \(j\^*\)}]\ p[k]\ p[\(i\^*\)]\ p[\(k\^*\)] - 
      2\ c[{j, \(j\^*\)}]\ \((1 - p[i])\)\ p[k]\ p[\(i\^*\)]\ p[\(k\^*\)] - 
      c[{i, \(j\^*\)}]\ \((1 - p[j])\)\ p[k]\ p[\(i\^*\)]\ p[\(k\^*\)] + 
      c[{i, \(j\^*\)}]\ p[j]\ p[k]\ p[\(i\^*\)]\ p[\(k\^*\)] - 
      2\ c[{i, j, k, \(i\^*\)}]\ \((1 - p[\(j\^*\)])\)\ p[\(k\^*\)] + 
      c[{j, k, \(i\^*\)}]\ \((1 - p[i])\)\ \((1 - p[\(j\^*\)])\)\ 
        p[\(k\^*\)] - 
      c[{j, k, \(i\^*\)}]\ p[i]\ \((1 - p[\(j\^*\)])\)\ p[\(k\^*\)] - 
      2\ c[{i, k, \(i\^*\)}]\ p[j]\ \((1 - p[\(j\^*\)])\)\ p[\(k\^*\)] + 
      c[{k, \(i\^*\)}]\ \((1 - p[i])\)\ p[j]\ \((1 - p[\(j\^*\)])\)\ 
        p[\(k\^*\)] - 
      c[{k, \(i\^*\)}]\ p[i]\ p[j]\ \((1 - p[\(j\^*\)])\)\ p[\(k\^*\)] - 
      2\ c[{i, j, \(i\^*\)}]\ p[k]\ \((1 - p[\(j\^*\)])\)\ p[\(k\^*\)] + 
      c[{j, \(i\^*\)}]\ \((1 - p[i])\)\ p[k]\ \((1 - p[\(j\^*\)])\)\ 
        p[\(k\^*\)] - 
      c[{j, \(i\^*\)}]\ p[i]\ p[k]\ \((1 - p[\(j\^*\)])\)\ p[\(k\^*\)] - 
      2\ c[{i, \(i\^*\)}]\ p[j]\ p[k]\ \((1 - p[\(j\^*\)])\)\ p[\(k\^*\)] + 
      c[{i, j, k}]\ \((1 - p[\(i\^*\)])\)\ \((1 - p[\(j\^*\)])\)\ 
        p[\(k\^*\)] + 
      c[{j, k}]\ p[i]\ \((1 - p[\(i\^*\)])\)\ \((1 - p[\(j\^*\)])\)\ 
        p[\(k\^*\)] + 
      c[{i, k}]\ p[j]\ \((1 - p[\(i\^*\)])\)\ \((1 - p[\(j\^*\)])\)\ 
        p[\(k\^*\)] + 
      c[{i, j}]\ p[k]\ \((1 - p[\(i\^*\)])\)\ \((1 - p[\(j\^*\)])\)\ 
        p[\(k\^*\)] + 
      p[i]\ p[j]\ p[k]\ \((1 - p[\(i\^*\)])\)\ \((1 - p[\(j\^*\)])\)\ 
        p[\(k\^*\)] - 
      c[{i, j, k}]\ p[\(i\^*\)]\ \((1 - p[\(j\^*\)])\)\ p[\(k\^*\)] + 
      c[{j, k}]\ \((1 - p[i])\)\ p[\(i\^*\)]\ \((1 - p[\(j\^*\)])\)\ 
        p[\(k\^*\)] - 
      c[{i, k}]\ p[j]\ p[\(i\^*\)]\ \((1 - p[\(j\^*\)])\)\ p[\(k\^*\)] - 
      c[{i, j}]\ p[k]\ p[\(i\^*\)]\ \((1 - p[\(j\^*\)])\)\ p[\(k\^*\)] + 
      \((1 - p[i])\)\ p[j]\ p[k]\ p[\(i\^*\)]\ \((1 - p[\(j\^*\)])\)\ 
        p[\(k\^*\)] + 2\ c[{i, j, k, \(i\^*\)}]\ p[\(j\^*\)]\ p[\(k\^*\)] - 
      c[{j, k, \(i\^*\)}]\ \((1 - p[i])\)\ p[\(j\^*\)]\ p[\(k\^*\)] + 
      c[{j, k, \(i\^*\)}]\ p[i]\ p[\(j\^*\)]\ p[\(k\^*\)] - 
      2\ c[{i, k, \(i\^*\)}]\ \((1 - p[j])\)\ p[\(j\^*\)]\ p[\(k\^*\)] + 
      c[{k, \(i\^*\)}]\ \((1 - p[i])\)\ \((1 - p[j])\)\ p[\(j\^*\)]\ 
        p[\(k\^*\)] - 
      c[{k, \(i\^*\)}]\ p[i]\ \((1 - p[j])\)\ p[\(j\^*\)]\ p[\(k\^*\)] + 
      2\ c[{i, j, \(i\^*\)}]\ p[k]\ p[\(j\^*\)]\ p[\(k\^*\)] - 
      c[{j, \(i\^*\)}]\ \((1 - p[i])\)\ p[k]\ p[\(j\^*\)]\ p[\(k\^*\)] + 
      c[{j, \(i\^*\)}]\ p[i]\ p[k]\ p[\(j\^*\)]\ p[\(k\^*\)] - 
      2\ c[{i, \(i\^*\)}]\ \((1 - p[j])\)\ p[k]\ p[\(j\^*\)]\ p[\(k\^*\)] - 
      c[{i, j, k}]\ \((1 - p[\(i\^*\)])\)\ p[\(j\^*\)]\ p[\(k\^*\)] - 
      c[{j, k}]\ p[i]\ \((1 - p[\(i\^*\)])\)\ p[\(j\^*\)]\ p[\(k\^*\)] + 
      c[{i, k}]\ \((1 - p[j])\)\ \((1 - p[\(i\^*\)])\)\ p[\(j\^*\)]\ 
        p[\(k\^*\)] - 
      c[{i, j}]\ p[k]\ \((1 - p[\(i\^*\)])\)\ p[\(j\^*\)]\ p[\(k\^*\)] + 
      p[i]\ \((1 - p[j])\)\ p[k]\ \((1 - p[\(i\^*\)])\)\ p[\(j\^*\)]\ 
        p[\(k\^*\)] + c[{i, j, k}]\ p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)] - 
      c[{j, k}]\ \((1 - p[i])\)\ p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)] - 
      c[{i, k}]\ \((1 - p[j])\)\ p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)] + 
      c[{i, j}]\ p[k]\ p[\(i\^*\)]\ p[\(j\^*\)]\ p[\(k\^*\)] + 
      \((1 - p[i])\)\ \((1 - p[j])\)\ p[k]\ p[\(i\^*\)]\ p[\(j\^*\)]\ 
        p[\(k\^*\)]\)], "Output",
  CellLabel->"Out[109]="]
}, Closed]],

Cell["\<\
This is a compiled version, which requires that moments and allele \
frequencies be given as lists of numbers.  Allele frequencies are now assumed \
to be the same across the male & female gamete pools: \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(n = 3; pp = {0.2, 0.3, 0.4}; \n
    DiploidGenotypeFrequency[{1, 1, 2}, Array[0&, 2\^\(2  n\) - 2  n - 1], pp]
      \)], "Input",
  CellLabel->"In[110]:="],

Cell[BoxData[
    \(0.0215039999999999986`\)], "Output",
  CellLabel->"Out[110]="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{550, 692},
WindowMargins->{{Automatic, -16}, {Automatic, -2}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "HaploidGenotypeFrequency"->{
    Cell[1801, 53, 553, 10, 84, "DefinitionBox",
      CellTags->"HaploidGenotypeFrequency"]},
  "DiploidGenotypeFrequency"->{
    Cell[6180, 197, 617, 12, 98, "DefinitionBox",
      CellTags->"DiploidGenotypeFrequency"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"HaploidGenotypeFrequency", 21768, 485},
  {"DiploidGenotypeFrequency", 21895, 488}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 59, 0, 36, "SubsectionIcon"],
Cell[1801, 53, 553, 10, 84, "DefinitionBox",
  CellTags->"HaploidGenotypeFrequency"],
Cell[2357, 65, 125, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2507, 72, 115, 2, 27, "Input"],
Cell[2625, 76, 191, 3, 20, "Output"]
}, Closed]],
Cell[2831, 82, 212, 6, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[3068, 92, 143, 3, 27, "Input"],
Cell[3214, 97, 80, 2, 20, "Output"]
}, Closed]],
Cell[3309, 102, 73, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[3407, 106, 154, 4, 27, "Input"],
Cell[3564, 112, 80, 2, 20, "Output"]
}, Closed]],
Cell[3659, 117, 166, 4, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[3850, 125, 83, 2, 27, "Input"],
Cell[3936, 129, 94, 2, 20, "Output"]
}, Closed]],
Cell[4045, 134, 130, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[4200, 141, 450, 9, 87, "Input"],
Cell[4653, 152, 185, 4, 20, "Output"]
}, Closed]],
Cell[4853, 159, 48, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[4926, 163, 389, 8, 72, "Input"],
Cell[5318, 173, 187, 4, 20, "Output"]
}, Closed]],
Cell[5520, 180, 415, 8, 60, "DefinitionBox"],
Cell[5938, 190, 239, 5, 36, "Text"],
Cell[6180, 197, 617, 12, 98, "DefinitionBox",
  CellTags->"DiploidGenotypeFrequency"],
Cell[6800, 211, 512, 12, 54, "Text"],

Cell[CellGroupData[{
Cell[7337, 227, 111, 2, 27, "Input"],
Cell[7451, 231, 12884, 209, 905, "Output"]
}, Closed]],
Cell[20350, 443, 227, 4, 32, "Text"],

Cell[CellGroupData[{
Cell[20602, 451, 176, 4, 42, "Input"],
Cell[20781, 457, 82, 2, 20, "Output"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

