(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10992,        371]*)
(*NotebookOutlinePosition[     12154,        409]*)
(*  CellTagsIndexPosition[     12053,        402]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Finding the MLE", "SubsectionIcon"],

Cell[TextData[{
  "For details of this method, see the sections above  on the ",
  ButtonBox["Metropolis",
    ButtonData:>{"Metropolis algorithm", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Metropolis"],
  " algorithm and on ",
  ButtonBox["MetropolisDisequilibrium[]",
    ButtonData:>{"Estimating moments", "MetropolisDisequilibrium"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"MetropolisDisequilibrium[]"],
  "."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"FindMLE", "[", 
              RowBox[{"s", ",", 
                RowBox[{"{", 
                  RowBox[{\(Log[L]\), ",", 
                    RowBox[{"{", 
                      RowBox[{\({{p\_1, \[Ellipsis]}}\), ",", 
                        RowBox[{"{", 
                          RowBox[{"{", 
                            RowBox[{
                              SubscriptBox[
                                StyleBox["\[Delta]p",
                                  FontSlant->"Italic"], "1"], ",", 
                              "\[Ellipsis]"}], "}"}], "}"}], 
                        ",", \({{\[Kappa]\_\(0, 0\), \[Ellipsis]} \
\[Ellipsis]}\)}], "}"}], 
                    ",", \({{{\[CapitalDelta]p\_1, \[Ellipsis]}}, {{\
\[CapitalDelta]\[Delta]p\_1, \[Ellipsis]}}, {{\[CapitalDelta]\[Kappa]\_\(0, 0\
\), \[Ellipsis]} \[Ellipsis]}}\)}], "}"}], ",", 
                StyleBox["metList",
                  FontSlant->"Italic"]}], "]"}], 
            
            RowBox[{\(returns\ the\ MLE\ for\ the\ site\ s\), ",", 
              " ", \(using\ the\ Metropolis\ algorithm\ \((see\ \
MetropolisDisequilibrium[])\) . \ \ The\ initial\ allele\ frequencies\), ",", 
              " ", "divergences", ",", 
              " ", \(and\ matrix\ of\ cumulants\ are\ supplied\ as\ a\ \
triplet\ of\ lists\), ",", 
              " ", \({{{p\_1, \[Ellipsis]}}, {{\[Delta]p\_1, \[Ellipsis]}}, \
{{\[Kappa]\_\(0, 0\), \[Ellipsis]} \[Ellipsis]}}; \ 
              the\ initial\ step\ sizes\ take\ the\ same\ form\), ",", " ", 
              RowBox[{
                
                RowBox[{\({{{\[CapitalDelta]p\_1, \[Ellipsis]}}, {{\
\[CapitalDelta]\[Delta]p\_1, \[Ellipsis]}}, {{\[CapitalDelta]\[Kappa]\_\(0, 0\
\), \[Ellipsis]} \[Ellipsis]}}\), ".", "  ", 
                  StyleBox["metList",
                    FontSlant->"Italic"]}], " ", "has", " ", "the", " ", 
                "form", " ", \({{T, {\(n\_tries\) n\_print}} .. }\)}], ",", 
              " ", \(and\ determines\ the\ sequence\ of\ temperatures\ that\ \
is\ \(\(tried\)\(.\)\)\)}]},
          {\(Cumulant \[Rule] 
              False\), \(fits\ moments\ instead\ of\ \
\(\(cumulants\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"FindMLE", "Cumulant"}],

Cell["Here are the allele frequencies for site 1063:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pl = \(\(AlleleFrequencyTable[1063, 4] // N\) // Transpose\) // 
        Last\)], "Input",
  CellLabel->"In[127]:="],

Cell["", "Output"]
}, Closed]],

Cell["\<\
This matrix of cumulants represents a population in Hardy-Weinberg \
and linkage equilibrium, for 4 loci:\
\>", "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{"c0", "=", 
        RowBox[{"(", GridBox[{
              {"1", "0", "0", "0", "0"},
              {"0", "0", "0", "0", "0"},
              {"0", "0", "0", "0", "0"},
              {"0", "0", "0", "0", "0"},
              {"0", "0", "0", "0", "0"}
              }], ")"}]}], ";", \(\[Delta]p = {1, 1, 1, 1}\), ";"}]], "Input",\

  CellLabel->"In[84]:="],

Cell["\<\
Here is a suitable initial step size for the matrix of cumulants, \
assuming HWLE: \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(is = InitialStep[pl, \[Delta]p, c0]; is // MatrixForm\)], "Input",
  CellLabel->"In[128]:="],

Cell["", "Output"]
}, Closed]],

Cell[TextData[{
  "This list specifies an \"annealing schedule\".  There should be 100 tries \
with temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T = 2\)]],
  "; 100 tries with temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T = 1\)]],
  "; and 100 tries with temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T = 0\)]],
  " (i.e., climbing uphill).   Information is printed every 10 tries:"
}], "MathCaption"],

Cell[BoxData[
    \(metList = {{1, {100, 10}}, {0.1, {100, 10}}, {0, {100, 
            10}}}; \)], "Input",
  CellLabel->"In[129]:="],

Cell[TextData[{
  "This calls MetropolisDisequilibrium[] for that schedule; the initial \
population is in HWLE and at the observed allele frequencies, ",
  StyleBox["pl",
    FontSlant->"Italic"],
  ".  The divergences are fixed at 1: "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(met = 
      FindMLE[1063, {0, {{pl}, {{1, 1, 1, 1}}, 
            c0}, {{0.05 \@\( pl \((1 - pl)\)\)}, {{0, 0, 0, 0}}, is}}, 
        metList]\)], "Input",
  CellLabel->"In[130]:="],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Print"],

Cell["", "Output"]
}, Closed]],

Cell["\<\
The output is in the same form as the parameters that were \
supplied.  The first element gives the log likelihood; the second, the MLE \
for allele frequencies and moments; and the third, the current step \
sizes.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(FindMLE[
              s, {p\_1, \[Ellipsis]}, {{c\_\(0, 0\), \[Ellipsis]} \
\[Ellipsis]}]\), \(returns\ the\ likelihood\ for\ some\ actual\ allele\ \
frequencies\ and\ cumulants; \ 
            calls\ \(\(LogLikelihoodDisequilibrium[]\)\(.\)\)\)},
          {\(FindMLE[s, {p\_1, \[Ellipsis]}]\), \(assumes\ Hardy - 
              Weinberg\ and\ linkage\ \(\(equilibrium\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["\<\
This is the log likelihood for the observed allele frequencies, \
assuming HWLE:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMLE[1063, pl]\)], "Input",
  CellLabel->"In[88]:="],

Cell[BoxData[
    \({\(-45.2726915967121179`\), {{{0.391891891891891894`, 
            0.175675675675675684`, 0.324324324324324342`, 
            0.310810810810810789`}}, {{1, 1, 1, 1}}, {{1, 0, 0, 0, 0}, {0, 0, 
            0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 
            0}}}}\)], "Output",
  CellLabel->"Out[88]="]
}, Closed]],

Cell[TextData[{
  "The same is returned if ",
  "cumulants",
  " are specified as zero (except for ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(0, 0\)\)]],
  "=1)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FindMLE", "[", 
      RowBox[{"1063", ",", "pl", ",", \({1, 1, 1, 1}\), ",", 
        RowBox[{"(", GridBox[{
              {"1", "0", "0", "0", "0"},
              {"0", "0", "0", "0", "0"},
              {"0", "0", "0", "0", "0"},
              {"0", "0", "0", "0", "0"},
              {"0", "0", "0", "0", "0"}
              }], ")"}]}], "]"}]], "Input",
  CellLabel->"In[89]:="],

Cell[BoxData[
    \({\(-45.2726915967121179`\), {{{0.391891891891891894`, 
            0.175675675675675684`, 0.324324324324324342`, 
            0.310810810810810789`}}, {{1, 1, 1, 1}}, {{1, 0, 0, 0, 0}, {0, 0, 
            0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 
            0}}}}\)], "Output",
  CellLabel->"Out[89]="]
}, Closed]],

Cell[TextData[{
  "A cross-genome ",
  "cumulants",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(1, 1\)\)]],
  "=0.01 is slightly more likely:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"FindMLE", "[", 
      RowBox[{"1063", ",", "pl", ",", \({1, 1, 1, 1}\), ",", 
        RowBox[{"(", GridBox[{
              {"1", "0", "0", "0", "0"},
              {"0", "0.01", "0", "0", "0"},
              {"0", "0", "0", "0", "0"},
              {"0", "0", "0", "0", "0"},
              {"0", "0", "0", "0", "0"}
              }], ")"}]}], "]"}]], "Input",
  CellLabel->"In[90]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(-41.2528773739529164`\), ",", 
        RowBox[{"{", 
          
          RowBox[{\({{0.391891891891891894`, 0.175675675675675684`, 
                0.324324324324324342`, 0.310810810810810789`}}\), 
            ",", \({{1, 1, 1, 1}}\), ",", 
            RowBox[{"{", 
              RowBox[{\({1, 0, 0, 0, 0}\), ",", 
                RowBox[{"{", 
                  RowBox[{"0", ",", 
                    StyleBox["0.01`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->1], ",", "0", ",", "0", ",", "0"}], 
                  "}"}], ",", \({0, 0, 0, 0, 0}\), ",", \({0, 0, 0, 0, 0}\), 
                ",", \({0, 0, 0, 0, 0}\)}], "}"}]}], "}"}]}], "}"}]], "Output",\

  CellLabel->"Out[90]="]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{785, 602},
WindowMargins->{{Automatic, 109}, {Automatic, 46}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "FindMLE"->{
    Cell[2210, 65, 2330, 47, 134, "DefinitionBox",
      CellTags->{"FindMLE", "Cumulant"}]},
  "Cumulant"->{
    Cell[2210, 65, 2330, 47, 134, "DefinitionBox",
      CellTags->{"FindMLE", "Cumulant"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"FindMLE", 11824, 392},
  {"Cumulant", 11934, 395}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 41, 0, 36, "SubsectionIcon"],
Cell[1761, 51, 446, 12, 23, "Text"],
Cell[2210, 65, 2330, 47, 134, "DefinitionBox",
  CellTags->{"FindMLE", "Cumulant"}],
Cell[4543, 114, 69, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4637, 118, 136, 3, 26, "Input"],
Cell[4776, 123, 18, 0, 70, "Output"]
}, Closed]],
Cell[4809, 126, 136, 3, 18, "MathCaption"],
Cell[4948, 131, 393, 11, 88, "Input"],
Cell[5344, 144, 114, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5483, 151, 112, 2, 26, "Input"],
Cell[5598, 155, 18, 0, 70, "Output"]
}, Closed]],
Cell[5631, 158, 434, 12, 32, "MathCaption"],
Cell[6068, 172, 134, 3, 26, "Input"],
Cell[6205, 177, 256, 6, 44, "MathCaption"],

Cell[CellGroupData[{
Cell[6486, 187, 202, 5, 50, "Input"],
Cell[6691, 194, 17, 0, 70, "Print"],
Cell[6711, 196, 17, 0, 70, "Print"],
Cell[6731, 198, 17, 0, 70, "Print"],
Cell[6751, 200, 17, 0, 70, "Print"],
Cell[6771, 202, 17, 0, 70, "Print"],
Cell[6791, 204, 17, 0, 70, "Print"],
Cell[6811, 206, 17, 0, 70, "Print"],
Cell[6831, 208, 17, 0, 70, "Print"],
Cell[6851, 210, 17, 0, 70, "Print"],
Cell[6871, 212, 17, 0, 70, "Print"],
Cell[6891, 214, 17, 0, 70, "Print"],
Cell[6911, 216, 17, 0, 70, "Print"],
Cell[6931, 218, 17, 0, 70, "Print"],
Cell[6951, 220, 17, 0, 70, "Print"],
Cell[6971, 222, 17, 0, 70, "Print"],
Cell[6991, 224, 17, 0, 70, "Print"],
Cell[7011, 226, 17, 0, 70, "Print"],
Cell[7031, 228, 17, 0, 70, "Print"],
Cell[7051, 230, 17, 0, 70, "Print"],
Cell[7071, 232, 17, 0, 70, "Print"],
Cell[7091, 234, 17, 0, 70, "Print"],
Cell[7111, 236, 17, 0, 70, "Print"],
Cell[7131, 238, 17, 0, 70, "Print"],
Cell[7151, 240, 17, 0, 70, "Print"],
Cell[7171, 242, 17, 0, 70, "Print"],
Cell[7191, 244, 17, 0, 70, "Print"],
Cell[7211, 246, 17, 0, 70, "Print"],
Cell[7231, 248, 17, 0, 70, "Print"],
Cell[7251, 250, 17, 0, 70, "Print"],
Cell[7271, 252, 17, 0, 70, "Print"],
Cell[7291, 254, 18, 0, 70, "Output"]
}, Closed]],
Cell[7324, 257, 238, 5, 32, "Text"],
Cell[7565, 264, 497, 9, 72, "DefinitionBox"],
Cell[8065, 275, 104, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[8194, 282, 75, 2, 26, "Input"],
Cell[8272, 286, 339, 6, 35, "Output"]
}, Closed]],
Cell[8626, 295, 180, 7, 18, "Text"],

Cell[CellGroupData[{
Cell[8831, 306, 408, 10, 88, "Input"],
Cell[9242, 318, 339, 6, 35, "Output"]
}, Closed]],
Cell[9596, 327, 163, 7, 18, "Text"],

Cell[CellGroupData[{
Cell[9784, 338, 411, 10, 88, "Input"],
Cell[10198, 350, 778, 18, 35, "Output"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

