(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    128502,       2458]*)
(*NotebookOutlinePosition[    129384,       2486]*)
(*  CellTagsIndexPosition[    129340,       2482]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Making a random walk", "SubsectionIcon"],

Cell[TextData[{
  "If the Metropolis algorithm is run at a constant ",
  Cell[BoxData[
      \(TraditionalForm\`T = 1\)]],
  ", then the random walk that is generated has a distribution equal to the \
liikelihood.  This is a convenient way of generating the likelihood surface.  \
(The likelihood could also be interpreted as a Bayesian probability density \
with uniform prior)."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MakeRandomWalk[
              s, {Log[L], {{{\(p\_1\) \[Ellipsis]}}, {{\(\[Delta]p\_1\) \
\[Ellipsis]}}, {{\(\[Kappa]\_\(0, 
                            0\)\) \[Ellipsis]}}}, {{{\(\[CapitalDelta]p\_1\) \
\[Ellipsis]}}, {{\(\[CapitalDelta]\[Delta]p\_1\) \[Ellipsis]}}, {{\(\
\[CapitalDelta]\[Kappa]\_\(0, 0\)\) \[Ellipsis]}}}}, {T, {n\_tries, 
                  n\_print}}, \ 
              n\_values]\), \(generates\ a\ random\ walk\ at\ temperature\ T; \
\ with\ T = 1, \ 
            this\ follows\ the\ likelihood\ surface . \ \ Each\ element\ of\ \
the\ output\ list\ has\ the\ same\ form\ as\ the\ second\ argument . \ \ \
Output\ is\ generated\ every\ n\_tries\ cycles; \ 
            the\ total\ number\ of\ elements\ is\ \(\(n\_values\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell[BoxData[
    RowBox[{
      RowBox[{"c0", "=", 
        RowBox[{"(", GridBox[{
              {"1", "0", "0", "0", "0"},
              {"0", "0", "0", "0", "0"},
              {"0", "0", "0", "0", "0"},
              {"0", "0", "0", "0", "0"},
              {"0", "0", "0", "0", "0"}
              }], ")"}]}], ";", \(\[Delta]p = {1, 1, 1, 1}\), ";"}]], "Input",\

  CellLabel->"In[9]:="],

Cell["\<\
Here is a suitable initial step size for the matrix of cumulants, \
assuming HWLE: \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(is = InitialStep[pl, \[Delta]p, c0]; is // MatrixForm\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0.0327544231718888978`", "0.0169545603960927726`", 
              "0.00885436203186386094`"},
            {"0", "0.00830225125570920319`", "0.00225197467170609`", 
              "0.00116568197160866771`", "0.000608766606123186893`"},
            {"0.0327544231718888978`", "0.00225197467170609`", 
              "0.000428785319924375496`", "0.000221950683285274896`", 
              "0.000115911687305102417`"},
            {"0.0169545603960927726`", "0.00116568197160866771`", 
              "0.000221950683285274896`", "0.000097832194591125603`", 
              "0.0000510919569156866781`"},
            {"0.00885436203186386094`", "0.000608766606123186893`", 
              "0.000115911687305102417`", "0.0000510919569156866781`", 
              "0.0000614484346688664029`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[12]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "This calls MetropolisDisequilibrium[] 100 times; the initial population is \
in HWLE and at the observed allele frequencies, ",
  StyleBox["pl",
    FontSlant->"Italic"],
  ".  The divergences are fixed at 1, but allele frequencies and cumulants \
are free to vary:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(met = 
      MakeRandomWalk[
        1063, {0, {{pl}, {{1, 1, 1, 1}}, 
            c0}, {{0.05 \@\( pl \((1 - pl)\)\)}, {{0, 0, 0, 0}}, 
            is}}, {1, {10, 20}}, 100]\)], "Input",
  CellLabel->"In[14]:="],

Cell["", "Output"]
}, Closed]],

Cell[TextData[{
  "Making ",
  Cell[BoxData[
      \(TraditionalForm\`n\_print\)]],
  "> ",
  Cell[BoxData[
      \(TraditionalForm\`n\_tries\)]],
  " ensures that intermediate results are not printed out."
}], "Text"],

Cell["This shows how the likelihood changes during the walk: ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[First /@ met];\)\)], "Input",
  CellLabel->"In[37]:="],

Cell[GraphicsData["PostScript", ], "Graphics",
  CellLabel->"From In[37]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0
ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`@00?moo`Qoo`005Goo00@007oo00000?moo`Qo
o`005Goo00<007ooOol0:goo10000goo0P00;7oo0`000goo0P00:goo0P0017oo0P00:goo0P0017oo
0P00:7oo0`0017oo0P0017oo0P000goo000EOol00`00Oomoo`0/Ool00`00Oomoo`02Ool01000Oomo
o`00;7oo00D007ooOomoo`00009oo`03001oogoo02Moo`04001oogoo0002Ool01000Oomoo`00:Goo
00@007ooOol0009oo`04001oogoo000XOol00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0
009oo`005Goo00<007ooOol0;Goo00D007ooOomoo`00009oo`03001oogoo02Qoo`@0009oo`04001o
ogoo000YOol01000Oomoo`000Woo00@007ooOol002Uoo`04001oogoo0002Ool01000Oomoo`00:7oo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0002Ool001Eoo`03001oogoo02ioo`04001o
ogoo0002Ool00`00Oomoo`0XOol00`00Ool00003Ool01000Oomoo`00:Goo0`000goo00@007ooOol0
02Yoo`8000=oo`04001oogoo000XOol00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0009o
o`005Goo0P00;7oo00@007ooOol0009oo`04001oogoo000ZOol00`00Ool00003Ool01000Oomoo`00
:Goo00<007ooOol00goo00@007ooOol002Uoo`04001oogoo0002Ool01000Oomoo`00:7oo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0002Ool001Eoo`03001oogoo02aoo`8000Aoo`8002ao
o`8000Aoo`8002]oo`<000=oo`8002]oo`8000Aoo`8002Qoo`8000Eoo`8000Aoo`8000=oo`005Goo
00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo
00<007ooOol0ogoo2Goo000>Oooo000@0003Ool001Eoo`03001oogoo00Yoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03
001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03
001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03
001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Moo`005Goo00<007ooOol0
<7oo00<007ooOol0<Goo00<007ooOol0<7oo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol0
1goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo
2Goo000EOol2003oOol:Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000E
Ool00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000E
Ool2003oOol:Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00
Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol2003o
Ool:Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3o
Ool9Ool000Qoo`<0009oo`@000Aoo`03001oogoo0?moo`Uoo`002Goo00<007ooOol00Woo00<007oo
Ool017oo00<007ooOol0ogoo2Goo00000goo0000000300000goo000000020004Ool00`00Oomoo`03
Ool3003oOol9Ool000Moo`03001oo`0000Ioo`03001oogoo009oo`03001oogoo0?moo`Uoo`001goo
00<007oo00000goo00@007ooOol000Aoo`03001oogoo0?moo`Uoo`0027oo0P0017oo0P001Goo00@0
07ooOomoo`800?moo`Ioo`005Goo00@007ooOomoo`800?moo`Ioo`005Goo00<007ooOol0ogoo2Goo
000EOol2003oOol:Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol0
0`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0H7oo0P00YWoo000E
Ool2001QOol2002VOol001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol0
0`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol2
003oOol:Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomo
o`1gOol2001COol2000jOol000Qoo`<000=oo`8000Eoo`03001oogoo07Moo`8005=oo`8003Yoo`00
2Goo00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo031oo`8003Aoo`8001Yoo`8008Ao
o`0000=oo`0000000`0000=oo`0000000P000Woo00@007ooOol000Aoo`<0031oo`8003Aoo`8001Yo
o`8008Aoo`001goo00<007oo00000goo00@007ooOol000Aoo`03001oogoo0?moo`Uoo`001goo00<0
07oo00000goo00@007ooOol000Aoo`03001oogoo0?moo`Uoo`0027oo0P0017oo0P001Goo00<007oo
Ool017oo0P00X7oo0P00H7oo000EOol00`00Oomoo`04Ool2000iOol2000ROol20011Ool2001POol0
01Eoo`03001oogoo03moo`8001Eoo`8000]oo`800:=oo`005Goo0P0027oo0P00CGoo0P00/7oo000E
Ool00`00Oomoo`07Ool2000kOol20032Ool001Eoo`03001oogoo04Aoo`800003Ool000000;moo`00
5Goo00<007ooOol0Agoo0P00_goo000EOol00`00Oomoo`09Ool20019Ool2002bOol001Eoo`03001o
ogoo00Uoo`8002Moo`8000Ioo`8001Qoo`8007Uoo`8003Moo`005Goo0P00<goo0P001Woo0P00R7oo
0P002Goo0P00=goo000EOol00`00Oomoo`24Ool2000nOol20012Ool001Eoo`03001oogoo08Aoo`80
03Aoo`8004aoo`005Goo00<007ooOol07Woo0P00DWoo0P00AWoo0P00C7oo000EOol00`00Oomoo`0N
Ool2001BOol2002DOol001Eoo`03001oogoo0:5oo`8006Eoo`005Goo0P00XWoo0P00IGoo000EOol0
0`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo0007Ool3
0004Ool20005Ool00`00Oomoo`1>Ool2002hOol000Yoo`04001oogoo0002Ool00`00Oomoo`02Ool0
0`00Oomoo`1>Ool2000HOol2001lOol2000POol00003Ool0000000<000Aoo`04001oogoo0002Ool0
0`00Oomoo`02Ool3001XOol2001lOol2000POol000Qoo`8000Aoo`8000Eoo`03001oogoo021oo`80
08]oo`8005Uoo`002Woo00@007ooOol0009oo`03001oogoo009oo`03001oogoo021oo`8004ioo`80
03]oo`8005Uoo`001goo0`0017oo0P001Goo00<007ooOol0=Goo0P001Goo0P0017oo0P00;7oo0P00
UWoo000EOol00`00Oomoo`0eOol20005Ool20004Ool2000=Ool20008Ool2001ROol2000WOol2000N
Ool001Eoo`03001oogoo04Uoo`8000Ioo`8000Qoo`80069oo`8002Moo`8001ioo`005Goo0P00;Woo
0P006Woo0P00;goo0P009goo0P00>Goo0P00:7oo000EOol00`00Oomoo`0]Ool2001;Ool2000WOol2
000iOol2000EOol2000AOol001Eoo`03001oogoo0>5oo`80019oo`80015oo`005Goo00<007ooOol0
GWoo0P00PGoo0P009Goo000EOol00`00Oomoo`1NOol2001aOol2000eOol001Eoo`03001oogoo01Uo
o`8001aoo`80021oo`8002aoo`8004Qoo`8003Eoo`005Goo0P006Woo0P0077oo0P0087oo0P00;7oo
0P00;goo0P00CWoo000EOol00`00Oomoo`2hOol2000LOol2000`Ool001Eoo`03001oogoo01=oo`80
0;Eoo`8000Yoo`80031oo`005Goo00<007ooOol04goo0P0047oo0P0000=oo`000000EGoo0P00=7oo
0P004goo0P005goo0P003Woo0P004goo000EOol00`00Oomoo`0>Ool2000EOol200000goo0000001E
Ool2000dOol2000/Ool2000>Ool2000COol001Eoo`03001oogoo00aoo`@00?Qoo`005Goo0P003Goo
0P00XWoo0P009goo0P00;Goo000EOol00`00Oomoo`29Ool2000UOol2000WOol2000]Ool001Eoo`03
001oogoo02]oo`8005aoo`8001eoo`8005ioo`005Goo00<007ooOol0:goo0P00Ngoo0P00GWoo0007
Ool30004Ool20005Ool00`00Oomoo`2mOol20019Ool000Yoo`04001oogoo0002Ool00`00Oomoo`02
Ool00`00Oomoo`0KOol2001HOol2000OOol2000UOol20003Ool20014Ool00003Ool0000000<000Ao
o`04001oogoo0002Ool00`00Oomoo`02Ool3000KOol2001HOol2000OOol2000ZOol2000@Ool2000b
Ool000Qoo`8000=oo`<000Eoo`03001oogoo0=Aoo`80039oo`002Woo00@007ooOol000Moo`03001o
ogoo07eoo`8008Uoo`001goo0`0017oo0`0017oo00<007ooOol0OGoo0P00RGoo000EOol00`00Oomo
o`2[Ool2000_Ool2000ZOol001Eoo`03001oogoo06eoo`8002Eoo`8001Eoo`8002moo`8002Yoo`00
5Goo0P00KWoo0P009Goo0P00LWoo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo095oo`80
07Eoo`005Goo00<007ooOol05Woo0P00NGoo0P00MGoo000EOol00`00Oomoo`0FOol2003`Ool001Eo
o`03001oogoo0?moo`Uoo`005Goo0P00ogoo2Woo000EOol00`00Oomoo`2cOol2001COol001Eoo`03
001oogoo015oo`800:1oo`8003Ioo`8001]oo`005Goo00<007ooOol04Goo0P00>Goo0P00?Woo0P00
>Goo0P008Woo0P006goo000EOol00`00Oomoo`1<Ool2000nOol2000=Ool2000ZOol2000oOol001Eo
o`03001oogoo09]oo`800003Ool0000006Qoo`005Goo0P00Wgoo0P00D7oo0P005Woo000EOol00`00
Oomoo`3`Ool2000FOol001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo0007Ool3
0004Ool30004Ool00`00Oomoo`2IOol2001]Ool000Yoo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo09Uoo`8006eoo`0000=oo`0000000`0017oo00<007ooOol0100017oo0`00Jgoo0P008Woo
0P00Mgoo0008Ool20003Ool00`00Ool00005Ool00`00Oomoo`1[Ool2000ROol2001YOol2000<Ool0
00Yoo`06001oogoo001oo`001Goo00<007ooOol0nWoo0P0037oo0007Ool30004Ool20005Ool00`00
Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol2003o
Ool:Ool001Eoo`03001oogoo02=oo`800>=oo`005Goo00<007ooOol08goo0P00bGoo0P0067oo000E
Ool00`00Oomoo`3^Ool2000HOol001Eoo`03001oogoo0?eoo`8000Uoo`005Goo00<007ooOol0oGoo
0P002Goo000EOol2003oOol:Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo
000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo
000EOol2003oOol:Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol0
0`00Oomoo`3oOol9Ool000Moo`<000=oo`@000Aoo`03001oogoo0?moo`Uoo`002Woo00D007ooOomo
o`0000Ioo`03001oogoo0?moo`Uoo`0000=oo`0000000`0017oo00<007ooOol00Woo00<007ooOol0
0goo0`00ogoo2Goo0008Ool20006Ool00`00Oomoo`02Ool00`00Oomoo`3oOol9Ool000Yoo`04001o
ogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`3oOol9Ool000Moo`<000Aoo`8000Eoo`03001oogoo
0?Qoo`8000ioo`005Goo00<007ooOol0n7oo0P003Woo000EOol00`00Oomoo`3oOol9Ool001Eoo`80
0?moo`Yoo`005Goo00<007ooOol0ogoo2Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-8.32696, -45.7125, \
0.389667, 0.0831617}}]
}, Open  ]],

Cell["\<\
There is no systematic increase after the first 10 tries, which \
suggests that a statistical equilibrium has been reached.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pWalk = \(#\[LeftDoubleBracket]2, 1, 1\[RightDoubleBracket] &\) /@ 
        met\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \({{0.348140541376794043`, 0.19383772662041407`, 0.32513924498208202`, 
        0.352968185719201876`}, {0.376989668748573691`, 
        0.214037815062022351`, 0.303069718690227318`, 
        0.358918037625883457`}, {0.446912016555639635`, 0.26923792961344759`, 
        0.271710625674441219`, 
        0.317749195039389231`}, {0.289641740708711115`, 
        0.287909195855416477`, 0.31042441818625428`, 
        0.274462083998633055`}, {0.367954126693063265`, 
        0.261879915224842463`, 0.31345746655527531`, 
        0.362128180091409612`}, {0.35860237069030072`, 0.25554162063548218`, 
        0.328686021982129883`, 
        0.233906387417390426`}, {0.418508266967315822`, 
        0.281030786465877735`, 0.37019798513472395`, 
        0.323263264086610435`}, {0.442345147447357778`, 
        0.275236938696499144`, 0.400054980485678246`, 
        0.340760702769729961`}, {0.403869000059326399`, 0.29802396687501762`, 
        0.438103607199028388`, 0.31488925608373286`}, {0.452544160117837357`, 
        0.259508694546225937`, 0.380354614471380703`, 
        0.402453652572466857`}, {0.36477130868042451`, 0.290604880539266741`, 
        0.335862127889642492`, 
        0.419328473866766682`}, {0.342144301561439512`, 
        0.291007524639948123`, 0.358585174005856144`, 
        0.326025859192431788`}, {0.350177810195351923`, 
        0.313260068317144835`, 0.351568944029109697`, 
        0.344540340680139145`}, {0.368457193361540458`, 
        0.363211355565029503`, 0.392352282910466776`, 
        0.30637220183103011`}, {0.403293973480551226`, 0.308724864630123496`, 
        0.357695496830963666`, 
        0.349369829461681158`}, {0.395657162428685573`, 
        0.300840791036428134`, 0.320238514410928098`, 
        0.389813164327159089`}, {0.355629213147602651`, 
        0.307985832557254912`, 0.307504994318845481`, 
        0.339843312904055583`}, {0.448744381872749986`, 
        0.322858875427708458`, 0.419744897293430518`, 
        0.389630930330182678`}, {0.466855940310478167`, 
        0.331950450023931198`, 0.440861669227723496`, 
        0.460527160071152952`}, {0.458541121461703582`, 0.32280651667807132`, 
        0.342814690754933248`, 
        0.473545228680671659`}, {0.366270558252498945`, 
        0.337410737221178358`, 0.373007473805822398`, 
        0.378628180361951649`}, {0.391109918656366239`, 
        0.340199236054387554`, 0.420679272137479554`, 
        0.327735110161927734`}, {0.400484757670193491`, 
        0.335857132567515881`, 0.399748140581519564`, 
        0.325946857618019958`}, {0.360934539659310171`, 0.32181160067688368`, 
        0.406596635362657909`, 
        0.367126984505500564`}, {0.414823969030725692`, 
        0.315051203936002321`, 0.415799311184778019`, 
        0.41737790948559148`}, {0.421914744016249088`, 0.299261351520420415`, 
        0.369520235449552814`, 
        0.410075185413190723`}, {0.402414331803858082`, 
        0.304642891443353613`, 0.351580770234584516`, 
        0.317583073420888783`}, {0.340295089481261259`, 
        0.280545983656518558`, 0.313242659672259771`, 
        0.366807360271267191`}, {0.358167663287327364`, 
        0.261226207044016067`, 0.321741113388481014`, 
        0.359221980182206968`}, {0.371419220155171725`, 0.29995786607935857`, 
        0.444956549173934412`, 0.37147733717330631`}, {0.400948303254384441`, 
        0.292671227765032462`, 0.328018231915809455`, 
        0.29546273953161922`}, {0.43684222669868209`, 0.321253821909439007`, 
        0.391131014519079922`, 
        0.380960235906461264`}, {0.408682701576301443`, 
        0.320833436355500722`, 0.378244712039538644`, 
        0.30531798588570469`}, {0.454531710064403426`, 0.339463279719053012`, 
        0.418052522674462601`, 
        0.467261483499285201`}, {0.412721279443627864`, 
        0.324250113753836188`, 0.391352177851911307`, 
        0.429017400770667833`}, {0.406487561392079843`, 
        0.307204641564917402`, 0.432195257828027035`, 
        0.307956588770618022`}, {0.409633210445070794`, 
        0.309641713633181092`, 0.43654576527640474`, 
        0.317175984005203392`}, {0.39306709376122848`, 0.298362435322104566`, 
        0.379589871802445344`, 
        0.332323340310028259`}, {0.349603995280623536`, 
        0.320439079335905319`, 0.451644730507437941`, 
        0.326243165318742622`}, {0.38506218295404162`, 0.319604294910208253`, 
        0.353899995975818804`, 
        0.312318638287429539`}, {0.447178658364364167`, 
        0.332829752146003121`, 0.368114070595018372`, 
        0.401433282731513507`}, {0.459009374094400612`, 
        0.345179771494566578`, 0.370349169261733512`, 
        0.394299240224951486`}, {0.36995091626764136`, 0.281403813208396069`, 
        0.336879232715260146`, 
        0.312890547179284617`}, {0.382039580091678523`, 
        0.289501069413268563`, 0.353331508012243`, 
        0.35909505700718225`}, {0.410271338772112947`, 0.311801479771168521`, 
        0.385611235300539014`, 
        0.409647923421174908`}, {0.361072143030599512`, 
        0.313326168878007838`, 0.32637164848066269`, 
        0.350122721284946347`}, {0.519008117061972118`, 
        0.296165682687758611`, 0.385307442821726819`, 
        0.333450166058580954`}, {0.358286165391626987`, 0.33655442728095144`, 
        0.383923866273338845`, 
        0.414352654266816955`}, {0.414634367813109783`, 
        0.335432124450360458`, 0.361530311782993285`, 
        0.333770581222252404`}, {0.462912852560081944`, 
        0.310772299900008874`, 0.401816741024247647`, 
        0.368002073091299131`}, {0.370078781552636826`, 
        0.302416434213716645`, 0.395073679363804686`, 
        0.348479093486402646`}, {0.384582615561132499`, 
        0.326830773901010074`, 0.344673732858577697`, 
        0.314195162887281131`}, {0.383763133767194641`, 
        0.354043842886944748`, 0.393784494311083754`, 
        0.350571718535473131`}, {0.388764192714982392`, 0.31522661358921491`, 
        0.364975009261250349`, 
        0.325490668083727907`}, {0.374617677201816512`, 
        0.300996239657131559`, 0.382455307050285817`, 
        0.297012093570544077`}, {0.403388498911248571`, 
        0.248208451061477086`, 0.39421358003212612`, 
        0.278029269115963373`}, {0.433468750949459113`, 
        0.271396425248272121`, 0.335157227411582558`, 
        0.318427606963208376`}, {0.343070898534175405`, 
        0.289524879194788287`, 0.315710403605262346`, 
        0.289349137909015485`}, {0.391612947111101306`, 
        0.262802375472533977`, 0.394391002389455369`, 
        0.417539787382359328`}, {0.407691818873985312`, 
        0.290475845938619503`, 0.400086305244158335`, 
        0.405140244664195581`}, {0.43492654727893214`, 0.277212250879831145`, 
        0.375303199515911423`, 0.36783132738950659`}, {0.393893870354666866`, 
        0.300900076441112895`, 0.377478446552337798`, 
        0.326001622489976039`}, {0.378773376703160868`, 
        0.300401036092697992`, 0.333958792339598176`, 
        0.307058872670418425`}, {0.342990340855247044`, 
        0.309040151048763211`, 0.315851604446457034`, 
        0.306651036755516326`}, {0.3260132621077787`, 0.2957312260577722`, 
        0.365577023928856092`, 
        0.284543413256773636`}, {0.347137332805903264`, 
        0.288199427745328051`, 0.360211233889713478`, 
        0.343540802797210442`}, {0.401436040171159103`, 
        0.258652231410738853`, 0.369030361110945914`, 
        0.317099018394330078`}, {0.401485673368099682`, 
        0.312910356550923829`, 0.342799030123297843`, 
        0.363904800218643931`}, {0.414246782312385697`, 
        0.333401216384627785`, 0.376506574937407734`, 
        0.39044022396367378`}, {0.378649532066002825`, 0.288954654621099891`, 
        0.318604517513211771`, 0.38518273051801156`}, {0.379005306052033974`, 
        0.253314987143479353`, 0.379934851313789279`, 
        0.305582227378881521`}, {0.360078840570926983`, 
        0.267974671990629476`, 0.35533246592329597`, 
        0.372583808186998544`}, {0.386079324300926174`, 
        0.289372883284410455`, 0.352046657782085725`, 
        0.361095874303122732`}, {0.341047038734608953`, 
        0.296188622072408591`, 0.323963306957316454`, 
        0.391352070043072952`}, {0.371463685172848068`, 
        0.311786408468606524`, 0.375863072159982447`, 
        0.345348030143546536`}, {0.350598685484277527`, 
        0.334788819009875915`, 0.33993090403535402`, 
        0.318171732234297222`}, {0.39864103169961762`, 0.340222993612708446`, 
        0.38367491563141316`, 0.347713573349196192`}, {0.392860251428802662`, 
        0.371089090455065262`, 0.396585886797767717`, 
        0.362638577738854817`}, {0.356625268255188876`, 
        0.271078253098831911`, 0.355269043201229139`, 
        0.322903526108016469`}, {0.325205718917618202`, 
        0.294163830771357268`, 0.329484549060531506`, 
        0.314153838574051214`}, {0.277415298724545511`, 
        0.281959827085296268`, 0.298927968313314718`, 
        0.309326613846685205`}, {0.334268471386765142`, 
        0.299875776137491634`, 0.307857501367359942`, 
        0.33987974929139475`}, {0.362948160391828489`, 0.279216730403777768`, 
        0.309574170066684661`, 
        0.280298290999550747`}, {0.320369969775410901`, 
        0.257326337936731031`, 0.322059336645706073`, 
        0.329975701560634115`}, {0.347017079747516277`, 
        0.269758259393820631`, 0.270589344774652351`, 
        0.311986793685812502`}, {0.350404769017321715`, 
        0.300274389860849755`, 0.32083042163273161`, 
        0.307213143055559001`}, {0.399264148524217166`, 
        0.319104820777346098`, 0.36718738950912293`, 
        0.317349143759242391`}, {0.382186722089658736`, 
        0.312911782970972707`, 0.38892975029196064`, 
        0.361122152536401674`}, {0.381069012964535591`, 
        0.320007169037040561`, 0.360740025801010411`, 
        0.378926078907436503`}, {0.399914688288127209`, 
        0.322150435302395843`, 0.361909941646567645`, 
        0.413236568880150834`}, {0.416871463316774715`, 0.35250422909530692`, 
        0.37832685153649348`, 0.383272187973648961`}, {0.413996173191863015`, 
        0.35833132192055892`, 0.355091695022594011`, 
        0.381591954437112654`}, {0.352558838042363387`, 
        0.328660077906034464`, 0.368806894180185418`, 
        0.317004551392152489`}, {0.365101477303043786`, 
        0.273915686963862281`, 0.370215337069654593`, 
        0.366471338776538235`}, {0.344161334303003396`, 
        0.261962854909067921`, 0.373668951188923292`, 
        0.330846128955931462`}, {0.307655649004484876`, 
        0.264909890932291114`, 0.338655960461465177`, 
        0.328990824934333891`}, {0.356833141879223969`, 
        0.248308487051806991`, 0.375397609275667587`, 
        0.398299780585906582`}, {0.377957303511282294`, 
        0.253800922511520576`, 0.363484313210681797`, 
        0.290140921513884322`}, {0.350873274642016008`, 
        0.268470682741252675`, 0.316008319877135734`, 
        0.33401885860663083`}, {0.397650507948686815`, 0.303891523453981715`, 
        0.360018513741935786`, 0.283765774530914516`}}\)], "Output",
  CellLabel->"Out[15]="]
}, Closed]],

Cell["\<\
This is the likelihood of the mean frequency, dropping the first 10 \
tries: \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pWalk = \(#\[LeftDoubleBracket]2, 1, 1\[RightDoubleBracket] &\) /@ met; 
    BarChart[Transpose[{BinCounts[
            Mean /@ Drop[pWalk, 10], {0.28, 0.43, 0.01}], 
          Range[0.285, 0.425, 0.01]}]];\)], "Input",
  CellLabel->"In[41]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0263158 0.0657895 0.0147151 0.0452772 [
[.03947 .00222 -15 -9 ]
[.03947 .00222 15 0 ]
[.10526 .00222 -15 -9 ]
[.10526 .00222 15 0 ]
[.17105 .00222 -15 -9 ]
[.17105 .00222 15 0 ]
[.23684 .00222 -15 -9 ]
[.23684 .00222 15 0 ]
[.30263 .00222 -15 -9 ]
[.30263 .00222 15 0 ]
[.36842 .00222 -15 -9 ]
[.36842 .00222 15 0 ]
[.43421 .00222 -15 -9 ]
[.43421 .00222 15 0 ]
[.5 .00222 -15 -9 ]
[.5 .00222 15 0 ]
[.56579 .00222 -15 -9 ]
[.56579 .00222 15 0 ]
[.63158 .00222 -15 -9 ]
[.63158 .00222 15 0 ]
[.69737 .00222 -15 -9 ]
[.69737 .00222 15 0 ]
[.76316 .00222 -15 -9 ]
[.76316 .00222 15 0 ]
[.82895 .00222 -15 -9 ]
[.82895 .00222 15 0 ]
[.89474 .00222 -15 -9 ]
[.89474 .00222 15 0 ]
[.96053 .00222 -15 -9 ]
[.96053 .00222 15 0 ]
[-0.0125 .10527 -6 -4.5 ]
[-0.0125 .10527 0 4.5 ]
[-0.0125 .19582 -6 -4.5 ]
[-0.0125 .19582 0 4.5 ]
[-0.0125 .28638 -6 -4.5 ]
[-0.0125 .28638 0 4.5 ]
[-0.0125 .37693 -6 -4.5 ]
[-0.0125 .37693 0 4.5 ]
[-0.0125 .46749 -12 -4.5 ]
[-0.0125 .46749 0 4.5 ]
[-0.0125 .55804 -12 -4.5 ]
[-0.0125 .55804 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03947 .01472 m
.03947 .02097 L
s
[(0.285)] .03947 .00222 0 1 Mshowa
.10526 .01472 m
.10526 .02097 L
s
[(0.295)] .10526 .00222 0 1 Mshowa
.17105 .01472 m
.17105 .02097 L
s
[(0.305)] .17105 .00222 0 1 Mshowa
.23684 .01472 m
.23684 .02097 L
s
[(0.315)] .23684 .00222 0 1 Mshowa
.30263 .01472 m
.30263 .02097 L
s
[(0.325)] .30263 .00222 0 1 Mshowa
.36842 .01472 m
.36842 .02097 L
s
[(0.335)] .36842 .00222 0 1 Mshowa
.43421 .01472 m
.43421 .02097 L
s
[(0.345)] .43421 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(0.355)] .5 .00222 0 1 Mshowa
.56579 .01472 m
.56579 .02097 L
s
[(0.365)] .56579 .00222 0 1 Mshowa
.63158 .01472 m
.63158 .02097 L
s
[(0.375)] .63158 .00222 0 1 Mshowa
.69737 .01472 m
.69737 .02097 L
s
[(0.385)] .69737 .00222 0 1 Mshowa
.76316 .01472 m
.76316 .02097 L
s
[(0.395)] .76316 .00222 0 1 Mshowa
.82895 .01472 m
.82895 .02097 L
s
[(0.405)] .82895 .00222 0 1 Mshowa
.89474 .01472 m
.89474 .02097 L
s
[(0.415)] .89474 .00222 0 1 Mshowa
.96053 .01472 m
.96053 .02097 L
s
[(0.425)] .96053 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
0 .10527 m
.00625 .10527 L
s
[(2)] -0.0125 .10527 1 0 Mshowa
0 .19582 m
.00625 .19582 L
s
[(4)] -0.0125 .19582 1 0 Mshowa
0 .28638 m
.00625 .28638 L
s
[(6)] -0.0125 .28638 1 0 Mshowa
0 .37693 m
.00625 .37693 L
s
[(8)] -0.0125 .37693 1 0 Mshowa
0 .46749 m
.00625 .46749 L
s
[(10)] -0.0125 .46749 1 0 Mshowa
0 .55804 m
.00625 .55804 L
s
[(12)] -0.0125 .55804 1 0 Mshowa
.125 Mabswid
0 .03735 m
.00375 .03735 L
s
0 .05999 m
.00375 .05999 L
s
0 .08263 m
.00375 .08263 L
s
0 .12791 m
.00375 .12791 L
s
0 .15055 m
.00375 .15055 L
s
0 .17319 m
.00375 .17319 L
s
0 .21846 m
.00375 .21846 L
s
0 .2411 m
.00375 .2411 L
s
0 .26374 m
.00375 .26374 L
s
0 .30902 m
.00375 .30902 L
s
0 .33166 m
.00375 .33166 L
s
0 .35429 m
.00375 .35429 L
s
0 .39957 m
.00375 .39957 L
s
0 .42221 m
.00375 .42221 L
s
0 .44485 m
.00375 .44485 L
s
0 .49013 m
.00375 .49013 L
s
0 .51276 m
.00375 .51276 L
s
0 .5354 m
.00375 .5354 L
s
0 .58068 m
.00375 .58068 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01316 .01472 m
.01316 .01472 L
.06579 .01472 L
.06579 .01472 L
F
0 g
.5 Mabswid
.01316 .01472 m
.01316 .01472 L
.06579 .01472 L
.06579 .01472 L
.01316 .01472 L
s
1 0 0 r
.07895 .01472 m
.07895 .10527 L
.13158 .10527 L
.13158 .01472 L
F
0 g
.07895 .01472 m
.07895 .10527 L
.13158 .10527 L
.13158 .01472 L
.07895 .01472 L
s
1 0 0 r
.14474 .01472 m
.14474 .15055 L
.19737 .15055 L
.19737 .01472 L
F
0 g
.14474 .01472 m
.14474 .15055 L
.19737 .15055 L
.19737 .01472 L
.14474 .01472 L
s
1 0 0 r
.21053 .01472 m
.21053 .28638 L
.26316 .28638 L
.26316 .01472 L
F
0 g
.21053 .01472 m
.21053 .28638 L
.26316 .28638 L
.26316 .01472 L
.21053 .01472 L
s
1 0 0 r
.27632 .01472 m
.27632 .51276 L
.32895 .51276 L
.32895 .01472 L
F
0 g
.27632 .01472 m
.27632 .51276 L
.32895 .51276 L
.32895 .01472 L
.27632 .01472 L
s
1 0 0 r
.34211 .01472 m
.34211 .55804 L
.39474 .55804 L
.39474 .01472 L
F
0 g
.34211 .01472 m
.34211 .55804 L
.39474 .55804 L
.39474 .01472 L
.34211 .01472 L
s
1 0 0 r
.40789 .01472 m
.40789 .51276 L
.46053 .51276 L
.46053 .01472 L
F
0 g
.40789 .01472 m
.40789 .51276 L
.46053 .51276 L
.46053 .01472 L
.40789 .01472 L
s
1 0 0 r
.47368 .01472 m
.47368 .46749 L
.52632 .46749 L
.52632 .01472 L
F
0 g
.47368 .01472 m
.47368 .46749 L
.52632 .46749 L
.52632 .01472 L
.47368 .01472 L
s
1 0 0 r
.53947 .01472 m
.53947 .60332 L
.59211 .60332 L
.59211 .01472 L
F
0 g
.53947 .01472 m
.53947 .60332 L
.59211 .60332 L
.59211 .01472 L
.53947 .01472 L
s
1 0 0 r
.60526 .01472 m
.60526 .42221 L
.65789 .42221 L
.65789 .01472 L
F
0 g
.60526 .01472 m
.60526 .42221 L
.65789 .42221 L
.65789 .01472 L
.60526 .01472 L
s
1 0 0 r
.67105 .01472 m
.67105 .33166 L
.72368 .33166 L
.72368 .01472 L
F
0 g
.67105 .01472 m
.67105 .33166 L
.72368 .33166 L
.72368 .01472 L
.67105 .01472 L
s
1 0 0 r
.73684 .01472 m
.73684 .19582 L
.78947 .19582 L
.78947 .01472 L
F
0 g
.73684 .01472 m
.73684 .19582 L
.78947 .19582 L
.78947 .01472 L
.73684 .01472 L
s
1 0 0 r
.80263 .01472 m
.80263 .01472 L
.85526 .01472 L
.85526 .01472 L
F
0 g
.80263 .01472 m
.80263 .01472 L
.85526 .01472 L
.85526 .01472 L
.80263 .01472 L
s
1 0 0 r
.86842 .01472 m
.86842 .05999 L
.92105 .05999 L
.92105 .01472 L
F
0 g
.86842 .01472 m
.86842 .05999 L
.92105 .05999 L
.92105 .01472 L
.86842 .01472 L
s
1 0 0 r
.93421 .01472 m
.93421 .05999 L
.98684 .05999 L
.98684 .01472 L
F
0 g
.93421 .01472 m
.93421 .05999 L
.98684 .05999 L
.98684 .01472 L
.93421 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[41]:=",
  ImageSize->{514, 317.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000820001?A000`40O003h00Oogooogoo17oo003o
OoooOol4Ool00?mooomoo`Aoo`0067oo0P0017oo0P000goo10000goo0P000goo0`001goo0P0017oo
0P000goo10000Woo0`000goo0`001Woo0P0017oo0P000goo0`0017oo0P000goo0`001goo0P0017oo
0P000goo0`000goo0`000goo0`001Woo0P0017oo0P000goo0`000goo10000Woo0`001goo0P0017oo
0P000goo0`000goo0`000goo0`001goo0P0017oo0P000goo0`0017oo0`000Woo0`001Woo0P0017oo
0P000goo0`000goo0`000goo0`001goo0P0017oo0P000goo0`0017oo0P000goo0`001Woo0P0017oo
0P000goo0`0017oo00<007ooOol00Woo0`001goo0P0017oo0P000goo0`0017oo0P000goo0`001Woo
0P0017oo0P000goo0`000goo0`000goo0`001goo0P0017oo0P0017oo0`000goo0P000goo0`001Woo
0P0017oo0P0017oo0`000Woo0`000goo0`001goo0P0017oo0P0017oo0`000Woo10000Woo0`0027oo
000GOol01000Oomoo`000goo0P0017oo00<007ooOol00Woo00@007ooOol000Eoo`03001oogoo00=o
o`04001oogoo0003Ool20004Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01000
Oomoo`000goo0P001Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00=oo`04001oogoo
0003Ool20006Ool01@00Oomoogoo00001goo00<007ooOol00Woo00@007ooOol000=oo`8000Ioo`05
001oogooOol00007Ool00`00Oomoo`03Ool01000Oomoo`000goo0P001Woo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol00goo00@007ooOol000=oo`8000Ioo`03001oogoo009oo`03001oogoo
00Aoo`03001oogoo009oo`04001oogoo0003Ool20006Ool00`00Oomoo`03Ool00`00Oomoo`03Ool0
0`00Oomoo`03Ool01000Oomoo`000goo0P001Woo00@007ooOol0009oo`03001oogoo00=oo`03001o
ogoo009oo`04001oogoo0003Ool20006Ool01@00Oomoogoo00001goo00<007ooOol00goo00@007oo
Ool000=oo`8000Ioo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`00
0goo0P001Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00@007ooOol000=oo`80
00Eoo`05001oogooOol00002Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`000goo0P00
1Goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00goo00@007ooOol000=oo`8000Eoo`03
001oogoo009oo`03001oogoo00Eoo`03001oogoo00Eoo`005goo00@007ooOol000Yoo`05001oogoo
Ool00002Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000Oomoo`002Woo00<007ooOol00Woo0`00
1Goo00<007ooOol00Woo00@007ooOol000]oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool01000Oomoo`002goo00D007ooOomoo`0000Moo`03001oogoo009oo`04001oogoo000;Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool01000Oomoo`002goo00<007ooOol00goo
00<007ooOol00goo00<007ooOol00goo00@007ooOol000]oo`03001oogoo00@000Eoo`03001oogoo
009oo`04001oogoo000;Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000Oomo
o`002goo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo009oo`04001oogoo000;Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool01000Oomoo`002goo00@007ooOol0009oo`03
001oogoo00=oo`03001oogoo009oo`04001oogoo000;Ool01000Oomoogoo0`001Goo00<007ooOol0
0goo00@007ooOol000Qoo`@0009oo`04001oogoo0005Ool00`00Oomoo`02Ool01000Oomoo`0027oo
10000goo00<007ooOol01Goo00<007ooOol00goo00@007ooOol000Qoo`@000Aoo`03001oogoo00Ao
o`03001oogoo00Eoo`005goo00@007ooOol000]oo`04001oogooOol20003Ool30006Ool01000Oomo
o`002goo00@007ooOol0009oo`03001oogoo00<000Eoo`04001oogoo0009Ool20003Ool01000Oomo
o`000Woo0`001Woo00@007ooOol000Uoo`8000Aoo`03001oogoo009oo`<000Eoo`04001oogoo0009
Ool20006Ool00`00Oomoo`030006Ool01000Oomoo`002Goo0P0017oo0P000goo0`001Woo00@007oo
Ool000Uoo`8000=oo`03001oo`0000=oo`<000Eoo`04001oogoo0009Ool20003Ool30003Ool30006
Ool01000Oomoo`002Goo0P000goo0`000goo0`001Goo00@007ooOol000Uoo`8000Eoo`04001oogoo
Ool30006Ool01000Oomoo`002Goo0P0017oo0P000goo0`001Goo00@007ooOol000Uoo`8000=oo`04
001oogoo0002Ool30006Ool01000Oomoo`0027oo00<007oo00000goo00@007ooOol0009oo`<000Eo
o`04001oogoo0008Ool00`00Ool00004Ool00`00Oomoo`02Ool30006Ool01000Oomoo`0027oo00<0
07oo00001Woo00<007ooOol00`0027oo000GOol01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo0002Ool00`00Oomoo`06Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool0
0`00Oomoo`05Ool01000Oomoo`002goo00@007ooOol0009oo`04001oogoo0008Ool01000Oomoo`00
2goo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`04001oogoo000;Ool01000Oomoo`000Woo00@0
07ooOol000Qoo`04001oogoo000;Ool00`00Oomoo`03Ool01000Oomoo`0027oo00@007ooOol000]o
o`06001oogoo001oo`000goo00<007ooOol01Goo00@007ooOol000]oo`04001oogoo0005Ool00`00
Oomoo`06Ool01000Oomoo`002goo00@007ooOol000Eoo`03001oogoo00Eoo`04001oogoo000;Ool0
0`00Oomoo`03Ool01000Oomoo`0027oo00@007ooOol000]oo`04001oogoo0002Ool01000Oomoo`00
1goo00@007ooOol000]oo`04001oogoo0002Ool01000Oomoo`0027oo00@007ooOol000Qoo`03001o
o`0000=oo`04001oogoo0002Ool00`00Oomoo`05Ool01000Oomoo`0027oo00<007oo000017oo00<0
07ooOol00Woo00<007ooOol01Woo00@007ooOol000Qoo`03001oo`0000=oo`04001oogoo0002Ool0
0`00Oomoo`08Ool001Qoo`8000Yoo`8000Aoo`8000=oo`@000Ioo`8000Yoo`8000Aoo`8000=oo`@0
00Eoo`8000Uoo`<000Aoo`8000=oo`@000Ioo`8000Uoo`<000=oo`8000Aoo`@000Eoo`8000Uoo`<0
00Aoo`8000=oo`@000Ioo`8000Uoo`<000=oo`<000=oo`@000Ioo`8000Uoo`<000Aoo`8000=oo`@0
00Eoo`8000Uoo`<000=oo`@0009oo`@000Ioo`8000Uoo`<000Aoo`<0009oo`@000Eoo`8000Uoo`<0
00=oo`@0009oo`@000Ioo`8000Uoo`<000Aoo`8000=oo`@000Eoo`8000Uoo`<000Aoo`8000=oo`@0
00Ioo`8000Yoo`8000Aoo`8000=oo`@000Eoo`8000Yoo`8000=oo`8000Aoo`@000Ioo`8000Yoo`80
00Aoo`8000=oo`@000Moo`004Woo00<007ooOol0ogookWoo000BOol00`00Oomoo`3oOoo^Ool0019o
o`03001oogoo0?moonioo`004Woo00<007ooOol0ogookWoo000BOol00`00Oomoo`3oOoo^Ool0019o
o`03001oogoo0?moonioo`004Woo00<007ooOol0ogookWoo000BOol00`00Oomoo`03Ool00`00Oomo
o`0GOol00`00Oomoo`3oOom[Ool00`00Oomoo`0GOol00`00Oomoo`16Ool0019oool00?00005oo`00
4Woo00<007ooOol047oo00<007ooOol04Goo00<007`0O0005g`000<007ooOol00goo00<007`0O000
5g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol0
17oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O000
5g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol0
17oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol04Goo00<007ooOol0
47oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol01Goo000BOol00`00
Oomoo`0@Ool00`00Oomoo`0AOol00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00
Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00
O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00
Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00
O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`0AOol00`00Oomoo`0@Ool00`00
O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`05Ool0019oo`03001oogoo011o
o`03001oogoo015oo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Ao
o`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Ao
o`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo00=oo`03001l07`001Ml0003001oogoo015oo`03001oogoo011oo`03001l07`001Ml
0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Eoo`004Woo00<007ooOol097oo00<007`0
O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007oo
Ool00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0
O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007oo
Ool00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0
O0005g`000<007ooOol097oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007oo
Ool01Goo000BOol00`00Oomoo`0TOol00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO000
0`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool0
0`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO000
0`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool0
0`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`0TOol00`00O01l000GO000
0`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`05Ool0019oo`03001oogoo02Aoo`03001l07`0
01Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo
00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`0
01Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo
00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`0
01Ml0003001oogoo02Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo
00Eoo`004Woo00<007ooOol097oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<0
07ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<0
07`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<0
07ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<0
07`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol097oo00<007`0O0005g`000<0
07ooOol017oo00<007`0O0005g`000<007ooOol01Goo000BOol00`00Oomoo`0TOol00`00O01l000G
O0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03
Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000G
O0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03
Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000G
O0000`00Oomoo`0TOol00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`05
Ool0019oo`03001oogoo02Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001o
ogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l
07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001o
ogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l
07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo02Aoo`03001l07`001Ml0003001o
ogoo00Aoo`03001l07`001Ml0003001oogoo00Eoo`004Woo00<007ooOol097oo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo
00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo
00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`0
00<007ooOol097oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol01Goo
000BOol3000TOol00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool0
0`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO000
0`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool0
0`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO000
0`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`0TOol00`00O01l000GO0000`00Oomoo`04Ool0
0`00O01l000GO0000`00Oomoo`05Ool0019oo`03001oogoo02Aoo`03001l07`001Ml0003001oogoo
00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`0
01Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo
00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`0
01Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo
02Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Eoo`004Woo00<0
07ooOol097oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<0
07`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<0
07ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<0
07`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<0
07ooOol00goo00<007`0O0005g`000<007ooOol097oo00<007`0O0005g`000<007ooOol017oo00<0
07`0O0005g`000<007ooOol01Goo000BOol00`00Oomoo`0TOol00`00O01l000GO0000`00Oomoo`03
Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03
Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`0T
Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`05Ool0019oo`03001o
ogoo02Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l
07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001o
ogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l
07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001o
ogoo00=oo`03001l07`001Ml0003001oogoo02Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l
07`001Ml0003001oogoo00Eoo`004Woo00<007ooOol097oo00<007`0O0005g`000<007ooOol00goo
00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`0
00<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo
00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`0
00<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol097oo
00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol01Goo000BOol00`00Oomo
o`0TOol00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l
000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomo
o`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l
000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomo
o`03Ool00`00O01l000GO0000`00Oomoo`0TOol00`00O01l000GO0000`00Oomoo`04Ool00`00O01l
000GO0000`00Oomoo`05Ool0019oo`03001oogoo02Aoo`03001l07`001Ml0003001oogoo00=oo`03
001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003
001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03
001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003
001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo02Aoo`03
001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Eoo`004Woo00<007ooOol0
97oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O000
5g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0
17oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O000
5g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0
0goo00<007`0O0005g`000<007ooOol097oo00<007`0O0005g`000<007ooOol017oo00<007`0O000
5g`000<007ooOol01Goo000BOol00`00Oomoo`0TOol00`00O01l000GO0000`00Oomoo`03Ool00`00
O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00
Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00
O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00
Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`0TOol00`00
O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`05Ool0019oo`03001oogoo02Ao
o`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Ao
o`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=o
o`03001l07`001Ml0003001oogoo02Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo00Eoo`004Woo0`0097oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`0
00<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo
00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`0
00<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo
00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol097oo6`001Woo6`001goo
000BOol00`00Oomoo`0TOol00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomo
o`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l
000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomo
o`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l
000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`1WOol0019oo`03001oogoo02Aoo`03
001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003
001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03
001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003
001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03
001l07`001Ml0003001oogoo06Moo`004Woo00<007ooOol097oo00<007`0O0005g`000<007ooOol0
0goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O000
5g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0
0goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O000
5g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol0
Igoo000BOol00`00Oomoo`0TOol00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00
Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00
O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00
Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00
O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`1WOol0019oo`03001oogoo02Ao
o`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Ao
o`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=o
o`03001l07`001Ml0003001oogoo06Moo`004Woo00<007ooOol097oo00<007`0O0005g`000<007oo
Ool00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0
O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007oo
Ool00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0
O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007oo
Ool0Igoo000BOol00`00Oomoo`0TOol00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO000
0`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool0
0`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO000
0`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool0
0`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`1WOol0019oo`03001oogoo
02Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`0
01Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo
00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`0
01Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo
00=oo`03001l07`001Ml0003001oogoo06Moo`004Woo00<007ooOol097oo00<007`0O0005g`000<0
07ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<0
07`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<0
07ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<0
07`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<0
07ooOol0Igoo000BOol00`00Oomoo`0TOol00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04
Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04
Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`1WOol0019oo`<002Ao
o`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Ao
o`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=o
o`03001l07`001Ml0003001oogoo06Moo`004Woo00<007ooOol097oo00<007`0O0005g`000<007oo
Ool00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0
O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007oo
Ool00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0
O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007oo
Ool0Igoo000BOol00`00Oomoo`0TOol00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO000
0`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool0
0`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO000
0`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool0
0`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`1WOol0019oo`03001oogoo
02Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`0
01Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo
00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`0
01Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo
00=oo`03001l07`001Ml0003001oogoo06Moo`004Woo00<007ooOol097oo00<007`0O0005g`000<0
07ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<0
07`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<0
07ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<0
07`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<0
07ooOol0Igoo000BOol00`00Oomoo`0TOol00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04
Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04
Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`1WOol0019oo`03001o
ogoo02Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l
07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001o
ogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l
07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001o
ogoo00=oo`03001l07`001Ml0003001oogoo06Moo`004Woo00<007ooOol097oo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo
00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo
00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`0
00<007ooOol0Igoo000BOol00`00Oomoo`0TOol00`00O01l000GO0000`00Oomoo`03Ool00`00O01l
000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomo
o`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l
000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomo
o`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`1WOol000Moo`@0
00Moo`03001oogoo02Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo
00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`0
01Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo
00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`0
01Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo06Moo`0027oo00<007ooOol01goo00<0
07ooOol097oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<0
07`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<0
07ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<0
07`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<0
07ooOol00goo00<007`0O0005g`000<007ooOol0Igoo0009Ool00`00Oomoo`06Ool4000SOolK0005
Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03
Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`1W
Ool000Yoo`03001oogoo00Eoo`03001oogoo04Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l
07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001o
ogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l
07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001o
ogoo00=oo`03001l07`001Ml0003001oogoo06Moo`001goo00@007ooOol000Moo`03001oogoo04Ao
o`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml
0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=o
o`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml
0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo06Mo
o`0027oo0P0027oo00<007ooOol0A7oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo
00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo
00<007`0O0005g`000<007ooOol0Igoo000BOol00`00Oomoo`14Ool00`00O01l000GO0000`00Oomo
o`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l
000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomo
o`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l
000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`1WOol0019oo`03001oogoo04Aoo`03
001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003
001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03
001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003
001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo06Moo`00
4Woo00<007ooOol0A7oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0
0goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O000
5g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0
0goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O000
5g`000<007ooOol0Igoo000BOol00`00Oomoo`14Ool00`00O01l000GO0000`00Oomoo`04Ool00`00
O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00
Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00
O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00
Oomoo`03Ool00`00O01l000GO0000`00Oomoo`1WOol0019oo`03001oogoo04Aoo`03001l07`001Ml
0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Ao
o`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml
0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Ao
o`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo06Moo`004Woo00<007oo
Ool0A7oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0
O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007oo
Ool00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0
O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007oo
Ool0Igoo000BOol00`00Oomoo`14Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO000
0`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool0
0`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO000
0`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool0
0`00O01l000GO0000`00Oomoo`1WOol0019oo`03001oogoo04Aoo`03001l07`001Ml0003001oogoo
00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`0
01Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo
00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`0
01Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo06Moo`004Woo0`00A7oo00<007`0O000
5g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol0
17oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O000
5g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol0
17oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol0Igoo000BOol00`00
Oomoo`14Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00
O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00
Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00
O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00
Oomoo`1WOol0019oo`03001oogoo04Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Ao
o`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=o
o`03001l07`001Ml0003001oogoo06Moo`004Woo00<007ooOol0A7oo00<007`0O0005g`000<007oo
Ool017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0
O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007oo
Ool017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0
O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol0Igoo000BOol00`00Oomoo`14Ool0
0`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO000
0`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool0
0`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO000
0`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`1WOol0
019oo`03001oogoo04Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo
00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`0
01Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo
00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`0
01Ml0003001oogoo06Moo`004Woo00<007ooOol0A7oo00<007`0O0005g`000<007ooOol017oo00<0
07`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<0
07ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<0
07`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<0
07ooOol00goo00<007`0O0005g`000<007ooOol0Igoo000BOol00`00Oomoo`14Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04
Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04
Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`1WOol0019oo`03001o
ogoo04Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l
07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001o
ogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l
07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001o
ogoo06Moo`004Woo00<007ooOol0A7oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo
00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo
00<007`0O0005g`000<007ooOol0Igoo000BOol00`00Oomoo`14Ool00`00O01l000GO0000`00Oomo
o`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l
000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomo
o`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l
000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`1WOol0019oo`<004Aooa/000Ioo`03
001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003
001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03
001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003
001oogoo00=oo`03001l07`001Ml0003001oogoo06Moo`004Woo00<007ooOol0IGoo00<007`0O000
5g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0
17oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O000
5g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0
0goo00<007`0O0005g`000<007ooOol0Igoo000BOol00`00Oomoo`1UOol00`00O01l000GO0000`00
Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00
O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00
Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00
O01l000GO0000`00Oomoo`1WOol0019oo`03001oogoo06Eoo`03001l07`001Ml0003001oogoo00=o
o`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=o
o`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml
0003001oogoo06Moo`004Woo00<007ooOol0IGoo00<007`0O0005g`000<007ooOol00goo00<007`0
O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007oo
Ool00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0
O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007oo
Ool0Igoo000BOol00`00Oomoo`1UOol00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO000
0`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool0
0`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO000
0`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`1WOol0
019oo`03001oogoo06Eoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo
00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`0
01Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo
00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo06Moo`004Woo00<0
07ooOol0IGoo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<0
07`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<0
07ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<0
07`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol0Igoo000BOol00`00Oomoo`1U
Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04
Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000G
O0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`1WOol0019oo`03001oogoo06Eoo`03001l
07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001o
ogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l
07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001o
ogoo00=oo`03001l07`001Ml0003001oogoo06Moo`004Woo00<007ooOol0IGoo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo
00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo
00<007`0O0005g`000<007ooOol0Igoo000BOol3001UOol00`00O01l000GO0000`00Oomoo`03Ool0
0`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO000
0`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool0
0`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO000
0`00Oomoo`1WOol0019oo`03001oogoo06Eoo`03001l07`001Ml0003001oogoo00=oo`03001l07`0
01Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo
00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`0
01Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo
06Moo`004Woo00<007ooOol0IGoo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<0
07ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<0
07`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<0
07ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol0Igoo000B
Ool00`00Oomoo`1UOol00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04
Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04
Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`1WOol0019oo`03001o
ogoo06Eoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l
07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001o
ogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l
07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo06Moo`004Woo00<007ooOol0IGoo
00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo
00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol0Igoo000BOol00`00Oomoo`1UOol00`00O01l
000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomo
o`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l
000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomo
o`03Ool00`00O01l000GO0000`00Oomoo`1WOol0019oo`03001oogoo06Eoo`03001l07`001Ml0003
001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03
001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003
001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03
001l07`001Ml0003001oogoo06Moo`004Woo00<007ooOol0IGoo00<007`0O0005g`000<007ooOol0
0goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O000
5g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0
0goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O000
5g`000<007ooOol0Igoo0008Ool30007Ool00`00Oomoo`1UOol00`00O01l000GO0000`00Oomoo`03
Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000G
O0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03
Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000G
O0000`00Oomoo`1WOol000Uoo`03001oogoo00Ioo`03001oogoo06Eoo`03001l07`001Ml0003001o
ogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l
07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001o
ogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l
07`001Ml0003001oogoo06Moo`001goo10001goo1000I7oo00<007`0O0005g`000<007ooOol00goo
00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo
00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo6`00JGoo0007Ool0
0`00Ool00008Ool00`00Oomoo`1UOol00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO000
0`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool0
0`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO000
0`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`27Ool000Moo`03001oo`0000Qoo`03001oogoo
06Eoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`0
01Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo
00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`0
01Ml0003001oogoo08Moo`0027oo0P0027oo00<007ooOol0IGoo00<007`0O0005g`000<007ooOol0
0goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O000
5g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0
0goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0Qgoo000BOol00`00
Oomoo`1UOol00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00
O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00
Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00
O01l000GO0000`00Oomoo`27Ool0019oo`03001oogoo06Eoo`03001l07`001Ml0003001oogoo00=o
o`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=o
o`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo08Moo`004Woo00<007oo
Ool0IGoo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0
O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007oo
Ool017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0
O0005g`000<007ooOol0Qgoo000BOol00`00Oomoo`1UOol00`00O01l000GO0000`00Oomoo`03Ool0
0`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO000
0`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool0
0`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`27Ool0019oo`03001oogoo
06Eoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`0
01Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo
00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`0
01Ml0003001oogoo08Moo`004Woo00<007ooOol0IGoo00<007`0O0005g`000<007ooOol00goo00<0
07`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<0
07ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<0
07`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0Qgoo000BOol00`00Oomoo`1U
Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04
Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000G
O0000`00Oomoo`27Ool0019oo`<006Eoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml
0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=o
o`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml
0003001oogoo00Aoo`03001l07`001Ml0003001oogoo08Moo`004Woo00<007ooOol0IGoo00<007`0
O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007oo
Ool017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0
O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007oo
Ool0Qgoo000BOol00`00Oomoo`1UOol00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO000
0`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool0
0`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO000
0`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`27Ool0019oo`03001oogoo06Eoo`03001l07`0
01Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo
00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`0
01Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo
08Moo`004Woo00<007ooOol0IGoo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<0
07ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<0
07`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<0
07ooOol017oo00<007`0O0005g`000<007ooOol0Qgoo000BOol00`00Oomoo`1UOol00`00O01l000G
O0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04
Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000G
O0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`27
Ool0019oo`03001oogoo06Eoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001o
ogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l
07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001o
ogoo00Aoo`03001l07`001Ml0003001oogoo08Moo`004Woo00<007ooOol0IGoo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo
00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0Qgoo
000BOol00`00Oomoo`1UOol00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomo
o`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l
000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomo
o`04Ool00`00O01l000GO0000`00Oomoo`27Ool0019oo`03001oogoo06Eoo`03001l07`001Ml0003
001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03
001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003
001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo08Moo`00
4Woo00<007ooOol0IGoo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol0
17oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O000
5g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol0
17oo00<007`0O0005g`000<007ooOol0Qgoo000BOol00`00Oomoo`1UOol00`00O01l000GO0000`00
Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00
O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00
Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`27Ool0019o
o`<006Eoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l
07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001o
ogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l
07`001Ml0003001oogoo08Moo`004Woo00<007ooOol0IGoo00<007`0O0005g`000<007ooOol00goo
00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo
00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0Qgoo000BOol00`00Oomo
o`1UOol00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l
000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomo
o`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l
000GO0000`00Oomoo`27Ool0019oo`03001oogoo06Eoo`03001l07`001Ml0003001oogoo00=oo`03
001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003
001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03
001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo08Moo`004Woo00<007ooOol0
IGoo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O000
5g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol0
17oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O000
5g`000<007ooOol0Qgoo000BOol00`00Oomoo`1UOol00`00O01l000GO0000`00Oomoo`03Ool00`00
O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00
Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00
O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`27Ool0019oo`03001oogoo06Eo
o`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Ao
o`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo08Moo`004Woo00<007ooOol0IGoo00<007`0O0005g`000<007ooOol00goo00<007`0
O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007oo
Ool00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0
O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0Qgoo000BOol00`00Oomoo`1UOol0
0`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO000
0`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool0
0`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO000
0`00Oomoo`27Ool0019oo`03001oogoo06Eoo`03001l07`001Ml0003001oogoo00=oo`03001l07`0
01Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo
00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`0
01Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo08Moo`004Woo00<007ooOol0IGoo00<0
07`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<0
07ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<0
07`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<0
07ooOol0Qgoo000BOol3001UOol00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00
Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00
O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00
Oomoo`04Ool00`00O01l000GO0000`00Oomoo`27Ool0019oo`03001oogoo06Eoo`03001l07`001Ml
0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Ao
o`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo08Mo
o`004Woo00<007ooOol0IGoo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007oo
Ool017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0
O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007oo
Ool017oo00<007`0O0005g`000<007ooOol0Qgoo000BOol00`00Oomoo`1UOol00`00O01l000GO000
0`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool0
0`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO000
0`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`27Ool0
019oo`03001oogoo06Eoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo
00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`0
01Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo
00Aoo`03001l07`001Ml0003001oogoo08Moo`004Woo00<007ooOol0IGoo00<007`0O0005g`000<0
07ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<0
07`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<0
07ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0Qgoo000B
Ool00`00Oomoo`1UOol00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04
Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04
Ool00`00O01l000GO0000`00Oomoo`27Ool0019oo`03001oogoo06Eoo`03001l07`001Ml0003001o
ogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l
07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001o
ogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo08Moo`004Woo
00<007ooOol0IGoo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo
00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`0
00<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo
00<007`0O0005g`000<007ooOol0Qgoo0008Ool20008Ool00`00Oomoo`1UOol00`00O01l000GO000
0`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool0
0`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO000
0`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`27Ool0
00Moo`04001oogoo0007Ool00`00Oomoo`1UOol00`00O01l000GO0000`00Oomoo`03Ool00`00O01l
000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomo
o`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l
000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`27Ool000Moo`04001oogoo0007Ool4
001TOolK0005Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool0
0`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO000
0`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`27Ool0
00Moo`<000Qoo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003
001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03
001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003
001oogoo08Moo`001goo00<007ooOol027oo00<007ooOol0QGoo00<007`0O0005g`000<007ooOol0
17oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O000
5g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol0
17oo00<007`0O0005g`000<007ooOol0Qgoo0008Ool30007Ool00`00Oomoo`25Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03
Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`27Ool0019oo`03001oogoo08Eoo`03001l
07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001o
ogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l
07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo08Moo`004Woo00<007ooOol0QGoo
00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo
00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0Qgoo000BOol00`00Oomo
o`25Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l
000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomo
o`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`27Ool0019oo`03
001oogoo08Eoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03
001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003
001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo08Moo`00
4Woo00<007ooOol0QGoo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0
17oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O000
5g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0
Qgoo000BOol00`00Oomoo`25Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00
Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00
O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00
Oomoo`27Ool0019oo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Ao
o`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo08Moo`004Woo0`00QGoo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo
00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol0Qgoo000BOol00`00Oomoo`25Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l
000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomo
o`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l
000GO0000`00Oomoo`27Ool0019oo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo00Aoo`03
001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003
001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03
001l07`001Ml0003001oogoo08Moo`004Woo00<007ooOol0QGoo00<007`0O0005g`000<007ooOol0
17oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O000
5g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol0
17oo00<007`0O0005g`000<007ooOol0Qgoo000BOol00`00Oomoo`25Ool00`00O01l000GO0000`00
Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00
O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00
Oomoo`04Ool00`00O01l000GO0000`00Oomoo`27Ool0019oo`03001oogoo08Eoo`03001l07`001Ml
0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=o
o`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml
0003001oogoo00Aoo`03001l07`001Ml0003001oogoo08Moo`004Woo00<007ooOol0QGoo00<007`0
O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007oo
Ool00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0
O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0Qgoo000BOol00`00Oomoo`25Ool0
0`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO000
0`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool0
0`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`27Ool0019oo`03001oogoo
08Eoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`0
01Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo
00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo08Moo`004Woo00<0
07ooOol0QGoo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<0
07`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<0
07ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0Qgoo000B
Ool00`00Oomoo`25Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04
Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000G
O0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`27
Ool0019oo`<008Eoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Ao
o`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aooa/008Uoo`004Woo00<007ooOol0QGoo
00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo
00<007`0O0005g`000<007ooOol0Z7oo000BOol00`00Oomoo`25Ool00`00O01l000GO0000`00Oomo
o`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l
000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomo
o`2XOol0019oo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003
001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03
001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo0:Qoo`004Woo00<007ooOol0
QGoo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O000
5g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0
0goo00<007`0O0005g`000<007ooOol0Z7oo000BOol00`00Oomoo`25Ool00`00O01l000GO0000`00
Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00
O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00
Oomoo`2XOol0019oo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Ao
o`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo0:Qoo`004Woo00<007oo
Ool0QGoo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0
O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007oo
Ool00goo00<007`0O0005g`000<007ooOol0Z7oo000BOol00`00Oomoo`25Ool00`00O01l000GO000
0`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool0
0`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO000
0`00Oomoo`2XOol0019oo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`0
01Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo
00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo0:Qoo`004Woo00<0
07ooOol0QGoo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<0
07`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<0
07ooOol00goo00<007`0O0005g`000<007ooOol0Z7oo000BOol00`00Oomoo`25Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03
Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000G
O0000`00Oomoo`2XOol0019oo`<008Eoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Ao
o`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo0:Qoo`004Woo00<007oo
Ool0QGoo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0
O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007oo
Ool00goo00<007`0O0005g`000<007ooOol0Z7oo000BOol00`00Oomoo`25Ool00`00O01l000GO000
0`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool0
0`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO000
0`00Oomoo`2XOol0019oo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`0
01Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo
00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo0:Qoo`004Woo00<0
07ooOol0QGoo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<0
07`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<0
07ooOol00goo00<007`0O0005g`000<007ooOol0Z7oo000BOol00`00Oomoo`25Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03
Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000G
O0000`00Oomoo`2XOol0019oo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo00Aoo`03001l
07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001o
ogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo0:Qoo`004Woo
00<007ooOol0QGoo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo
00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol0Z7oo000BOol00`00Oomoo`25Ool00`00O01l
000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomo
o`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l
000GO0000`00Oomoo`2XOol000Qoo`8000Qoo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo
00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`0
01Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo
0:Qoo`001goo00@007ooOol000Moo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo00Aoo`03
001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003
001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo0:Qoo`00
1goo00@007ooOol000Moo`@008Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003
001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03
001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo0:Qoo`0027oo0P0027oo00<0
07ooOol0QGoo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<0
07`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<0
07ooOol00goo00<007`0O0005g`000<007ooOol0Z7oo0007Ool01000Oomoo`001goo00<007ooOol0
QGoo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O000
5g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0
0goo00<007`0O0005g`000<007ooOol0Z7oo0008Ool20008Ool00`00Oomoo`25Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03
Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000G
O0000`00Oomoo`2XOol0019oo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo00Aoo`03001l
07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001o
ogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo0:Qoo`004Woo
00<007ooOol0QGoo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo
00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol0Z7oo000BOol00`00Oomoo`25Ool00`00O01l
000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomo
o`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l
000GO0000`00Oomoo`2XOol0019oo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo00Aoo`03
001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003
001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo0:Qoo`00
4Woo00<007ooOol0QGoo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0
17oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O000
5g`000<007ooOol00goo00<007`0O0005g`000<007ooOol0Z7oo000BOol00`00Oomoo`25Ool00`00
O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00
Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00
O01l000GO0000`00Oomoo`2XOol0019oo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo00Ao
o`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml
0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo0:Qo
o`004Woo0`00QGoo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo
00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol0Z7oo000BOol00`00Oomoo`25Ool00`00O01l
000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomo
o`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l
000GO0000`00Oomoo`2XOol0019oo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo00Aoo`03
001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003
001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo0:Qoo`00
4Woo00<007ooOol0QGoo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0
17oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O000
5g`000<007ooOol00goo00<007`0O0005g`000<007ooOol0Z7oo000BOol00`00Oomoo`25Ool00`00
O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00
Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00
O01l000GO0000`00Oomoo`2XOol0019oo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo00Ao
o`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml
0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo0:Qo
o`004Woo00<007ooOol0QGoo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007oo
Ool017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0
O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol0Z7oo000BOol00`00Oomoo`25Ool0
0`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO000
0`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool0
0`00O01l000GO0000`00Oomoo`2XOol0019oo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo
00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`0
01Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo
0:Qoo`004Woo00<007ooOol0QGoo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<0
07ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<0
07`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol0Z7oo000BOol00`00Oomoo`25
Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000G
O0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03
Ool00`00O01l000GO0000`00Oomoo`2XOol0019oo`<008Eoo`03001l07`001Ml0003001oogoo00Ao
o`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml
0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=ooa/00:Yoo`004Woo00<007ooOol0QGoo
00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0b7oo
000BOol00`00Oomoo`25Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomo
o`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l
000GO0000`00Oomoo`38Ool0019oo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo00Aoo`03
001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003
001oogoo00Aoo`03001l07`001Ml0003001oogoo0<Qoo`004Woo00<007ooOol0QGoo00<007`0O000
5g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0
0goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0b7oo000BOol00`00
Oomoo`25Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00
O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00
Oomoo`38Ool0019oo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Ao
o`03001l07`001Ml0003001oogoo0<Qoo`004Woo00<007ooOol0QGoo00<007`0O0005g`000<007oo
Ool017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0
O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0b7oo000BOol00`00Oomoo`25Ool0
0`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO000
0`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`38Ool0
019oo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo
00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`0
01Ml0003001oogoo0<Qoo`004Woo00<007ooOol0QGoo00<007`0O0005g`000<007ooOol017oo00<0
07`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<0
07ooOol017oo00<007`0O0005g`000<007ooOol0b7oo000BOol30025Ool00`00O01l000GO0000`00
Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00
O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`38Ool0019oo`03001oogoo08Eo
o`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml
0003001oogoo00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo0<Qo
o`004Woo00<007ooOol0QGoo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007oo
Ool017oo00<007`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0
O0005g`000<007ooOol0b7oo000BOol00`00Oomoo`25Ool00`00O01l000GO0000`00Oomoo`04Ool0
0`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO000
0`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`38Ool0019oo`03001oogoo08Eoo`03001l07`0
01Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo
00=oo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo0<Qoo`004Woo00<0
07ooOol0QGoo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<0
07`0O0005g`000<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<0
07ooOol0b7oo000BOol00`00Oomoo`25Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04
Ool00`00O01l000GO0000`00Oomoo`38Ool0019oo`03001oogoo08Eoo`03001l07`001Ml0003001o
ogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00=oo`03001l
07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo0<Qoo`004Woo00<007ooOol0QGoo
00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol00goo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0b7oo
000BOol00`00Oomoo`25Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomo
o`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l
000GO0000`00Oomoo`38Ool00004Ool000000004Ool20008Ool00`00Oomoo`25Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03
Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`38Ool0009oo`03001o
ogoo009oo`04001oogoo0007Ool00`00Oomoo`25Ool00`00O01l000GO0000`00Oomoo`04Ool00`00
O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`03Ool00`00O01l000GO0000`00
Oomoo`04Ool00`00O01l000GO0000`00Oomoo`38Ool0009oo`03001oogoo009oo`04001oogoo0007
Ool40024Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00
O01l000GO0000`00Oomoo`03OolK0006Ool00`00O01l000GO0000`00Oomoo`38Ool0009oo`03001o
ogoo009oo`04001oogoo0007Ool00`00Oomoo`25Ool00`00O01l000GO0000`00Oomoo`04Ool00`00
O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`0TOol00`00O01l000GO0000`00
Oomoo`38Ool0009oo`03001oogoo009oo`04001oogoo0007Ool00`00Oomoo`25Ool00`00O01l000G
O0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`0T
Ool00`00O01l000GO0000`00Oomoo`38Ool00003Ool0000000Eoo`8000Qoo`03001oogoo08Eoo`03
001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003
001oogoo02Aoo`03001l07`001Ml0003001oogoo0<Qoo`004Woo00<007ooOol0QGoo00<007`0O000
5g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol0
97oo00<007`0O0005g`000<007ooOol0b7oo000BOol00`00Oomoo`25Ool00`00O01l000GO0000`00
Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`0TOol00`00
O01l000GO0000`00Oomoo`38Ool0019oo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo00Ao
o`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo02Aoo`03001l07`001Ml
0003001oogoo0<Qoo`004Woo00<007ooOol0QGoo00<007`0O0005g`000<007ooOol017oo00<007`0
O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol097oo00<007`0O0005g`000<007oo
Ool0b7oo000BOol00`00Oomoo`25Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO000
0`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`0TOol00`00O01l000GO0000`00Oomoo`38Ool0
019oo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo
00Aoo`03001l07`001Ml0003001oogoo02Aoo`03001l07`001Ml0003001oogoo0<Qoo`004Woo00<0
07ooOol0QGoo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<0
07`0O0005g`000<007ooOol097oo00<007`0O0005g`000<007ooOol0b7oo000BOol30025Ool00`00
O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00
Oomoo`0TOol00`00O01l000GO0000`00Oomoo`38Ool0019oo`03001oogoo08Eoo`03001l07`001Ml
0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo02Ao
o`03001l07`001Ml0003001oogoo0<Qoo`004Woo00<007ooOol0QGoo00<007`0O0005g`000<007oo
Ool017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol097oo00<007`0
O0005g`000<007ooOol0b7oo000BOol00`00Oomoo`25Ool00`00O01l000GO0000`00Oomoo`04Ool0
0`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`0TOol00`00O01l000GO000
0`00Oomoo`38Ool0019oo`03001oogoo08Eoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`0
01Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo02Aoo`03001l07`001Ml0003001oogoo
0<Qoo`004Woo00<007ooOol0QGoo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<0
07ooOol017oo00<007`0O0005g`000<007ooOol097oo00<007`0O0005g`000<007ooOol0b7oo000B
Ool00`00Oomoo`25Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04
Ool00`00O01l000GO0000`00Oomoo`0TOol00`00O01l000GO0000`00Oomoo`38Ool0019oo`03001o
ogoo08Eoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l
07`001Ml0003001oogoo02Aoo`03001l07`001Ml0003001oogoo0<Qoo`004Woo00<007ooOol0QGoo
00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`000<007ooOol017oo00<007`0O0005g`0
00<007ooOol097oo00<007`0O0005g`000<007ooOol0b7oo000BOol00`00Oomoo`25Ool00`00O01l
000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomoo`04Ool00`00O01l000GO0000`00Oomo
o`0TOol00`00O01l000GO0000`00Oomoo`38Ool0019oo`03001oogoo08Eoo`03001l07`001Ml0003
001oogoo00Aoo`03001l07`001Ml0003001oogoo00Aoo`03001l07`001Ml0003001oogoo02Aoo`03
001l07`001Ml0003001oogoo0<Qoo`004Woo0`00QGoo6`001Woo00<007`0O0005g`000<007ooOol0
17oo6`009Woo00<007`0O0005g`000<007ooOol0b7oo000BOol00`00Oomoo`2VOol00`00O01l000G
O0000`00Oomoo`15Ool00`00O01l000GO0000`00Oomoo`38Ool0019oo`03001oogoo0:Ioo`03001l
07`001Ml0003001oogoo04Eoo`03001l07`001Ml0003001oogoo0<Qoo`004Woo00<007ooOol0YWoo
00<007`0O0005g`000<007ooOol0AGoo00<007`0O0005g`000<007ooOol0b7oo000BOol00`00Oomo
o`2VOol00`00O01l000GO0000`00Oomoo`15Ool00`00O01l000GO0000`00Oomoo`38Ool0019oo`03
001oogoo0:Ioo`03001l07`001Ml0003001oogoo04Eoo`03001l07`001Ml0003001oogoo0<Qoo`00
4Woo00<007ooOol0YWoo00<007`0O0005g`000<007ooOol0AGoo00<007`0O0005g`000<007ooOol0
b7oo000BOol00`00Oomoo`2VOol00`00O01l000GO0000`00Oomoo`15Ool00`00O01l000GO0000`00
Oomoo`38Ool0019oo`03001oogoo0:Ioo`03001l07`001Ml0003001oogoo04Eoo`03001l07`001Ml
0003001oogoo0<Qoo`004Woo00<007ooOol0YWoo00<007`0O0005g`000<007ooOol0AGoo00<007`0
O0005g`000<007ooOol0b7oo000BOol00`00Oomoo`2VOol00`00O01l000GO0000`00Oomoo`15Ool0
0`00O01l000GO0000`00Oomoo`38Ool0019oo`<00:Ioo`03001l07`001Ml0003001oogoo04Eoo`03
001l07`001Ml0003001oogoo0<Qoo`004Woo00<007ooOol0YWoo00<007`0O0005g`000<007ooOol0
AGoo00<007`0O0005g`000<007ooOol0b7oo000BOol00`00Oomoo`2VOol00`00O01l000GO0000`00
Oomoo`15Ool00`00O01l000GO0000`00Oomoo`38Ool0019oo`03001oogoo0:Ioo`03001l07`001Ml
0003001oogoo04Eoo`03001l07`001Ml0003001oogoo0<Qoo`004Woo00<007ooOol0YWoo00<007`0
O0005g`000<007ooOol0AGoo00<007`0O0005g`000<007ooOol0b7oo000BOol00`00Oomoo`2VOol0
0`00O01l000GO0000`00Oomoo`15Ool00`00O01l000GO0000`00Oomoo`38Ool0019oo`03001oogoo
0:Ioo`03001l07`001Ml0003001oogoo04Eoo`03001l07`001Ml0003001oogoo0<Qoo`004Woo00<0
07ooOol0YWoo00<007`0O0005g`000<007ooOol0AGoo00<007`0O0005g`000<007ooOol0b7oo000B
Ool00`00Oomoo`2VOol00`00O01l000GO0000`00Oomoo`15Ool00`00O01l000GO0000`00Oomoo`38
Ool00004Ool000000003Ool40007Ool00`00Oomoo`2VOol00`00O01l000GO0000`00Oomoo`15Ool0
0`00O01l000GO0000`00Oomoo`38Ool0009oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo
0:Ioo`03001l07`001Ml0003001oogoo04Eoo`03001l07`001Ml0003001oogoo0<Qoo`000Woo00<0
07ooOol017oo00<007ooOol01Woo1000YGoo6`00Agoo00<007`0O0005g`000<007ooOol0b7oo0002
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`3oOol9Ool00`00O01l000GO0000`00Oomo
o`38Ool0009oo`03001oogoo009oo`04001oogoo0007Ool00`00Oomoo`3oOol9Ool00`00O01l000G
O0000`00Oomoo`38Ool00003Ool0000000Eoo`8000Qoo`03001oogoo0?moo`Uoo`03001l07`001Ml
0003001oogoo0<Qoo`004Woo00<007ooOol0ogoo2Goo00<007`0O0005g`000<007ooOol0b7oo000B
Ool00`00Oomoo`3oOol9Ool00`00O01l000GO0000`00Oomoo`38Ool0019oo`03001oogoo0?moo`Uo
o`03001l07`001Ml0003001oogoo0<Qoo`004Woo00<007ooOol0ogoo2Goo00<007`0O0005g`000<0
07ooOol0b7oo000BOol00`00Oomoo`3oOol9Ool00`00O01l000GO0000`00Oomoo`38Ool0019oo`03
001oogoo0?moo`Uoo`03001l07`001Ml0003001oogoo0<Qoo`004Woo00<007ooOol0ogoo2Goo00<0
07`0O0005g`000<007ooOol0b7oo000BOol00`00Oomoo`3oOol9Ool00`00O01l000GO0000`00Oomo
o`38Ool0019oo`<00?moo`Uoo`03001l07`001Ml0003001oogoo0<Qoo`004Woo00<007ooOol0ogoo
2Goo00<007`0O0005g`000<007ooOol0b7oo000BOol00`00Oomoo`3oOol9Ool00`00O01l000GO000
0`00Oomoo`38Ool0019oo`03001oogoo0?moo`Uoo`03001l07`001Ml0003001oogoo0<Qoo`004Woo
00<007ooOol0ogoo2Goo00<007`0O0005g`000<007ooOol0b7oo000BOol00`00Oomoo`3oOol9Ool0
0`00O01l000GO0000`00Oomoo`38Ool0019oo`03001oogoo0?moo`Uoo`03001l07`001Ml0003001o
ogoo0<Qoo`004Woo00<007ooOol0ogoo2Goo00<007`0O0005g`000<007ooOol0b7oo000BOol00`00
Oomoo`3oOol9Ool00`00O01l000GO0000`00Oomoo`38Ool0019oo`03001oogoo0?moo`Uoo`03001l
07`001Ml0003001oogoo0<Qoo`004Woo00<007ooOol0ogoo2Goo00<007`0O0005g`000<007ooOol0
b7oo000BOol3003oOol9OolK003:Ool0019oo`03001oogoo0?moonioo`004Woo00<007ooOol0ogoo
kWoo000BOol00`00Oomoo`3oOoo^Ool0019oo`03001oogoo0?moonioo`004Woo00<007ooOol0ogoo
kWoo000BOol00`00Oomoo`3oOoo^Ool0019oo`03001oogoo0?moonioo`00ogooogoo17oo0000\
\>"],
  ImageRangeCache->{{{0, 513}, {316.5, 0}} -> {-0.158703, -0.739982, \
0.0307189, 0.0446357}}]
}, Open  ]],

Cell[TextData[{
  "This is the mean of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\_\(0, 2\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\_\(1, 1\)\)]],
  ", dropping the first 10 tries: "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Kappa]02\[Kappa]11Walk = \({#\[LeftDoubleBracket]2, 3, 3, 
                1\[RightDoubleBracket], #\[LeftDoubleBracket]2, 3, 2, 
                2\[RightDoubleBracket]} &\) /@ met;\)\), "\n", 
    \(Mean[Drop[\[Kappa]02\[Kappa]11Walk, 10]]\)}], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \({0.0482041127324242424`, 0.0341236863900519793`}\)], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell[TextData[{
  "This is the covariance of { ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\_\(0, 2\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\_\(1, 1\)\)]],
  "}, dropping the first 10 tries:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CovarianceMatrix[Drop[\[Kappa]02\[Kappa]11Walk, 10]] // 
      MatrixForm\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0.000138891760337638459`", "6.14216143444195772`*^-6"},
            {"6.14216143444195772`*^-6", "0.0000495504406733929858`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[40]//MatrixForm="]
}, Open  ]],

Cell["\<\
This shows their joint distribution, dropping the first 10 tries:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Drop[\[Kappa]02\[Kappa]11Walk, 10]];\)\)], "Input",
  CellLabel->"In[38]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.497638 20.173 -0.291975 17.5449 [
[.30928 .04642 -12 -9 ]
[.30928 .04642 12 0 ]
[.51101 .04642 -12 -9 ]
[.51101 .04642 12 0 ]
[.71274 .04642 -12 -9 ]
[.71274 .04642 12 0 ]
[.91447 .04642 -12 -9 ]
[.91447 .04642 12 0 ]
[.09505 .14665 -30 -4.5 ]
[.09505 .14665 0 4.5 ]
[.09505 .23437 -24 -4.5 ]
[.09505 .23437 0 4.5 ]
[.09505 .3221 -30 -4.5 ]
[.09505 .3221 0 4.5 ]
[.09505 .40982 -24 -4.5 ]
[.09505 .40982 0 4.5 ]
[.09505 .49755 -30 -4.5 ]
[.09505 .49755 0 4.5 ]
[.09505 .58527 -24 -4.5 ]
[.09505 .58527 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.30928 .05892 m
.30928 .06517 L
s
[(0.04)] .30928 .04642 0 1 Mshowa
.51101 .05892 m
.51101 .06517 L
s
[(0.05)] .51101 .04642 0 1 Mshowa
.71274 .05892 m
.71274 .06517 L
s
[(0.06)] .71274 .04642 0 1 Mshowa
.91447 .05892 m
.91447 .06517 L
s
[(0.07)] .91447 .04642 0 1 Mshowa
.125 Mabswid
.1479 .05892 m
.1479 .06267 L
s
.18824 .05892 m
.18824 .06267 L
s
.22859 .05892 m
.22859 .06267 L
s
.26894 .05892 m
.26894 .06267 L
s
.34963 .05892 m
.34963 .06267 L
s
.38997 .05892 m
.38997 .06267 L
s
.43032 .05892 m
.43032 .06267 L
s
.47067 .05892 m
.47067 .06267 L
s
.55136 .05892 m
.55136 .06267 L
s
.5917 .05892 m
.5917 .06267 L
s
.63205 .05892 m
.63205 .06267 L
s
.6724 .05892 m
.6724 .06267 L
s
.75309 .05892 m
.75309 .06267 L
s
.79343 .05892 m
.79343 .06267 L
s
.83378 .05892 m
.83378 .06267 L
s
.87413 .05892 m
.87413 .06267 L
s
.06721 .05892 m
.06721 .06267 L
s
.02686 .05892 m
.02686 .06267 L
s
.95482 .05892 m
.95482 .06267 L
s
.99516 .05892 m
.99516 .06267 L
s
.25 Mabswid
0 .05892 m
1 .05892 L
s
.10755 .14665 m
.1138 .14665 L
s
[(0.025)] .09505 .14665 1 0 Mshowa
.10755 .23437 m
.1138 .23437 L
s
[(0.03)] .09505 .23437 1 0 Mshowa
.10755 .3221 m
.1138 .3221 L
s
[(0.035)] .09505 .3221 1 0 Mshowa
.10755 .40982 m
.1138 .40982 L
s
[(0.04)] .09505 .40982 1 0 Mshowa
.10755 .49755 m
.1138 .49755 L
s
[(0.045)] .09505 .49755 1 0 Mshowa
.10755 .58527 m
.1138 .58527 L
s
[(0.05)] .09505 .58527 1 0 Mshowa
.125 Mabswid
.10755 .07647 m
.1113 .07647 L
s
.10755 .09401 m
.1113 .09401 L
s
.10755 .11156 m
.1113 .11156 L
s
.10755 .1291 m
.1113 .1291 L
s
.10755 .16419 m
.1113 .16419 L
s
.10755 .18174 m
.1113 .18174 L
s
.10755 .19928 m
.1113 .19928 L
s
.10755 .21683 m
.1113 .21683 L
s
.10755 .25192 m
.1113 .25192 L
s
.10755 .26946 m
.1113 .26946 L
s
.10755 .28701 m
.1113 .28701 L
s
.10755 .30455 m
.1113 .30455 L
s
.10755 .33964 m
.1113 .33964 L
s
.10755 .35719 m
.1113 .35719 L
s
.10755 .37473 m
.1113 .37473 L
s
.10755 .39228 m
.1113 .39228 L
s
.10755 .42737 m
.1113 .42737 L
s
.10755 .44491 m
.1113 .44491 L
s
.10755 .46246 m
.1113 .46246 L
s
.10755 .48 m
.1113 .48 L
s
.10755 .51509 m
.1113 .51509 L
s
.10755 .53264 m
.1113 .53264 L
s
.10755 .55018 m
.1113 .55018 L
s
.10755 .56773 m
.1113 .56773 L
s
.10755 .04138 m
.1113 .04138 L
s
.10755 .02383 m
.1113 .02383 L
s
.10755 .00629 m
.1113 .00629 L
s
.10755 .60282 m
.1113 .60282 L
s
.25 Mabswid
.10755 0 m
.10755 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.23334 .24494 Mdot
.21688 .12375 Mdot
.52093 .17576 Mdot
.38983 .30003 Mdot
.4063 .34171 Mdot
.51724 .21565 Mdot
.312 .32318 Mdot
.33678 .242 Mdot
.40077 .26835 Mdot
.21898 .01472 Mdot
.61693 .23946 Mdot
.64211 .25097 Mdot
.60989 .28202 Mdot
.18128 .28111 Mdot
.10756 .19381 Mdot
.08461 .27593 Mdot
.16475 .33161 Mdot
.24373 .15612 Mdot
.16303 .27186 Mdot
.21771 .25511 Mdot
.31044 .32819 Mdot
.02793 .43708 Mdot
.26649 .04347 Mdot
.32633 .1033 Mdot
.30486 .23505 Mdot
.49936 .35476 Mdot
.63577 .20206 Mdot
.68669 .11488 Mdot
.65026 .15633 Mdot
.6466 .1567 Mdot
.53649 .03423 Mdot
.23587 .13116 Mdot
.33091 .24114 Mdot
.27437 .13153 Mdot
.26681 .42173 Mdot
.36432 .22514 Mdot
.42487 .42128 Mdot
.54732 .46779 Mdot
.55038 .60332 Mdot
.25314 .54001 Mdot
.27432 .51678 Mdot
.37551 .35441 Mdot
.66433 .39677 Mdot
.72005 .309 Mdot
.28096 .44629 Mdot
.17688 .42592 Mdot
.21316 .37014 Mdot
.53935 .51326 Mdot
.51013 .49733 Mdot
.66339 .46819 Mdot
.69831 .5173 Mdot
.71299 .47991 Mdot
.79048 .43092 Mdot
.86308 .41974 Mdot
.90739 .36282 Mdot
.69584 .31109 Mdot
.6421 .30809 Mdot
.79055 .44049 Mdot
.83112 .36429 Mdot
.74238 .43614 Mdot
.92986 .34648 Mdot
.97619 .32863 Mdot
.92441 .27212 Mdot
.89941 .30801 Mdot
.94094 .35432 Mdot
.71921 .33652 Mdot
.5867 .31896 Mdot
.45853 .29405 Mdot
.82317 .23529 Mdot
.65342 .19965 Mdot
.69399 .1459 Mdot
.62369 .1284 Mdot
.50464 .13644 Mdot
.55807 .30941 Mdot
.61684 .22299 Mdot
.64651 .29831 Mdot
.45565 .42594 Mdot
.41668 .38986 Mdot
.35378 .2774 Mdot
.31497 .27038 Mdot
.26399 .26257 Mdot
.4958 .20157 Mdot
.26259 .32598 Mdot
.28535 .2907 Mdot
.07706 .37353 Mdot
.02381 .54405 Mdot
.23104 .30043 Mdot
.3415 .39147 Mdot
.40476 .42032 Mdot
.43169 .38925 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[38]:=",
  ImageSize->{392, 242.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000680000lQ000`40O003h00O:Woo00<007ooOol0
ogooG7oo000ZOol00`00Oomoo`3oOomLOol002Yoo`03001oogoo0?mooeaoo`00:Woo0P00ogooGGoo
000ZOol00`00Oomoo`3oOomLOol002Yoo`03001oogoo02Moo`<00?mooc9oo`00:Woo00<007ooOol0
9goo0`00ogoo<Woo000ZOol00`00Oomoo`0WOol3003oOolbOol002Yoo`03001oogoo0?mooeaoo`00
:Woo00<007ooOol0ogooG7oo000ZOol2003oOomMOol002Yoo`03001oogoo049oo`8000Aoo`8000Ao
o`8000Aoo`<003Uoo`8000Aoo`8000Aoo`8000=oo`<003]oo`8000Aoo`8000Aoo`8000Aoo`8003]o
o`8000Aoo`8000Aoo`8000Aoo`03001oogoo01Qoo`00:Woo00<007ooOol0@Goo00@007ooOol000=o
o`8000=oo`04001oogoo0004Ool00`00Oomoo`0gOol01000Oomoo`000goo0P000goo00@007ooOol0
00Eoo`03001oogoo03Moo`04001oogoo0003Ool20003Ool01000Oomoo`000Woo00@007ooOol003Uo
o`04001oogoo0003Ool20003Ool01000Oomoo`000goo00<007ooOol067oo000ZOol00`00Oomoo`11
Ool01000Oomoo`0027oo00@007ooOol0009oo`@003Qoo`04001oogoo0008Ool01000Oomoo`0017oo
0`00>7oo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00>Goo00@007ooOol000Qoo`04
001oogoo0004Ool00`00Oomoo`0GOol002Yoo`03001oogoo045oo`04001oogoo0008Ool01000Oomo
o`000Woo00<007oo0000>Goo00@007ooOol000Qoo`04001oogoo0002Ool5000hOol01000Oomoo`00
27oo00@007ooOol0009oo`<003Yoo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol05goo
000ZOol00`00Oomoo`11Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oo`0003Uoo`04001o
ogoo0008Ool01000Oomoo`000Woo00<007oo00000P00>7oo00@007ooOol000Qoo`04001oogoo0002
Ool00`00Oomoo`0jOol01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo01Ioo`00:Woo0P00
>goo0`001Goo0P002Woo0P0017oo0P00>Woo0P002Woo0P000goo1000>Woo0P002Woo0P0017oo0`00
>Woo0P002Woo0P000goo100067oo000ZOol00`00Oomoo`0jOol3003oOolOOol002Yoo`03001oogoo
03Yoo`<00?mooamoo`00:Woo00<007ooOol0ogooG7oo000ZOol00`00Oomoo`3oOomLOol002Yoo`03
001oogoo0?mooeaoo`00:Woo00<007ooOol0ogooG7oo003o00280001Ool000Yoo`03001oogoo00eo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00eo
o`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00eo
o`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00ao
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eo
o`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo005oo`002Woo00<007oo
Ool03Goo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol03Goo00<007oo
Ool03Goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol03Goo00<007oo
Ool03Goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol03Goo00<007oo
Ool037oo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol037oo00<007oo
Ool03Goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol00Goo000ZOol0
0`00Oomoo`1<Ool00`00Oomoo`1;Ool00`00Oomoo`1<Ool00`00Oomoo`1<Ool00`00Oomoo`0POol0
02Yoo`03001oogoo0?mooeaoo`00:Woo00<007ooOol0ogooG7oo000ZOol00`00Oomoo`3oOomLOol0
02Yoo`800?mooeeoo`00:Woo00<007ooOol0ogooG7oo000ZOol00`00Oomoo`3oOomLOol002Yoo`03
001oogoo0?mooeaoo`00:Woo00<007ooOol0ogooG7oo000ZOol00`00Oomoo`3oOomLOol002Yoo`03
001oogoo0?mooeaoo`00:Woo0P00ogooGGoo000ZOol00`00Oomoo`3oOomLOol002Yoo`03001oogoo
0?mooeaoo`00:Woo00<007ooOol0DGoo0`00ogoo27oo000ZOol00`00Oomoo`1AOol3003oOol8Ool0
02Yoo`03001oogoo055oo`<00?moo`Qoo`00:Woo00<007ooOol0ogooG7oo000ZOol2003OOol3001j
Ool002Yoo`03001oogoo0=ioo`<007Yoo`00:Woo00<007ooOol0gWoo0`00NWoo000ZOol00`00Oomo
o`3oOomLOol002Yoo`03001oogoo02Moo`<00?mooc9oo`00:Woo00<007ooOol09goo0`00Vgoo0`00
Tgoo000ZOol00`00Oomoo`0WOol30004Ool3002DOol3002COol002Yoo`8002moo`<000aoo`<008Eo
o`<009=oo`00:Woo00<007ooOol0;Woo0`0037oo0`00ogoo77oo000ZOol00`00Oomoo`0mOol3001G
Ool30031Ool002Yoo`03001oogoo09Moo`<00<5oo`00:Woo00<007ooOol0Ugoo0`00`Goo0009Ool2
0004Ool20004Ool20003Ool40002Ool30007Ool00`00Oomoo`3QOol3001gOol000Qoo`04001oogoo
0003Ool20003Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0hGoo
0`00Mgoo0008Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo00Aoo`03001oogoo00Ao
o`<00>5oo`<007Moo`0027oo00@007ooOol000Qoo`04001oogoo0005Ool00`00Oomoo`030007Ool0
0`00Oomoo`3oOomLOol000Qoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`03
001oogoo00Moo`03001oogoo035oo`<009Yoo`D008Qoo`002Goo0P002Woo0P0017oo0P000goo1000
1Woo00<007ooOol0<Goo0`00VWoo1@00R7oo000ZOol00`00Oomoo`0aOol3002JOol50028Ool002Yo
o`03001oogoo0?mooeaoo`00:Woo0P00ogooGGoo000ZOol00`00Oomoo`3oOomLOol002Yoo`03001o
ogoo0?mooeaoo`00:Woo00<007ooOol0ogooG7oo000ZOol00`00Oomoo`2MOol3002kOol002Yoo`03
001oogoo09eoo`<00;]oo`00:Woo00<007ooOol0WGoo0`00^goo000ZOol2003oOomMOol002Yoo`03
001oogoo0?mooeaoo`00:Woo00<007ooOol0ogooG7oo000ZOol00`00Oomoo`3oOomLOol002Uoo`<0
0?mooeeoo`00:Goo0`00ogooGGoo000YOol3003BOol30027Ool002Yoo`8009Aoo`<003Aoo`<000Ao
o`<008Moo`00:Woo00<007ooOol0Tgoo0`00=7oo0`0017oo0`00Qgoo000ZOol00`00Oomoo`2COol3
000dOol3002>Ool002Yoo`03001oogoo0?mooeaoo`00:Woo00<007ooOol0ogooG7oo000ZOol00`00
Oomoo`2LOol3002lOol002Yoo`03001oogoo09aoo`<00;aoo`00:Woo0P00WGoo0`00_7oo000ZOol0
0`00Oomoo`33Ool3002EOol002Yoo`03001oogoo061oo`<0061oo`<009Eoo`00:Woo00<007ooOol0
H7oo0`00H7oo0`00UGoo000ZOol00`00Oomoo`1POol3003hOol000moo`8000Aoo`8000Aoo`8000=o
o`<000Moo`03001oogoo0?mooeaoo`003Woo00@007ooOol000=oo`8000=oo`04001oogoo0005Ool0
0`00Oomoo`04Ool00`00Oomoo`19Ool30037Ool30015Ool000ioo`04001oogoo0008Ool01000Oomo
o`001Goo00<007ooOol017oo0`00BGoo0`00agoo0`00AGoo000>Ool01000Oomoo`0027oo00@007oo
Ool000=oo`8000Moo`03001oogoo04Uoo`<000Moo`<006eoo`<004eoo`<004Eoo`003Woo00@007oo
Ool000Qoo`04001oogoo0005Ool00`00Oomoo`04Ool00`00Oomoo`1COol5001[Ool3002EOol000mo
o`8000Yoo`8000=oo`<000Moo`03001oogoo02eoo`<002=oo`D006]oo`<009Eoo`00:Woo00<007oo
Ool0;Goo0`009Goo0`00ogoo17oo000ZOol00`00Oomoo`0]Ool3002LOol3002<Ool002Yoo`03001o
ogoo0<aoo`<008aoo`00:Woo0P00:7oo0`00XWoo0`00S7oo000ZOol00`00Oomoo`0WOol3003oOolb
Ool002Yoo`03001oogoo02Moo`<00?mooc9oo`00:Woo00<007ooOol0>Goo0`00ogoo87oo000ZOol0
0`00Oomoo`0iOol3003oOolPOol002Yoo`03001oogoo03Uoo`<0039oo`<00>Yoo`00:Woo0P004goo
0`00>7oo0`007Woo0`00jWoo000ZOol00`00Oomoo`0BOol3000hOol3000NOol3003:Ool3000MOol0
021oo`<000Moo`03001oogoo019oo`<003Qoo`<00>]oo`<001eoo`0087oo0`001goo00<007ooOol0
G7oo0`00g7oo0`007Goo000POol30007Ool00`00Oomoo`0IOol30010Ool3001QOol3002HOol002Yo
o`03001oogoo01Uoo`<0041oo`<0065oo`<009Qoo`00:Woo00<007ooOol06Goo0`00Y7oo0`00V7oo
000ZOol2003oOomMOol002Yoo`03001oogoo045oo`<00?mooaQoo`00:Woo00<007ooOol0@Goo0`00
@Goo0`00dgoo000ZOol00`00Oomoo`11Ool30011Ool3003COol002Yoo`03001oogoo06Yoo`<001Qo
o`<004Ioo`<008Yoo`00:Woo00<007ooOol0;7oo0`00>goo0`00HGoo0`00RWoo000ZOol00`00Oomo
o`0/Ool3000kOol3001QOol3002:Ool002Yoo`8002eoo`<00?moobeoo`00:Woo00<007ooOol0[7oo
0`007Goo0`0077oo0`00@goo0`009goo000ZOol00`00Oomoo`2/Ool3000MOol3000BOol30007Ool3
0013Ool3000WOol002Yoo`03001oogoo0:aoo`<001eoo`<0019oo`<000Moo`<004=oo`<002Moo`00
:Woo00<007ooOol0hGoo0`00Mgoo0009Ool20004Ool20004Ool20003Ool30003Ool30007Ool00`00
Oomoo`2gOol3002QOol000Qoo`04001oogoo0003Ool20003Ool01000Oomoo`001Goo00<007ooOol0
0goo00<007ooOol017oo00<007ooOol0C7oo0`00J7oo0`00XGoo0008Ool01000Oomoo`0027oo00@0
07ooOol000Eoo`03001oogoo00=oo`03001oogoo00Aoo`<004aoo`<006Qoo`<00:5oo`0027oo00@0
07ooOol000Qoo`04001oogoo0003Ool20003Ool30007Ool00`00Oomoo`0hOol3000@Ool4003oOol=
Ool000Qoo`04001oogoo0008Ool01000Oomoo`001Goo00@007ooOol000Uoo`03001oogoo03Qoo`<0
011oo`<00?moo`9oo`<000Uoo`002Goo0P002Woo0P000goo0`000goo10001Woo00<007ooOol04Woo
0`008goo0`0047oo0`00ogoo0Woo0`002Goo000ZOol00`00Oomoo`0BOol3003oOolkOol30009Ool0
02Yoo`03001oogoo019oo`<00=Ioo`<006eoo`00:Woo00<007ooOol0jgoo0`00KGoo000ZOol2001a
Ool3001hOol3001]Ool002Yoo`03001oogoo071oo`<00>Qoo`00:Woo00<007ooOol0L7oo0`00bWoo
0`006goo000ZOol00`00Oomoo`3oOolnOol3000KOol002Yoo`03001oogoo0?moocioo`<001]oo`00
:Woo00<007ooOol0I7oo0`00;Woo0`00ZGoo0`005goo000ZOol00`00Oomoo`1TOol3000^Ool3002Y
Ool3000GOol002Yoo`8006Eoo`<002ioo`<00:Uoo`<001Moo`00:Woo00<007ooOol0ogoo5goo0`00
6goo0`0097oo000ZOol00`00Oomoo`3oOolGOol3000KOol3000TOol002Yoo`03001oogoo0?mooaMo
o`<001]oo`<002Aoo`00:Woo00<007ooOol09Goo0`00ogoo=7oo000MOol3000:Ool00`00Oomoo`0U
Ool3003oOoldOol001eoo`<000Yoo`03001oogoo02Eoo`<00?moocAoo`007Goo0`002Woo0P00ogoo
GGoo000ZOol00`00Oomoo`3oOomLOol002Yoo`03001oogoo0?mooeaoo`00:Woo00<007ooOol0ogoo
G7oo000ZOol00`00Oomoo`1dOol30003Ool3003NOol002Yoo`03001oogoo05Moo`<001Yoo`<000=o
o`<00=ioo`00:Woo0P00F7oo0`006Woo0`000goo0`00gWoo000ZOol00`00Oomoo`1GOol3001kOol3
0023Ool002Yoo`03001oogoo0=Eoo`<008=oo`00:Woo00<007ooOol0eGoo0`00Pgoo000ZOol00`00
Oomoo`3oOomLOol000moo`8000Aoo`8000Aoo`8000Aoo`<000Ioo`03001oogoo0?mooeaoo`003Woo
00@007ooOol000=oo`8000=oo`04001oogoo0004Ool00`00Oomoo`05Ool00`00Oomoo`3oOomLOol0
00ioo`04001oogoo0008Ool01000Oomoo`000Woo10001Woo0`00ogooG7oo000>Ool01000Oomoo`00
27oo00@007ooOol0009oo`03001oo`0000Moo`03001oogoo0?mooeaoo`003Woo00@007ooOol000Qo
o`04001oogoo0002Ool00`00Ool00007Ool00`00Oomoo`3oOomLOol000moo`8000Yoo`8000Aoo`80
00Moo`03001oogoo071oo`<00;1oo`<003Eoo`00:Woo00<007ooOol0>Woo0`00<goo0`001Goo0`00
Z7oo0`00=Goo000ZOol00`00Oomoo`0jOol3000cOol30005Ool3002XOol3000eOol002Yoo`03001o
ogoo01Moo`<0021oo`<003]oo`<000Uoo`<00=Aoo`00:Woo0P0067oo0`00JWoo0`00Ogoo0`00DWoo
000ZOol00`00Oomoo`0GOol3001ZOol3001oOol3001BOol002Yoo`03001oogoo0?moo`Moo`<0059o
o`002Woo0`007Goo00<007ooOol0m7oo0`00I7oo000:Ool3000MOol00`00Oomoo`3dOol3000?Ool3
001BOol000Yoo`<001eoo`03001oogoo0?Aoo`<000moo`<0059oo`00:Woo00<007ooOol0@7oo0`00
`goo0`00DWoo000ZOol20011Ool3003oOolIOol002Yoo`03001oogoo041oo`<00?mooaUoo`00:Woo
00<007ooOol0ogooG7oo000ZOol00`00Oomoo`3oOomLOol002Yoo`03001oogoo0?mooeaoo`00:Woo
00<007ooOol0ogooG7oo000ZOol00`00Oomoo`3oOomLOol002Yoo`800?mooeeoo`00:Woo00<007oo
Ool0Ygoo0`00:goo0`00Pgoo000ZOol00`00Oomoo`2WOol3000[Ool30023Ool002Yoo`03001oogoo
0:Moo`<002]oo`<008=oo`00:Woo00<007ooOol0ogooG7oo000ZOol00`00Oomoo`3oOomLOol002Yo
o`03001oogoo0>Qoo`<0071oo`00:Woo0P00jGoo0`00L7oo000ZOol00`00Oomoo`3XOol3001`Ool0
02Yoo`03001oogoo0?mooeaoo`00:Woo00<007ooOol0ogooG7oo0009Ool20004Ool20004Ool20004
Ool30002Ool30007Ool00`00Oomoo`3oOomLOol000Qoo`04001oogoo0003Ool20003Ool01000Oomo
o`0017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol0VGoo0`00_goo0008Ool01000Oomo
o`0027oo00@007ooOol0009oo`@000Eoo`03001oogoo00Aoo`<009Uoo`<00;moo`0027oo00@007oo
Ool000Qoo`04001oogoo0002Ool00`00Ool00003Ool30007Ool00`00Oomoo`2IOol3002oOol000Qo
o`04001oogoo0008Ool01000Oomoo`000Woo00<007oo00000goo00<007ooOol01goo00<007ooOol0
ogooG7oo0009Ool2000:Ool20004Ool20003Ool40006Ool00`00Oomoo`3oOomLOol002Yoo`03001o
ogoo0?mooeaoo`00:Woo00<007ooOol0ogooG7oo000ZOol00`00Oomoo`2TOol3002dOol002Yoo`80
03ioo`<006Aoo`<003]oo`<007Ioo`00:Woo00<007ooOol0?Goo0`00I7oo0`00>goo0`00MWoo000Z
Ool00`00Oomoo`0mOol3002ROol3001fOol002Yoo`03001oogoo0?mooeaoo`00:Woo00<007ooOol0
ogooG7oo000ZOol00`00Oomoo`3oOomLOol002Yoo`03001oogoo0?mooeaoo`00:Woo0P00ogooGGoo
000ZOol00`00Oomoo`3oOomLOol002Yoo`03001oogoo03Eoo`<00?moobAoo`00:Woo00<007ooOol0
=Goo0`00ogoo97oo0008Ool3000OOol00`00Oomoo`0eOol3003oOolTOol000Qoo`<001moo`03001o
ogoo0?mooeaoo`0027oo0`007goo00<007ooOol0ogooG7oo000ZOol2003oOomMOol002Yoo`03001o
ogoo0?mooeaoo`00:Woo00<007ooOol0ogooG7oo000ZOol00`00Oomoo`3oOomLOol002Yoo`03001o
ogoo0?mooeaoo`00:Woo00<007ooOol0ogooG7oo000ZOol00`00Oomoo`3oOomLOol002Yoo`800?mo
oeeoo`00:Woo00<007ooOol0ogooG7oo000ZOol00`00Oomoo`3oOomLOol002Yoo`03001oogoo0?mo
oeaoo`00:Woo00<007ooOol0ogooG7oo000?Ool20004Ool20004Ool20003Ool30007Ool00`00Oomo
o`3oOomLOol000ioo`04001oogoo0003Ool20003Ool01000Oomoo`001Goo00<007ooOol017oo00<0
07ooOol0ogooG7oo000>Ool01000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo00Aoo`<00?mo
oeaoo`003Woo00@007ooOol000Qoo`04001oogoo0002Ool30007Ool00`00Oomoo`3oOomLOol000io
o`04001oogoo0008Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol0ogooG7oo000?Ool2
000:Ool20003Ool40006Ool00`00Oomoo`3oOomLOol002Yoo`03001oogoo0?mooeaoo`00:Woo00<0
07ooOol0ogooG7oo000ZOol00`00Oomoo`2YOol3002_Ool002Yoo`800:Yoo`<00:moo`00:Woo00<0
07ooOol0ZGoo0`00[goo000ZOol00`00Oomoo`3oOomLOol002Yoo`03001oogoo0?mooeaoo`00:Woo
00<007ooOol0ogooG7oo000ZOol00`00Oomoo`3oOomLOol00001\
\>"],
  ImageRangeCache->{{{0, 391}, {241.188, 0}} -> {0.0246208, 0.0166414, \
0.000127025, 0.000146052}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 46, 0, 36, "SubsectionIcon"],
Cell[1788, 53, 392, 8, 36, "Text"],
Cell[2183, 63, 869, 15, 64, "DefinitionBox"],
Cell[3055, 80, 392, 11, 92, "Input"],
Cell[3450, 93, 114, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3589, 100, 111, 2, 27, "Input"],
Cell[3703, 104, 953, 18, 83, "Output"]
}, Open  ]],
Cell[4671, 125, 304, 7, 44, "MathCaption"],

Cell[CellGroupData[{
Cell[5000, 136, 232, 6, 30, "Input"],
Cell[5235, 144, 18, 0, 12336, "Output"]
}, Closed]],
Cell[5268, 147, 218, 8, 18, "Text"],
Cell[5489, 157, 78, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5592, 161, 85, 2, 27, "Input"],
Cell[5680, 165, 8347, 108, 184, 46, 0, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[14042, 276, 154, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[14221, 283, 137, 3, 27, "Input"],
Cell[14361, 288, 11135, 194, 665, "Output"]
}, Closed]],
Cell[25511, 485, 108, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[25644, 492, 264, 5, 27, "Input"],
Cell[25911, 499, 83842, 1394, 324, 6061, 429, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[109768, 1896, 234, 8, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[110027, 1908, 304, 5, 42, "Input"],
Cell[110334, 1915, 107, 2, 20, "Output"]
}, Open  ]],
Cell[110456, 1920, 242, 8, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[110723, 1932, 131, 3, 27, "Input"],
Cell[110857, 1937, 291, 7, 41, "Output"]
}, Open  ]],
Cell[111163, 1947, 98, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[111286, 1954, 107, 2, 27, "Input"],
Cell[111396, 1958, 17078, 496, 249, 5166, 344, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

