(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     28801,        794]*)
(*NotebookOutlinePosition[     30587,        848]*)
(*  CellTagsIndexPosition[     30327,        837]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Description in terms of a matrix of moments", "SubsectionIcon",
  CellTags->"Description by moments"],

Cell[CellGroupData[{

Cell["The full description", "SubsubsectionIcon",
  CellTags->"full description"],

Cell[TextData[{
  "\tWith two alleles per locus, the full set of diploid genotype frequencies \
can be specified by the allele frequencies at each locus, ",
  Cell[BoxData[
      \(TraditionalForm\`p\_i\)]],
  ", and by the associations between sets of genes, ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(U, \(V\^*\)\)\)]],
  ".  In principle, the allele frequencies may differ between female and male \
gamete pools; these are referred to as ",
  Cell[BoxData[
      \(TraditionalForm\`p\_i, \ \(p\_i\%*\)\)]],
  ", respectively.  The associations are defined as multivariate moments \
amongst relevant sets of loci: ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(U, \(V\^*\)\) \[Congruent] 
        E[\[Product]\+\(i \[Element] U\)\((X\_i - 
                  p\_i)\) \(\[Product]\+\(j \[Element] V\)\((\(X\_i\%*\) - \
\(p\_i\%*\))\)\)]\)]],
  ".  These correspond to Slatkin's (",
  ButtonBox["1972",
    ButtonData:>{"References", "Slatkin 1972"},
    ButtonStyle->"AddOnsLink"],
  ") definitions of linkage disequilibrium; however, other definitions are in \
use.  Here, I refer to these as 'moments'.  It may be useful to change the \
representation to one involving multivariate cumulants."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The reduced description", "SubsubsectionIcon",
  CellTags->"reduced description"],

Cell[TextData[{
  "\tIn admixture models with just two sources of immigrants, and with two \
alleles at each locus, genotype frequencies can be specified in terms of \
allele frequencies, ",
  Cell[BoxData[
      \(TraditionalForm\`p\_\(\(i\)\(\ \)\)\)]],
  "; relative divergence of allele frequenciesacross loci, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]p\_i\)]],
  "; ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "'th order within-genome associations  ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(0, k\)\)]],
  "; and between-genome associations involving ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " genes from one parent, and ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " from the other, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c\_\(j, k\)\)\(.\)\)\)]],
  " With ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " loci, and symmetry across the sexes, there are ",
  Cell[BoxData[
      \(TraditionalForm\`\((n - 1)\)\)]],
  " within-genome coefficients, and ",
  Cell[BoxData[
      \(TraditionalForm\`\(n(n - 1)\)\/2\)]],
  " between-genome coefficients.  Therefore, the ",
  Cell[BoxData[
      \(TraditionalForm\`3\^n\)]],
  "genotype frequencies are determined by ",
  Cell[BoxData[
      \(TraditionalForm\`n + \(\((n + 4)\) \((n - 1)\)\)\/2\)]],
  " parameters.  (Note that the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]p\_i\)]],
  "only give the relative importance of each locus, and could be multiplied \
by an arbitrary constant; they are therefore associated with ",
  Cell[BoxData[
      \(TraditionalForm\`\((n - 1)\)\)]],
  " degrees of freedom).  For example, with 4 loci, the 81 distinguishable \
diploid genotypes are specified by just 16 parameters; with 5 loci,the 243 \
distinguishable genotypes depend on 23 parameters.  "
}], "Text"],

Cell[TextData[{
  "\tIn admixture models, all ",
  Cell[BoxData[
      \(TraditionalForm\`j + k = n\)]],
  "'th order cross-genome associations have similar values.  This suggests a \
further simplification: to equate all cross-genome moments or cumulants \
involving the same number of loci.  However, this can lead to negative \
genotype frequencies: even the small changes needed to force equality among \
cross-genome associations of the same order can force genotype frequencies \
outside their valid range. There are a set of algorithms which use this \
representation; they are described under '",
  StyleBox["Obsolete functions",
    FontSlant->"Italic"],
  "'."
}], "Text"],

Cell[TextData[{
  "\tIf the set of genes U all come from the same parent, ",
  Cell[BoxData[
      \(TraditionalForm\`c\_U\)]],
  "= ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(0, \(\(|\)\(U\)\(|\)\)\)\)]],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`\[Product]\_\(i \[Element] U\)\[Delta]p\_i\)]],
  "), where |U| is the number of genes in ",
  Cell[BoxData[
      \(TraditionalForm\`U\)]],
  "; if a set ",
  Cell[BoxData[
      \(TraditionalForm\`U\)]],
  " comes from one parent, and ",
  Cell[BoxData[
      \(TraditionalForm\`\(U\^*\)\)]],
  "from the other, then ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(c\_\(U, \(U\^*\)\)\), "=", 
          RowBox[{
            
            RowBox[{\(c\_\(\(\(|\)\(U\)\(|\)\), \(\(|\)\(U\^*\)\(|\)\)\)\), 
              "(", 
              FormBox[\(\[Product]\_\(i \[Element] U\)\[Delta]p\_i\),
                "TraditionalForm"], ")"}], 
            RowBox[{"(", 
              
              FormBox[\(\[Product]\_\(i \[Element] \
\(U\^*\)\)\[Delta]p\_\(i\^*\)\),
                "TraditionalForm"], ")"}]}]}], TraditionalForm]]],
  ".  The genotype frequency can then be written compactly as follows:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox[\(g[{{1, 1}, {1, 1}}]\),
          FontFamily->"Times"], 
        StyleBox["=",
          FontFamily->"Times"], 
        RowBox[{
          RowBox[{
            StyleBox[\(\(p\_i\) \(p\_j\) \(p\_\(i\^*\)\) p\_\(j\^*\)\),
              FontFamily->"Times"], 
            StyleBox["+",
              FontFamily->"Times"], 
            RowBox[{
              RowBox[{
                StyleBox["(",
                  FontFamily->"Times"], 
                RowBox[{
                  RowBox[{
                    StyleBox[\(p\_\(i\^*\)\),
                      FontFamily->"Times"], 
                    StyleBox[\(p\_\(j\^*\)\),
                      FontFamily->"Times"], 
                    SubscriptBox[
                      StyleBox["\[Delta]p",
                        FontFamily->"Times"], "i"], 
                    SubscriptBox[
                      StyleBox["\[Delta]p",
                        FontFamily->"Times"], "j"]}], 
                  StyleBox["+",
                    FontFamily->"Times"], 
                  RowBox[{
                    StyleBox[\(p\_i\),
                      FontFamily->"Times"], 
                    SubscriptBox[
                      StyleBox["p",
                        FontFamily->"Times"], "j"], 
                    SubscriptBox[
                      StyleBox["\[Delta]p",
                        FontFamily->"Times"], \(i\^*\)], 
                    SubscriptBox[
                      StyleBox["\[Delta]p",
                        FontFamily->"Times"], \(j\^*\)]}]}], 
                StyleBox[")",
                  FontFamily->"Times"]}], 
              StyleBox[
                SubscriptBox["c", 
                  StyleBox[\(0, 2\),
                    FontFamily->"Times"]],
                FontFamily->"Times"]}], 
            StyleBox["+",
              FontFamily->"Times"], 
            StyleBox[
              RowBox[{\((\(p\_i\) \[Delta]p\_j + \(\[Delta]p\_i\) p\_j)\), 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{\(p\_\(i\^*\)\), 
                      SubscriptBox[
                        StyleBox["\[Delta]p",
                          FontFamily->"Times"], \(j\^*\)]}], "+", 
                    RowBox[{
                      SubscriptBox[
                        StyleBox["\[Delta]p",
                          FontFamily->"Times"], \(i\^*\)], \(p\_j\%*\)}]}], 
                  ")"}], 
                SubscriptBox["c", 
                  StyleBox[\(1, 1\),
                    FontFamily->"Times"]]}],
              FontFamily->"Times"], 
            StyleBox["+",
              FontFamily->"Times"], 
            RowBox[{
              RowBox[{
                StyleBox["(",
                  FontFamily->"Times"], 
                RowBox[{
                  RowBox[{
                    StyleBox[\(p\_\(j\^*\)\),
                      FontFamily->"Times"], 
                    StyleBox[\(\[Delta]p\_i\),
                      FontFamily->"Times"], 
                    StyleBox[
                      SubscriptBox[
                        StyleBox["\[Delta]p",
                          FontFamily->"Times"], "j"],
                      FontFamily->"Times"], 
                    SubscriptBox[
                      StyleBox["\[Delta]p",
                        FontFamily->"Times"], \(i\^*\)]}], "+", 
                  RowBox[{
                    StyleBox[\(p\_j\),
                      FontFamily->"Times"], 
                    StyleBox[\(\[Delta]p\_i\),
                      FontFamily->"Times"], 
                    StyleBox[
                      SubscriptBox[
                        StyleBox["\[Delta]p",
                          FontFamily->"Times"], \(j\^*\)],
                      FontFamily->"Times"], 
                    SubscriptBox[
                      StyleBox["\[Delta]p",
                        FontFamily->"Times"], \(i\^*\)]}], 
                  StyleBox["+",
                    FontFamily->"Times"], 
                  RowBox[{
                    StyleBox[\(p\_\(i\^*\)\),
                      FontFamily->"Times"], 
                    StyleBox[\(\[Delta]p\_i\),
                      FontFamily->"Times"], 
                    StyleBox[
                      SubscriptBox[
                        StyleBox["\[Delta]p",
                          FontFamily->"Times"], "j"],
                      FontFamily->"Times"], 
                    SubscriptBox[
                      StyleBox["\[Delta]p",
                        FontFamily->"Times"], \(j\^*\)]}], 
                  StyleBox["+",
                    FontFamily->"Times"], 
                  RowBox[{
                    StyleBox[\(p\_i\),
                      FontFamily->"Times"], 
                    StyleBox[\(\[Delta]p\_j\),
                      FontFamily->"Times"], 
                    StyleBox[
                      SubscriptBox[
                        StyleBox["\[Delta]p",
                          FontFamily->"Times"], \(i\^*\)],
                      FontFamily->"Times"], 
                    SubscriptBox[
                      StyleBox["\[Delta]p",
                        FontFamily->"Times"], \(j\^*\)]}]}], 
                StyleBox[")",
                  FontFamily->"Times"]}], 
              StyleBox[
                SubscriptBox["c", 
                  StyleBox[\(1, 2\),
                    FontFamily->"Times"]],
                FontFamily->"Times"]}], 
            StyleBox["+",
              FontFamily->"Times"], 
            RowBox[{
              StyleBox[\(\[Delta]p\_i\),
                FontFamily->"Times"], 
              StyleBox[
                SubscriptBox[
                  StyleBox["\[Delta]p",
                    FontFamily->"Times"], "j"],
                FontFamily->"Times"], 
              SubscriptBox[
                StyleBox["\[Delta]p",
                  FontFamily->"Times"], \(i\^*\)], 
              SubscriptBox[
                StyleBox["\[Delta]p",
                  FontFamily->"Times"], \(j\^*\)], 
              StyleBox[
                SubscriptBox["c", 
                  StyleBox[\(2, 2\),
                    FontFamily->"Times"]],
                FontFamily->"Times"]}]}], "\n", 
          StyleBox[
            RowBox[{"\t\t", 
              StyleBox["\t",
                FontFamily->"Times"]}]], 
          StyleBox["=",
            FontFamily->"Times"], 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["\[CapitalGamma]",
                  FontFamily->"Times",
                  FontWeight->"Bold"], 
                StyleBox[".",
                  FontFamily->"Times"], 
                StyleBox["C",
                  FontFamily->"Times",
                  FontWeight->"Bold"], 
                StyleBox[".",
                  FontFamily->"Times"], 
                StyleBox[
                  SuperscriptBox[
                    SuperscriptBox[
                      StyleBox["\[CapitalGamma]",
                        FontFamily->"Times",
                        FontWeight->"Bold"], "*"], "T"],
                  FontFamily->"Times"]}], 
              StyleBox["      ",
                FontFamily->"Times"], 
              StyleBox["where",
                FontFamily->"Times"], 
              StyleBox[
                RowBox[{
                  StyleBox[" ",
                    FontFamily->"Times"], 
                  StyleBox["\t",
                    FontFamily->"Times",
                    FontWeight->"Bold"]}]], 
              StyleBox["\[CapitalGamma]",
                FontFamily->"Times",
                FontWeight->"Bold"]}], 
            StyleBox["=",
              FontFamily->"Times"], 
            StyleBox[
              RowBox[{"(", GridBox[{
                    {\(\(p\_i\) 
                        p\_j\), \((\(p\_i\) \[Delta]p\_j + \(\[Delta]p\_i\) 
                            p\_j)\), 
                      StyleBox[
                        RowBox[{\(\[Delta]p\_i\), 
                          SubscriptBox[
                            StyleBox["\[Delta]p",
                              FontFamily->"Times"], "j"]}],
                        FontFamily->"Times"]}
                    }], ")"}],
              FontFamily->"Times"]}]}]}], 
      StyleBox[",",
        FontFamily->"Times"], 
      StyleBox[" ",
        FontFamily->"Times"], 
      StyleBox[
        RowBox[{
          SuperscriptBox[
            StyleBox["\[CapitalGamma]",
              FontFamily->"Times",
              FontWeight->"Bold"], "*"], "=", 
          RowBox[{"(", GridBox[{
                {\(\(p\_\(i\^*\)\) p\_\(j\^*\)\), 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{\(p\_\(i\^*\)\), 
                        SubscriptBox[
                          StyleBox["\[Delta]p",
                            FontFamily->"Times"], \(j\^*\)]}], "+", 
                      RowBox[{
                        SubscriptBox[
                          StyleBox["\[Delta]p",
                            FontFamily->"Times"], \(i\^*\)], \(p\_j\%*\)}]}], 
                    ")"}], 
                  RowBox[{"(", 
                    RowBox[{
                      SubscriptBox[
                        StyleBox["\[Delta]p",
                          FontFamily->"Times"], \(i\^*\)], 
                      SubscriptBox[
                        StyleBox["\[Delta]p",
                          FontFamily->"Times"], \(j\^*\)]}], ")"}]}
                }], ")"}]}],
        FontFamily->"Times"], 
      StyleBox[",",
        FontFamily->"Times"], "\n", 
      StyleBox[" ",
        FontFamily->"Times"], 
      RowBox[{
        StyleBox["C",
          FontFamily->"Times",
          FontWeight->"Bold"], 
        StyleBox["=",
          FontFamily->"Times"], 
        RowBox[{
          StyleBox[
            RowBox[{"(", GridBox[{
                  {"1", "0", 
                    StyleBox[
                      SubscriptBox["c", 
                        StyleBox[\(0, 2\),
                          FontFamily->"Times"]],
                      FontFamily->"Times"]},
                  {"0", \(c\_\(1, 1\)\), 
                    StyleBox[
                      SubscriptBox["c", 
                        StyleBox[\(1, 2\),
                          FontFamily->"Times"]],
                      FontFamily->"Times"]},
                  {
                    StyleBox[
                      SubscriptBox["c", 
                        StyleBox[\(2, 0\),
                          FontFamily->"Times"]],
                      FontFamily->"Times"], 
                    StyleBox[
                      SubscriptBox["c", 
                        StyleBox[\(2, 1\),
                          FontFamily->"Times"]],
                      FontFamily->"Times"], 
                    StyleBox[
                      SubscriptBox["c", 
                        StyleBox[\(2, 2\),
                          FontFamily->"Times"]],
                      FontFamily->"Times"]}
                  }], ")"}],
            FontFamily->"Times"], "=", 
          RowBox[{"(", GridBox[{
                {"1", "0", 
                  StyleBox[
                    SubscriptBox["\[Kappa]", 
                      StyleBox[\(0, 2\),
                        FontFamily->"Times"]],
                    FontFamily->"Times"]},
                {"0", \(\[Kappa]\_\(1, 1\)\), 
                  StyleBox[
                    SubscriptBox["\[Kappa]", 
                      StyleBox[\(1, 2\),
                        FontFamily->"Times"]],
                    FontFamily->"Times"]},
                {
                  StyleBox[
                    SubscriptBox["\[Kappa]", 
                      StyleBox[\(2, 0\),
                        FontFamily->"Times"]],
                    FontFamily->"Times"], 
                  StyleBox[
                    SubscriptBox["\[Kappa]", 
                      StyleBox[\(2, 1\),
                        FontFamily->"Times"]],
                    FontFamily->"Times"], 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["\[Kappa]",
                        FontFamily->"Times"], \(2, 2\)], 
                    "+", \(\[Kappa]\_\(0, 2\)\%2\), 
                    "+", \(2 \( \[Kappa]\^2\)\_\(1, 1\)\)}]}
                }], ")"}]}]}]}]], "NumberedEquation",
  CellTags->"g[X] matrix"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\_\(j, k\)\)]],
  " are the multivariate cumulants."
}], "Text"],

Cell[TextData[{
  "\tThe frequency of other genotypes is found by replacing ",
  Cell[BoxData[
      \(TraditionalForm\`p\_i\ by\ q\_i\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]p\_i\ by\  - \[Delta]p\_i\)]],
  " whenever an allele ",
  Cell[BoxData[
      \(TraditionalForm\`X\_i = 1\)]],
  " is replaced by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(X\_i\)\(=\)\(0\)\(\ \)\)\)\)]],
  ".   In general, with ",
  StyleBox["n",
    FontSlant->"Italic"],
  " loci, ",
  StyleBox["C",
    FontWeight->"Bold"],
  " is the matrix of scaled moments (with ",
  Cell[BoxData[
      \(TraditionalForm\`C\_\(1, 0\) \[Congruent] 0, \ 
      C\_\(0, 0\) \[Congruent] 1\)]],
  "), and ",
  StyleBox["\[CapitalGamma]",
    FontWeight->"Bold"],
  " is a vector indexed 0\[Ellipsis]",
  StyleBox["n",
    FontSlant->"Italic"],
  ", whose",
  StyleBox[" i",
    FontSlant->"Italic"],
  "'th element is the sum of products of (",
  StyleBox["n",
    FontSlant->"Italic"],
  "-",
  StyleBox["i)",
    FontSlant->"Italic"],
  " distinct allele frequencies and the remaining ",
  StyleBox["i",
    FontSlant->"Italic"],
  " distinct ",
  StyleBox["\[Delta]p",
    FontSlant->"Italic"],
  "'s.  The complete matrix of ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\[Times]2\^n\)]],
  "diploid genotypes can be written as ",
  Cell[BoxData[
      RowBox[{
        StyleBox["\[CapitalTau]",
          FontWeight->"Bold"], ".", 
        StyleBox["C",
          FontWeight->"Bold"], ".", 
        SuperscriptBox[
          SuperscriptBox[
            StyleBox["\[CapitalTau]",
              FontWeight->"Bold"], "*"], "T"]}]]],
  ", where",
  StyleBox[" \[CapitalTau]",
    FontWeight->"Bold"],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\[Times]\((n + 1)\)\)]],
  " matrix, each row being a permutation of the vector ",
  StyleBox["\[CapitalGamma]",
    FontWeight->"Bold"],
  " defined in ",
  ButtonBox["(",
    ButtonData:>"g[X] matrix",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "g[X] matrix"],
  ButtonBox[")",
    ButtonData:>"g[X] matrix",
    ButtonStyle->"Hyperlink"],
  ".  For example, with two loci:"
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"(", GridBox[{
              {
                StyleBox[\(g[{{0, 0}, {0, 0}}]\),
                  FontFamily->"Times"], 
                StyleBox[\(g[{{0, 0}, {0, 1}}]\),
                  FontFamily->"Times"], "\[Ellipsis]", "\[Ellipsis]"},
              {
                StyleBox[\(g[{{0, 1}, {0, 0}}]\),
                  FontFamily->"Times"], 
                StyleBox[\(g[{{0, 1}, {0, 1}}]\),
                  FontFamily->"Times"], "\[Ellipsis]", "\[Ellipsis]"},
              {
                StyleBox[".",
                  FontFamily->"Times"], ".", "\[Ellipsis]", "\[Ellipsis]"},
              {".", ".", "\[Ellipsis]", "\[Ellipsis]"}
              }], ")"}], "=", 
        RowBox[{
          RowBox[{
            StyleBox["\[CapitalTau]",
              FontFamily->"Times",
              FontWeight->"Bold"], 
            StyleBox[".",
              FontFamily->"Times"], 
            StyleBox["C",
              FontFamily->"Times",
              FontWeight->"Bold"], 
            StyleBox[".",
              FontFamily->"Times"], 
            StyleBox[
              SuperscriptBox[
                SuperscriptBox[
                  StyleBox["\[CapitalTau]",
                    FontWeight->"Bold"], "*"], "T"],
              FontFamily->"Times"]}], 
          StyleBox["      ",
            FontFamily->"Times"], 
          StyleBox["where",
            FontFamily->"Times"]}]}], 
      StyleBox[" \t",
        FontFamily->"Times"]}], "\n", 
    RowBox[{
      StyleBox["\t",
        FontFamily->"Times"], 
      RowBox[{
        StyleBox["\[CapitalTau]",
          FontFamily->"Times",
          FontWeight->"Bold"], "=", 
        RowBox[{"(", 
          StyleBox[GridBox[{
                {
                  RowBox[{
                    SubscriptBox[
                      StyleBox["q",
                        FontFamily->"Times"], "i"], 
                    SubscriptBox[
                      StyleBox["q",
                        FontFamily->"Times"], "j"]}], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        RowBox[{"-", 
                          SubscriptBox[
                            StyleBox["q",
                              FontFamily->"Times"], 
                            "i"]}], \(\[Delta]p\_j\)}], 
                      StyleBox["-",
                        FontFamily->"Times"], 
                      RowBox[{\(\[Delta]p\_i\), 
                        SubscriptBox[
                          StyleBox["q",
                            FontFamily->"Times"], "j"]}]}], ")"}], 
                  StyleBox[
                    RowBox[{\(\[Delta]p\_i\), 
                      SubscriptBox[
                        StyleBox["\[Delta]p",
                          FontFamily->"Times"], "j"]}],
                    FontFamily->"Times"]},
                {\(\(q\_i\) p\_j\), 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        SubscriptBox[
                          StyleBox["q",
                            FontFamily->"Times"], "i"], \(\[Delta]p\_j\)}], 
                      StyleBox["-",
                        FontFamily->"Times"], \(\(\[Delta]p\_i\) p\_j\)}], 
                    ")"}], 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(\[Delta]p\_i\),
                        FontFamily->"Times"]}], 
                    StyleBox[
                      SubscriptBox[
                        StyleBox["\[Delta]p",
                          FontFamily->"Times"], "j"],
                      FontFamily->"Times"]}]},
                {
                  RowBox[{\(p\_i\), 
                    SubscriptBox[
                      StyleBox["q",
                        FontFamily->"Times"], "j"]}], 
                  RowBox[{"(", 
                    RowBox[{\(\(-p\_i\) \[Delta]p\_j\), "+", 
                      RowBox[{\(\[Delta]p\_i\), 
                        SubscriptBox[
                          StyleBox["q",
                            FontFamily->"Times"], "j"]}]}], ")"}], 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox[\(\[Delta]p\_i\),
                        FontFamily->"Times"]}], 
                    StyleBox[
                      SubscriptBox[
                        StyleBox["\[Delta]p",
                          FontFamily->"Times"], "j"],
                      FontFamily->"Times"]}]},
                {\(\(p\_i\) 
                    p\_j\), \((\(p\_i\) \[Delta]p\_j + \(\[Delta]p\_i\) 
                        p\_j)\), 
                  StyleBox[
                    RowBox[{\(\[Delta]p\_i\), 
                      SubscriptBox[
                        StyleBox["\[Delta]p",
                          FontFamily->"Times"], "j"]}],
                    FontFamily->"Times"]}
                }],
            FontFamily->"Times"], 
          StyleBox[")",
            FontFamily->"Times"]}]}]}]}], "NumberedEquation",
  CellTags->"g[X] full matrix"],

Cell[TextData[{
  "Expressed in this form, genotype frequencies can be calculated \
efficiently, since ",
  StyleBox["\[CapitalTau]",
    FontWeight->"Bold"],
  " depends only on allele frequencies, and",
  StyleBox[" C",
    FontWeight->"Bold"],
  " depends only on the moments or cumulants.  Thus, when exploring the \
statistical fit of alternative moments, ",
  StyleBox["T",
    FontWeight->"Bold"],
  " need not be recalculated."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extensions", "SubsubsectionIcon",
  CellTags->"extensions"],

Cell[TextData[{
  "\tThe model discussed so far has assumed migration from just two source \
demes.  More complex models, with migration from several demes, will retain \
the same structure only under special conditions.  The linkage disequilibrium \
after migration is a linear sum of the disequilibria contributed by each \
source.  Therefore, the effects of each locus will scale by a factor ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]p\_i\)]],
  "only if the deviations in allele frequency of all the sources from the \
target deme are proportional to this quantity.  That is plausible if there is \
mixing between two taxa, ",
  StyleBox["via",
    FontSlant->"Italic"],
  " some network of demes, with the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]p\_i\)]],
  "corresponding to the difference in allele frequency at locus ",
  StyleBox["i ",
    FontSlant->"Italic"],
  "between the parental taxa.  For example, consider a cline.  If there is \
diffusion from neighbouring demes, plus a lower rate from the parental taxa, \
then associations will scale with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]p\_i\)]],
  "provided that the gradient of the cline at some locus is proportional to \
the divergence between the taxa - which will be the case for neutral models.  \
In general, however, admixture between large numbers of demes could produce \
any distribution of genotype frequencies."
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{982, 665},
WindowMargins->{{-1, Automatic}, {Automatic, 2}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Description by moments"->{
    Cell[1739, 51, 107, 1, 36, "SubsectionIcon",
      CellTags->"Description by moments"]},
  "full description"->{
    Cell[1871, 56, 81, 1, 24, "SubsubsectionIcon",
      CellTags->"full description"]},
  "reduced description"->{
    Cell[3207, 90, 87, 1, 24, "SubsubsectionIcon",
      CellTags->"reduced description"]},
  "g[X] matrix"->{
    Cell[6991, 197, 12366, 322, 134, "NumberedEquation",
      CellTags->"g[X] matrix"]},
  "g[X] full matrix"->{
    Cell[21683, 607, 5100, 132, 179, "NumberedEquation",
      CellTags->"g[X] full matrix"]},
  "extensions"->{
    Cell[27270, 759, 65, 1, 24, "SubsubsectionIcon",
      CellTags->"extensions"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Description by moments", 29646, 815},
  {"full description", 29763, 818},
  {"reduced description", 29879, 821},
  {"g[X] matrix", 29990, 824},
  {"g[X] full matrix", 30104, 827},
  {"extensions", 30217, 830}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 107, 1, 36, "SubsectionIcon",
  CellTags->"Description by moments"],

Cell[CellGroupData[{
Cell[1871, 56, 81, 1, 24, "SubsubsectionIcon",
  CellTags->"full description"],
Cell[1955, 59, 1215, 26, 71, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3207, 90, 87, 1, 24, "SubsubsectionIcon",
  CellTags->"reduced description"],
Cell[3297, 93, 1824, 49, 84, "Text"],
Cell[5124, 144, 682, 14, 52, "Text"],
Cell[5809, 160, 1179, 35, 38, "Text"],
Cell[6991, 197, 12366, 322, 134, "NumberedEquation",
  CellTags->"g[X] matrix"],
Cell[19360, 521, 141, 5, 22, "Text"],
Cell[19504, 528, 2176, 77, 56, "Text"],
Cell[21683, 607, 5100, 132, 179, "NumberedEquation",
  CellTags->"g[X] full matrix"],
Cell[26786, 741, 447, 13, 40, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27270, 759, 65, 1, 24, "SubsubsectionIcon",
  CellTags->"extensions"],
Cell[27338, 762, 1435, 28, 96, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

