(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11682,        372]*)
(*NotebookOutlinePosition[     12840,        411]*)
(*  CellTagsIndexPosition[     12740,        404]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Moments & cumulants", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(Moment[\[Kappa], {j, 
                k}]\), \(returns\ an\ expression\ for\ the\ moment\ c[
                  U, \(V\^*\)]\ in\ terms\ of\ the\ cumulants\ within - \ 
              and\ between - 
              genomes\ \[Kappa]\_\(j, k\); \ \(\(j\)\(\[Congruent]\)\) | 
              U | , \ \(\(k\)\(\[Congruent]\)\) | V | \)},
          {\(Moment[\[Kappa], {j, k}, 
              Symmetric \[Rule] 
                True]\), \(assumes\ that\ the\ two\ sexes\ are\ \
\(\(equivalent\)\(.\)\)\)},
          {\(Moment[\[Kappa], {j, k}, 
              Centred \[Rule] True]\), \(assumes\ central\ moments, \ 
            so\ \[Kappa]\_\(0, 1\), \ \[Kappa]\_\(1, 0\)\ are\ \
\(\(zero\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"Moment"],

Cell[TextData[{
  "This is an expression for any moment such as ",
  Cell[BoxData[
      \(TraditionalForm\`c[{i, j, \(k\^*\), \(l\^*\)}]\)]],
  ", in terms of the reduced set of cumulants ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\_\(j, k\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " are the numbers of loci in the two genomes:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Moment[\[Kappa], {2, 2}]\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \(\[Kappa][0, 1]\^2\ \[Kappa][1, 0]\^2 + 
      \[Kappa][0, 2]\ \[Kappa][1, 0]\^2 + 
      4\ \[Kappa][0, 1]\ \[Kappa][1, 0]\ \[Kappa][1, 1] + 
      2\ \[Kappa][1, 1]\^2 + 2\ \[Kappa][1, 0]\ \[Kappa][1, 2] + 
      \[Kappa][0, 1]\^2\ \[Kappa][2, 0] + \[Kappa][0, 2]\ \[Kappa][2, 0] + 
      2\ \[Kappa][0, 1]\ \[Kappa][2, 1] + \[Kappa][2, 2]\)], "Output",
  CellLabel->"Out[3]="]
}, Closed]],

Cell["\<\
This can be simplified if one assumes that the two sexes are \
equivalent (Symmetric\[Rule]True):\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Moment[\[Kappa], {2, 2}, Symmetric \[Rule] True]\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\[Kappa][0, 1]\^4 + 2\ \[Kappa][0, 1]\^2\ \[Kappa][0, 2] + 
      \[Kappa][0, 2]\^2 + 4\ \[Kappa][0, 1]\^2\ \[Kappa][1, 1] + 
      2\ \[Kappa][1, 1]\^2 + 4\ \[Kappa][0, 1]\ \[Kappa][1, 2] + 
      \[Kappa][2, 2]\)], "Output",
  CellLabel->"Out[2]="]
}, Closed]],

Cell[TextData[{
  "There is a further simplification if moments are measured relative to the \
current mean (Centred\[Rule]True), so that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\_\(0, 1\), \ \[Kappa]\_\(1, 0\)\ are\ \
\(\(zero\)\(:\)\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Moment[\[Kappa], {2, 2}, Symmetric \[Rule] True, Centred \[Rule] True]
      \)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(\[Kappa][0, 2]\^2 + 2\ \[Kappa][1, 1]\^2 + \[Kappa][2, 2]\)], "Output",
  CellLabel->"Out[5]="]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(Cumulant[
              c, {j, k}]\), \(returns\ an\ expression\ for\ the\ cumulant\ \
\[Kappa][U, \(V\^*\)]\ in\ terms\ of\ the\ moments\ within - \ and\ between - 
              genomes\ \(\(c\_\(j, k\)\)\(.\)\)\)},
          {\(Cumulant[\[Kappa], {j, k}, 
              Symmetric \[Rule] 
                True]\), \(assumes\ that\ the\ two\ sexes\ are\ \
\(\(equivalent\)\(.\)\)\)},
          {\(Cumulant[\[Kappa], {j, k}, 
              Centred \[Rule] True]\), \(assumes\ central\ moments, \ 
            so\ c\_\(0, 1\), \ c\_\(1, 0\)\ are\ \(\(zero\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"Cumulant"],

Cell[TextData[{
  "This is an expression for any cumulant such as ",
  Cell[BoxData[
      \(TraditionalForm\`k[{i, j, \(k\^*\), \(l\^*\)}]\)]],
  ", in terms of the reduced set of moments ",
  Cell[BoxData[
      \(TraditionalForm\`c\_w[i]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`c\_b[j]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " are the numbers of loci involved:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cumulant[c, {2, 2}]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(\(-6\)\ c[0, 1]\^2\ c[1, 0]\^2 + 2\ c[0, 2]\ c[1, 0]\^2 + 
      8\ c[0, 1]\ c[1, 0]\ c[1, 1] - 2\ c[1, 1]\^2 - 2\ c[1, 0]\ c[1, 2] + 
      2\ c[0, 1]\^2\ c[2, 0] - c[0, 2]\ c[2, 0] - 2\ c[0, 1]\ c[2, 1] + 
      c[2, 2]\)], "Output",
  CellLabel->"Out[5]="]
}, Closed]],

Cell["\<\
This can be simplified if one assumes that the two sexes are \
equivalent (Symmetric\[Rule]True):\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cumulant[c, {2, 2}, Symmetric \[Rule] True]\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(\(-6\)\ c[0, 1]\^4 + 4\ c[0, 1]\^2\ c[0, 2] - c[0, 2]\^2 + 
      8\ c[0, 1]\^2\ c[1, 1] - 2\ c[1, 1]\^2 - 4\ c[0, 1]\ c[1, 2] + 
      c[2, 2]\)], "Output",
  CellLabel->"Out[6]="]
}, Closed]],

Cell[TextData[{
  "There is a further simplification if moments are measured relative to the \
current mean (Centred\[Rule]True), so that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\_\(0, 1\), \ \[Kappa]\_\(1, 0\)\ are\ \
\(\(zero\)\(:\)\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cumulant[c, {2, 2}, Symmetric \[Rule] True, Centred \[Rule] True]\)], 
  "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(\(-c[0, 2]\^2\) - 2\ c[1, 1]\^2 + c[2, 2]\)], "Output",
  CellLabel->"Out[7]="]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            \(\(Moment[n]\)[{{\[Kappa]\_\(0, 0\), \[Ellipsis]}, \[Ellipsis]}]
              \), \(is\ a\ compiled\ version\ that\ calculates\ the\ matrix\ 
              of\ moments\ from\ a\ matrix\ of\ \(cumulants . \)\)},
          {\(\(Cumulant[n]\)[{{c\_\(0, 0\), \[Ellipsis]}, \[Ellipsis]}]\), 
            \(is\ a\ compiled\ version\ that\ calculates\ the\ matrix\ of\ 
              cumulants\ from\ a\ matrix\ of\ \(moments . \)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell[TextData[{
  "This compiled function gives the matrix of moments ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c\)\([\)\(U, \(V\^*\)\)\)\)]],
  "], where |U|, |V| run from ",
  Cell[BoxData[
      \(TraditionalForm\`0  \[Ellipsis]\ n\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((n = 3)\)\)]],
  ".  The cumulants are zero, except for ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(\(0\)\(,\)\(0\)\(\ \ \)\)\)]],
  "(necessarily 1), ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(1, 1\) = 0.01\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(2, 0\) = \(c\_\(0, 2\) = \
\(\(0.02\)\(:\)\)\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"mm", "=", 
        RowBox[{\(Moment[3]\), "[", 
          RowBox[{"(", GridBox[{
                {"1", "0", "0.02", "0"},
                {"0", "0.01", "0", "0"},
                {"0.02", "0", "0", "0"},
                {"0", "0", "0", "0"}
                }], ")"}], "]"}]}], ";", \(mm // MatrixForm\)}]], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1.`", "0.`", "0.02`", "0.`"},
            {"0.`", "0.01`", "0.`", "0.000599999999999999822`"},
            {"0.02`", "0.`", "0.0006`", "0.`"},
            {"0.`", "0.000599999999999999822`", "0.`", 
              "0.0000420000000000000106`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[12]//MatrixForm="]
}, Closed]],

Cell[TextData[{
  "This compiled function gives the matrix of cumulants ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c\)\([\)\(U, \(V\^*\)\)\)\)]],
  "], where |U|, |V| run from ",
  Cell[BoxData[
      \(TraditionalForm\`0  \[Ellipsis]\ n\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((n = 3)\)\)]],
  ".  The moments are given by the above matrix:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Cumulant[3]\)[mm] // Chop\) // MatrixForm\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0.02`", "0"},
            {"0", "0.01`", "0", "0"},
            {"0.02`", "0", "0", "0"},
            {"0", "0", "0", "0"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[14]//MatrixForm="]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(Moment[U, c, \[Delta]p]\), 
            \(returns\ moments\ in\ terms\ of\ the\ within - \ and\ between - 
              genome\ moments\ of\ order\ j, \ \(k . \)\)},
          {\(Cumulant[U, \[Kappa], \[Delta]p]\), 
            \(returns\ cumulants\ in\ terms\ of\ the\ within - \ 
              and\ between - genome\ cumulants\ of\ order\ j, \ \(k . \)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["\<\
In an admixture model, the many moments can be approximated in \
terms of a small number of reduced moments of various orders:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Moment[{i, j, k, l}, c, \[Delta]p]\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \(c[4, 0]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[k]\ \[Delta]p[l]\)], 
  "Output",
  CellLabel->"Out[16]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cumulant[{i, j, \(k\^*\), \(l\^*\)}, c, \[Delta]p]\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \(c[2, 2]\ \[Delta]p[i]\ \[Delta]p[j]\ \[Delta]p[\(k\^*\)]\ 
      \[Delta]p[\(l\^*\)]\)], "Output",
  CellLabel->"Out[17]="]
}, Closed]],

Cell[TextData[
"Each moment is scaled by the magnitude of the allele frequency difference at \
each locus which drives the association.  The options Symmetric\[Rule]True \
and Centred\[Rule]True can be used."], "Text"],

Cell["\<\
Moment[] and Cumulant[] extend the functions first defined in \
Multilocus`Cumulants`.\
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{550, 692},
WindowMargins->{{Automatic, -16}, {Automatic, -2}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Moment"->{
    Cell[1787, 53, 829, 17, 104, "DefinitionBox",
      CellTags->"Moment"]},
  "Cumulant"->{
    Cell[4692, 143, 706, 14, 88, "DefinitionBox",
      CellTags->"Cumulant"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Moment", 12541, 394},
  {"Cumulant", 12635, 397}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 45, 0, 36, "SubsectionIcon"],
Cell[1787, 53, 829, 17, 104, "DefinitionBox",
  CellTags->"Moment"],
Cell[2619, 72, 442, 14, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[3086, 90, 81, 2, 27, "Input"],
Cell[3170, 94, 398, 7, 37, "Output"]
}, Closed]],
Cell[3583, 104, 128, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[3736, 111, 105, 2, 27, "Input"],
Cell[3844, 115, 270, 5, 22, "Output"]
}, Closed]],
Cell[4129, 123, 271, 6, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[4425, 133, 134, 3, 27, "Input"],
Cell[4562, 138, 115, 2, 22, "Output"]
}, Closed]],
Cell[4692, 143, 706, 14, 88, "DefinitionBox",
  CellTags->"Cumulant"],
Cell[5401, 159, 483, 17, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[5909, 180, 76, 2, 27, "Input"],
Cell[5988, 184, 279, 5, 39, "Output"]
}, Closed]],
Cell[6282, 192, 128, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[6435, 199, 100, 2, 27, "Input"],
Cell[6538, 203, 201, 4, 22, "Output"]
}, Closed]],
Cell[6754, 210, 271, 6, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[7050, 220, 125, 3, 27, "Input"],
Cell[7178, 225, 99, 2, 22, "Output"]
}, Closed]],
Cell[7292, 230, 554, 9, 80, "DefinitionBox"],
Cell[7849, 241, 643, 20, 55, "MathCaption"],

Cell[CellGroupData[{
Cell[8517, 265, 382, 10, 76, "Input"],
Cell[8902, 277, 407, 10, 78, "Output"]
}, Closed]],
Cell[9324, 290, 381, 11, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[9730, 305, 103, 2, 27, "Input"],
Cell[9836, 309, 298, 9, 78, "Output"]
}, Closed]],
Cell[10149, 321, 473, 8, 80, "DefinitionBox"],
Cell[10625, 331, 159, 4, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[10809, 339, 92, 2, 27, "Input"],
Cell[10904, 343, 125, 3, 20, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[11066, 351, 108, 2, 23, "Input"],
Cell[11177, 355, 143, 3, 20, "Output"]
}, Closed]],
Cell[11335, 361, 218, 3, 32, "Text"],
Cell[11556, 366, 110, 3, 22, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

