(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     57430,       1667]*)
(*NotebookOutlinePosition[     58276,       1694]*)
(*  CellTagsIndexPosition[     58232,       1690]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
An example: site 1063 has 37 toads, scored for 4 biallelic \
loci\
\>", "SubsubsectionIcon"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(<< Multilocus`EstimatingD`; \)], "Input",
  CellLabel->"In[41]:=  (16:49:36 on 8/14/00)"],

Cell[TextData[{
  "It can be most convenient to enter the data in this compact form (see ",
  ButtonBox["Multilocus`DataManipulation`",
    ButtonData:>{"Notation for genetic data", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Multilocus`DataManipulation`"],
  "):"
}], "MathCaption"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(rawdata[1063]\), "=", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"1", "0", "0", "0"},
                {"0", "0", "0", "0"},
                {"0", "0", "0", "0"},
                {"2", "0", "1", "0"},
                {"0", "0", "0", "0"},
                {"1", "0", "1", "2"},
                {"1", "0", "0", "2"},
                {"2", "0", "1", "0"},
                {"0", "1", "2", "1"},
                {"1", "1", "1", "2"},
                {"0", "0", "0", "0"},
                {"2", "1", "0", "1"},
                {"0", "1", "2", "2"},
                {"0", "0", "1", "0"},
                {"2", "1", "1", "1"},
                {"1", "0", "0", "2"},
                {"0", "1", "1", "0"},
                {"0", "0", "0", "0"},
                {"1", "1", "0", "1"},
                {"1", "0", "1", "1"},
                {"0", "0", "1", "0"},
                {"1", "1", "1", "1"},
                {"0", "0", "0", "0"},
                {"1", "0", "0", "0"},
                {"0", "0", "0", "0"},
                {"2", "1", "1", "1"},
                {"0", "0", "0", "0"},
                {"0", "1", "2", "1"},
                {"0", "2", "2", "1"},
                {"2", "0", "1", "0"},
                {"2", "1", "1", "2"},
                {"0", "0", "0", "0"},
                {"2", "0", "1", "0"},
                {"1", "0", "0", "1"},
                {"1", "0", "0", "0"},
                {"1", "0", "2", "1"},
                {"1", "0", "0", "0"}
                }], ")"}],
          (MatrixForm[ #]&)]}], ";"}]], "Input",
  CellLabel->"In[2]:=  (14:56:52 on 8/14/00)"],

Cell["\<\
It can then be converted into the standard form, which in principle \
allows for multiple alleles:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Data[1063] = ConvertData[rawdata[1063]]; 
    Data[1063] // MatrixForm\)], "Input",
  CellLabel->"In[3]:=  (14:56:56 on 8/14/00)"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{0, 1}, {0, 0}, {0, 0}, {0, 0}}, {{0, 0}, {0, 0}, {0, 
        0}, {0, 0}}, {{0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{1, 1}, {0, 0}, {0, 
        1}, {0, 0}}, {{0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{0, 1}, {0, 0}, {0, 
        1}, {1, 1}}, {{0, 1}, {0, 0}, {0, 0}, {1, 1}}, {{1, 1}, {0, 0}, {0, 
        1}, {0, 0}}, {{0, 0}, {0, 1}, {1, 1}, {0, 1}}, {{0, 1}, {0, 1}, {0, 
        1}, {1, 1}}, {{0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{1, 1}, {0, 1}, {0, 
        0}, {0, 1}}, {{0, 0}, {0, 1}, {1, 1}, {1, 1}}, {{0, 0}, {0, 0}, {0, 
        1}, {0, 0}}, {{1, 1}, {0, 1}, {0, 1}, {0, 1}}, {{0, 1}, {0, 0}, {0, 
        0}, {1, 1}}, {{0, 0}, {0, 1}, {0, 1}, {0, 0}}, {{0, 0}, {0, 0}, {0, 
        0}, {0, 0}}, {{0, 1}, {0, 1}, {0, 0}, {0, 1}}, {{0, 1}, {0, 0}, {0, 
        1}, {0, 1}}, {{0, 0}, {0, 0}, {0, 1}, {0, 0}}, {{0, 1}, {0, 1}, {0, 
        1}, {0, 1}}, {{0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{0, 1}, {0, 0}, {0, 
        0}, {0, 0}}, {{0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{1, 1}, {0, 1}, {0, 
        1}, {0, 1}}, {{0, 0}, {0, 0}, {0, 0}, {0, 0}}, {{0, 0}, {0, 1}, {1, 
        1}, {0, 1}}, {{0, 0}, {1, 1}, {1, 1}, {0, 1}}, {{1, 1}, {0, 0}, {0, 
        1}, {0, 0}}, {{1, 1}, {0, 1}, {0, 1}, {1, 1}}, {{0, 0}, {0, 0}, {0, 
        0}, {0, 0}}, {{1, 1}, {0, 0}, {0, 1}, {0, 0}}, {{0, 1}, {0, 0}, {0, 
        0}, {0, 1}}, {{0, 1}, {0, 0}, {0, 0}, {0, 0}}, {{0, 1}, {0, 0}, {1, 
        1}, {0, 1}}, {{0, 1}, {0, 0}, {0, 0}, {0, 0}}}]]], "Output",
  CellLabel->"Out[3]//MatrixForm=  (14:56:56 on 8/14/00)"]
}, Closed]],

Cell["Locus names should be specified:", "MathCaption"],

Cell[BoxData[
    \(LocusNames[
        1063] = {"\<Gpi\>", "\<Mdh\>", "\<Idh\>", "\<Pgi\>"}; \)], "Input",
  CellLabel->"In[4]:=  (14:56:58 on 8/14/00)"],

Cell["These are the numbers of each of the 81 possible genotypes:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ReducedData[1063, 4, Detail \[Rule] True] // TableForm\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"9", GridBox[{
                {"0", "0"},
                {"0", "0"},
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "0"},
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "0"},
                {"0", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"2", GridBox[{
                {"0", "0"},
                {"0", "0"},
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "0"},
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "0"},
                {"0", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "0"},
                {"1", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "0"},
                {"1", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "0"},
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "1"},
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "1"},
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "1"},
                {"0", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"0", "0"},
                {"0", "1"},
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "1"},
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "1"},
                {"0", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"0", "1"},
                {"1", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"2", GridBox[{
                {"0", "0"},
                {"0", "1"},
                {"1", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"0", "0"},
                {"0", "1"},
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"1", "1"},
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"1", "1"},
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"1", "1"},
                {"0", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"1", "1"},
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"1", "1"},
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"1", "1"},
                {"0", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"1", "1"},
                {"1", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"0", "0"},
                {"1", "1"},
                {"1", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "0"},
                {"1", "1"},
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"4", GridBox[{
                {"0", "1"},
                {"0", "0"},
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"0", "1"},
                {"0", "0"},
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"2", GridBox[{
                {"0", "1"},
                {"0", "0"},
                {"0", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"0", "0"},
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"0", "1"},
                {"0", "0"},
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"0", "1"},
                {"0", "0"},
                {"0", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"0", "0"},
                {"1", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"0", "1"},
                {"0", "0"},
                {"1", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"0", "0"},
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"0", "1"},
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"0", "1"},
                {"0", "1"},
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"0", "1"},
                {"0", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"0", "1"},
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"0", "1"},
                {"0", "1"},
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"0", "1"},
                {"0", "1"},
                {"0", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"0", "1"},
                {"1", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"0", "1"},
                {"1", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"0", "1"},
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"1", "1"},
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"1", "1"},
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"1", "1"},
                {"0", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"1", "1"},
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"1", "1"},
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"1", "1"},
                {"0", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"1", "1"},
                {"1", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"1", "1"},
                {"1", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"0", "1"},
                {"1", "1"},
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "0"},
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "0"},
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "0"},
                {"0", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"4", GridBox[{
                {"1", "1"},
                {"0", "0"},
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "0"},
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "0"},
                {"0", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "0"},
                {"1", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "0"},
                {"1", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "0"},
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "1"},
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"1", "1"},
                {"0", "1"},
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "1"},
                {"0", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "1"},
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"2", GridBox[{
                {"1", "1"},
                {"0", "1"},
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"1", GridBox[{
                {"1", "1"},
                {"0", "1"},
                {"0", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "1"},
                {"1", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "1"},
                {"1", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"0", "1"},
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"1", "1"},
                {"0", "0"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"1", "1"},
                {"0", "0"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"1", "1"},
                {"0", "0"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"1", "1"},
                {"0", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"1", "1"},
                {"0", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"1", "1"},
                {"0", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"1", "1"},
                {"1", "1"},
                {"0", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"1", "1"},
                {"1", "1"},
                {"0", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {"0", GridBox[{
                {"1", "1"},
                {"1", "1"},
                {"1", "1"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{9, {{0, 0}, {0, 0}, {0, 0}, {0, 0}}}, {0, {{0, 0}, {0, 
        0}, {0, 0}, {0, 1}}}, {0, {{0, 0}, {0, 0}, {0, 0}, {1, 1}}}, {2, {{0, 
        0}, {0, 0}, {0, 1}, {0, 0}}}, {0, {{0, 0}, {0, 0}, {0, 1}, {0, 1}}}, {
        0, {{0, 0}, {0, 0}, {0, 1}, {1, 1}}}, {0, {{0, 0}, {0, 0}, {1, 1}, {0,
         0}}}, {0, {{0, 0}, {0, 0}, {1, 1}, {0, 1}}}, {0, {{0, 0}, {0, 0}, {1,
         1}, {1, 1}}}, {0, {{0, 0}, {0, 1}, {0, 0}, {0, 0}}}, {0, {{0, 0}, {0,
         1}, {0, 0}, {0, 1}}}, {0, {{0, 0}, {0, 1}, {0, 0}, {1, 1}}}, {1, {{0,
         0}, {0, 1}, {0, 1}, {0, 0}}}, {0, {{0, 0}, {0, 1}, {0, 1}, {0, 
        1}}}, {0, {{0, 0}, {0, 1}, {0, 1}, {1, 1}}}, {0, {{0, 0}, {0, 1}, {1, 
        1}, {0, 0}}}, {2, {{0, 0}, {0, 1}, {1, 1}, {0, 1}}}, {1, {{0, 0}, {0, 
        1}, {1, 1}, {1, 1}}}, {0, {{0, 0}, {1, 1}, {0, 0}, {0, 0}}}, {0, {{0, 
        0}, {1, 1}, {0, 0}, {0, 1}}}, {0, {{0, 0}, {1, 1}, {0, 0}, {1, 1}}}, {
        0, {{0, 0}, {1, 1}, {0, 1}, {0, 0}}}, {0, {{0, 0}, {1, 1}, {0, 1}, {0,
         1}}}, {0, {{0, 0}, {1, 1}, {0, 1}, {1, 1}}}, {0, {{0, 0}, {1, 1}, {1,
         1}, {0, 0}}}, {1, {{0, 0}, {1, 1}, {1, 1}, {0, 1}}}, {0, {{0, 0}, {1,
         1}, {1, 1}, {1, 1}}}, {4, {{0, 1}, {0, 0}, {0, 0}, {0, 0}}}, {1, {{0,
         1}, {0, 0}, {0, 0}, {0, 1}}}, {2, {{0, 1}, {0, 0}, {0, 0}, {1, 
        1}}}, {0, {{0, 1}, {0, 0}, {0, 1}, {0, 0}}}, {1, {{0, 1}, {0, 0}, {0, 
        1}, {0, 1}}}, {1, {{0, 1}, {0, 0}, {0, 1}, {1, 1}}}, {0, {{0, 1}, {0, 
        0}, {1, 1}, {0, 0}}}, {1, {{0, 1}, {0, 0}, {1, 1}, {0, 1}}}, {0, {{0, 
        1}, {0, 0}, {1, 1}, {1, 1}}}, {0, {{0, 1}, {0, 1}, {0, 0}, {0, 0}}}, {
        1, {{0, 1}, {0, 1}, {0, 0}, {0, 1}}}, {0, {{0, 1}, {0, 1}, {0, 0}, {1,
         1}}}, {0, {{0, 1}, {0, 1}, {0, 1}, {0, 0}}}, {1, {{0, 1}, {0, 1}, {0,
         1}, {0, 1}}}, {1, {{0, 1}, {0, 1}, {0, 1}, {1, 1}}}, {0, {{0, 1}, {0,
         1}, {1, 1}, {0, 0}}}, {0, {{0, 1}, {0, 1}, {1, 1}, {0, 1}}}, {0, {{0,
         1}, {0, 1}, {1, 1}, {1, 1}}}, {0, {{0, 1}, {1, 1}, {0, 0}, {0, 
        0}}}, {0, {{0, 1}, {1, 1}, {0, 0}, {0, 1}}}, {0, {{0, 1}, {1, 1}, {0, 
        0}, {1, 1}}}, {0, {{0, 1}, {1, 1}, {0, 1}, {0, 0}}}, {0, {{0, 1}, {1, 
        1}, {0, 1}, {0, 1}}}, {0, {{0, 1}, {1, 1}, {0, 1}, {1, 1}}}, {0, {{0, 
        1}, {1, 1}, {1, 1}, {0, 0}}}, {0, {{0, 1}, {1, 1}, {1, 1}, {0, 1}}}, {
        0, {{0, 1}, {1, 1}, {1, 1}, {1, 1}}}, {0, {{1, 1}, {0, 0}, {0, 0}, {0,
         0}}}, {0, {{1, 1}, {0, 0}, {0, 0}, {0, 1}}}, {0, {{1, 1}, {0, 0}, {0,
         0}, {1, 1}}}, {4, {{1, 1}, {0, 0}, {0, 1}, {0, 0}}}, {0, {{1, 1}, {0,
         0}, {0, 1}, {0, 1}}}, {0, {{1, 1}, {0, 0}, {0, 1}, {1, 1}}}, {0, {{1,
         1}, {0, 0}, {1, 1}, {0, 0}}}, {0, {{1, 1}, {0, 0}, {1, 1}, {0, 
        1}}}, {0, {{1, 1}, {0, 0}, {1, 1}, {1, 1}}}, {0, {{1, 1}, {0, 1}, {0, 
        0}, {0, 0}}}, {1, {{1, 1}, {0, 1}, {0, 0}, {0, 1}}}, {0, {{1, 1}, {0, 
        1}, {0, 0}, {1, 1}}}, {0, {{1, 1}, {0, 1}, {0, 1}, {0, 0}}}, {2, {{1, 
        1}, {0, 1}, {0, 1}, {0, 1}}}, {1, {{1, 1}, {0, 1}, {0, 1}, {1, 1}}}, {
        0, {{1, 1}, {0, 1}, {1, 1}, {0, 0}}}, {0, {{1, 1}, {0, 1}, {1, 1}, {0,
         1}}}, {0, {{1, 1}, {0, 1}, {1, 1}, {1, 1}}}, {0, {{1, 1}, {1, 1}, {0,
         0}, {0, 0}}}, {0, {{1, 1}, {1, 1}, {0, 0}, {0, 1}}}, {0, {{1, 1}, {1,
         1}, {0, 0}, {1, 1}}}, {0, {{1, 1}, {1, 1}, {0, 1}, {0, 0}}}, {0, {{1,
         1}, {1, 1}, {0, 1}, {0, 1}}}, {0, {{1, 1}, {1, 1}, {0, 1}, {1, 
        1}}}, {0, {{1, 1}, {1, 1}, {1, 1}, {0, 0}}}, {0, {{1, 1}, {1, 1}, {1, 
        1}, {0, 1}}}, {0, {{1, 1}, {1, 1}, {1, 1}, {1, 1}}}}]]], "Output",
  CellLabel->"Out[4]//TableForm="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{245, Automatic}, {Automatic, 46}},
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 102, 3, 24, "SubsubsectionIcon"],
Cell[1844, 56, 46, 0, 28, "MathCaption"],
Cell[1893, 58, 109, 2, 27, "Input"],
Cell[2005, 62, 294, 7, 44, "MathCaption"],
Cell[2302, 71, 1642, 44, 636, "Input"],
Cell[3947, 117, 129, 3, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[4101, 124, 150, 3, 70, "Input"],
Cell[4254, 129, 24345, 652, 70, "Output"]
}, Closed]],
Cell[28614, 784, 55, 0, 70, "MathCaption"],
Cell[28672, 786, 154, 3, 70, "Input"],
Cell[28829, 791, 84, 1, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[28938, 796, 111, 2, 70, "Input"],
Cell[29052, 800, 28350, 863, 70, "Output"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

