(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     96911,       2329]*)
(*NotebookOutlinePosition[    168237,       4900]*)
(*  CellTagsIndexPosition[    168193,       4896]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["The method", "SubsectionIcon"],

Cell["\<\
This section shows how MakeOneWayTable[] and MakePairwiseTable[] \
are constructed.  A similar method can be used to fit other hypotheses.\
\>", \
"Text"],

Cell["These are the allele frequencies for the four loci:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pl = \(\(AlleleFrequencyTable[1063, 4] // N\) // Transpose\) // 
          Last;\)\), "\[IndentingNewLine]", 
    \({LocusNames[1063], pl} // TableForm\)}], "Input",
  CellLabel->"In[149]:=  (10:48:05 on 8/14/00)"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"Gpi\"\>", "\<\"Mdh\"\>", "\<\"Idh\"\>", "\<\"Pgi\"\>"},
          {"0.3918918918918919`", "0.17567567567567569`", 
            "0.32432432432432434`", "0.3108108108108108`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[150]//TableForm=  (10:48:05 on 8/14/00)"]
}, Open  ]],

Cell["Now, choose just two of the loci:", "MathCaption"],

Cell[BoxData[
    \(SelectLoci[{1063, {1, 2}}, 1063, {1, 2}]\)], "Input",
  CellLabel->"In[124]:=  (9:33:13 on 8/14/00)"],

Cell["\<\
This gives a complicated expression for the log likelihood as a \
function of the symmetric matrix of moments:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"L", "=", 
      RowBox[{"LogLikelihoodDisequilibrium", "[", 
        RowBox[{\({1063, {1, 2}}\), 
          ",", \(pl\[LeftDoubleBracket]{1, 2}\[RightDoubleBracket]\), 
          ",", \({1, 1}\), ",", 
          RowBox[{"(", GridBox[{
                {"1", "0", \(c\_\(2, 0\)\)},
                {"0", \(c\_\(1, 1\)\), \(c\_\(2, 1\)\)},
                {\(c\_\(2, 0\)\), \(c\_\(2, 1\)\), \(c\_\(2, 2\)\)}
                }], ")"}]}], "]"}]}]], "Input",
  CellLabel->"In[126]:=  (9:34:00 on 8/14/00)"],

Cell[BoxData[
    \(37\ Log[37] + 
      Log[0.10682980277574873`\ \((\(\(0.10682980277574873`\)\(\
\[InvisibleSpace]\)\) - 1.`\ c\_\(2, 0\))\) + 
          0.43243243243243246`\ \((0.43243243243243246`\ c\_\(1, 1\) - 
                1.`\ c\_\(2, 1\))\) - 
          1.`\ \((0.10682980277574873`\ c\_\(2, 0\) + 
                0.43243243243243246`\ c\_\(2, 1\) - 1.`\ c\_\(2, 2\))\)] + 
      4\ Log[1\/4\ \((0.32304601899196494`\ \((\(\(0.32304601899196494`\)\(\
\[InvisibleSpace]\)\) - 1.`\ c\_\(2, 0\))\) + 
                0.4324324324324325`\ \((0.4324324324324325`\ c\_\(1, 1\) - 
                      1.`\ c\_\(2, 1\))\) - 
                1.`\ \((0.32304601899196494`\ c\_\(2, 0\) + 
                      0.4324324324324325`\ c\_\(2, 1\) - 
                      1.`\ c\_\(2, 2\))\))\)] + 
      4\ Log[1\/2\ \((0.06884587289992695`\ \((\(\(0.32304601899196494`\)\(\
\[InvisibleSpace]\)\) - 1.`\ c\_\(2, 0\))\) + 
                0.5675675675675674`\ \((0.4324324324324325`\ c\_\(1, 1\) - 
                      1.`\ c\_\(2, 1\))\) + 
                0.9999999999999999`\ \((0.32304601899196494`\ c\_\(2, 0\) + 
                      0.4324324324324325`\ c\_\(2, 1\) - 
                      1.`\ c\_\(2, 2\))\))\)] + 
      4\ Log[1\/2\ \((0.10682980277574873`\ \((\(\(0.5012783053323594`\)\(\
\[InvisibleSpace]\)\) + 1.`\ c\_\(2, 0\))\) + 
                0.43243243243243246`\ \((\(-1.4324324324324325`\)\ c\_\(1, \
1\) + 1.`\ c\_\(2, 1\))\) - 
                1.`\ \((0.5012783053323594`\ c\_\(2, 0\) - 
                      1.4324324324324325`\ c\_\(2, 1\) + 
                      1.`\ c\_\(2, 2\))\))\)] + 
      10\ Log[1\/5\ \((0.32304601899196494`\ \((\(\(0.5012783053323594`\)\(\
\[InvisibleSpace]\)\) + 1.`\ c\_\(2, 0\))\) + 
                0.4324324324324325`\ \((\(-1.4324324324324325`\)\ c\_\(1, 1\) \
+ 1.`\ c\_\(2, 1\))\) - 
                1.`\ \((0.5012783053323594`\ c\_\(2, 0\) - 
                      1.4324324324324325`\ c\_\(2, 1\) + 
                      1.`\ c\_\(2, 2\))\))\)] + 
      3\ Log[2\/3\ \((0.32304601899196494`\ \((\(\(0.10682980277574873`\)\(\
\[InvisibleSpace]\)\) - 1.`\ c\_\(2, 0\))\) + 
                0.06884587289992695`\ \((\(\(0.5012783053323594`\)\(\
\[InvisibleSpace]\)\) + 1.`\ c\_\(2, 0\))\) + 
                0.4324324324324325`\ \((0.43243243243243246`\ c\_\(1, 1\) - 
                      1.`\ c\_\(2, 1\))\) + 
                0.5675675675675674`\ \((\(-1.4324324324324325`\)\ c\_\(1, 1\) \
+ 1.`\ c\_\(2, 1\))\) - 
                1.`\ \((0.10682980277574873`\ c\_\(2, 0\) + 
                      0.43243243243243246`\ c\_\(2, 1\) - 
                      1.`\ c\_\(2, 2\))\) + 
                0.9999999999999999`\ \((0.5012783053323594`\ c\_\(2, 0\) - 
                      1.4324324324324325`\ c\_\(2, 1\) + 
                      1.`\ c\_\(2, 2\))\))\)] + 
      11\ Log[1\/11\ \((0.5012783053323594`\ \((\(\(0.5012783053323594`\)\(\
\[InvisibleSpace]\)\) + 1.`\ c\_\(2, 0\))\) - 
                1.4324324324324325`\ \((\(-1.4324324324324325`\)\ c\_\(1, 1\) \
+ 1.`\ c\_\(2, 1\))\) + 
                1.`\ \((0.5012783053323594`\ c\_\(2, 0\) - 
                      1.4324324324324325`\ c\_\(2, 1\) + 
                      1.`\ c\_\(2, 2\))\))\)]\)], "Output",
  CellLabel->"Out[126]=  (9:34:00 on 8/14/00)"]
}, Closed]],

Cell[TextData[{
  "The association ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c\_\(2, 0\)\)\(\ \)\)\)]],
  "represents gametic linkage disequilibrium, and ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(1, 1\)\)]],
  "the heterozygote deficit.   The analysis consists of fitting models which \
make variopus assumptions about these cross-locus moments."
}], "Text"],

Cell[TextData[{
  "This is the log likelihood for there to be no association among the \
moments.  ",
  Cell[BoxData[
      \(TraditionalForm\`log \((L)\) = \(-3.04\)\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"L0", "=", 
      RowBox[{"LogLikelihoodDisequilibrium", "[", 
        RowBox[{\({1063, {1, 2}}\), 
          ",", \(pl\[LeftDoubleBracket]{1, 2}\[RightDoubleBracket]\), 
          ",", \({1, 1}\), ",", 
          RowBox[{"(", GridBox[{
                {"1", "0", "0"},
                {"0", "0", "0"},
                {"0", "0", "0"}
                }], ")"}]}], "]"}]}]], "Input",
  CellLabel->"In[152]:=  (10:50:15 on 8/14/00)"],

Cell[BoxData[
    \(\(-3.037168352263592`\)\)], "Output",
  CellLabel->"Out[152]=  (10:50:15 on 8/14/00)"]
}, Open  ]],

Cell[TextData[{
  "This is the log. likelihood for there to be gametic associations, but \
random union of gametes.  ",
  Cell[BoxData[
      \(TraditionalForm\`D\&^ = 0.0077\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`log \((L)\) = \(-2.99\)\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"LD", "=", 
        RowBox[{"LogLikelihoodDisequilibrium", "[", 
          
          RowBox[{\({1063, {1, 2}}\), 
            ",", \(pl\[LeftDoubleBracket]{1, 2}\[RightDoubleBracket]\), 
            ",", \({1, 1}\), ",", 
            RowBox[{"(", GridBox[{
                  {"1", "0", "d"},
                  {"0", "0", "0"},
                  {"d", "0", \(d\^2\)}
                  }], ")"}]}], "]"}]}], ";"}], "\n", \(Plot[
      LD, {d, \(-0.05\), 0.05}]; FindMinimum[\(-LD\), {d, 0}]\)}], "Input",
  CellLabel->"In[153]:=  (10:51:33 on 8/14/00)"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 9.52381 1.3943 0.264344 [
[.11905 .06008 -15 -9 ]
[.11905 .06008 15 0 ]
[.30952 .06008 -15 -9 ]
[.30952 .06008 15 0 ]
[.69048 .06008 -12 -9 ]
[.69048 .06008 12 0 ]
[.88095 .06008 -12 -9 ]
[.88095 .06008 12 0 ]
[.4875 .20475 -24 -4.5 ]
[.4875 .20475 0 4.5 ]
[.4875 .33692 -12 -4.5 ]
[.4875 .33692 0 4.5 ]
[.4875 .46909 -24 -4.5 ]
[.4875 .46909 0 4.5 ]
[.4875 .60127 -12 -4.5 ]
[.4875 .60127 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .07258 m
.11905 .07883 L
s
[(-0.04)] .11905 .06008 0 1 Mshowa
.30952 .07258 m
.30952 .07883 L
s
[(-0.02)] .30952 .06008 0 1 Mshowa
.69048 .07258 m
.69048 .07883 L
s
[(0.02)] .69048 .06008 0 1 Mshowa
.88095 .07258 m
.88095 .07883 L
s
[(0.04)] .88095 .06008 0 1 Mshowa
.125 Mabswid
.16667 .07258 m
.16667 .07633 L
s
.21429 .07258 m
.21429 .07633 L
s
.2619 .07258 m
.2619 .07633 L
s
.35714 .07258 m
.35714 .07633 L
s
.40476 .07258 m
.40476 .07633 L
s
.45238 .07258 m
.45238 .07633 L
s
.54762 .07258 m
.54762 .07633 L
s
.59524 .07258 m
.59524 .07633 L
s
.64286 .07258 m
.64286 .07633 L
s
.7381 .07258 m
.7381 .07633 L
s
.78571 .07258 m
.78571 .07633 L
s
.83333 .07258 m
.83333 .07633 L
s
.07143 .07258 m
.07143 .07633 L
s
.02381 .07258 m
.02381 .07633 L
s
.92857 .07258 m
.92857 .07633 L
s
.97619 .07258 m
.97619 .07633 L
s
.25 Mabswid
0 .07258 m
1 .07258 L
s
.5 .20475 m
.50625 .20475 L
s
[(-4.5)] .4875 .20475 1 0 Mshowa
.5 .33692 m
.50625 .33692 L
s
[(-4)] .4875 .33692 1 0 Mshowa
.5 .46909 m
.50625 .46909 L
s
[(-3.5)] .4875 .46909 1 0 Mshowa
.5 .60127 m
.50625 .60127 L
s
[(-3)] .4875 .60127 1 0 Mshowa
.125 Mabswid
.5 .09901 m
.50375 .09901 L
s
.5 .12545 m
.50375 .12545 L
s
.5 .15188 m
.50375 .15188 L
s
.5 .17832 m
.50375 .17832 L
s
.5 .23119 m
.50375 .23119 L
s
.5 .25762 m
.50375 .25762 L
s
.5 .28405 m
.50375 .28405 L
s
.5 .31049 m
.50375 .31049 L
s
.5 .36336 m
.50375 .36336 L
s
.5 .38979 m
.50375 .38979 L
s
.5 .41623 m
.50375 .41623 L
s
.5 .44266 m
.50375 .44266 L
s
.5 .49553 m
.50375 .49553 L
s
.5 .52196 m
.50375 .52196 L
s
.5 .5484 m
.50375 .5484 L
s
.5 .57483 m
.50375 .57483 L
s
.5 .04614 m
.50375 .04614 L
s
.5 .01971 m
.50375 .01971 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.10852 0 m
.14415 .11049 L
.18221 .20899 L
.22272 .29692 L
.26171 .36784 L
.30316 .43062 L
.34309 .48037 L
.3815 .51933 L
.42237 .55203 L
.44268 .56513 L
.46172 .57558 L
.48111 .58447 L
.49955 .59129 L
.50923 .59426 L
.5198 .59701 L
.52934 .59906 L
.53832 .60063 L
.54328 .60134 L
.54864 .60198 L
.5531 .60242 L
.558 .6028 L
.56056 .60296 L
.56331 .6031 L
.56483 .60316 L
.56621 .60321 L
.56762 .60325 L
.56892 .60328 L
.57012 .6033 L
.57139 .60331 L
.57267 .60332 L
.5734 .60332 L
.57408 .60332 L
.57531 .60331 L
.57643 .6033 L
.57767 .60328 L
.57897 .60325 L
.58154 .60317 L
.58397 .60307 L
.58851 .60282 L
.59341 .60244 L
.59871 .60191 L
.60827 .60066 L
.61708 .59915 L
.63584 .5948 L
.65648 .58824 L
.67593 .58035 L
.69682 .56999 L
.7381 .54373 L
.77786 .51093 L
.8161 .47212 L
Mistroke
.8568 .42257 L
.89598 .36628 L
.93762 .29648 L
.97619 .22177 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[153]:=  (10:51:33 on 8/14/00)",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O7goo00<007ooOol0
KGoo00<007ooOol0SWoo000OOol00`00Oomoo`1]Ool00`00Oomoo`2>Ool001moo`03001oogoo06eo
o`03001oogoo08ioo`0087oo00<007ooOol0K7oo00<007ooOol0SWoo000POol00`00Oomoo`1/Ool0
0`00Oomoo`2>Ool0021oo`03001oogoo06aoo`8008moo`008Goo00<007ooOol0Jgoo00<007ooOol0
SWoo000QOol00`00Oomoo`1[Ool00`00Oomoo`2>Ool0025oo`03001oogoo06]oo`03001oogoo08io
o`006goo0P0017oo0P0017oo0P0017oo0`008Goo0P0017oo00<007ooOol00goo0P000Woo1@00:Goo
00<007ooOol0:Woo0P0017oo00<007ooOol00goo0P000Woo1@008Goo0P0017oo00<007ooOol00goo
0P0017oo0`006Goo000JOol01000Oomoo`0017oo00D007ooOomoo`00009oo`03001oogoo009oo`03
001oogoo01moo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol002Uoo`03001oogoo02Uo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0021oo`04001oogoo0008Ool01000Oomo
o`0017oo00<007ooOol067oo000COol50002Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`03
001oo`0000@001Uoo`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0:Goo00<0
07ooOol0:Goo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`0POol01000Oomoo`0027oo
00D007ooOol007oo00D001Uoo`006Woo00@007ooOol000Eoo`04001oogoo0002Ool00`00Ool00002
Ool00`00Oomoo`0OOol01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo02Qoo`03001oogoo
02Uoo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol07goo00@007ooOol000Qoo`06001o
ogoo001oo`000Woo00<007ooOol067oo000JOol01000Oomoo`001Goo00@007ooOol0009oo`06001o
ogoo001oo`008Goo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol09goo0P00:Woo
00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol07Woo00@007ooOol000Qoo`04001o
ogoo0002Ool00`00Ool0000JOol001Yoo`04001oogoo0005Ool01000Oomoo`000Woo00@007ooOomo
o`80025oo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo02Moo`03001oogoo02Uo
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo01ioo`04001oogoo0008Ool01000
Oomoo`000goo0P006Woo000KOol20007Ool00`00Oomoo`020005Ool00`00Oomoo`0POol2000:Ool2
0003Ool3000ZOol00`00Oomoo`0ZOol2000:Ool20003Ool3000ROol2000:Ool20005Ool00`00Oomo
o`0HOol002Aoo`03001oogoo06Qoo`03001oogoo08ioo`0097oo00<007ooOol0J7oo00<007ooOol0
SWoo000UOol00`00Oomoo`1WOol00`00Oomoo`2>Ool002Eoo`03001oogoo06Moo`03001oogoo08io
o`00o`0080000Goo0007Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool01@00Oomoogoo00002Goo00<0
07ooOol02Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02goo00<0
07ooOol02Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<0
07ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<0
07ooOol02goo00<007ooOol02Woo00<007ooOol01Woo000ROol01@00Oomoogoo0000<Goo00<007oo
Ool0=7oo00<007ooOol0=7oo00<007ooOol0<goo00<007ooOol08Goo000VOol00`00Oomoo`1VOol0
0`00Oomoo`2>Ool002Moo`03001oogoo06Eoo`03001oogoo08ioo`009goo00<007ooOol0IGoo00<0
07ooOol0SWoo000WOol00`00Oomoo`1UOol00`00Oomoo`2>Ool002Qoo`03001oogoo06Aoo`03001o
ogoo08ioo`00:7oo00<007ooOol0I7oo0P00Sgoo000XOol00`00Oomoo`1TOol00`00Oomoo`2>Ool0
02Uoo`03001oogoo06=oo`03001oogoo08ioo`00:Goo00<007ooOol0Hgoo00<007ooOol0SWoo000Y
Ool00`00Oomoo`1SOol00`00Oomoo`2>Ool002Yoo`03001oogoo069oo`03001oogoo08ioo`00:Woo
00<007ooOol0HWoo00<007ooOol0SWoo000ZOol00`00Oomoo`1ROol2002?Ool002]oo`03001oogoo
065oo`03001oogoo08ioo`00:goo00<007ooOol0HGoo00<007ooOol0SWoo000/Ool00`00Oomoo`1P
Ool00`00Oomoo`2>Ool002aoo`03001oogoo061oo`03001oogoo08ioo`00;7oo00<007ooOol0H7oo
00<007ooOol0SWoo000]Ool00`00Oomoo`1OOol00`00Oomoo`2>Ool002eoo`03001oogoo05moo`03
001oogoo08ioo`00;Woo00<007ooOol0GWoo0P00Sgoo000^Ool00`00Oomoo`1NOol00`00Oomoo`2>
Ool002ioo`03001oogoo05ioo`03001oogoo08ioo`00;goo00<007ooOol0GGoo00<007ooOol0SWoo
000_Ool00`00Oomoo`1MOol00`00Oomoo`2>Ool002moo`03001oogoo05eoo`03001oogoo08ioo`00
<7oo00<007ooOol0G7oo00<007ooOol0SWoo000`Ool00`00Oomoo`1LOol00`00Oomoo`2>Ool0035o
o`03001oogoo05]oo`8008moo`00<Goo00<007ooOol0Fgoo00<007ooOol0SWoo000aOol00`00Oomo
o`1KOol00`00Oomoo`2>Ool0039oo`03001oogoo05Yoo`03001oogoo08ioo`00<Woo00<007ooOol0
FWoo00<007ooOol0SWoo000cOol00`00Oomoo`15Ool30003Ool00`00Oomoo`02Ool30006Ool00`00
Oomoo`2>Ool003=oo`03001oogoo04Ioo`03001oogoo00Ioo`05001oogooOol00005Ool00`00Oomo
o`2>Ool003=oo`03001oogoo03eoo`D00003Ool0000000<000]oo`03001oogoo00=oo`<008ioo`00
=7oo00<007ooOol0@Woo00@007ooOol000aoo`03001oogoo00=oo`03001oogoo08ioo`00=7oo00<0
07ooOol0@goo00<007oo000027oo10001Woo00<007ooOol0SWoo000eOol00`00Oomoo`13Ool20008
Ool00`00Oomoo`07Ool00`00Oomoo`2>Ool003Eoo`03001oogoo04Aoo`03001oogoo00Ioo`D000Eo
o`03001oogoo08ioo`00=Woo00<007ooOol0EWoo00<007ooOol0QGoo00<007ooOol01Woo000fOol0
0`00Oomoo`1FOol00`00Oomoo`25Ool00`00Oomoo`06Ool003Moo`03001oogoo05Eoo`03001oogoo
08Aoo`03001oogoo00Moo`00=goo00<007ooOol0EGoo0P00QGoo00<007ooOol01goo000gOol00`00
Oomoo`1EOol00`00Oomoo`23Ool00`00Oomoo`08Ool003Qoo`03001oogoo05Aoo`03001oogoo08=o
o`03001oogoo00Qoo`00>7oo00<007ooOol0E7oo00<007ooOol0PWoo00<007ooOol02Goo000iOol0
0`00Oomoo`1COol00`00Oomoo`22Ool00`00Oomoo`09Ool003Uoo`03001oogoo05=oo`03001oogoo
085oo`03001oogoo00Yoo`00>Woo00<007ooOol0DWoo00<007ooOol0PGoo00<007ooOol02Woo000j
Ool00`00Oomoo`1BOol20021Ool00`00Oomoo`0;Ool003]oo`03001oogoo055oo`03001oogoo07mo
o`03001oogoo00aoo`00>goo00<007ooOol0DGoo00<007ooOol0Ogoo00<007ooOol037oo000lOol0
0`00Oomoo`1@Ool00`00Oomoo`1nOol00`00Oomoo`0=Ool003aoo`03001oogoo051oo`03001oogoo
07ioo`03001oogoo00eoo`00?Goo00<007ooOol0Cgoo00<007ooOol0OGoo00<007ooOol03Woo000m
Ool00`00Oomoo`1?Ool00`00Oomoo`1mOol00`00Oomoo`0>Ool003eoo`03001oogoo04moo`03001o
ogoo07aoo`03001oogoo00moo`00?Woo00<007ooOol0CWoo0P00OGoo00<007ooOol03goo000nOol0
0`00Oomoo`1>Ool00`00Oomoo`1kOol00`00Oomoo`0@Ool003moo`03001oogoo04eoo`03001oogoo
07]oo`03001oogoo011oo`00?goo00<007ooOol0CGoo00<007ooOol0NWoo00<007ooOol04Goo0010
Ool00`00Oomoo`1<Ool00`00Oomoo`1jOol00`00Oomoo`0AOol0041oo`03001oogoo04aoo`03001o
ogoo07Uoo`03001oogoo019oo`00@Goo00<007ooOol0Bgoo00<007ooOol0N7oo00<007ooOol04goo
0011Ool00`00Oomoo`1;Ool2001iOol00`00Oomoo`0COol0049oo`03001oogoo04Yoo`03001oogoo
07Moo`03001oogoo01Aoo`00@Woo00<007ooOol0BWoo00<007ooOol0Mgoo00<007ooOol057oo0013
Ool00`00Oomoo`19Ool00`00Oomoo`1fOol00`00Oomoo`0EOol004Aoo`03001oogoo04Qoo`03001o
ogoo07Eoo`03001oogoo01Ioo`00A7oo00<007ooOol0B7oo00<007ooOol0MGoo00<007ooOol05Woo
0015Ool00`00Oomoo`0oOol30005Ool00`00Oomoo`1dOol00`00Oomoo`0GOol004Eoo`03001oogoo
041oo`03001oogoo00Aoo`03001oogoo07Aoo`03001oogoo01Moo`00AWoo00<007ooOol0=Woo1@00
00=oo`0000000`001Goo0`00Lgoo00<007ooOol067oo0016Ool00`00Oomoo`0lOol01000Oomoo`00
1Woo00<007ooOol0LWoo00<007ooOol06Goo0017Ool00`00Oomoo`0lOol00`00Ool00006Ool00`00
Oomoo`1bOol00`00Oomoo`0IOol004Moo`03001oogoo03eoo`8000Ioo`03001oogoo075oo`03001o
ogoo01Yoo`00B7oo00<007ooOol0?Goo00<007ooOol017oo00<007ooOol0LGoo00<007ooOol06Woo
0019Ool00`00Oomoo`13Ool00`00Oomoo`1`Ool00`00Oomoo`0KOol004Uoo`03001oogoo04=oo`03
001oogoo06moo`03001oogoo01aoo`00BWoo00<007ooOol0@Woo00<007ooOol0Kgoo00<007ooOol0
77oo001:Ool00`00Oomoo`12Ool2001_Ool00`00Oomoo`0MOol004]oo`03001oogoo045oo`03001o
ogoo06ioo`03001oogoo01eoo`00Bgoo00<007ooOol0@Goo00<007ooOol0KGoo00<007ooOol07Woo
001<Ool00`00Oomoo`10Ool00`00Oomoo`1/Ool00`00Oomoo`0OOol004eoo`03001oogoo03moo`03
001oogoo06aoo`03001oogoo01moo`00CGoo00<007ooOol0?goo00<007ooOol0Jgoo00<007ooOol0
87oo001>Ool00`00Oomoo`0nOol00`00Oomoo`1ZOol00`00Oomoo`0QOol004moo`03001oogoo03eo
o`8006]oo`03001oogoo025oo`00Cgoo00<007ooOol0?Goo00<007ooOol0JGoo00<007ooOol08Woo
001@Ool00`00Oomoo`0lOol00`00Oomoo`1XOol00`00Oomoo`0SOol0055oo`03001oogoo03]oo`03
001oogoo06Qoo`03001oogoo02=oo`00DGoo00<007ooOol0>goo00<007ooOol0Igoo00<007ooOol0
97oo001BOol00`00Oomoo`0jOol00`00Oomoo`1WOol00`00Oomoo`0TOol005=oo`03001oogoo03Uo
o`03001oogoo06Ioo`03001oogoo02Eoo`00Dgoo00<007ooOol0>Goo00<007ooOol0IGoo00<007oo
Ool09Woo001DOol00`00Oomoo`0hOol2001VOol00`00Oomoo`0VOol005Eoo`03001oogoo03Moo`03
001oogoo06Aoo`03001oogoo02Moo`00EGoo00<007ooOol0=goo00<007ooOol0Hgoo00<007ooOol0
:7oo001FOol00`00Oomoo`0fOol00`00Oomoo`1SOol00`00Oomoo`0XOol005Moo`03001oogoo03Eo
o`03001oogoo069oo`03001oogoo02Uoo`00Egoo00<007ooOol0=Goo00<007ooOol0HGoo00<007oo
Ool0:Woo001HOol00`00Oomoo`0dOol00`00Oomoo`1POol00`00Oomoo`0[Ool005Uoo`03001oogoo
03=oo`80061oo`03001oogoo02aoo`00FWoo00<007ooOol0<Woo00<007ooOol0GWoo00<007ooOol0
;Goo001KOol00`00Oomoo`0aOol00`00Oomoo`1MOol00`00Oomoo`0^Ool005]oo`03001oogoo035o
o`03001oogoo05eoo`03001oogoo02ioo`00G7oo00<007ooOol0<7oo00<007ooOol0G7oo00<007oo
Ool0;goo001MOol00`00Oomoo`0JOol30004Ool00`00Oomoo`02Ool30006Ool00`00Oomoo`1KOol0
0`00Oomoo`0`Ool005ioo`03001oogoo01Qoo`05001oogooOol00007Ool01@00Oomoogoo00001Goo
00<007ooOol0FWoo00<007ooOol0<Goo001NOol00`00Oomoo`0BOol50005Ool00`00Oomoo`09Ool0
0`00Oomoo`03Ool00`00Oomoo`1IOol00`00Oomoo`0bOol005moo`03001oogoo01Uoo`8000aoo`03
001oogoo00=oo`<005Qoo`03001oogoo03=oo`00H7oo00<007ooOol06Woo00<007ooOol01Goo1000
1Woo00<007ooOol0Egoo00<007ooOol0=7oo001QOol00`00Oomoo`0EOol01@00Oomoogoo00001goo
00<007ooOol01goo00<007ooOol0Egoo00<007ooOol0=7oo001ROol00`00Oomoo`0EOol30008Ool5
0005Ool00`00Oomoo`1FOol00`00Oomoo`0eOol006=oo`03001oogoo02Uoo`03001oogoo05Eoo`03
001oogoo03Ioo`00I7oo00<007ooOol0:7oo00<007ooOol0E7oo00<007ooOol0=goo001UOol00`00
Oomoo`0WOol00`00Oomoo`1COol00`00Oomoo`0hOol006Ioo`03001oogoo02Ioo`8005=oo`03001o
ogoo03Uoo`00Igoo00<007ooOol09Goo00<007ooOol0DGoo00<007ooOol0>Woo001XOol00`00Oomo
o`0TOol00`00Oomoo`1@Ool00`00Oomoo`0kOol006Uoo`03001oogoo02=oo`03001oogoo04moo`03
001oogoo03aoo`00JWoo00<007ooOol08Woo00<007ooOol0CWoo00<007ooOol0?Goo001[Ool00`00
Oomoo`0QOol00`00Oomoo`1<Ool20010Ool006aoo`03001oogoo021oo`03001oogoo04]oo`03001o
ogoo041oo`00KGoo0P0087oo00<007ooOol0BWoo00<007ooOol0@Goo001_Ool00`00Oomoo`0MOol2
0019Ool20014Ool0071oo`03001oogoo01aoo`03001oogoo04Moo`03001oogoo04Aoo`00LGoo00<0
07ooOol06goo00<007ooOol0AWoo00<007ooOol0AGoo001bOol00`00Oomoo`0JOol00`00Oomoo`14
Ool20018Ool007=oo`8001Yoo`03001oogoo04=oo`03001oogoo04Qoo`00MGoo00<007ooOol05goo
00<007ooOol0@Woo00<007ooOol0BGoo001fOol00`00Oomoo`0FOol00`00Oomoo`10Ool2001<Ool0
07Moo`03001oogoo01Eoo`03001oogoo03moo`03001oogoo04aoo`00N7oo00<007ooOol057oo0P00
?Woo0P00Cgoo001iOol2000DOol00`00Oomoo`0lOol00`00Oomoo`1?Ool007]oo`80019oo`03001o
ogoo03Yoo`80059oo`00OGoo0P0047oo00<007ooOol0>Goo00<007ooOol0DWoo001oOol2000>Ool0
0`00Oomoo`0gOol2001EOol0085oo`8000aoo`03001oogoo03Ioo`03001oogoo05Eoo`00Pgoo00<0
07ooOol02Goo00<007ooOol0=7oo0P00F7oo0024Ool20009Ool2000cOol2001JOol008Ioo`8000Mo
o`03001oogoo031oo`8005aoo`00R7oo0P001Goo00<007ooOol0;Woo0P00GWoo002:Ool20003Ool0
0`00Oomoo`0[Ool3001POol008aoo`@002]oo`8006=oo`00QWoo0`001Woo0`009Woo0`00IGoo0025
Ool01@00Oomoogoo00001Goo00<007ooOol01@007Goo1000J7oo001oOol50005Ool00`00Oomoo`03
Ool00`00Oomoo`05Ool3000FOol4001/Ool008Moo`8000Ioo`<000QooaH0071oo`00RGoo00<007oo
Ool00goo00<007ooOol0SWoo0025Ool01@00Oomoogoo00001Goo00<007ooOol0SWoo0026Ool30006
Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0526302, -5.27458, \
0.000366761, 0.0132137}}],

Cell[BoxData[
    \({2.992236769932532`, {d \[Rule] 0.007701651696288808`}}\)], "Output",
  CellLabel->"Out[154]=  (10:51:34 on 8/14/00)"]
}, Open  ]],

Cell[TextData[{
  "This is the log. likelihood for there to be a nheterozygote deficit, but \
no association across loci.  ",
  Cell[BoxData[
      \(TraditionalForm\`F\&^ = 0.019\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`log \((L)\) = \(-2.60\)\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"LF", "=", 
        RowBox[{"LogLikelihoodDisequilibrium", "[", 
          
          RowBox[{\({1063, {1, 2}}\), 
            ",", \(pl\[LeftDoubleBracket]{1, 2}\[RightDoubleBracket]\), 
            ",", \({1, 1}\), ",", 
            RowBox[{"(", GridBox[{
                  {"1", "0", "0"},
                  {"0", "f", "0"},
                  {"0", "0", "0"}
                  }], ")"}]}], "]"}]}], ";"}], "\n", \(Plot[
      LF, {f, \(-0.05\), 0.08}]; FindMinimum[\(-LF\), {f, 0}]\)}], "Input",
  CellLabel->"In[155]:=  (10:52:48 on 8/14/00)"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.39011 7.32601 0.77489 0.0660162 [
[.09707 .23426 -15 -9 ]
[.09707 .23426 15 0 ]
[.24359 .23426 -15 -9 ]
[.24359 .23426 15 0 ]
[.53663 .23426 -12 -9 ]
[.53663 .23426 12 0 ]
[.68315 .23426 -12 -9 ]
[.68315 .23426 12 0 ]
[.82967 .23426 -12 -9 ]
[.82967 .23426 12 0 ]
[.97619 .23426 -12 -9 ]
[.97619 .23426 12 0 ]
[.37761 .11473 -18 -4.5 ]
[.37761 .11473 0 4.5 ]
[.37761 .37879 -12 -4.5 ]
[.37761 .37879 0 4.5 ]
[.37761 .51082 -12 -4.5 ]
[.37761 .51082 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09707 .24676 m
.09707 .25301 L
s
[(-0.04)] .09707 .23426 0 1 Mshowa
.24359 .24676 m
.24359 .25301 L
s
[(-0.02)] .24359 .23426 0 1 Mshowa
.53663 .24676 m
.53663 .25301 L
s
[(0.02)] .53663 .23426 0 1 Mshowa
.68315 .24676 m
.68315 .25301 L
s
[(0.04)] .68315 .23426 0 1 Mshowa
.82967 .24676 m
.82967 .25301 L
s
[(0.06)] .82967 .23426 0 1 Mshowa
.97619 .24676 m
.97619 .25301 L
s
[(0.08)] .97619 .23426 0 1 Mshowa
.125 Mabswid
.1337 .24676 m
.1337 .25051 L
s
.17033 .24676 m
.17033 .25051 L
s
.20696 .24676 m
.20696 .25051 L
s
.28022 .24676 m
.28022 .25051 L
s
.31685 .24676 m
.31685 .25051 L
s
.35348 .24676 m
.35348 .25051 L
s
.42674 .24676 m
.42674 .25051 L
s
.46337 .24676 m
.46337 .25051 L
s
.5 .24676 m
.5 .25051 L
s
.57326 .24676 m
.57326 .25051 L
s
.60989 .24676 m
.60989 .25051 L
s
.64652 .24676 m
.64652 .25051 L
s
.71978 .24676 m
.71978 .25051 L
s
.75641 .24676 m
.75641 .25051 L
s
.79304 .24676 m
.79304 .25051 L
s
.8663 .24676 m
.8663 .25051 L
s
.90293 .24676 m
.90293 .25051 L
s
.93956 .24676 m
.93956 .25051 L
s
.06044 .24676 m
.06044 .25051 L
s
.02381 .24676 m
.02381 .25051 L
s
.25 Mabswid
0 .24676 m
1 .24676 L
s
.39011 .11473 m
.39636 .11473 L
s
[(-10)] .37761 .11473 1 0 Mshowa
.39011 .37879 m
.39636 .37879 L
s
[(-6)] .37761 .37879 1 0 Mshowa
.39011 .51082 m
.39636 .51082 L
s
[(-4)] .37761 .51082 1 0 Mshowa
.125 Mabswid
.39011 .14774 m
.39386 .14774 L
s
.39011 .18074 m
.39386 .18074 L
s
.39011 .21375 m
.39386 .21375 L
s
.39011 .27977 m
.39386 .27977 L
s
.39011 .31278 m
.39386 .31278 L
s
.39011 .34578 m
.39386 .34578 L
s
.39011 .4118 m
.39386 .4118 L
s
.39011 .44481 m
.39386 .44481 L
s
.39011 .47782 m
.39386 .47782 L
s
.39011 .08172 m
.39386 .08172 L
s
.39011 .04871 m
.39386 .04871 L
s
.39011 .0157 m
.39386 .0157 L
s
.39011 .54383 m
.39386 .54383 L
s
.39011 .57684 m
.39386 .57684 L
s
.39011 .60985 m
.39386 .60985 L
s
.25 Mabswid
.39011 0 m
.39011 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .15383 m
.06244 .2373 L
.10458 .31135 L
.14415 .36943 L
.18221 .41703 L
.22272 .46024 L
.26171 .49549 L
.30316 .52686 L
.34309 .55163 L
.3815 .57072 L
.40095 .57868 L
.42237 .58615 L
.44292 .59205 L
.46172 .59637 L
.48113 .59974 L
.49183 .60113 L
.502 .60214 L
.50694 .60252 L
.51159 .60281 L
.51416 .60294 L
.51695 .60306 L
.51927 .60314 L
.52181 .60322 L
.52297 .60324 L
.52422 .60327 L
.52529 .60328 L
.52647 .6033 L
.52779 .60331 L
.52904 .60332 L
.53026 .60332 L
.53139 .60332 L
.53243 .60331 L
.53342 .6033 L
.5345 .60329 L
.53566 .60327 L
.53803 .60322 L
.5402 .60316 L
.54494 .60298 L
.55 .60271 L
.55912 .60203 L
.56997 .60087 L
.57982 .5995 L
.59901 .59591 L
.6198 .59063 L
.63968 .58417 L
.66072 .57573 L
.69861 .55609 L
.73895 .52809 L
.77777 .49293 L
.81905 .44453 L
Mistroke
.85881 .38369 L
.89706 .30623 L
.91841 .2511 L
.93775 .19033 L
.95756 .11223 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[155]:=  (10:52:48 on 8/14/00)",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo001]Ool0
0`00Oomoo`2`Ool006eoo`03001oogoo0;1oo`00KGoo00<007ooOol0/7oo001]Ool00`00Oomoo`2`
Ool006eoo`800:Aoo`03001oogoo00Yoo`00KGoo00<007ooOol0Xgoo00<007ooOol02Woo001]Ool0
0`00Oomoo`2SOol00`00Oomoo`0:Ool006eoo`03001oogoo0:9oo`03001oogoo00]oo`00KGoo00<0
07ooOol0XWoo00<007ooOol02goo001]Ool00`00Oomoo`2ROol00`00Oomoo`0;Ool006eoo`03001o
ogoo0:9oo`03001oogoo00]oo`00KGoo00<007ooOol0XWoo00<007ooOol02goo001]Ool00`00Oomo
o`2QOol00`00Oomoo`0<Ool006eoo`03001oogoo0:5oo`03001oogoo00aoo`00KGoo0P00XWoo00<0
07ooOol037oo001]Ool00`00Oomoo`2QOol00`00Oomoo`0<Ool006eoo`03001oogoo0:5oo`03001o
ogoo00aoo`00KGoo00<007ooOol0X7oo00<007ooOol03Goo001]Ool00`00Oomoo`2POol00`00Oomo
o`0=Ool006eoo`03001oogoo0:1oo`03001oogoo00eoo`00KGoo00<007ooOol0X7oo00<007ooOol0
3Goo001]Ool00`00Oomoo`2OOol00`00Oomoo`0>Ool006eoo`03001oogoo09moo`03001oogoo00io
o`00KGoo0P00X7oo00<007ooOol03Woo001]Ool00`00Oomoo`2OOol00`00Oomoo`0>Ool006eoo`03
001oogoo09moo`03001oogoo00ioo`00KGoo00<007ooOol0WWoo00<007ooOol03goo001]Ool00`00
Oomoo`2NOol00`00Oomoo`0?Ool006eoo`03001oogoo09ioo`03001oogoo00moo`00KGoo00<007oo
Ool0WWoo00<007ooOol03goo001OOol30004Ool20005Ool00`00Oomoo`2NOol00`00Oomoo`0?Ool0
061oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`2MOol00`00Oomoo`0@Ool005Qoo`D0
00=oo`03001oogoo009oo`04001oogoo0004Ool3002MOol00`00Oomoo`0@Ool0061oo`03001oogoo
009oo`04001oogoo0004Ool00`00Oomoo`2MOol00`00Oomoo`0@Ool0061oo`03001oogoo009oo`04
001oogoo0004Ool00`00Oomoo`2MOol00`00Oomoo`0@Ool005moo`8000Aoo`04001oogoo0004Ool0
0`00Oomoo`2LOol00`00Oomoo`0AOol0061oo`03001oogoo00=oo`8000Eoo`03001oogoo09aoo`03
001oogoo015oo`00KGoo00<007ooOol0W7oo00<007ooOol04Goo001]Ool00`00Oomoo`2LOol00`00
Oomoo`0AOol006eoo`03001oogoo09aoo`03001oogoo015oo`00KGoo00<007ooOol0Vgoo00<007oo
Ool04Woo001]Ool00`00Oomoo`2KOol00`00Oomoo`0BOol006eoo`8009aoo`03001oogoo019oo`00
1Woo00<007ooOol0I7oo00<007ooOol0Vgoo00<007ooOol04Woo0006Ool00`00Oomoo`1TOol00`00
Oomoo`2JOol00`00Oomoo`0COol000Moo`03001oogoo06=oo`03001oogoo09Yoo`03001oogoo01=o
o`001goo00<007ooOol0Hgoo00<007ooOol0VWoo00<007ooOol04goo0008Ool00`00Oomoo`1ROol0
0`00Oomoo`2JOol00`00Oomoo`0COol000Qoo`03001oogoo069oo`03001oogoo09Uoo`03001oogoo
01Aoo`002Goo00<007ooOol0HGoo00<007ooOol0VGoo00<007ooOol057oo0009Ool00`00Oomoo`1Q
Ool00`00Oomoo`2IOol00`00Oomoo`0DOol000Uoo`03001oogoo065oo`8009Yoo`03001oogoo01Ao
o`002Woo00<007ooOol0H7oo00<007ooOol0VGoo00<007ooOol057oo000:Ool00`00Oomoo`1POol0
0`00Oomoo`2HOol00`00Oomoo`0EOol000]oo`03001oogoo05moo`03001oogoo09Qoo`03001oogoo
01Eoo`002goo00<007ooOol0Ggoo00<007ooOol0V7oo00<007ooOol05Goo000<Ool00`00Oomoo`1N
Ool00`00Oomoo`2GOol00`00Oomoo`0FOol000aoo`03001oogoo05ioo`03001oogoo09Moo`03001o
ogoo01Ioo`003Goo00<007ooOol017oo0P0017oo00<007ooOol00goo0P0017oo0`0057oo0P0017oo
00<007ooOol00goo0P000Woo1@006goo00<007ooOol07Goo0P0017oo00<007ooOol00goo0P000Woo
1@0057oo0P0017oo00<007ooOol00goo0P0017oo0`0057oo0P0017oo00<007ooOol00goo0P000goo
0`0057oo00@007oo000000Aoo`03001oogoo00=oo`8000=oo`<000=oo`003Goo00<007ooOol00goo
00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`0BOol01000Oomoo`0027oo00@007ooOol0
009oo`04001oogoo000KOol00`00Oomoo`0LOol01000Oomoo`0027oo00@007ooOol0009oo`04001o
ogoo000COol01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo019oo`04001oogoo0008Ool0
1P00Oomoo`00Ool000=oo`03001oogoo011oo`03001oo`00009oo`03001oogoo00Ioo`06001oogoo
001oo`000goo0@000Goo0Goo000<Ool50002Ool01000Oomoo`0027oo00D007ooOol007oo00D000ao
o`D0009oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol06goo0P007Goo00@007ooOol0
00Qoo`04001oogoo0003Ool00`00Oomoo`0COol01000Oomoo`0027oo00D007ooOol007oo00D001=o
o`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo011oo`03001oo`00009oo`03001o
ogoo00Ioo`06001oogoo001oo`000goo0@000Goo0Goo000>Ool00`00Oomoo`02Ool01000Oomoo`00
27oo00H007ooOol007oo0002Ool00`00Oomoo`0BOol01000Oomoo`0027oo00@007ooOol000Aoo`03
001oogoo01Yoo`03001oogoo01aoo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol04Woo
00@007ooOol000Qoo`06001oogoo001oo`000Woo00<007ooOol04Woo00@007ooOol000Qoo`05001o
ogoo001oo`04000COol00`00Ool00002Ool00`00Oomoo`06Ool01000Oomoo`000Woo0`000goo000>
Ool00`00Oomoo`02Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oo`0001Aoo`04001oogoo
0008Ool01P00Oomoo`00Ool000=oo`03001oogoo01Uoo`03001oogoo01aoo`04001oogoo0008Ool0
1P00Oomoo`00Ool000=oo`03001oogoo015oo`04001oogoo0008Ool01000Oomoo`000Woo00<007oo
000057oo00@007ooOol000Qoo`06001oogoo001oo`005Goo00@007ooOol0009oo`03001oogoo00Io
o`06001oogoo001oo`000goo0@000Goo0Goo000?Ool01@00Oomoogoo00000Woo00<007ooOol01Woo
00@007ooOol000=oo`8001Aoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo01Uo
o`03001oogoo01aoo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo015oo`04001o
ogoo0008Ool01000Oomoo`000goo0P0057oo00@007ooOol000Qoo`04001oogoo0002Ool00`00Oomo
o`0BOol01000Oomoo`000Woo00<007ooOol01Woo00H007ooOol007oo0003Ool10001Ool1Ool000mo
o`03001oogoo009oo`8000Yoo`8000Eoo`03001oogoo01=oo`8000Yoo`8000=oo`<001aoo`03001o
ogoo01eoo`8000Yoo`8000=oo`<001Eoo`8000Yoo`8000Eoo`03001oogoo01=oo`8000Yoo`8000Ao
o`80019oo`04001oogooOol2000:Ool20003Ool30003Ool0011oo`03001oogoo05Yoo`03001oogoo
09Aoo`03001oogoo01Uoo`0047oo00<007ooOol0FWoo00<007ooOol0U7oo00<007ooOol06Goo000A
Ool00`00Oomoo`1IOol00`00Oomoo`2DOol00`00Oomoo`0IOol0015oo`03001oogoo05Uoo`03001o
ogoo09=oo`03001oogoo01Yoo`00o`006`001Woo0006Ool00`00Oomoo`08Ool20008Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`08Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomo
o`0:Ool000Ioo`03001oogoo00Qoo`03001oo`0000Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`05
001oogooOol00005Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool001Aoo`03001oogoo05Ioo`03001o
ogoo099oo`03001oogoo01]oo`0057oo00<007ooOol0EWoo00<007ooOol0TGoo00<007ooOol077oo
000EOol00`00Oomoo`1EOol00`00Oomoo`2AOol00`00Oomoo`0LOol001Eoo`03001oogoo05Eoo`03
001oogoo095oo`03001oogoo01aoo`005Woo00<007ooOol0E7oo00<007ooOol0T7oo00<007ooOol0
7Goo000FOol00`00Oomoo`1DOol00`00Oomoo`2@Ool00`00Oomoo`0MOol001Moo`03001oogoo05=o
o`03001oogoo08moo`03001oogoo01ioo`0067oo00<007ooOol0DWoo0P00T7oo00<007ooOol07Woo
000HOol00`00Oomoo`1BOol00`00Oomoo`2?Ool00`00Oomoo`0NOol001Uoo`03001oogoo055oo`03
001oogoo08ioo`03001oogoo01moo`006Goo00<007ooOol0DGoo00<007ooOol0SWoo00<007ooOol0
7goo000JOol00`00Oomoo`1@Ool00`00Oomoo`2=Ool00`00Oomoo`0POol001Yoo`03001oogoo051o
o`03001oogoo08eoo`03001oogoo021oo`006goo00<007ooOol0Cgoo00<007ooOol0SGoo00<007oo
Ool087oo000LOol00`00Oomoo`1>Ool00`00Oomoo`2<Ool00`00Oomoo`0QOol001aoo`03001oogoo
04ioo`03001oogoo08aoo`03001oogoo025oo`007Goo00<007ooOol0CGoo0P00S7oo00<007ooOol0
8Woo000MOol00`00Oomoo`1=Ool00`00Oomoo`2;Ool00`00Oomoo`0ROol001ioo`03001oogoo04ao
o`03001oogoo08Yoo`03001oogoo02=oo`007goo00<007ooOol0Bgoo00<007ooOol0RWoo00<007oo
Ool08goo000OOol00`00Oomoo`1;Ool00`00Oomoo`29Ool00`00Oomoo`0TOol0021oo`03001oogoo
04Yoo`03001oogoo08Uoo`03001oogoo02Aoo`008Goo00<007ooOol0BGoo00<007ooOol0R7oo00<0
07ooOol09Goo000QOol00`00Oomoo`19Ool00`00Oomoo`28Ool00`00Oomoo`0UOol0029oo`03001o
ogoo04Qoo`03001oogoo08Moo`03001oogoo02Ioo`008goo00<007ooOol0Agoo0P00R7oo00<007oo
Ool09Woo000TOol00`00Oomoo`16Ool00`00Oomoo`26Ool00`00Oomoo`0WOol002Aoo`03001oogoo
04Ioo`03001oogoo08Ioo`03001oogoo02Moo`009Goo00<007ooOol0AGoo00<007ooOol0QGoo00<0
07ooOol0:7oo000VOol00`00Oomoo`14Ool00`00Oomoo`25Ool00`00Oomoo`0XOol002Ioo`03001o
ogoo04Aoo`03001oogoo08Aoo`03001oogoo02Uoo`009goo00<007ooOol0@goo00<007ooOol0Q7oo
00<007ooOol0:Goo000XOol00`00Oomoo`0jOol30005Ool00`00Oomoo`23Ool00`00Oomoo`0ZOol0
02Qoo`03001oogoo03Uoo`05001oogooOol00004Ool00`00Oomoo`23Ool00`00Oomoo`0ZOol002Uo
o`03001oogoo039oo`D00003Ool007oo009oo`03001oogoo009oo`03001oogoo089oo`03001oogoo
02]oo`00:Woo00<007ooOol0=goo10001Goo0`00PWoo00<007ooOol0:goo000[Ool00`00Oomoo`0f
Ool00`00Oomoo`06Ool00`00Oomoo`21Ool00`00Oomoo`0/Ool002aoo`03001oogoo03Ioo`03001o
ogoo00Eoo`03001oogoo085oo`03001oogoo02aoo`00;Goo00<007ooOol0=Woo0P001Goo00<007oo
Ool0P7oo00<007ooOol0;Goo000^Ool00`00Oomoo`0lOol00`00Oomoo`1oOol00`00Oomoo`0^Ool0
02ioo`03001oogoo03aoo`03001oogoo07moo`03001oogoo02ioo`00;goo00<007ooOol0>goo00<0
07ooOol0OWoo00<007ooOol0;goo000`Ool00`00Oomoo`0jOol00`00Oomoo`1mOol00`00Oomoo`0`
Ool0035oo`03001oogoo03Uoo`03001oogoo07eoo`03001oogoo031oo`00<Woo00<007ooOol0>7oo
0P00OGoo00<007ooOol0<Goo000cOol00`00Oomoo`0gOol00`00Oomoo`1kOol00`00Oomoo`0bOol0
03=oo`03001oogoo03Moo`03001oogoo07]oo`03001oogoo039oo`00=7oo00<007ooOol0=Woo00<0
07ooOol0NWoo00<007ooOol0<goo000eOol00`00Oomoo`0eOol00`00Oomoo`1jOol00`00Oomoo`0c
Ool003Ioo`03001oogoo03Aoo`03001oogoo07Uoo`03001oogoo03Aoo`00=goo00<007ooOol0<goo
00<007ooOol0N7oo00<007ooOol0=Goo000hOol00`00Oomoo`0bOol00`00Oomoo`1hOol00`00Oomo
o`0eOol003Uoo`03001oogoo035oo`03001oogoo07Moo`03001oogoo03Ioo`00>Goo00<007ooOol0
<Goo0P00Mgoo00<007ooOol0=goo000jOol00`00Oomoo`0`Ool00`00Oomoo`1fOol00`00Oomoo`0g
Ool003]oo`03001oogoo02moo`03001oogoo07Eoo`03001oogoo03Qoo`00?7oo00<007ooOol0;Woo
00<007ooOol0M7oo00<007ooOol0>Goo000mOol00`00Oomoo`0]Ool00`00Oomoo`1cOol00`00Oomo
o`0jOol003ioo`8002eoo`03001oogoo079oo`03001oogoo03]oo`00@7oo00<007ooOol0:Woo00<0
07ooOol0LWoo00<007ooOol0>goo0011Ool00`00Oomoo`0YOol00`00Oomoo`1aOol00`00Oomoo`0l
Ool0049oo`03001oogoo02Qoo`03001oogoo071oo`03001oogoo03eoo`00@goo00<007ooOol09goo
00<007ooOol0Kgoo00<007ooOol0?Woo0014Ool00`00Oomoo`0VOol2001`Ool00`00Oomoo`0nOol0
04Eoo`03001oogoo02Eoo`03001oogoo06ioo`03001oogoo03moo`00AWoo00<007ooOol097oo00<0
07ooOol0KGoo00<007ooOol0@7oo0017Ool00`00Oomoo`0SOol00`00Oomoo`1/Ool00`00Oomoo`11
Ool004Qoo`03001oogoo029oo`03001oogoo06Yoo`8004Aoo`00BGoo0P008Woo00<007ooOol0JGoo
00<007ooOol0A7oo001;Ool00`00Oomoo`0HOol30004Ool00`00Oomoo`1XOol00`00Oomoo`15Ool0
04aoo`8001Uoo`03001oogoo00=oo`03001oogoo06Moo`03001oogoo04Ioo`00CWoo00<007ooOol0
3Goo1@0000=oo`0000000`0017oo00<007ooOol0IWoo00<007ooOol0Agoo001?Ool2000COol01000
Oomoo`001Goo0`00IGoo00<007ooOol0B7oo001AOol00`00Oomoo`0AOol00`00Ool00005Ool00`00
Oomoo`1TOol00`00Oomoo`19Ool0059oo`80019oo`8000Eoo`03001oogoo06=oo`03001oogoo04Yo
o`00E7oo00<007ooOol047oo00<007ooOol00goo00<007ooOol0HWoo00<007ooOol0Bgoo001EOol2
000FOol00`00Oomoo`1QOol00`00Oomoo`1<Ool005Moo`03001oogoo01=oo`03001oogoo05moo`80
04moo`00F7oo0P004goo00<007ooOol0GWoo00<007ooOol0Cgoo001JOol2000AOol00`00Oomoo`1L
Ool2001BOol005aoo`03001oogoo00ioo`03001oogoo05]oo`03001oogoo059oo`00GGoo0P003Woo
0P00FWoo0P00EGoo001OOol00`00Oomoo`0;Ool00`00Oomoo`1HOol00`00Oomoo`1EOol0061oo`80
00]oo`03001oogoo05Ioo`8005Qoo`00HWoo0P002Goo00<007ooOol0EGoo00<007ooOol0F7oo001T
Ool20007Ool00`00Oomoo`1COol2001KOol006Ioo`03001oogoo00Aoo`03001oogoo055oo`8005eo
o`00Igoo0P0017oo00<007ooOol0Cgoo0P00Ggoo001YOol20002Ool00`00Oomoo`1=Ool2001QOol0
06]oo`<004eoo`8006=oo`00KGoo0`00BGoo0P00IGoo001]Ool00`00Oomoo`030014Ool2001WOol0
06eoo`03001oogoo00=oo`<003moo`8006Uoo`00KGoo00<007ooOol01Woo0`00>7oo1000Jgoo001]
Ool00`00Oomoo`09Ool3000aOol4001_Ool006eoo`03001oogoo00aoo`@002Yoo`<007=oo`00KGoo
00<007ooOol047oo1P0087oo1000MWoo001]Ool00`00Oomoo`0FOol7000BOol7001jOol006eoo`03
001oogoo01eooa80085oo`00KGoo00<007ooOol0/7oo001]Ool2002aOol006eoo`03001oogoo0;1o
o`00KGoo00<007ooOol0/7oo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0532507, -11.8141, \
0.00048455, 0.0537719}}],

Cell[BoxData[
    \({2.5989171197118424`, {f \[Rule] 0.019102242949256575`}}\)], "Output",
  CellLabel->"Out[156]=  (10:52:48 on 8/14/00)"]
}, Open  ]],

Cell[TextData[{
  "Other more complex hypotheses could be made about the values of all the \
various moments.  For example, there might be a correlation between \
hetrozygosity at the two loci ",
  Cell[BoxData[
      \(TraditionalForm\`\((c\_\(2, 2\))\)\)]],
  ".   ",
  Cell[BoxData[
      \(TraditionalForm\`F\&^ = 0.020, \ c\&^\_\(2, 2\) = \(-0.0036\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`log \((L)\) = \(-2.48\)\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"LFC", "=", 
        RowBox[{"LogLikelihoodDisequilibrium", "[", 
          
          RowBox[{\({1063, {1, 2}}\), 
            ",", \(pl\[LeftDoubleBracket]{1, 2}\[RightDoubleBracket]\), 
            ",", \({1, 1}\), ",", 
            RowBox[{"(", GridBox[{
                  {"1", "0", "0"},
                  {"0", "f", "0"},
                  {"0", "0", "fc"}
                  }], ")"}], ",", \(Compiled \[Rule] True\)}], "]"}]}], 
      ";"}], "\n", \(Plot3D[LFC, {f, \(-0.02\), 0.04}, {fc, \(-0.01\), 0.01}, 
      PlotRange \[Rule] {{\(-0.02\), 0.04}, {\(-0.01\), 
            0.01}, {\(-5\), \(-2\)}}]; 
    FindMinimum[\(-LFC\), {f, {0, 0.01}}, {fc, {0, 0.005}}]\)}], "Input",
  CellLabel->"In[189]:=  (11:01:14 on 8/14/00)"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -30 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.22808 .16727 -5.79519 -9 ]
[.22808 .16727 .20481 0 ]
[.44535 .08183 -21.5128 -9 ]
[.44535 .08183 2.48716 0 ]
[.68156 -0.01098 -19.8449 -9 ]
[.68156 -0.01098 4.1551 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 30 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 36 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 30 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 24 3.14607 ]
[.02494 .25992 -12 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.0131 .33416 -12 -2.80073 ]
[.0131 .33416 0 6.19927 ]
[.00067 .41207 -12 -2.86695 ]
[.00067 .41207 0 6.13305 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-0.02)] .02757 .24618 1 .93395 Mshowa
.23703 .17687 m
.2415 .18167 L
s
[(0)] .22808 .16727 .93173 1 Mshowa
.4535 .09211 m
.45758 .09725 L
s
[(0.02)] .44535 .08183 .79274 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(0.04)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.08568 .23614 m
.08851 .23887 L
s
.13514 .21677 m
.13793 .21955 L
s
.18558 .19702 m
.18832 .19985 L
s
.28951 .15632 m
.29214 .15925 L
s
.34306 .13535 m
.34564 .13834 L
s
.39772 .11395 m
.40023 .11699 L
s
.51046 .06981 m
.51284 .07294 L
s
.56863 .04703 m
.57093 .05022 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-0.01)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(-0.005)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(0.005)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(0.01)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-5)] .02494 .25992 1 -0.39157 Mshowa
.02537 .32952 m
.03151 .3272 L
s
[(-4)] .0131 .33416 1 -0.37762 Mshowa
.013 .40759 m
.01917 .40535 L
s
[(-3)] .00067 .41207 1 -0.3629 Mshowa
0 .48963 m
.0062 .48748 L
s
[(-2)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03485 .26973 m
.03852 .26831 L
s
.03251 .28447 m
.03618 .28305 L
s
.03016 .29934 m
.03383 .29793 L
s
.02778 .31436 m
.03145 .31296 L
s
.02295 .34483 m
.02663 .34345 L
s
.0205 .36029 m
.02419 .35892 L
s
.01802 .37591 m
.02172 .37454 L
s
.01552 .39167 m
.01922 .39032 L
s
.01045 .42367 m
.01416 .42234 L
s
.00788 .43991 m
.01159 .43859 L
s
.00528 .45632 m
.00899 .45501 L
s
.00265 .47289 m
.00637 .47159 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.664 .741 .907 r
.38333 .57844 .40529 .59895 .442 .5879 .42036 .56711 Metetra
.664 .741 .907 r
.42036 .56711 .442 .5879 .47922 .5767 .45791 .55562 Metetra
.664 .741 .907 r
.45791 .55562 .47922 .5767 .51696 .56535 .49598 .54397 Metetra
.664 .741 .907 r
.49598 .54397 .51696 .56535 .55522 .55384 .53459 .53216 Metetra
.664 .741 .907 r
.53459 .53216 .55522 .55384 .59402 .54217 .57375 .52018 Metetra
.666 .182 0 r
.57375 .52018 .59402 .54217 .63336 .53033 .61526 .57522 Metetra
.502 .14 .284 r
.61526 .57522 .63336 .53033 .67327 .51832 .65678 .57341 Metetra
.495 .158 .324 r
.65678 .57341 .67327 .51832 .71715 .56603 .69898 .56757 Metetra
.263 .771 .8 r
.69898 .56757 .71715 .56603 .75917 .55666 .74171 .55759 Metetra
.399 .855 .854 r
.74171 .55759 .75917 .55666 .80153 .54275 .78483 .54328 Metetra
.512 .914 .878 r
.78483 .54328 .80153 .54275 .84403 .52403 .82816 .52438 Metetra
.604 .953 .879 r
.82816 .52438 .84403 .52403 .88648 .50013 .8715 .50056 Metetra
.679 .978 .861 r
.8715 .50056 .88648 .50013 .92859 .47051 .91461 .47135 Metetra
.738 .992 .826 r
.91461 .47135 .92859 .47051 .97006 .43446 .9572 .43613 Metetra
.664 .741 .907 r
.3608 .5574 .38333 .57844 .42036 .56711 .39815 .54577 Metetra
.664 .741 .907 r
.39815 .54577 .42036 .56711 .45791 .55562 .43603 .53399 Metetra
.664 .741 .907 r
.43603 .53399 .45791 .55562 .49598 .54397 .47445 .52203 Metetra
.664 .741 .907 r
.47445 .52203 .49598 .54397 .53459 .53216 .51342 .50991 Metetra
.777 .305 0 r
.51342 .50991 .53459 .53216 .57375 .52018 .55359 .57391 Metetra
.526 .18 .324 r
.55359 .57391 .57375 .52018 .61526 .57522 .5949 .57505 Metetra
.096 .653 .766 r
.5949 .57505 .61526 .57522 .65678 .57341 .63704 .57241 Metetra
.249 .76 .852 r
.63704 .57241 .65678 .57341 .69898 .56757 .67988 .56592 Metetra
.381 .839 .904 r
.67988 .56592 .69898 .56757 .74171 .55759 .72332 .55544 Metetra
.491 .896 .93 r
.72332 .55544 .74171 .55759 .78483 .54328 .76719 .54079 Metetra
.582 .935 .936 r
.76719 .54079 .78483 .54328 .82816 .52438 .81133 .52173 Metetra
.657 .963 .927 r
.81133 .52173 .82816 .52438 .8715 .50056 .85556 .49795 Metetra
.719 .982 .906 r
.85556 .49795 .8715 .50056 .91461 .47135 .89965 .46906 Metetra
.771 .994 .874 r
.89965 .46906 .91461 .47135 .9572 .43613 .94331 .4345 Metetra
.664 .741 .907 r
.33769 .53581 .3608 .5574 .39815 .54577 .37536 .52388 Metetra
.664 .741 .907 r
.37536 .52388 .39815 .54577 .43603 .53399 .41358 .51178 Metetra
.664 .741 .907 r
.41358 .51178 .43603 .53399 .47445 .52203 .45235 .49951 Metetra
.821 .36 0 r
.45235 .49951 .47445 .52203 .51342 .50991 .49087 .5672 Metetra
.538 .194 .333 r
.49087 .5672 .51342 .50991 .55359 .57391 .53177 .57113 Metetra
.083 .638 .807 r
.53177 .57113 .55359 .57391 .5949 .57505 .57365 .57149 Metetra
.231 .739 .888 r
.57365 .57149 .5949 .57505 .63704 .57241 .61638 .5682 Metetra
.359 .814 .937 r
.61638 .5682 .63704 .57241 .67988 .56592 .65988 .56117 Metetra
.466 .868 .963 r
.65988 .56117 .67988 .56592 .72332 .55544 .704 .55026 Metetra
.554 .906 .97 r
.704 .55026 .72332 .55544 .76719 .54079 .74862 .53531 Metetra
.628 .934 .966 r
.74862 .53531 .76719 .54079 .81133 .52173 .79356 .5161 Metetra
.69 .954 .952 r
.79356 .5161 .81133 .52173 .85556 .49795 .83866 .49233 Metetra
.743 .97 .931 r
.83866 .49233 .85556 .49795 .89965 .46906 .8837 .46364 Metetra
.789 .982 .902 r
.8837 .46364 .89965 .46906 .94331 .4345 .9284 .42958 Metetra
.664 .741 .907 r
.31396 .51366 .33769 .53581 .37536 .52388 .35197 .50141 Metetra
.651 .145 0 r
.35197 .50141 .37536 .52388 .41358 .51178 .38826 .54489 Metetra
.555 .146 .221 r
.38826 .54489 .41358 .51178 .45235 .49951 .42738 .555 Metetra
.546 .195 .323 r
.42738 .555 .45235 .49951 .49087 .5672 .46769 .56167 Metetra
.067 .615 .836 r
.46769 .56167 .49087 .5672 .53177 .57113 .50909 .56489 Metetra
.21 .71 .911 r
.50909 .56489 .53177 .57113 .57365 .57149 .55151 .56463 Metetra
.334 .782 .957 r
.55151 .56463 .57365 .57149 .61638 .5682 .59483 .56081 Metetra
.438 .833 .981 r
.59483 .56081 .61638 .5682 .65988 .56117 .63896 .55333 Metetra
.524 .871 .989 r
.63896 .55333 .65988 .56117 .704 .55026 .68376 .54207 Metetra
.596 .899 .987 r
.68376 .54207 .704 .55026 .74862 .53531 .72911 .52684 Metetra
.656 .92 .977 r
.72911 .52684 .74862 .53531 .79356 .5161 .77485 .50746 Metetra
.709 .936 .961 r
.77485 .50746 .79356 .5161 .83866 .49233 .8208 .48365 Metetra
.755 .95 .941 r
.8208 .48365 .83866 .49233 .8837 .46364 .86676 .45509 Metetra
.797 .961 .916 r
.86676 .45509 .8837 .46364 .9284 .42958 .91247 .42136 Metetra
.484 0 0 r
.28961 .49091 .31396 .51366 .35197 .50141 .32521 .52424 Metetra
.562 .11 .135 r
.32521 .52424 .35197 .50141 .38826 .54489 .36342 .53703 Metetra
0 .469 .754 r
.36342 .53703 .38826 .54489 .42738 .555 .40294 .54646 Metetra
.048 .583 .855 r
.40294 .54646 .42738 .555 .46769 .56167 .44368 .55253 Metetra
.186 .675 .924 r
.44368 .55253 .46769 .56167 .50909 .56489 .48557 .55523 Metetra
.306 .744 .967 r
.48557 .55523 .50909 .56489 .55151 .56463 .5285 .55449 Metetra
.407 .795 .99 r
.5285 .55449 .55151 .56463 .59483 .56081 .5724 .55025 Metetra
.491 .832 .998 r
.5724 .55025 .59483 .56081 .63896 .55333 .61714 .5424 Metetra
.562 .86 .997 r
.61714 .5424 .63896 .55333 .68376 .54207 .66261 .53081 Metetra
.622 .882 .989 r
.66261 .53081 .68376 .54207 .72911 .52684 .70867 .51533 Metetra
.674 .899 .977 r
.70867 .51533 .72911 .52684 .77485 .50746 .75518 .49575 Metetra
.72 .913 .961 r
.75518 .49575 .77485 .50746 .8208 .48365 .80197 .47185 Metetra
.761 .926 .942 r
.80197 .47185 .8208 .48365 .86676 .45509 .84883 .44331 Metetra
.799 .937 .92 r
.84883 .44331 .86676 .45509 .91247 .42136 .89552 .40978 Metetra
.705 .202 0 r
.26459 .46755 .28961 .49091 .32521 .52424 .29935 .51271 Metetra
0 .434 .772 r
.29935 .51271 .32521 .52424 .36342 .53703 .33786 .52507 Metetra
.025 .544 .865 r
.33786 .52507 .36342 .53703 .40294 .54646 .37773 .53409 Metetra
.16 .632 .929 r
.37773 .53409 .40294 .54646 .44368 .55253 .41887 .53977 Metetra
.276 .7 .968 r
.41887 .53977 .44368 .55253 .48557 .55523 .4612 .5421 Metetra
.375 .751 .99 r
.4612 .5421 .48557 .55523 .5285 .55449 .50464 .54101 Metetra
.458 .79 .999 r
.50464 .54101 .5285 .55449 .5724 .55025 .54908 .53644 Metetra
.528 .819 .999 r
.54908 .53644 .5724 .55025 .61714 .5424 .59441 .52828 Metetra
.587 .842 .993 r
.59441 .52828 .61714 .5424 .66261 .53081 .64053 .5164 Metetra
.638 .86 .983 r
.64053 .5164 .66261 .53081 .70867 .51533 .6873 .50067 Metetra
.684 .875 .97 r
.6873 .50067 .70867 .51533 .75518 .49575 .73457 .48088 Metetra
.724 .888 .955 r
.73457 .48088 .75518 .49575 .80197 .47185 .78217 .45682 Metetra
.762 .9 .938 r
.78217 .45682 .80197 .47185 .84883 .44331 .8299 .42822 Metetra
.797 .911 .918 r
.8299 .42822 .84883 .44331 .89552 .40978 .87754 .39474 Metetra
.664 .741 .907 r
.23889 .44355 .26459 .46755 .29935 .51271 .27792 .43027 Metetra
0 0 .508 r
.27792 .43027 .29935 .51271 .33786 .52507 .31163 .50886 Metetra
.13 .58 .924 r
.31163 .50886 .33786 .52507 .37773 .53409 .3518 .51774 Metetra
.243 .649 .962 r
.3518 .51774 .37773 .53409 .41887 .53977 .39329 .52325 Metetra
.34 .703 .983 r
.39329 .52325 .41887 .53977 .4612 .5421 .43603 .52537 Metetra
.422 .744 .993 r
.43603 .52537 .4612 .5421 .50464 .54101 .47993 .52407 Metetra
.492 .775 .995 r
.47993 .52407 .50464 .54101 .54908 .53644 .52489 .51925 Metetra
.551 .8 .991 r
.52489 .51925 .54908 .53644 .59441 .52828 .5708 .51085 Metetra
.603 .82 .983 r
.5708 .51085 .59441 .52828 .64053 .5164 .61754 .49872 Metetra
.648 .837 .973 r
.61754 .49872 .64053 .5164 .6873 .50067 .66499 .48273 Metetra
.689 .851 .96 r
.66499 .48273 .6873 .50067 .73457 .48088 .71299 .46271 Metetra
.726 .863 .946 r
.71299 .46271 .73457 .48088 .78217 .45682 .76138 .43843 Metetra
.76 .874 .93 r
.76138 .43843 .78217 .45682 .8299 .42822 .80997 .40966 Metetra
.792 .884 .912 r
.80997 .40966 .8299 .42822 .87754 .39474 .85852 .37608 Metetra
.664 .741 .907 r
.21248 .41888 .23889 .44355 .27792 .43027 .25185 .40522 Metetra
.664 .741 .907 r
.25185 .40522 .27792 .43027 .31163 .50886 .29182 .39136 Metetra
0 0 .471 r
.29182 .39136 .31163 .50886 .3518 .51774 .3252 .49711 Metetra
.303 .645 .968 r
.3252 .49711 .3518 .51774 .39329 .52325 .36699 .5027 Metetra
.384 .69 .98 r
.36699 .5027 .39329 .52325 .43603 .52537 .41009 .50482 Metetra
.454 .726 .984 r
.41009 .50482 .43603 .52537 .47993 .52407 .45441 .50344 Metetra
.514 .755 .983 r
.45441 .50344 .47993 .52407 .52489 .51925 .49984 .4985 Metetra
.567 .778 .978 r
.49984 .4985 .52489 .51925 .5708 .51085 .54629 .48991 Metetra
.613 .796 .97 r
.54629 .48991 .5708 .51085 .61754 .49872 .59364 .47757 Metetra
.654 .812 .959 r
.59364 .47757 .61754 .49872 .66499 .48273 .64174 .46133 Metetra
.691 .825 .947 r
.64174 .46133 .66499 .48273 .71299 .46271 .69045 .44104 Metetra
.725 .837 .934 r
.69045 .44104 .71299 .46271 .76138 .43843 .73961 .41649 Metetra
.756 .848 .919 r
.73961 .41649 .76138 .43843 .80997 .40966 .78901 .38744 Metetra
.787 .857 .903 r
.78901 .38744 .80997 .40966 .85852 .37608 .83844 .35361 Metetra
.664 .741 .907 r
.18532 .39351 .21248 .41888 .25185 .40522 .22504 .37947 Metetra
.664 .741 .907 r
.22504 .37947 .25185 .40522 .29182 .39136 .26537 .36521 Metetra
.664 .741 .907 r
.26537 .36521 .29182 .39136 .3252 .49711 .30634 .35073 Metetra
0 0 .454 r
.30634 .35073 .3252 .49711 .36699 .5027 .34001 .47769 Metetra
.413 .668 .966 r
.34001 .47769 .36699 .5027 .41009 .50482 .38341 .48007 Metetra
.474 .702 .968 r
.38341 .48007 .41009 .50482 .45441 .50344 .4281 .47881 Metetra
.528 .73 .967 r
.4281 .47881 .45441 .50344 .49984 .4985 .47397 .47388 Metetra
.576 .752 .961 r
.47397 .47388 .49984 .4985 .54629 .48991 .52093 .46521 Metetra
.618 .771 .954 r
.52093 .46521 .54629 .48991 .59364 .47757 .56884 .4527 Metetra
.656 .787 .944 r
.56884 .4527 .59364 .47757 .64174 .46133 .61757 .43623 Metetra
.69 .8 .933 r
.61757 .43623 .64174 .46133 .69045 .44104 .66696 .41564 Metetra
.722 .812 .921 r
.66696 .41564 .69045 .44104 .73961 .41649 .71685 .39075 Metetra
.752 .822 .907 r
.71685 .39075 .73961 .41649 .78901 .38744 .76704 .36131 Metetra
.78 .831 .891 r
.76704 .36131 .78901 .38744 .83844 .35361 .81731 .32708 Metetra
.664 .741 .907 r
.15738 .36742 .18532 .39351 .22504 .37947 .19746 .35297 Metetra
.664 .741 .907 r
.19746 .35297 .22504 .37947 .26537 .36521 .23816 .3383 Metetra
.664 .741 .907 r
.23816 .3383 .26537 .36521 .30634 .35073 .27951 .32339 Metetra
.664 .741 .907 r
.27951 .32339 .30634 .35073 .34001 .47769 .32152 .30825 Metetra
0 0 .447 r
.32152 .30825 .34001 .47769 .38341 .48007 .35607 .45053 Metetra
.485 .672 .947 r
.35607 .45053 .38341 .48007 .4281 .47881 .40106 .44969 Metetra
.535 .701 .946 r
.40106 .44969 .4281 .47881 .47397 .47388 .44732 .44498 Metetra
.579 .725 .942 r
.44732 .44498 .47397 .47388 .52093 .46521 .49473 .43637 Metetra
.619 .744 .936 r
.49473 .43637 .52093 .46521 .56884 .4527 .54316 .42378 Metetra
.655 .761 .928 r
.54316 .42378 .56884 .4527 .61757 .43623 .59248 .40711 Metetra
.688 .774 .917 r
.59248 .40711 .61757 .43623 .66696 .41564 .64252 .38621 Metetra
.718 .786 .906 r
.64252 .38621 .66696 .41564 .71685 .39075 .69311 .36091 Metetra
.746 .796 .893 r
.69311 .36091 .71685 .39075 .76704 .36131 .74405 .33098 Metetra
.774 .805 .878 r
.74405 .33098 .76704 .36131 .81731 .32708 .7951 .29617 Metetra
.664 .741 .907 r
.12864 .34057 .15738 .36742 .19746 .35297 .16907 .3257 Metetra
.664 .741 .907 r
.16907 .3257 .19746 .35297 .23816 .3383 .21014 .31059 Metetra
.664 .741 .907 r
.21014 .31059 .23816 .3383 .27951 .32339 .25188 .29524 Metetra
.664 .741 .907 r
.25188 .29524 .27951 .32339 .32152 .30825 .2943 .27964 Metetra
.664 .741 .907 r
.2943 .27964 .32152 .30825 .35607 .45053 .3374 .26378 Metetra
0 0 .446 r
.3374 .26378 .35607 .45053 .40106 .44969 .37338 .41531 Metetra
.534 .668 .923 r
.37338 .41531 .40106 .44969 .44732 .44498 .41994 .41117 Metetra
.578 .694 .921 r
.41994 .41117 .44732 .44498 .49473 .43637 .46774 .40286 Metetra
.616 .716 .916 r
.46774 .40286 .49473 .43637 .54316 .42378 .51664 .39034 Metetra
.651 .733 .909 r
.51664 .39034 .54316 .42378 .59248 .40711 .5665 .37355 Metetra
.683 .748 .9 r
.5665 .37355 .59248 .40711 .64252 .38621 .61714 .35236 Metetra
.713 .761 .89 r
.61714 .35236 .64252 .38621 .69311 .36091 .66839 .3266 Metetra
.74 .771 .878 r
.66839 .3266 .69311 .36091 .74405 .33098 .72003 .29606 Metetra
.767 .779 .864 r
.72003 .29606 .74405 .33098 .7951 .29617 .77183 .26049 Metetra
.664 .741 .907 r
.09904 .31293 .12864 .34057 .16907 .3257 .13983 .29762 Metetra
.664 .741 .907 r
.13983 .29762 .16907 .3257 .21014 .31059 .18129 .28206 Metetra
.664 .741 .907 r
.18129 .28206 .21014 .31059 .25188 .29524 .22342 .26624 Metetra
.664 .741 .907 r
.22342 .26624 .25188 .29524 .2943 .27964 .26625 .25016 Metetra
.664 .741 .907 r
.26625 .25016 .2943 .27964 .3374 .26378 .30978 .23382 Metetra
.664 .741 .907 r
.30978 .23382 .3374 .26378 .37338 .41531 .35405 .2172 Metetra
0 0 .451 r
.35405 .2172 .37338 .41531 .41994 .41117 .39194 .3715 Metetra
.57 .658 .896 r
.39194 .3715 .41994 .41117 .46774 .40286 .44003 .36391 Metetra
.61 .684 .895 r
.44003 .36391 .46774 .40286 .51664 .39034 .48933 .35174 Metetra
.645 .704 .89 r
.48933 .35174 .51664 .39034 .5665 .37355 .53967 .33498 Metetra
.677 .721 .882 r
.53967 .33498 .5665 .37355 .61714 .35236 .59086 .31356 Metetra
.706 .734 .872 r
.59086 .31356 .61714 .35236 .66839 .3266 .64271 .28732 Metetra
.734 .745 .861 r
.64271 .28732 .66839 .3266 .72003 .29606 .69501 .25607 Metetra
.759 .754 .847 r
.69501 .25607 .72003 .29606 .77183 .26049 .74748 .21955 Metetra
.664 .741 .907 r
.06856 .28447 .09904 .31293 .13983 .29762 .10972 .26869 Metetra
.664 .741 .907 r
.10972 .26869 .13983 .29762 .18129 .28206 .15156 .25265 Metetra
.664 .741 .907 r
.15156 .25265 .18129 .28206 .22342 .26624 .19409 .23635 Metetra
.664 .741 .907 r
.19409 .23635 .22342 .26624 .26625 .25016 .23733 .21978 Metetra
.664 .741 .907 r
.23733 .21978 .26625 .25016 .30978 .23382 .2813 .20292 Metetra
.664 .741 .907 r
.2813 .20292 .30978 .23382 .35405 .2172 .32602 .18578 Metetra
.664 .741 .907 r
.32602 .18578 .35405 .2172 .39194 .3715 .37151 .16834 Metetra
0 0 .462 r
.37151 .16834 .39194 .3715 .44003 .36391 .41174 .31828 Metetra
.597 .646 .869 r
.41174 .31828 .44003 .36391 .48933 .35174 .46132 .30699 Metetra
.634 .671 .867 r
.46132 .30699 .48933 .35174 .53967 .33498 .51205 .2906 Metetra
.668 .69 .862 r
.51205 .2906 .53967 .33498 .59086 .31356 .56372 .26912 Metetra
.698 .706 .854 r
.56372 .26912 .59086 .31356 .64271 .28732 .61612 .24244 Metetra
.726 .718 .843 r
.61612 .24244 .64271 .28732 .69501 .25607 .669 .21039 Metetra
.752 .727 .83 r
.669 .21039 .69501 .25607 .74748 .21955 .72208 .17269 Metetra
.664 .741 .907 r
.03716 .25514 .06856 .28447 .10972 .26869 .07869 .23888 Metetra
.664 .741 .907 r
.07869 .23888 .10972 .26869 .15156 .25265 .12091 .22234 Metetra
.664 .741 .907 r
.12091 .22234 .15156 .25265 .19409 .23635 .16384 .20553 Metetra
.664 .741 .907 r
.16384 .20553 .19409 .23635 .23733 .21978 .20751 .18843 Metetra
.664 .741 .907 r
.20751 .18843 .23733 .21978 .2813 .20292 .25192 .17104 Metetra
.664 .741 .907 r
.25192 .17104 .2813 .20292 .32602 .18578 .2971 .15335 Metetra
.664 .741 .907 r
.2971 .15335 .32602 .18578 .37151 .16834 .34306 .13535 Metetra
.664 .741 .907 r
.34306 .13535 .37151 .16834 .41174 .31828 .38984 .11704 Metetra
.007 0 .481 r
.38984 .11704 .41174 .31828 .46132 .30699 .43277 .2545 Metetra
.617 .63 .841 r
.43277 .2545 .46132 .30699 .51205 .2906 .48376 .23917 Metetra
.654 .655 .839 r
.48376 .23917 .51205 .2906 .56372 .26912 .53581 .21801 Metetra
.687 .675 .832 r
.53581 .21801 .56372 .26912 .61612 .24244 .58866 .19106 Metetra
.717 .689 .823 r
.58866 .19106 .61612 .24244 .669 .21039 .64204 .15818 Metetra
.743 .7 .81 r
.64204 .15818 .669 .21039 .72208 .17269 .69565 .1191 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-0.02)] .02757 .24618 1 .93395 Mshowa
.23703 .17687 m
.2415 .18167 L
s
[(0)] .22808 .16727 .93173 1 Mshowa
.4535 .09211 m
.45758 .09725 L
s
[(0.02)] .44535 .08183 .79274 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(0.04)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.08568 .23614 m
.08851 .23887 L
s
.13514 .21677 m
.13793 .21955 L
s
.18558 .19702 m
.18832 .19985 L
s
.28951 .15632 m
.29214 .15925 L
s
.34306 .13535 m
.34564 .13834 L
s
.39772 .11395 m
.40023 .11699 L
s
.51046 .06981 m
.51284 .07294 L
s
.56863 .04703 m
.57093 .05022 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[189]:=  (11:01:14 on 8/14/00)",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jA000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00Zgoo0P0017oo00<007ooOol00goo0P0017oo0`00H7oo002Z
Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo05moo`00ZWoo00@007ooOol000Qoo`05
001oogoo001oo`05001POol00:Yoo`04001oogoo0008Ool01P00Oomoo`00Ool0009oo`03001oogoo
05moo`00ZWoo00@007ooOol000Qoo`04001oogoo0002Ool00`00Ool0001QOol00:Yoo`04001oogoo
0008Ool01000Oomoo`000goo0P002goo0P0017oo00<007ooOol00goo0P000goo0`00@Woo002[Ool2
000:Ool20005Ool00`00Oomoo`08Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo045o
o`00`Woo1@000Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`11Ool00<Uoo`04001o
ogoo0008Ool01000Oomoo`000goo00<007ooOol0@Goo0039Ool01000Oomoo`0027oo00@007ooOol0
00=oo`03001oogoo045oo`00bGoo00@007ooOol000Qoo`04001oogoo0002Ool20013Ool00;ioo`80
00Yoo`8000Yoo`8000Aoo`03001oogoo045oo`00^goo0`0000=oo`000000Ggoo002iOol20004Ool2
001OOol00;Ioo`<000Ioo`03001oo`0005ioo`00/goo0`002Goo00<007oo0000GWoo002aOol2000<
Ool01000Oomoo`00GGoo002^Ool3000>Ool01@00Oomoogoo0000G7oo002/Ool20003Ool00`00Oomo
o`0;Ool00`00Oomoo`02001LOol00:Uoo`<001=oo`03001oogoo009oo`03001oogoo05Uoo`00Ygoo
0P005Woo00<007ooOol00goo00<007ooOol0F7oo002TOol3000HOol00`00Oomoo`03Ool00`00Oomo
o`1HOol00:9oo`8001aoo`03001oogoo00=oo`03001oogoo05Moo`00L7oo0P0017oo00<007ooOol0
0goo0P000Woo1@006Woo10007Goo00<007ooOol00goo00<007ooOol0Egoo001_Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo000GOol3000QOol00`00Oomoo`03Ool2001HOol006moo`04
001oogoo0008Ool01000Oomoo`000goo00<007ooOol05Goo0P0097oo00<007ooOol01Goo00<007oo
Ool0EGoo001_Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo015oo`<002Ioo`03001o
ogoo00Eoo`03001oogoo05Eoo`00Kgoo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007oo
Ool03Woo0P00:Goo00<007ooOol01Woo00<007ooOol0E7oo001_Ool01000Oomoo`0027oo00H007oo
Ool007oo0003Ool00`00Oomoo`0;Ool3000[Ool00`00Oomoo`07Ool00`00Oomoo`1COol0071oo`80
00Yoo`8000=oo`<000aoo`80009oo`03001oogoo02Uoo`03001oogoo00Moo`03001oogoo05=oo`00
SGoo0`00<7oo00<007ooOol01goo0P00E7oo002:Ool3000cOol00`00Oomoo`09Ool00`00Oomoo`1A
Ool008Qoo`8003Ioo`03001oogoo00Uoo`03001oogoo055oo`00QGoo0`00>7oo00<007ooOol02Woo
00<007ooOol0D7oo0023Ool3000jOol00`00Oomoo`0;Ool00`00Oomoo`1?Ool0081oo`<000=oo`03
001oogoo03Moo`03001oogoo00]oo`03001oogoo04moo`00OWoo0P00@7oo00<007ooOol02goo0P00
3Woo0P0017oo00<007ooOol00goo0P0017oo0P000goo0`00:7oo001kOol30012Ool00`00Oomoo`0=
Ool00`00Oomoo`0:Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`000goo00<0
07ooOol09Goo001hOol30015Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool50002Ool01000Oomoo`00
27oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`0UOol007Ioo`<004Moo`03001oogoo
00ioo`03001oogoo00Uoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001o
ogoo02Eoo`00Lgoo100000=oo`00Ool0AWoo0P003goo00<007ooOol02Goo00@007ooOol000Qoo`04
001oogoo0002Ool01@00Oomoo`00Ool01000:7oo001aOol400000eKm001oo`17Ool3000@Ool00`00
Oomoo`08Ool01000Oomoo`0027oo00@007ooOol0009oo`06001oogoo001oo`00:goo001^Ool40004
E_d00`00Oomoo`15Ool00`00G]UNf@02000>Ool3000:Ool2000:Ool20004Ool20002Ool5000WOol0
06aoo`<000MFo@8004Aoo`8000=Nf@80011oo`03001oogoo04Yoo`00Bgoo0P0077oo0`002UKm0P00
@goo00<005kIG]T00ekI00<005kI000047oo00<007ooOol0BGoo001:Ool01000Oomoo`006Goo0`00
00=Fo@00E_d02EKm0P00@Woo00<005kIG]T015kI00<005kI00004Goo00<007ooOol0B7oo001:Ool0
1000Oomoo`005Woo0`001EKm00<005KmE_d025Km0P00@7oo00<005kIG]T01EkI00@005kIG]T0011o
o`03001oogoo04Qoo`00BWoo00@007ooOol001=oo`<000UFo@03001FoEKm00MFo@8003ioo`8000QN
f@04001NfEkI000AOol20018Ool004Yoo`04001oogoo000@Ool3000=E_d00`00E_eFo@06E_d2000m
Ool00`00G]UNf@08G]T01000G]UNf@004Goo0P00B7oo001:Ool01000Oomoo`003Woo10003UKm00<0
05KmE_d01UKm00<0000?0000>goo00<005kIG]T02EkI00D005kIG]UNf@00015oo`03001oogoo04Io
o`00Bgoo0P0037oo0`000UKm00<005Km00003UKm00<005KmE_d01EKm00<0000?0000>Goo0P0035kI
00D005kIG]UNf@00019oo`03001oogoo04Eoo`00Egoo0`001eKm00<005KmE_d035Km00<005KmE_d0
15Km00<0000?0000=goo0P0000=JfP00G]T02ekI00<005kIG]T00UkI00<007ooOol047oo00<007oo
Ool0A7oo001EOol2000;E_d00`00E_eFo@0;E_d20005E_d00`0000l0000fOol00`00F]YJfP02F]X0
0`00G]UNf@09G]T00`00G]UNf@02G]T00`00Oomoo`0@Ool00`00Oomoo`14Ool0059oo`<000iFo@03
001FoEKm00MFo@<00003E_d005Km00AFo@0400003`0?000cOol20005F]X00`00G]UNf@09G]T00`00
G]UNf@02G]T2000AOol20015Ool004moo`@00003E_d005Km00iFo@03001FoEKm00=Fo@<000AFo@03
001FoEKm00=Fo@0400003`0?000aOol20008F]X00`00G]UNf@08G]T01`00G]UNfEkI001RnP0001=o
o`03001oogoo049oo`00CGoo0`000UKm00@005KmE_d000mFo@03001Fo@00008000MFo@8000AFo@04
00003`0?000_Ool2000:F]X00`00G]UNf@08G]T01000G]T000000f;j00<007ooOol047oo00<007oo
Ool0@Woo001:Ool30009E_d00`00E_eFo@0<E_d2000:E_d20005E_d0100000l03`00;Goo00<005[J
F]X02e[J00<005kIG]T01ekI0P001F;j00<007ooOol04Goo00<007ooOol0@Goo0018Ool2000=E_d0
0`00E_eFo@09E_d200000eKm001Fo@09E_d20005E_d0100000l03`00:goo0P003U[J00<005kIG]T0
1UkI0P001f;j00<007ooOol047oo00<007ooOol0@Goo0015Ool30002E_d00`00E_eFo@0;E_d00`00
E_eFo@05E_d30004E_d00`00E_eFo@08E_d00`00E_eFo@03E_d0100000l03`00:Goo0P004E[J00<0
05kIG]T015kI00<006;j00001f;j00<007ooOol04Goo0P00@Goo0013Ool20006E_d00`00E_eFo@0;
E_d00`00E_eFo@02E_d20008E_d00`00E_eFo@07E_d20004E_d01@0000l03`0?00009Woo0P0000=F
^P00F]X045[J00<005kIG]T00ekI00@006;jH_X000QRnP03001oogoo011oo`80045oo`00@7oo0`00
0UKm00<005KmE_d015Km00<005KmE_d02eKm00@005Km000000]Fo@03001FoEKm00IFo@8000AFo@05
00003`0?00l0000TOol20004E[X00`00F]YJfP0?F]X00`00G]UNf@020003H_X00`00H_YRnP06H_X0
0`00Oomoo`0AOol00`00Oomoo`0oOol003eoo`<000eFo@03001FoEKm00YFo@8000iFo@03001FoEKm
00EFo@8000AFo@0500003`0?00l0000ROol20006E[X00`00F]YJfP0?F]X00`00G]T00005H_X00`00
H_YRnP07H_X00`00Oomoo`0AOol00`00Oomoo`0nOol003]oo`<00003E_d005Km00eFo@03001FoEKm
00IFo@<0009Fo@03001FoEKm00aFo@03001FoEKm00AFo@0300003P0000=Fo@0300003`0?00803`03
001oogoo01eoo`8000UF^P03001JfU[J00iJfP8000MRnP03001RnV;j00IRnP03001oogoo019oo`03
001oogoo03eoo`00>7oo0`001EKm00<005KmE_d035Km00<005KmE_d00eKm0P001UKm00<005KmE_d0
35Km00<005KmE_d00eKm00<0000>00000eKm00<0000?00l00P0?00<007ooOol06goo0P0035Jj00<0
05[JF]X035[J00<005kJ00001f;j00<006;jH_X01f;j00<007ooOol04Goo00<007ooOol0?Goo0008
Ool20004Ool00`00Oomoo`03Ool20002Ool5000HOol40008E_d00`00E_eFo@0<E_d00`00E_d00002
0009E_d00`00E_eFo@0;E_d20004E_d00`0000h00003E_d00`0000l03`0200l00`00Oomoo`0IOol2
000>E[X00`00F]YJfP0:F]X20003G]X00`00H_YRnP04H_X00`00H_YRnP07H_X00`00Oomoo`0BOol0
0`00Oomoo`06Ool2000dOol000Moo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol001Io
o`<0009Fo@03001FoEKm00MFo@03001FoEKm00]Fo@8000eFo@03001FoEKm00MFo@<00003E_d005Km
00=Fo@0300003P0000AFo@0500003`0?00l0000HOol300000e:J001F^P0>E[X00`00F]YJfP07F]X2
0005G]X00`00H_YRnP04H_X00`00H_YRnP07H_X2000DOol00`00Oomoo`04Ool01000Oomoo`00<goo
00050002Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo01=oo`<0009Fo@03001FoEKm
00]Fo@03001FoEKm00MFo@<0009Fo@03001FoEKm00]Fo@03001FoEKm00=Fo@<000AFo@03001FoEKm
009Fo@0400003P0>0003E_d00`0000l03`0200l00`00Oomoo`0BOol30005DYX00`00E[YF^P0<E[X0
0`00F]YJfP06F]X00`00G]YNfP06G]X00`00H_YRnP03H_X00`00H_YRnP06H_X00`00Ha/0000DOol0
0`00Oomoo`04Ool01000Oomoo`00<goo0007Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001o
ogoo011oo`<000EFo@03001FoEKm00]Fo@03001FoEKm00=Fo@<000IFo@03001FoEKm00]Fo@03001F
o@00008000MFo@8000=Fo@0400003P0>0003E_d00`0000l03`0200l00`00Oomoo`0@Ool20008DYX0
0`00E[YF^P0=E[X00`00F]YJfP03F]X20009G]X00`00H_YRnP03H_X00`00H_YRnP04H_X20003Ha/0
0`00Oomoo`0BOol00`00Oomoo`03Ool01000Oomoo`00<goo0007Ool01000Oomoo`0027oo00H007oo
Ool007oo0003Ool00`00Oomoo`0<Ool30009E_d00`00E_eFo@0;E_d00`00E_d00002000:E_d00`00
E_eFo@0:E_d2000:E_d20004E_d00`0000h00003E_d00`0000l03`0200l00`00Oomoo`0=Ool3000;
DYX00`00E[YF^P0=E[X00`00F]YJfP02000<G]X00`00H_YRnP02H_X00`00H_YRnP03H_X00`00Ha]S
6`04Ha/00`00Oomoo`0BOol00`00Oomoo`02Ool01000Oomoo`00<goo0007Ool01000Oomoo`0027oo
00H007ooOol007oo0003Ool00`00Oomoo`0:Ool4000;E_d00`00E_eFo@0:E_d2000>E_d00`00E_eF
o@06E_d30002E_d00`00E_eFo@07E_d20004E_d00`0000h00003E_d00`0000l03`0300l00`00Oomo
o`09Ool3000>DYX00`00E[YF^P0=E[X00`00F]X0000>G]X00`00H_YRnP02H_X01000H_YRnV;j0P00
1f<K00<007ooOol04Woo0P000goo00@007ooOol003=oo`0027oo0P002Woo0P000goo0`002Woo0`00
0UKm00<005KmE_d02eKm00<005KmE_d01UKm0`000UKm00<005KmE_d035Km00<005KmE_d00eKm0P00
1UKm00<005KmE_d01eKm00<005KmE_d00UKm00@0000>00h0009Fo@0300003`0?00<03`03001oogoo
00Ioo`<0009>VP03001BVU:J00eBVP03001F^UJj00aF^P80011NfP05001RnV;jH_X00002H_X00`00
Ha]S6`08Ha/00`00Oomoo`0@Ool00`00Ool00004Ool2000dOol002Aoo`8000IFo@03001FoEKm00]F
o@03001FoEKm00=Fo@8000IFo@03001FoEKm00aFo@03001Fo@00008000UFo@03001FoEKm00IFo@80
00=Fo@0400003P0>0002E_d00`0000l03`0300l00`00Oomoo`03Ool30006CYX00`00DYYBVP0<DYX0
0`00E[YF^P0:E[X200000e[K001NfP0?G]X00`00H_YRnP0200000f;j001S6`0:Ha/00`00Oomoo`0C
Ool00`00Oomoo`0gOol0025oo`<000UFo@03001FoEKm00]Fo@03001Fo@00008000UFo@03001FoEKm
00]Fo@8000eFo@03001FoEKm00EFo@8000=Fo@0400003P0>0002E_d00`0000l03`0400l00`00Ool0
00020009CYX00`00DYYBVP0<DYX00`00E[YF^P08E[X20004F]/00`00G]YNfP0=G]X300000f;j0000
000=Ha/00`00Oomoo`0BOol00`00Oomoo`0gOol0021oo`8000aFo@03001FoEKm00YFo@8000eFo@03
001FoEKm00MFo@<0009Fo@03001FoEKm00]Fo@03001FoEKm00AFo@8000=Fo@0700003P0>00h005Km
00001P0?0P003DjJ00<005:JDYX035:J00<005JjE[X01EJj0P001e[K00<005kJG]X02EkJ0`0000IN
fP00H_X006<K000>Ha/00`00Oomoo`0BOol00`00Oomoo`0fOol001Qoo`<000Eoo`<000aFo@03001F
oEKm00IFo@<0009Fo@03001FoEKm00]Fo@03001FoEKm00=Fo@<000IFo@03001FoEKm00]Fo@03001F
oEKm00=Fo@8000=Fo@0700003P0>00h005Km00001P0?00<004jJCYX034jJ00<005:JDYX035:J00<0
05JjE[X015Jj00<005[KF]/01e[K00<005kJG]X01UkJ0`0015kJ0P000f<K00<006<KHa/02f<K00<0
07ooOol04Woo0P00=goo000GOol01@00Oomoogoo000017oo00@007ooOol000aFo@03001FoEKm00=F
o@8000IFo@03001FoEKm00]Fo@03001Fo@00008000YFo@03001FoEKm00YFo@8000AFo@8000=Fo@05
00003P0>00h00002E_d00`0000l03`0400l00`00CYY>VP0<CYX00`00DYYBVP0<DYX01000E[YF^UJj
0P002e[K00<005kJG]X00UkJ0`001EkJ0P0000=Nn`00Ha/00f<K00<006<KHa/02V<K0P0057oo00<0
07ooOol0=Goo000AOol50005Ool00`00Oomoo`02Ool01@00Oomoogoo000035Km00<005Km00000P00
2EKm00<005KmE_d02UKm0P003UKm00<005KmE_d01UKm0`0000=Fo@00E_d00eKm00<0000>00000UKm
00D0000>00h03P00009Fo@0300003`0?00@03`03001>VTjJ00e>VP03001BVU:J00]BVP04001F^P00
000>F]/40007G]X00`00G_]Nn`02G_/01@00Ha]S6f<K00002f<K00<006<K00005Goo00<007ooOol0
=7oo000KOol01000Oomoogoo0P0017oo00<005KmE_d025Km0`003EKm00<005KmE_d01UKm0`000UKm
00<005KmE_d035Km00<005KmE_d00eKm0P0015Km00<005KmE_d00UKm00<0000>00000UKm00<0000>
00h00P0>00<005Km00001`0?00<004jJCYX034jJ00<005:JDYX02e:J0P003U[K0`0025kJ0P001Ukk
00D006<KHa]S6`0000QS6`8000=S6`03001oogoo019oo`03001oogoo03Aoo`005goo100017oo00<0
07ooOol017oo00<005KmE_d015Km0`000eKm00<005KmE_d02eKm00<005KmE_d00eKm0P001UKm00<0
05KmE_d035Km00<005Km00000P001UKm0P000eKm00<0000>00000eKm00L0000>00h03P00E_d00007
00l00`00CYY>VP0=CYX00`00DYYBVP07DYX300000eKK001Jf`0;F]/20003F]/00`00G]YNfP03G]X2
0009G_/01@00Ha]S6f<K00001V<K00<006<KHa/016<K00<007ooOol04Woo00<007ooOol0<goo000G
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00E_eFo@030007E_d00`00E_eFo@0;E_d00`00E_d0
00020009E_d00`00E_eFo@0;E_d20009E_d20004E_d20003E_d01`0000h03P0>001Fo@0000P03`03
001>VTjJ00a>VP03001BVU:J00EBVP8000EFf`03001Jfe[K00IJf`<000EJf`03001NfUkJ009NfP03
001Nnekk00YNn`04001S6f<K0004Ha/20008Ha/00`00Oomoo`0BOol00`00Oomoo`0bOol001Moo`D0
00=oo`8000Moo`8000]Fo@03001FoEKm00YFo@8000eFo@03001FoEKm00MFo@<00003E_d005Km00QF
o@8000AFo@0300003P00009Fo@0700003P0>00h005Km00002@0?00<004jJCYX034jJ00<005:JDYX0
0U:J0P0025KK00<005[KF]/00U[K0`002E[K00@005kJ000000eNn`05001S6f<KHa/00002Ha/00`00
Ha]S6`08Ha/00`00Oomoo`0BOol00`00Oomoo`0bOol001moo`03001oogoo00Moo`03001FoEKm00YF
o@03001FoEKm00IFo@<0009Fo@03001FoEKm00]Fo@03001FoEKm00=Fo@<000EFo@03001FoEKm00MF
o@03001FoEKm009Fo@0300003P00009Fo@0300003P0>00803P8000T03`03001>VTjJ00a>VP03001B
VP00008000YFf`03001Jf`00008000aJf`80011Nn`04001S6f<KHa/2000<Ha/00`00Oomoo`0BOol0
0`00Oomoo`0aOol001moo`03001oogoo00Qoo`03001FoEKm00YFo@03001FoEKm00=Fo@8000IFo@03
001FoEKm00]Fo@03001Fo@00008000UFo@03001FoEKm00IFo@8000=Fo@0300003P00009Fo@030000
3P0>00803P8000X03`03001>VTjJ00Y>VP<000aFf`<000eJf`800003F_/005kk011Nn`05001S6`00
Ha/0000=Ha/00`00Oomoo`0BOol00`00Oomoo`0`Ool001moo`03001oogoo00Uoo`03001FoEKm00YF
o@03001Fo@00008000UFo@03001FoEKm00YFo@8000eFo@03001FoEKm00EFo@8000=Fo@0300003P00
009Fo@0300003P0>00803P8000X03`03001>VTjJ00M>VP<0009B^`03001FfeKK00MFf`<000=Ff`03
001Jfe[K00QJf`8000AJn`03001Nnekk00iNn`80009S6`03001S6f<K00]S6`8001=oo`03001oogoo
031oo`007Woo0P0037oo00<005KmE_d025Km0`003EKm00<005KmE_d01UKm0`000UKm00<005KmE_d0
2eKm00<005KmE_d015Km0P000eKm00H0000>00h005Km000500h00`0000l03`0900l00`00CYY>VP03
CYX30006D[/00`00E]]Ff`04E]/20006E]/00`00F]]Jf`06F]/20007F_/00`00G_]Nn`0<G_/00`00
Ga`00003Ha/00`00Ha]S6`09Ha/00`00Hc`0000DOol2000`Ool001ioo`03001oogoo00aoo`03001F
oEKm00AFo@<000=Fo@03001FoEKm00]Fo@03001FoEKm00=Fo@8000IFo@03001FoEKm00]Fo@03001F
oEKm00=Fo@8000=Fo@0600003P0>001Fo@001@0>0P002P0?00<004jJCYX00`002U:k00<005KKE]/0
0`002EKK00<005[KF]/015[K00<005[kF_/01e[k00<005kkG_/02Ukk0P000elL00D006<KHa]S6`00
00QS6`8000=S?003001oogoo019oo`03001oogoo02ioo`007Woo00<007ooOol03Goo00<005KmE_d0
0`001eKm00<005KmE_d02eKm00<005Km00000P002EKm00<005KmE_d02UKm0P0015Km00<0000>0000
0UKm00H0000>00h005Km000500h2000900l4000=D[/3000<E]/00`00F]]Jf`02F]/2000;F_/00`00
G_]Nn`07G_/20005Ga`00`00Ha]S6`02Ha/00`00Ha]S6`04Ha/00`00HcaS?004Hc`00`00Oomoo`0A
Ool00`00Oomoo`0^Ool001ioo`03001oogoo00ioo`8000]Fo@03001FoEKm00YFo@8000eFo@03001F
oEKm00IFo@<00003E_d005Km00=Fo@0300003P00009Fo@0600003P0>001Fo@001@0>0P001@0?1000
0TjK00<005:kD[/02E:k0`0000=B^`00E]/03EKK00@005[K000000eJn`03001Nnekk00INn`03001O
75lL00IO7005001S6f<KHa/00004Ha/20007Hc`00`00Oomoo`0BOol00`00Oomoo`0]Ool001ioo`03
001oogoo00moo`03001FoEKm00YFo@03001FoEKm00IFo@<0009Fo@03001FoEKm00]Fo@03001FoEKm
00=Fo@8000AFo@03001FoEKm009Fo@0300003P00009Fo@0700003P0>00h005Km00001@0>00<0000?
00000`001djK00<005:kD[/01E:k0`001E:k00<005KKE]/02eKK0P0045[k00<005kkG_/00ekk0P00
2UlL00D006<KHa]S6`00009S6`03001S?6<l00QS?003001oogoo019oo`03001oogoo00Ioo`8000Ao
o`03001oogoo00=oo`8000Aoo`8000=oo`<000aoo`007Woo00<007ooOol047oo00<005KmE_d02UKm
00<005KmE_d00eKm0P001UKm00<005KmE_d02eKm00<005Km00000P001UKm0P000eKm00<0000>0000
0eKm00H0000>00h005Km000500h2000<CY/01000D[]B^e:k0`0025:k00<005KKE]/025KK0`0000=F
o000F_/045[k00<005kkG_/00P0035lL00<006<KHa/00V<K0P002f<l00<007ooOol04Woo0P001Woo
00@007ooOol000Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000=oo`03001oogoo00Uoo`007Goo
00<007ooOol04Woo00<005KmE_d02UKm00<005Km00000P002EKm00<005KmE_d02UKm0P002EKm0P00
15Km00<0000>00000UKm00H0000>00h005Km000500h00`00CY]>V`0;CY/4000<D[/00`00E]]Ff`05
E]/20005E_`00`00F_]Jn`0>F_/00`00G_/0000?Ga`00`00Ha]S6`03000<Hc`00`00Oomoo`0BOol0
0`00Oomoo`04Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`09
Ool001eoo`8001Aoo`03001FoEKm00QFo@@000aFo@03001FoEKm00IFo@<0009Fo@03001FoEKm00MF
o@03001FoEKm009Fo@0300003P00009Fo@0600003P0>001Fo@001P0>00<004jKCY/02DjK0`003U:k
00<005KKE]/00eKK0P0025Kl00<005[kF_/03E[k0P0045lL00<006<K00000V<l00<006<lHc`02V<l
0P004goo00<007ooOol017oo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`001Goo00<0
07ooOol02Goo000FOol30004Ool00`00Oomoo`0DOol00`00E_eFo@04E_d30004E_d00`00E_eFo@0:
E_d00`00E_eFo@03E_d20006E_d00`00E_eFo@06E_d00`00E_eFo@02E_d00`0000h00002E_d01000
00h03P0>0P001`0>00<004jKCY/01DjK0`000djK00<005:kD[/035:k00<005KK00000P002UKl00<0
05[kF_/02e[k0P0000=K7000Ga`03elL0P0016<l00<006<lHc`026<l00<006=L000057oo00<007oo
Ool00goo00@007ooOol000Qoo`04001oogoo0002Ool01@00Oomoo`00Ool0100037oo000GOol00`00
Oomoo`03Ool00`00Oomoo`0EOol00`00E_eFo@030008E_d00`00E_eFo@0:E_d00`00E_d000020009
E_d00`00E_eFo@05E_d20003E_d00`0000h00002E_d0100000h03P0>0P001`0>00<004jKCY/00TjK
0`001TjK00<005:kD[/02e:k0`003UKl00<005[kF_/025[k0P0015/L00<005lLGa`02elL0P0000=O
?000Hc`016<l00<006<lHc`01F<l0P000f=L00<007ooOol04Woo00<007ooOol00Woo00@007ooOol0
00Qoo`04001oogoo0002Ool01P00Oomoo`00Ool000moo`003Woo1@0000=oo`0000000`0017oo00<0
07ooOol05Woo0P0035Km00<005KmE_d025Km100035Km00<005KmE_d015Km0P000eKm00H0000>00h0
05Km000300h2000800h4000:CY/00`00D[]B^`07D[/30002D]`00`00E_aFo00=E_`00`00F_]Jn`04
F_/30007Fa`00`00GaaO7009Ga`00`00GcaO?002Gc`00`00HcaS?002Hc`00`00HcaS?004Hc`00`00
HeaSG004He`00`00Oomoo`0@Ool30004Ool2000:Ool20004Ool20002Ool5000;Ool001Aoo`04001o
ogoo0004Ool2000IOol00`00E_eFo@0;E_d00`00E_eFo@04E_d30004E_d00`00E_eFo@0:E_d00`00
E_eFo@03E_d20003E_d01P0000h03P00E_d000<03P8000H03P@000a>V`03001B^e:k00AB^`<000IB
g003001Fo5Kl00aFo003001Jne[k009Jn`8000]K7003001O75lL00IO708000IO?003001S?6<l009S
?004001S?6<lHc`20008He`00`00Oomoo`0AOol00`00Oomoo`0XOol001Eoo`03001oo`0000Eoo`03
001oogoo01Qoo`03001FoEKm00]Fo@03001FoEKm00<000QFo@03001FoEKm00YFo@03001FoEKm009F
o@8000=Fo@0600003P0>001Fo@000`0>0P000`0>0`000`0>00<004jKCY/02djK00<005:kD[/00`00
2U;L00<005KlE_`035Kl00@005[k000000eK7003001O75lL00AO708000UO?003001S?6<l009S?003
001S?00000]SG003001oogoo015oo`03001oogoo02Moo`005Woo0P0017oo00<007ooOol06Woo00<0
05KmE_d02UKm0`0035Km00<005KmE_d025Km0`000eKm00<0000>00000UKm00H0000>00h005Km0004
00h4000700h00`00CY]>V`09CY/4000=D]`00`00E_aFo00<E_`2000@Fa`00`00GaaO7002Ga`00`00
GcaO?00:Gc`01000HcaS?6<l0P0036=L0P004Woo00<007ooOol09goo000GOol00`00Oomoo`02Ool0
0`00Oomoo`0KOol00`00E_eFo@06E_d30002E_d00`00E_eFo@0;E_d00`00E_eFo@04E_d30002E_d0
1`00E_eFoEKm00003P00009Fo@0600003P0>001Fo@000`0>0`002@0>00<004jKCY/01DjK10000Tjl
00<005;LD]`03E;L00<005KlE_`025Kl0`0000=Fo000Fa`045/L00@005lL000000iO?005001S?000
He`0000;He`00`00Ig`0000COol2000WOol001aoo`8001eoo`03001FoEKm00=Fo@8000IFo@03001F
oEKm00]Fo@03001FoEKm00<000EFo@07001FoEKmE_d0000>00000eKm00D0000>00h005Km00<00003
00h0000000X03P03001>VdjK00@000M>_003001Bg5;L00eBg003001Fo5Kl00EFo08000EFo003001K
75/L00iK7080011O?08000=SG003001SG6=L00MSG005001WO6MlIg`0000BOol2000WOol001aoo`03
001oogoo01eoo`03001Fo@00008000UFo@03001FoEKm00YFo@<000QFo@8000=Fo@8000=Fo@030000
3P0000<000<03P8000P03PD000a>_003001Bg5;L00aBg003001Fo5Kl00=Fo08000QFo003001K75/L
00]K70800003Fc`005ll00eO?0800003Hed006=L00=SG003001SG6=L00ASG08000EWO003001oogoo
011oo`03001oogoo02Eoo`0077oo00<007ooOol07Woo0P0035Km00<005KmE_d01UKm0`0000=Fo@00
E_d025Km0P000eKm00@0000>001Fo@<0000400h005Km000400h00`0000h03P060003B[`00`00C[a>
_00<C[`00`00D]aBg00<D]`00`00E_`00002000;E_`00`00FaaK7008Fa`20004Fc`00`00GcaO?00:
Gc`00`00HeeSG@02Hed00`00HeaSG002He`00`00HeaSG002He`00`00IgaWO006Ig`00`00Oomoo`0@
Ool00`00Oomoo`0TOol001aoo`03001oogoo021oo`03001FoEKm00YFo@03001FoEKm00=Fo@8000EF
o@03001FoEKm00MFo@04001FoEKmE_d400001eKm00003P0>001Fo@0000@03P<000Y:_003001>_4jl
00a>_003001Bg5;L00]Bg08000mFo003001K75/L00EK708000MK?003001O?5ll00MO?08000ISG@05
001SG6=LHe`00003He`00`00IgaWO008Ig`00`00Oomoo`0@Ool00`00Oomoo`0SOol001]oo`03001o
ogoo029oo`03001FoEKm00YFo@03001Fo@00008000QFo@03001FoEKm00IFo@03001Fo@0000800005
00h005KmE_d0000300h2000400h00`00B[a:_00;B[`00`00C[a>_00;C[`00`00D]aBg008D]`30000
0e;m001Fo00?E_`00`00FaaK7002Fa`2000:Fc`00`00GcaO?004Gc`20009Hed01000HeaSG6=L0`00
2fMl0`0047oo0P0097oo000KOol00`00Oomoo`0SOol00`00E_eFo@08E_d3000<E_d00`00E_eFo@05
E_d20002E_d01P0000h03P00E_d000<03P8000D03P03001:_4Zl00]:_003001>_4jl00]>_003001B
g5;L00ABg0<000EBo@03001Fo5Kl00iFo004001K7000000=Fc`00`00GcaO?002Gc`00`00HeeSG@09
Hed01000HeaSG6=L0P002fMl00D006NMIieWW@00011oo`03001oogoo029oo`006goo00<007ooOol0
97oo00<005KmE_d015Km0`000eKm00<005KmE_d02UKm00@005KmE_eFo@D0009Fo@0600003P0>001F
o@000`0>0P001P0>00<004ZlB[`02dZl00<004jlC[`02djl00<005;LD]`00`002E;m00<005KlE_`0
3EKl0P0045/l00@005ll000000eSG@05001SG000Ig`0000:Ig`00`00IieWW@03Iid00`00Oomoo`0>
Ool00`00Oomoo`0QOol001]oo`03001oogoo02Eoo`03001FoEKm00<000MFo@03001FoEKm00YFo@<0
00=Fo@80009Fo@0600003P0>001Fo@000`0>0P001`0>00<004ZlB[`02TZl00<004jlC[`02Tjl1000
3E;m00<005KlE_`02EKl0`0000=K7@00Fc`03e/l0P003f=M0`000VMl00<006MlIg`01FMl0P001fNM
00<007ooOol03Goo00<007ooOol08Goo000KOol00`00Oomoo`0VOol2000;E_d00`00E_eFo@06E_d5
0004E_d20002E_d01P0000h03P00E_d000@03P0300003P0>00H03P03001:_4Zl00Y:_003001>_4jl
00E>_0@0009>g@03001BoE;m00aBo@03001Fo5Kl00IFo0<000EK7@03001K?5/l00]K?0800003Gcd0
06=M00aSG@8000=SO@04001WO6Ml0005Ig`00`00IieWW@07Iid2000?Ool2000QOol001]oo`03001o
ogoo02Qoo`03001FoEKm00UFo@03001FoEKm009Fo@D0009Fo@03001FoEKm009Fo@0300003P00009F
o@0600003P0>001Fo@000`0>0P001`0>00<004ZlB[`02dZl00<004jlC[`010001dkM00<005;mD_d0
35;m00<005KlE_`00eKl0P002E/M00<005/lFc`02E/l00<005lmGcd00Ulm00<006=MHed02F=M00<0
06=mHgd016=m00@006MlIg`0009WO08000UWW@04001W_FNm000>Ool00`00Oomoo`0POol001Yoo`03
001oogoo02Yoo`03001FoEKm00UFo@H000EFo@03001FoEKm009Fo@0300003P00009Fo@0600003P0>
001Fo@000`0>0P00200>00<004ZlB[`024Zl1@0034kM00<005;mD_d035;m00<005Kl00000P0035/M
00<005/lFc`01U/l0P001Ulm00<006=MHed01V=M0P0026=m00D006Ml001WO00000YWW@03001W_FNm
009W_@03001oogoo00aoo`03001oogoo01moo`006Woo0P00;7oo00<005KmE_d01UKm1@0025Km0P00
0eKm00<0000>00000UKm00H0000>00h005Km000300h2000900h01000B[a:_4Zl1P000d[M00<004kM
C]d02dkM00<005;mD_d035;m0P003e/M00<005/lFc`015/l0P002Elm00<006=MHed00f=M0P002f=m
00<006Ml00002FNM0P001VNm00<007ooOol037oo00<007ooOol07Woo000BOol30005Ool00`00Oomo
o`0/Ool00`00E_eFo@03E_d40003E_d00`00E_eFo@06E_d00`00E_eFo@02E_d20002E_d01P0000h0
3P00E_d000@03P0300003P0>00<03PP000Y:g@03001>gDkM00]>g@03001BoE;m00QBo@<00003Dad0
05/M00mK7@03001K?5/l009K?003001O?Elm00UO?@03001SGF=M009SG@03001SOF=m00]SO@800003
Iid006NM00IWW@03001W_FNm00IW_@<000aoo`03001oogoo00Moo`8000Aoo`03001oogoo00=oo`80
00=oo`<000=oo`004Goo00D007ooOomoo`0000Aoo`03001oogoo02eoo`03001Fo@0000<000MFo@03
001FoEKm00EFo@03001FoEKm009Fo@0500003P00E_d0000300h2000400h60005A[d00`00B]e:g@0;
B]d00`00C]e>g@0;C]d00`00D_eBo@05D_d20005Dad00`00FaeK7@0>Fad01000Fc`000003Elm00@0
06=M000000aSO@800005Hgd006NMIid00005Iid00`00IkeW_@06Ikd01000IkeW_FNm0P002goo0P00
1Woo00@007ooOol000Qoo`04001oogoo0003Ool00`00Oomoo`02Ool000]oo`D000Eoo`03001oogoo
009oo`03001oogoo02aoo`@000]Fo@03001FoEKm00AFo@8000=Fo@0500003P00E_d0000300h20004
00h00`00A[e6_@09A[d00`00B]e:g@0;B]d00`00C]e>g@0:C]d00`00D_eBo@03D_d20008Dad00`00
FaeK7@0=Fad2000?Gcd3000<Hgd00`00HgeSO@02Hgd00`00Iid00003Iid20008Ikd00`00IkeW_@04
Ikd00`00Oomoo`09Ool00`00Oomoo`04Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
009oo`004goo0P0017oo0P00:goo0`000goo00<005KmE_d02UKm00<005KmE_d00eKm0P000eKm00D0
000>001Fo@0000<03P8000D03P030016_DJm00U6_@03001:gD[M00]:g@03001>gDkM00Y>g@03001B
o@00008000]C7@03001K7E/M00UK7@<00003Fcd005lm00aO?@8000=OG@03001SOF=m00MSO@8000IS
O@05001WW@00Iid00008Ikd20007Ikd30009Ool00`00Oomoo`04Ool01000Oomoo`0027oo00@007oo
Ool000=oo`03001oogoo009oo`005Goo00<007ooOol00Woo00<007ooOol09Woo0`001goo00<005Km
E_d02UKm00<005KmE_d00UKm0P000eKm00<0000>00h00P000`0>0P001P0>00<004JmA[d02DJm00<0
04[MB]d02T[M00<004kMC]d02DkM0`003e<M00<005/MFad01U/M0P001E/m00<005lmGcd025lm0P00
1UmM00<006=mHgd016=m0P002F=m00<006NM000026Nm00<006NmIkd01VNm00D006OMImeWg@0000Uo
o`03001oogoo00=oo`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol00Woo000AOol01@00
Oomoogoo00000goo00<007ooOol097oo0`002goo00<005KmE_d025Km0`0015Km0P000UKm00H0000>
00h005Km000300h00`0000h03P0500h00`00A[e6_@09A[d00`00B]e:g@0:B]d00`00C]e>g@04C]d4
0003C_d00`00DaeC7@0=Dad00`00FaeK7@03Fad20008Fcd00`00GceO?@05Gcd20009Ged00`00HgeS
O@02Hgd00`00HgeSO@09Hgd30006Ikd20007Ikd20004Imd40005Ool30004Ool01000Oomoo`0027oo
00@007ooOol0009oo`8000Aoo`004Woo0`0017oo00<007ooOol08Goo0`003goo00<005KmE_d015Km
0`000UKm00<005KmE_d00UKm0P000UKm00H0000>00h005Km000300h2000700h00`00A[e6_@08A[d0
0`00B]e:g@0;B]d00`00C]e>g@030008C_d00`00DaeC7@0=Dad00`00Fad00002000;Fcd00`00GceO
?@02Gcd2000<Ged01000Hgd000002f=m00@006>NHiiSWP8000=W_@03001W_FNm00IW_@03001WgFOM
00=Wg@03001Wo6Ol009Wo0D00004Ool000000004Ool2000:Ool20004Ool00`00Oomoo`02Ool001Uo
o`80021oo`8001=oo`03001FoEKm00<000EFo@8000=Fo@80009Fo@0600003P0>001Fo@000`0>0P00
1`0>00<004JmA[d02DJm00<004[MB]d024[M1@0034km00<005<MDad035<M0P003e/m00@005lm0000
00iOG@8000]SO@8000ESWP800003Ikd006Nm00IW_@8000EWg@03001Wo6Ol009Wo004001Snf?kHo/5
000LOol001Uoo`03001oogoo01aoo`<001Ioo`8000UFo@09001FoEKmE_d0000?001Fo@0000<03P80
00<03P8000P03P030016_DJm00U6_@04001:gD[MB]d60003B_h00`00C_e>o@0<C_d00`00DaeC7@08
Dad300000e<n001K?@0>Fcd3000=Ged20002Ggh00`00HgeSO@06Hgd20008Hih30006Ikd00`00ImeW
g@04Imd00`00IoaWo002Io`01@00Ho]Snf?k00000Uoj00<007oo000077oo000IOol00`00Oomoo`0I
Ool3000JOol00`00E_eFo@07E_d01`00E_eFoEKm00003`00009Fo@0300003P0>008000@03P030000
3P0>00L03P030016_DJm00A6_@P000Y:oP03001>oDkm00a>o@03001C7E<M00AC7@<000EC?P03001K
?E/m00UK?@<000=KGP03001OGEmM00QOG@8000EOOP03001SOF=m00ASO@03001SWV>N00MSWP80009S
_P04001W_FNmIkd20005Imd20004Io`01@00Ho]Snf?k00000Uoj00D007ooOomoo`0001]oo`006Goo
00<007ooOol05Woo0`007Woo00<005KmE_d01UKm0P000UKm00<0000?00000UKm00<0000>00h00P00
100>4@001DKN00<004[nB_h02d[n00<004kmC_d034km00<005<MDad00`002E<n00<005/mFcd01U/m
0P001e]N00<005mMGed01EmM0P0025mn00@006=mHgeSO@8000QSWP80009S_P06001S_V>n001W_@00
1VOM00<006OlIo`00VOl0P000f?k00@005oj000000Aoo`03001oogoo01Uoo`0067oo0P005Goo0`00
8Woo00<005KmE_d01EKm0P000eKm00D0000?001Fo@0000803P8000@03P03000n_Sjn00Pn_P030016
gTKN00U6gP03001:oT[n00]:oP03001>oDkm00Y>o@@000eC?P03001K?E/m00=K?@8000YKGP03001O
GEmM009OG@8000]OOP03001SO@0000QSWP8000ES_P03001S_P00008000EWg@03001Wo6Ol009Wo004
001Snf?kHo/200000eoj001oo`05Ool00`00Oomoo`0IOol001Qoo`03001oogoo015oo`<002Ioo`03
001FoEKm00EFo@80009Fo@0500003`00E_d0000300h00`0000h03P0300h00`00?[hn_P08?[h00`00
A]i6gP09A]h00`00B_i:oP0;B_h00`00C_e>o@05C_d40003Cah00`00DciC?P0<Dch00`00Fcd00002
000=Feh01000Ged000003Emn0`001f>N00<006>nHkh01V>n00@006?NHmiSgP<00003Imd006Ol00=W
o005001Snf?kHo/00002GoX00`00Oomoo`05Ool00`00Oomoo`0IOol001Qoo`03001oogoo00moo`80
02Yoo`03001FoEKm00AFo@80009Fo@0500003`00E_d0000300h00`0000h03P0400h00`00?[hn_P08
?[h00`00A]i6gP09A]h00`00B_i:oP0;B_h00`00C_e>o@040008Cah00`00DciC?P0;Dch3000?Feh3
000;Ggh30003Gih20003Hih20007Hkh30005Hmh30003Io`01@00Ho]Snf?k00000Uoj00<007ooOol0
1Woo00<007ooOol06Goo000HOol00`00Oomoo`0<Ool3000]Ool00`00E_eFo@03E_d01@00010005Km
00000P0?0P000`0>0P001P0>00<003jn?[h023jn00<004KNA]h02DKN00<004[nB_h024[n1@003DlN
00<005<nDch01e<n0`000e<n00<005]NFeh02E]N0`000e]n00<005mnGgh01Umn0P0025nN00<006>N
00001f>n0P000f?N00D006?NHmiSgP0000=Oo@03001Wo00000=Sn`04001OnUoj0009Ool00`00Oomo
o`0IOol001Moo`8000]oo`<0031oo`03001FoEKm00=Fo@0500004000E_d0000200l2000300h20007
00h00`00?[hn_P08?[h00`00A]i6gP09A]h01000B_i:oT[n1P0014/N00<004lNCah034lN00<005<n
Dch00e<n0`001e<n00<005]NFeh01U]N0P001e]n00<005mnGgh00emn0P002UnN0`001V>n00<006?N
Hmh016?N0`0015om2@002Woo00<007ooOol06Goo000HOol00`00Oomoo`06Ool3000dOol00`00E_eF
o@03E_d2000015Km00003`0?0P00100>00<0000>00h01P0>00<003jn?[h023jn00<004KNA]h014KN
20002d/N00<004lNCah034lN00<005<n00000P002e<n00<005]NFeh00e]N0P002U]n00<005mn0000
0P002UnN0P000enn00@006>nHkiS_P8000ISgP<000AOo@05001Oo5olGo`00002Eo/00`00Oomoo`0;
Ool00`00Oomoo`0HOol001Qoo`03001oogoo00=oo`<003Qoo`03001FoEKm009Fo@0500004000E_d0
000200l00`0000h03P0200hK0007@_h00`00Bai;7P0:Bah00`00Cai?7P0:Cah4000>Dch00`00Feh0
0002000<Fgh3000:Gih20006Gkh00`00Hkh00007Hmh01000GoeOo@000Uom0P000Uol0P0000=Gn`00
00003Woo00<007ooOol067oo000GOol01000Oomoogoo0`00?7oo00T005KmE_eFo@00010005Km0000
0P0?0P00100>00<003Jn=[h023Jn00<003kN?]h023kN00<004;n@_h02D;n00<004/NBah02T/N00<0
04lNCah01DlN100014lo00<005<nDch02e<n0`0035]n0P000eMo00<005nNGih01EnN0P0025nn0`00
1F?N0P0015om0P000eol00@005OkEo/0011oo`03001oogoo01Qoo`005goo1000@7oo00@005KmE_d0
0080408000803`8000D03P03000f_SJn00Pf_P03000ngSkN00PngP030012oT;n00U2oP03001;7T/N
00Y;7P03001?7TlN00@000U??`03001C?U<n00MC?P<000=CG`03001KOU]n00IKOP<000IGO`03001O
WUnN009OWP8000QO_P8000=K_P<00003Hmh005om00EOo@80009Oo004001GneOk000AOol00`00Oomo
o`0HOol000ioo`D000Aoo`8004=oo`05001FoEKm00004002000300l00`0000h03P0400h00`00=[hf
_P08=[h00`00?]hngP08?]h00`00@_i2oP09@_h00`00Bai;7P07Bah5000>Ccl00`00DciC?P03Dch3
0007Del20004Fgh2000:Egl01000Gih0000025nn0P001e^n0`0015om0P0000EOo000000005Ok0080
019oo`03001oogoo01Qoo`003goo00@007ooOol000Ioo`03001oogoo041oo`04001FoEKm00020100
100000l03`0?1000100>00<003Jn=[h023Jn00<003kN?]h023kN00<004;n@_h02D;n00@004/NBai;
7PD000E;7`03001??dlo00a??`03001C?P00008000aCG`04001KOP00000<Egl30008Gkh00`00FkiK
_P05Fkh20003Fmh200000eom001Oo002Go`200000eOk001oo`0COol00`00Oomoo`0HOol000Qoo`D0
00=oo`03001oogoo00Moo`03001oogoo041oo`03001Fo@000080408000@03`03000VWP0000D000Xf
_P03000ngSkN00PngP030012oT;n00A2oPP000];7`03001??dlo00Y??`@000iCG`<000]GO`8000=G
W`8000AO_P8000IK_P8000IKgPT001Eoo`03001oogoo01Qoo`004Goo00<007ooOol01goo00<007oo
Ool0@7oo0P000P0@0P001@0?0P0012JN7@001d<O00<004/OBal02T/O00<004loCcl01Dlo100014mO
00<005=ODel025=O0`000e=o00<005MoEgl01EMo0`001eNO00@005nn000000MK_P03001KgU_N00AK
gP80009Gg@800003Cm`00000009oo`03001oogoo01=oo`03001oogoo01Moo`003Woo00D007ooOomo
o`0000Uoo`80045oo`80008040@000@03`03000VWRJN00@VWP03000bgc;O00Pbg`03000joc[o00Pj
o`0300137d<O00U37`03001;7d/O00Y;7`03001??dlo00@000U?G`03001CGe=O00ACG`<000MCO`03
001GOeMo009GO`8000YGW`<000IK_P8000AKgP<0009Gg@80009?g003001oogoo009oo`03001oogoo
01=oo`03001oogoo01Moo`003Woo00D007ooOomoo`0000]oo`03001oogoo03moo`<000804003000B
G@0000D000HVWP8000Tbg`03000joc[o00Pjo`0300137d<O00U37`03001;7d/O00M;7`D000i?G`03
001CGe=O00<000]CO`04001GO`00000:Eil20003Dkl300000e^n00000004Fmh20004Emd00`00Cma?
g0020006Ool00`00Oomoo`0BOol00`00Oomoo`0GOol000moo`<000eoo`03001oogoo041oo`H000@B
G@D000@VWP03000bgc;O00Lbg`03000joc[o00Pjo`0300137d<O00U37`04001;7d/OBal50005Acl0
0`00Cem?G`0:Cel4000>Dgl30008Eil30007Dkl40002Fmh20004Emd200000doL00000009Ool00`00
Oomoo`0AOol00`00Oomoo`0GOol0021oo`03001oogoo045oo`D000HBG@03000NWP0000D000Tbg`03
000joc[o00Pjo`0300137d<O00A37`P000]7?`8000I?G`@000A;G`03001COe=o00QCO`<000=?W`80
00AGW`8000QC_`8000AC_P@0009Gg@80009?g003001oogoo00Yoo`03001oogoo011oo`03001oogoo
01Moo`008Goo0P00@goo1`000a9M0P0011jN70001clO00<004LoAcl02dLo00<004mOCel00`002D]O
0P001E=o0`0024nO00@005NO000000MC_`<000AC_P8000A;_@H000eoo`03001oogoo011oo`03001o
ogoo01Moo`008goo00<007ooOol0@Goo00<005Km00002@001QjN00<002[O:]l01b[O00<003Ko=_l0
23Ko00<003lO?al02ClO0P002DLo1@003T]O00<005=o00000P002TnO10001U>o0P0015>n0`0014^m
0P000T>l0P0047oo00<007ooOol03goo00<007ooOol05goo000TOol00`00Oomoo`11Ool00`00E_eF
o@0400030S/500037Yh20008:]l20009=_l2000;?al01000Acm7?dLo1@001D=O0P002T]O1@0024nO
100014nO0`0000=C_`00000015>n0P0014^m0`0000A3_000000001=oo`03001oogoo00moo`03001o
ogoo01Ioo`009Goo00<007ooOol0@Goo0P0015Km10000P8k20002B[O00<003Ko=_l023Ko00<003lO
?al013lO200034=O00@004]OBem;G`H000E7O`<0009?W`<000U?W`D0009C_P8000A;_@800093_080
01Ioo`03001oogoo00moo`03001oogoo01Ioo`009Woo0P00@goo00<005KmE_d015Km1`000aJM7000
1c/o0P002T=O1@0034Mo100024nO10001DNO10000T^m0P000T>l0P006Goo00<007ooOol03Woo00<0
07ooOol05Woo000XOol00`00Oomoo`11Ool00`00E_eFo@06E_d800025Yd200088]h00`00;al_7`08
;al2000;>cl20003@el50004?el20007Agl40004@gl30002Cil30006Ail30003?id7000LOol00`00
Oomoo`0=Ool00`00Oomoo`0FOol002Uoo`03001oogoo045oo`03001FoEKm00AFo@<0009Fo@X000LR
gP8000X_7`8000Hk?`P000/oG`800097O`<000U3O`@000I7W`<000<oW@<00004<g/00000000POol0
0`00Oomoo`0<Ool00`00Oomoo`0FOol002Yoo`03001oogoo045oo`03001FoEKm00<000IFo@03001F
o@00008000<6F`L000<RgP03000_7blO00@_7`/000Lg?`8000ToG`D000Q3O`@000@kOP800004Ail0
00000003?id3000013=k000000008goo00<007ooOol037oo00<007ooOol05Woo000[Ool20012Ool2
000:E_d01000E_eFoEKm1P0000<6F`0000002`001bKn0P002cLo00@003mO?eloG`D000DkG`<00093
O`<000PkOPd002Moo`03001oogoo00]oo`03001oogoo01Ioo`00;Goo00<007ooOol0@7oo00<005Km
E_d02EKm00@005KmE_eFo@l000045[d0000000099_h00`00=clg?`04=cl8000:>el70004>gh50000
0c=L00000006000/Ool00`00Oomoo`0;Ool00`00Oomoo`0EOol002ioo`03001oogoo041oo`03001F
oEKm00QFo@@000UFo@03001FoEKm01L000L[?P<000<kG`D000D_G@H000<cG0H0039oo`03001oogoo
00Yoo`03001oogoo01Eoo`00;goo00<007ooOol0@7oo00<005KmE_d015Km0`000UKm00<005KmE_d0
2EKm00<005KmE_d00UKm400000@Jg@00000000D[?PT000@_G@D0008O6`P003Moo`03001oogoo00Yo
o`03001oogoo01Eoo`00<7oo00<007ooOol0@7oo00<005KmE_d00`001UKm00<005KmE_d02EKm00<0
05KmE_d00`0037oo7`00@7oo00<007ooOol02Goo00<007ooOol05Goo000aOol20011Ool2000:E_d0
0`00E_eFo@08E_d3001_Ool00`00Oomoo`08Ool00`00Oomoo`0EOol003=oo`03001oogoo041oo`03
001FoEKm00QFo@03001FoEKm00AFo@<0079oo`03001oogoo00Qoo`03001oogoo01Eoo`00=7oo00<0
07ooOol0@7oo00<005KmE_d025Km00<005KmE_d00`00MWoo00<007ooOol01goo00<007ooOol05Goo
000eOol00`00Oomoo`10Ool00`00E_eFo@06E_d4001jOol00`00Oomoo`07Ool00`00Oomoo`0DOol0
03Ioo`80045oo`03001FoEKm00D007moo`03001oogoo00Ioo`03001oogoo01Aoo`00>7oo00<007oo
Ool0?goo0P00Q7oo00<007ooOol01Woo00<007ooOol057oo000iOol00`00Oomoo`0nOol00`00Oomo
o`24Ool00`00Oomoo`05Ool00`00Oomoo`0DOol003Yoo`03001oogoo03eoo`03001oogoo08Eoo`03
001oogoo00Aoo`03001oogoo01Aoo`00>goo0P00?Goo00<007ooOol0QWoo00<007ooOol00goo00<0
07ooOol057oo000mOol00`00Oomoo`0jOol00`00Oomoo`26Ool00`00Oomoo`03Ool00`00Oomoo`0D
Ool003ioo`03001oogoo03Uoo`03001oogoo08Moo`03001oogoo00=oo`03001oogoo01=oo`00?goo
00<007ooOol0>7oo00<007ooOol0R7oo00<007ooOol00Woo00<007ooOol04goo0010Ool2000hOol0
0`00Oomoo`29Ool01@00Oomoogoo00005Goo0012Ool00`00Oomoo`0eOol00`00Oomoo`29Ool01@00
Oomoogoo00005Goo0013Ool00`00Oomoo`0dOol00`00Oomoo`2:Ool01000Oomoo`005Goo0014Ool0
0`00Oomoo`0cOol00`00Oomoo`2;Ool00`00Ool0000EOol004Eoo`8003=oo`03001oogoo08]oo`03
001oo`0001Eoo`00Agoo00<007ooOol0<7oo00<007ooOol0S7oo00<007oo000057oo0018Ool00`00
Oomoo`0_Ool00`00Oomoo`2=Ool2000DOol004Uoo`03001oogoo02eoo`03001oogoo08eoo`<001Ao
o`00BWoo0P00;Goo00<007ooOol0RGoo10005goo001<Ool00`00Oomoo`0ZOol00`00Oomoo`25Ool4
000KOol004eoo`03001oogoo02Uoo`03001oogoo085oo`@001moo`00CWoo00<007ooOol0:7oo00<0
07ooOol0OWoo0`008goo001?Ool2000XOol00`00Oomoo`1jOol4000VOol0055oo`03001oogoo02Eo
o`03001oogoo07Ioo`@002Yoo`00DWoo00<007ooOol097oo00<007ooOol0LWoo1000;Woo001COol0
0`00Oomoo`0SOol00`00Oomoo`1^Ool4000bOol005Aoo`8002=oo`03001oogoo06Yoo`@003Ioo`00
EWoo00<007ooOol087oo00<007ooOol0IWoo1000>Woo001GOol00`00Oomoo`0OOol00`00Oomoo`1S
Ool3000nOol005Qoo`03001oogoo01ioo`03001oogoo05moo`@0045oo`00FGoo0P007Woo00<007oo
Ool0Fgoo1000AGoo001KOol00`00Oomoo`0KOol00`00Oomoo`1GOol40019Ool005aoo`03001oogoo
01Yoo`03001oogoo05=oo`@004eoo`00GGoo00<007ooOol06Goo00<007ooOol0Cgoo1000DGoo001N
Ool2000IOol00`00Oomoo`1;Ool4001EOol0061oo`03001oogoo01Ioo`03001oogoo04Moo`@005Uo
o`00HGoo00<007ooOol05Goo00<007ooOol0A7oo0`00GGoo001ROol00`00Oomoo`0DOol00`00Oomo
o`10Ool4001POol006=oo`03001oogoo01=oo`03001oogoo03aoo`@006Aoo`00I7oo0P004goo00<0
07ooOol0>7oo1000J7oo001VOol00`00Oomoo`0@Ool00`00Oomoo`0dOol4001/Ool006Moo`03001o
ogoo00moo`03001oogoo031oo`@0071oo`00J7oo00<007ooOol03Woo00<007ooOol0;7oo1000M7oo
001YOol2000=Ool00`00Oomoo`0YOol4001hOol006]oo`03001oogoo00Yoo`03001oogoo02Ioo`<0
07aoo`00K7oo00<007ooOol02Goo00<007ooOol08Woo1000Ogoo001]Ool00`00Oomoo`08Ool00`00
Oomoo`0NOol40023Ool006ioo`8000Qoo`03001oogoo01Yoo`@008Moo`00L7oo00<007ooOol01Goo
00<007ooOol05Woo1000Rgoo001aOol00`00Oomoo`04Ool00`00Oomoo`0BOol4002?Ool0079oo`03
001oogoo00=oo`03001oogoo00ioo`@009=oo`00Lgoo0P000goo00<007ooOol02goo0`00Ugoo001e
Ool01000Oomoo`002Goo1000VWoo001fOol00`00Ool00005Ool4002NOol007Moo`800003Ool00000
00800:9oo`00N7oo0P00YWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0907936, -0.0254072, \
0.00390173, 0.00390173}}],

Cell[BoxData[
    \({2.480548891438559`, {f \[Rule] 0.019822040849929414`, 
        fc \[Rule] \(-0.0035992913227209425`\)}}\)], "Output",
  CellLabel->"Out[190]=  (11:01:14 on 8/14/00)"]
}, Open  ]],

Cell[TextData[{
  "Note that there are strong constraints on the values of these moments.  \
The option Compiled\[Rule]True is used to ensure that the numerical value ",
  Cell[BoxData[
      \(TraditionalForm\`\(-10\^10\)\)]],
  "is returned for invalid combinations."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00`0001804P000000bX2@?oaooL3>@99:P85N0?N0@00004/0B`000003Bl9H001
0000I0000@400@0000000BL?0040000000000000000000000000000000000?o2
omX=K@V600P100000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 36, 0, 36, "SubsectionIcon"],
Cell[1778, 53, 164, 4, 22, "Text"],
Cell[1945, 59, 74, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2044, 63, 237, 4, 42, "Input"],
Cell[2284, 69, 452, 11, 35, "Output"]
}, Open  ]],
Cell[2751, 83, 56, 0, 28, "MathCaption"],
Cell[2810, 85, 121, 2, 27, "Input"],
Cell[2934, 89, 141, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3100, 96, 527, 11, 62, "Input"],
Cell[3630, 109, 3293, 57, 249, "Output"]
}, Closed]],
Cell[6938, 169, 371, 9, 32, "Text"],
Cell[7312, 180, 196, 6, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7533, 190, 457, 11, 58, "Input"],
Cell[7993, 203, 106, 2, 20, "Output"]
}, Open  ]],
Cell[8114, 208, 282, 9, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[8421, 221, 594, 14, 77, "Input"],
Cell[9018, 237, 14351, 394, 184, 3559, 256, "GraphicsData", "PostScript", \
"Graphics"],
Cell[23372, 633, 138, 2, 20, "Output"]
}, Open  ]],
Cell[23525, 638, 287, 9, 32, "MathCaption"],

Cell[CellGroupData[{
Cell[23837, 651, 589, 14, 73, "Input"],
Cell[24429, 667, 15603, 417, 184, 3844, 267, "GraphicsData", "PostScript", \
"Graphics"],
Cell[40035, 1086, 139, 2, 20, "Output"]
}, Open  ]],
Cell[40189, 1091, 463, 13, 50, "MathCaption"],

Cell[CellGroupData[{
Cell[40677, 1108, 777, 17, 73, "Input"],
Cell[41457, 1127, 54952, 1185, 240, 20648, 757, "GraphicsData", "PostScript", \
"Graphics"],
Cell[96412, 2314, 187, 3, 20, "Output"]
}, Open  ]],
Cell[96614, 2320, 281, 6, 24, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

