(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     78097,       2467]*)
(*NotebookOutlinePosition[     79386,       2509]*)
(*  CellTagsIndexPosition[     79244,       2501]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Presenting results", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"PresentResults", "[", 
              RowBox[{
                StyleBox["results",
                  FontSlant->"Italic"], ",", " ", \({m, \ p}\), ",", " ", 
                StyleBox["options",
                  FontSlant->"Italic"]}], 
              "]"}], \(gives\ a\ table\ which\ presents\ the\ mean\ and\ \
standard\ deviation\ of\ log \((L)\)\ and\ \[Kappa]\_\(0, 2\), \ \
\[Kappa]\_\(1, 1\), \ \[Kappa]\_\(1, 2\), \ \[Kappa]\_\(2, 2\) . \ \ The\ \
same\ set\ of\ options\ should\ be\ given\ as\ for\ the\ run\ of\ \
DoReplicates[]\ which\ generated\ the\ results; \ {m, \ 
                p}\ were\ the\ migration\ rate\ and\ true\ allele\ frequency\ \
used\ in\ \(\(DoReplicates[]\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"PresentResults"],

Cell["This summarises results from the above example:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PresentResults[results, {0.2, 0.3}, MethodP \[Rule] {Fit, Sample}, 
        MethodC -> {HWLE, Fit, Sample, TrueC2, True}] // TableForm\)], "Input",\

  CellLabel->"In[83]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\("allele\nfrequencies"\), "\<\"moments\"\>", \("log(L)\nmean"\), 
            \("\nvariance"\), "\<\"d.f.\"\>", \("#\ninvalid"\), 
            \("\!\(\[Kappa]\_\(0, 2\)\)\nmean"\), \("\ns.d."\), 
            \("\!\(\[Kappa]\_\(1, 1\)\)\nmean"\), \("\ns.d."\), 
            \("\!\(\[Kappa]\_\(1, 2\)\)\nmean"\), \("\ns.d."\), 
            \("\!\(\[Kappa]\_\(2, 2\)\)\nmean"\), \("\ns.d."\)},
          {"\<\"fit \\!\\(p\\_i\\)\"\>", "\<\"HWLE\"\>", 
            TagBox[
              InterpretationBox["\<\"    -61.68\"\>",
                -61.684180524504413,
                AutoDelete->True],
              (PaddedForm[ #, {8, 2}]&)], 
            TagBox[
              InterpretationBox["\<\"    178.72\"\>",
                178.71998401417815,
                AutoDelete->True],
              (PaddedForm[ #, {8, 2}]&)], "23", "0", 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)]},
          {"\<\"fit \\!\\(p\\_i\\)\"\>", 
            "\<\"fit all \\!\\(\[Kappa]\\_\\(j, k\\)\\)\"\>", 
            TagBox[
              InterpretationBox["\<\"     -8.49\"\>",
                -8.4853770862456486,
                AutoDelete->True],
              (PaddedForm[ #, {8, 2}]&)], 
            TagBox[
              InterpretationBox["\<\"      3.56\"\>",
                3.556837616573886,
                AutoDelete->True],
              (PaddedForm[ #, {8, 2}]&)], "15", "0", 
            TagBox[
              InterpretationBox["\<\"   0.1010\"\>",
                0.1010216427128712,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0205\"\>",
                0.020460425754998873,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0411\"\>",
                0.041110889245252927,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0244\"\>",
                0.024387241945199336,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0155\"\>",
                0.015484353509000504,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0094\"\>",
                0.0094444864532642545,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0037\"\>",
                0.0036677641911927019,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0028\"\>",
                0.0028420158082778446,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)]},
          {"\<\"fit \\!\\(p\\_i\\)\"\>", 
            "\<\"sample \\!\\(\[Kappa]\\_\\(j, k\\)\\)\"\>", 
            TagBox[
              InterpretationBox["\<\"     -8.67\"\>",
                -8.671629803098412,
                AutoDelete->True],
              (PaddedForm[ #, {8, 2}]&)], 
            TagBox[
              InterpretationBox["\<\"      3.86\"\>",
                3.8561023697107877,
                AutoDelete->True],
              (PaddedForm[ #, {8, 2}]&)], "15", "2", 
            TagBox[
              InterpretationBox["\<\"   0.1010\"\>",
                0.10096416666666666,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0208\"\>",
                0.020838257954991463,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0422\"\>",
                0.042165833333333333,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0205\"\>",
                0.020491339803547372,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0167\"\>",
                0.016659100000000003,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0090\"\>",
                0.0089548077405070241,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0046\"\>",
                0.0045758853819444457,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0030\"\>",
                0.0030192823067560983,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)]},
          {"\<\"fit \\!\\(p\\_i\\)\"\>", 
            "\<\"true \\!\\(\[Kappa]\\_\\(1, 1\\)\\), \\!\\(\[Kappa]\\_\\(0, \
2\\)\\)\"\>", 
            TagBox[
              InterpretationBox["\<\"     -9.40\"\>",
                -9.3965147138579503,
                AutoDelete->True],
              (PaddedForm[ #, {8, 2}]&)], 
            TagBox[
              InterpretationBox["\<\"      3.30\"\>",
                3.2952968320179812,
                AutoDelete->True],
              (PaddedForm[ #, {8, 2}]&)], "17", "1", 
            TagBox[
              InterpretationBox["\<\"   0.0980\"\>",
                0.09799999999999999,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0420\"\>",
                0.041999999999999989,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0175\"\>",
                0.01753913983692993,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0088\"\>",
                0.0087959156498182596,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0065\"\>",
                0.0065135993984217766,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0061\"\>",
                0.0060943920054846792,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)]},
          {"\<\"fit \\!\\(p\\_i\\)\"\>", 
            "\<\"true \\!\\(\[Kappa]\\_\\(j, k\\)\\)\"\>", 
            TagBox[
              InterpretationBox["\<\"    -12.63\"\>",
                -12.628499835167919,
                AutoDelete->True],
              (PaddedForm[ #, {8, 2}]&)], 
            TagBox[
              InterpretationBox["\<\"      8.46\"\>",
                8.4601243982390777,
                AutoDelete->True],
              (PaddedForm[ #, {8, 2}]&)], "23", "0", 
            TagBox[
              InterpretationBox["\<\"   0.0980\"\>",
                0.09799999999999999,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0420\"\>",
                0.041999999999999989,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0168\"\>",
                0.016799999999999992,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0063\"\>",
                0.0063279999999999986,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)]},
          {"\<\"sample \\!\\(p\\_i\\)\"\>", "\<\"HWLE\"\>", 
            TagBox[
              InterpretationBox["\<\"    -61.68\"\>",
                -61.684177101605158,
                AutoDelete->True],
              (PaddedForm[ #, {8, 2}]&)], 
            TagBox[
              InterpretationBox["\<\"    178.72\"\>",
                178.71995090941516,
                AutoDelete->True],
              (PaddedForm[ #, {8, 2}]&)], "23", "0", 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)]},
          {"\<\"sample \\!\\(p\\_i\\)\"\>", 
            "\<\"fit all \\!\\(\[Kappa]\\_\\(j, k\\)\\)\"\>", 
            TagBox[
              InterpretationBox["\<\"     -8.62\"\>",
                -8.6189500846236804,
                AutoDelete->True],
              (PaddedForm[ #, {8, 2}]&)], 
            TagBox[
              InterpretationBox["\<\"      3.59\"\>",
                3.5859192057036324,
                AutoDelete->True],
              (PaddedForm[ #, {8, 2}]&)], "15", "0", 
            TagBox[
              InterpretationBox["\<\"   0.1009\"\>",
                0.10090914587791296,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0220\"\>",
                0.021954708334002801,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0394\"\>",
                0.039389333339008369,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0189\"\>",
                0.018923987042406099,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0155\"\>",
                0.015460450528885478,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0067\"\>",
                0.006713176322448596,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0041\"\>",
                0.0040712287745814984,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0024\"\>",
                0.0024165486401623278,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)]},
          {"\<\"sample \\!\\(p\\_i\\)\"\>", 
            "\<\"sample \\!\\(\[Kappa]\\_\\(j, k\\)\\)\"\>", 
            TagBox[
              InterpretationBox["\<\"     -9.46\"\>",
                -9.4594177997983024,
                AutoDelete->True],
              (PaddedForm[ #, {8, 2}]&)], 
            TagBox[
              InterpretationBox["\<\"      3.03\"\>",
                3.030828348290179,
                AutoDelete->True],
              (PaddedForm[ #, {8, 2}]&)], "15", "7", 
            TagBox[
              InterpretationBox["\<\"   0.1010\"\>",
                0.10096416666666666,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0208\"\>",
                0.020838257954991463,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0422\"\>",
                0.042165833333333333,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0205\"\>",
                0.020491339803547372,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0167\"\>",
                0.016659100000000003,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0090\"\>",
                0.0089548077405070241,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0046\"\>",
                0.0045758853819444457,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0030\"\>",
                0.0030192823067560983,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)]},
          {"\<\"sample \\!\\(p\\_i\\)\"\>", 
            "\<\"true \\!\\(\[Kappa]\\_\\(1, 1\\)\\), \\!\\(\[Kappa]\\_\\(0, \
2\\)\\)\"\>", 
            TagBox[
              InterpretationBox["\<\"    -10.07\"\>",
                -10.067597020074075,
                AutoDelete->True],
              (PaddedForm[ #, {8, 2}]&)], 
            TagBox[
              InterpretationBox["\<\"      3.65\"\>",
                3.6451093590400325,
                AutoDelete->True],
              (PaddedForm[ #, {8, 2}]&)], "17", "2", 
            TagBox[
              InterpretationBox["\<\"   0.0980\"\>",
                0.09799999999999999,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0420\"\>",
                0.041999999999999989,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0169\"\>",
                0.016898536167280452,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0089\"\>",
                0.0089216813655026428,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0059\"\>",
                0.0058892335939652578,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0063\"\>",
                0.006250776641464951,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)]},
          {"\<\"sample \\!\\(p\\_i\\)\"\>", 
            "\<\"true \\!\\(\[Kappa]\\_\\(j, k\\)\\)\"\>", 
            TagBox[
              InterpretationBox["\<\"    -14.43\"\>",
                -14.4255246477975,
                AutoDelete->True],
              (PaddedForm[ #, {8, 2}]&)], 
            TagBox[
              InterpretationBox["\<\"     12.71\"\>",
                12.708339123118082,
                AutoDelete->True],
              (PaddedForm[ #, {8, 2}]&)], "23", "1", 
            TagBox[
              InterpretationBox["\<\"   0.0980\"\>",
                0.09799999999999999,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0420\"\>",
                0.041999999999999989,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0168\"\>",
                0.016799999999999992,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0063\"\>",
                0.0063279999999999986,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], 
            TagBox[
              InterpretationBox["\<\"   0.0000\"\>",
                0,
                Editable->False],
              (PaddedForm[ #, {7, 4}]&)]},
          {"\<\"\"\>", \("true\ncumulants"\), "\<\"\"\>", "\<\"\"\>", 
            "\<\"\"\>", "\<\"\"\>", 
            TagBox[
              InterpretationBox["\<\"   0.0980\"\>",
                0.09799999999999999,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], "\<\"\"\>", 
            TagBox[
              InterpretationBox["\<\"   0.0420\"\>",
                0.041999999999999996,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], "\<\"\"\>", 
            TagBox[
              InterpretationBox["\<\"   0.0168\"\>",
                0.016799999999999995,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], "\<\"\"\>", 
            TagBox[
              InterpretationBox["\<\"   0.0063\"\>",
                0.0063279999999999968,
                AutoDelete->True],
              (PaddedForm[ #, {7, 4}]&)], "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[83]//TableForm="]
}, Open  ]],

Cell["\<\
Where allele frequencies or moments are calculated from the sample, \
the degrees of freedom are counted as if the parameters had been fitted.  \
Those cases where the initial parameter combination was invalid are excluded \
from statistics on log. likelihood, but not from those for the \
cumulants.\
\>", "Text"],

Cell["\<\
The last row gives the true cumulants used to generate the \
replicate samples.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"CompareLogL", "[", 
              RowBox[{
                StyleBox["results",
                  FontSlant->"Italic"], ",", \({i, j}\)}], 
              "]"}], \(compares\ the\ likelihood\ of\ method\ i\ with\ that\ \
of\ method\ j, \ 
            using\ a\ set\ of\ replicates\ generated\ by\ DoReplicates[] . \ \
\ Returns\ a\ list\ of\ the\ differences\ in\ \(log \(\((likelihood)\)\(.\)\)\
\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"CompareLogL"],

Cell["\<\
This compares the second and fifth hypotheses in the table above: \
allele frequencies fitted, and either all cumulants fitted, or all cumulants \
held at their true values.  This comparison involves 8 degrees of \
freedom:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CompareLogL[results, {2, 5}]\)], "Input",
  CellLabel->"In[134]:="],

Cell[BoxData[
    \({4.14041189093313732`, 5.32498793188335639`, 5.42831170633758119`, 
      7.9658925029735883`, 8.80228669890936998`, 8.96578638284779572`, 
      12.2139422683568454`, 12.2579622048507408`, 12.54384980707266`, 
      13.3495940732362905`}\)], "Output",
  CellLabel->"Out[134]="]
}, Open  ]],

Cell["\<\
This compares the second and fourth hypotheses in the table above: \
allele frequencies fitted, and either all cumulants fitted, or pairwise \
cumulants held at their true values, and the remaining cumulants fitted.  \
This comparison involves 2 degrees of freedom:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CompareLogL[results, {2, 4}]\)], "Input",
  CellLabel->"In[123]:="],

Cell[BoxData[
    \({\(-1.62355860195168588`\), 0.295346705629413008`, 
      1.06672191926395498`, 1.14297249723801996`, 1.16406482793956911`, 
      1.65070122259089657`, 2.16759305664891144`, 3.87663936123419716`, 
      4.24267118936234055`, 1.99999999838516657`*^10}\)], "Output",
  CellLabel->"Out[123]="]
}, Open  ]],

Cell["\<\
The first value is negative.  This indicates that the Metropolis \
algorithm was not run long enough to truly maximise the likelihood.  The last \
value is extremely large, reflecting the fact that for this sample, the \
allele frequencies and moments are incompatible with eachother.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"PresentLogL", "[", 
              RowBox[{
                StyleBox["results",
                  FontSlant->"Italic"], ",", \({{j, k}, \[Ellipsis]}\), ",", 
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["df",
                        FontSlant->"Italic"], \(j, k\)], ",", 
                    "\[Ellipsis]"}], "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["name",
                        FontSlant->"Italic"], \(j, k\)], ",", 
                    "\[Ellipsis]"}], "}"}], ",", "P"}], "]"}], 
            RowBox[{
            "presents", " ", "a", " ", "table", " ", "summarising", " ", "a", 
              " ", "list", " ", "of", " ", "comparisons", " ", "based", " ", 
              "on", " ", 
              StyleBox["results",
                FontSlant->"Italic"], " ", "produced", " ", "by", " ", 
              \(DoReplicates[] . \ \ {{j, k}, \[Ellipsis]}\), " ", "is", " ", 
              "a", " ", "list", " ", "of", " ", "comparisons", " ", 
              "between", " ", "method", " ", "j", " ", "and", " ", "method", 
              " ", "k", " ", "in", " ", 
              RowBox[{
                StyleBox["results",
                  FontSlant->"Italic"], ".", " ", 
                RowBox[{"{", 
                  RowBox[{
                    SubscriptBox[
                      StyleBox["df",
                        FontSlant->"Italic"], \(j, k\)], ",", 
                    "\[Ellipsis]"}], "}"}]}], " ", "and", " ", 
              RowBox[{"{", 
                RowBox[{
                  SubscriptBox[
                    StyleBox["name",
                      FontSlant->"Italic"], \(j, k\)], ",", "\[Ellipsis]"}], 
                "}"}], " ", "give", " ", "the", " ", "corresponding", " ", 
              "degrees", " ", "of", " ", "freedom", " ", "and", " ", "names", 
              " ", "of", " ", "the", " ", \(comparisons . \ \ P\), " ", "is", 
              " ", "the", " ", "significance", " ", \(level . \)}]}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["\<\
This is a table summarising comparisons in log(likelihood) for a \
table of 2 locus results.  The tests compare HWLE (method 1); fixing just \
pairwise associations at their true values (method 4); and fixing all \
cumulants at their true values (method 5) with fitting all cumulants (method \
2).  The corresponding degrees of freedom for each comparison are {4, 2, 4}.  \
\
\>", "Text"],

Cell[TextData[{
  "Some results may be invalid if the combination of cumulants and allele \
frequencies gave negative genotype frequencies; log(L) is then set to ",
  Cell[BoxData[
      \(TraditionalForm\`\(-10\^10\)\)]],
  ".  Such cases are ignored here."
}], "Text"],

Cell[TextData[
"The mean and variance of \[CapitalDelta]log(L) should equal d.f./2, \
d.f./2."], "Text"],

Cell["\<\
Some comparisons are negative, implying that fitting more \
parameters gives a lower likelihood.  This can happen when the Metropolis \
algorithm fails to find the global optimum.\
\>", "Text"],

Cell[TextData[{
  "The last column shows the numbers rejected at the 5% level.  This fraction \
may deviate from 5% if the asymptotic ",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/2\) \[Chi]\^2\)]],
  "distribution is not a good approximation."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PresentLogL[
        results2, {{2, 1}, {2, 4}, {2, 5}}, {4, 2, 4}, {"\<HWLE\>", 
          \*"\"\<\!\(\[Kappa]\_\(1, 1\)\), \!\(\[Kappa]\_\(0, 2\)\)\>\"", 
          \*"\"\<all \!\(\[Kappa]\_\(j, k\)\)\>\""}, 0.05] // TableForm\)], 
  "Input",
  CellLabel->"(Dialog) In[220]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", \("# valid\nresults"\), \("log(L)\nmean"\), 
            \("\nvariance"\), \("# negative\nvalues"\), 
            \("# rejected\n at P=0.05"\)},
          {"\<\"HWLE\"\>", "100", "36.2672328139054656`", 
            "111.524460149862725`", "0", "100"},
          {
            "\<\"\\!\\(\[Kappa]\\_\\(1, 1\\)\\), \\!\\(\[Kappa]\\_\\(0, \
2\\)\\)\"\>", "98", "0.786321065026775567`", "0.740258906050887599`", "9", 
            "3"},
          {"\<\"all \\!\\(\[Kappa]\\_\\(j, k\\)\\)\"\>", "100", 
            "1.81284591334807032`", "1.46646339967197647`", "0", "4"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"(Dialog) Out[220]//TableForm="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"PlotLogL", "[", 
              FormBox[
                RowBox[{
                  StyleBox["results",
                    FontSlant->"Italic"], ",", \({{j, k}, \[Ellipsis]}\), ",",
                   
                  RowBox[{"{", 
                    RowBox[{
                      SubscriptBox[
                        StyleBox["df",
                          FontSlant->"Italic"], \(j, k\)], ",", 
                      "\[Ellipsis]"}], "}"}]}],
                "TraditionalForm"], 
              "]"}], \(plots\ the\ cumulative\ distributions\ of\ \(\
\[CapitalDelta]log \((L)\)\), \ 
            and\ the\ asymptotic\ \(1\/2\) \[Chi]\^2\ distribution . \ \ Uses\
\ results\ produced\ by\ \(\(DoReplicates[]\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"PlotLogL"],

Cell["\<\
These are plots comparing the cumulative distribution of \
\[CapitalDelta]log(L) with the asymptotic expectation, for the three tests \
above:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PlotLogL[results2, {{2, 1}, {2, 4}, {2, 5}}, {4, 2, 4}]\)], "Input",
  CellLabel->"(Dialog) In[220]:="],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0139799 0.0147151 0.588604 [
[.16361 .00222 -6 -9 ]
[.16361 .00222 6 0 ]
[.30341 .00222 -6 -9 ]
[.30341 .00222 6 0 ]
[.44321 .00222 -6 -9 ]
[.44321 .00222 6 0 ]
[.58301 .00222 -6 -9 ]
[.58301 .00222 6 0 ]
[.7228 .00222 -6 -9 ]
[.7228 .00222 6 0 ]
[.8626 .00222 -6 -9 ]
[.8626 .00222 6 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16361 .01472 m
.16361 .02097 L
s
[(10)] .16361 .00222 0 1 Mshowa
.30341 .01472 m
.30341 .02097 L
s
[(20)] .30341 .00222 0 1 Mshowa
.44321 .01472 m
.44321 .02097 L
s
[(30)] .44321 .00222 0 1 Mshowa
.58301 .01472 m
.58301 .02097 L
s
[(40)] .58301 .00222 0 1 Mshowa
.7228 .01472 m
.7228 .02097 L
s
[(50)] .7228 .00222 0 1 Mshowa
.8626 .01472 m
.8626 .02097 L
s
[(60)] .8626 .00222 0 1 Mshowa
.125 Mabswid
.05177 .01472 m
.05177 .01847 L
s
.07973 .01472 m
.07973 .01847 L
s
.10769 .01472 m
.10769 .01847 L
s
.13565 .01472 m
.13565 .01847 L
s
.19157 .01472 m
.19157 .01847 L
s
.21953 .01472 m
.21953 .01847 L
s
.24749 .01472 m
.24749 .01847 L
s
.27545 .01472 m
.27545 .01847 L
s
.33137 .01472 m
.33137 .01847 L
s
.35933 .01472 m
.35933 .01847 L
s
.38729 .01472 m
.38729 .01847 L
s
.41525 .01472 m
.41525 .01847 L
s
.47117 .01472 m
.47117 .01847 L
s
.49913 .01472 m
.49913 .01847 L
s
.52709 .01472 m
.52709 .01847 L
s
.55505 .01472 m
.55505 .01847 L
s
.61097 .01472 m
.61097 .01847 L
s
.63893 .01472 m
.63893 .01847 L
s
.66689 .01472 m
.66689 .01847 L
s
.69484 .01472 m
.69484 .01847 L
s
.75076 .01472 m
.75076 .01847 L
s
.77872 .01472 m
.77872 .01847 L
s
.80668 .01472 m
.80668 .01847 L
s
.83464 .01472 m
.83464 .01847 L
s
.89056 .01472 m
.89056 .01847 L
s
.91852 .01472 m
.91852 .01847 L
s
.94648 .01472 m
.94648 .01847 L
s
.97444 .01472 m
.97444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.04258 .24326 L
.05214 .36859 L
.06237 .4631 L
.06781 .49847 L
.07277 .52345 L
.07774 .54295 L
.08245 .55721 L
.08793 .56982 L
.09299 .57848 L
.09854 .58551 L
.10443 .59086 L
.10934 .59409 L
.11383 .59632 L
.11901 .59825 L
.12393 .59959 L
.12846 .60052 L
.13266 .60117 L
.13728 .60172 L
.1422 .60215 L
.14754 .60249 L
.15246 .60271 L
.15786 .60289 L
.16058 .60296 L
.16357 .60302 L
.16859 .60311 L
.17398 .60317 L
.17907 .60321 L
.1837 .60324 L
.1885 .60326 L
.1936 .60328 L
.19795 .60329 L
.20275 .6033 L
.2079 .6033 L
.21079 .60331 L
.21344 .60331 L
.21833 .60331 L
.22348 .60331 L
.22847 .60331 L
.233 .60332 L
.23824 .60332 L
.24318 .60332 L
.24776 .60332 L
.25198 .60332 L
.25661 .60332 L
.26151 .60332 L
.26644 .60332 L
.27093 .60332 L
.27612 .60332 L
.28105 .60332 L
Mistroke
.28559 .60332 L
.2898 .60332 L
.29442 .60332 L
.29933 .60332 L
.3047 .60332 L
.30962 .60332 L
.31504 .60332 L
.31776 .60332 L
.32074 .60332 L
.32578 .60332 L
.3286 .60332 L
.33117 .60332 L
.33616 .60332 L
.34089 .60332 L
.34549 .60332 L
.35055 .60332 L
.3531 .60332 L
.35584 .60332 L
.3608 .60332 L
.36548 .60332 L
.37041 .60332 L
.37461 .60332 L
.3792 .60332 L
.38174 .60332 L
.38449 .60332 L
.38948 .60332 L
.39434 .60332 L
.39881 .60332 L
.40366 .60332 L
.40899 .60332 L
.41167 .60332 L
.41455 .60332 L
.41974 .60332 L
.42229 .60332 L
.425 .60332 L
.42988 .60332 L
.43512 .60332 L
.43811 .60332 L
.44092 .60332 L
.44595 .60332 L
.45057 .60332 L
.45565 .60332 L
.4582 .60332 L
.46099 .60332 L
.46352 .60332 L
.46626 .60332 L
.47123 .60332 L
.47607 .60332 L
.48054 .60332 L
.48537 .60332 L
Mistroke
.48812 .60332 L
.49069 .60332 L
.49588 .60332 L
.49879 .60332 L
.50145 .60332 L
.50621 .60332 L
.51128 .60332 L
.51607 .60332 L
.52041 .60332 L
.52553 .60332 L
.52842 .60332 L
.53107 .60332 L
.53591 .60332 L
.5411 .60332 L
.54372 .60332 L
.545 .60332 L
.54619 .60332 L
.54727 .60332 L
.54841 .60332 L
.55083 .60332 L
.55515 .60332 L
.55633 .60332 L
.5576 .60332 L
.5588 .60332 L
.55991 .60332 L
.56111 .60332 L
.5624 .60332 L
.56361 .60332 L
.56471 .60332 L
.56601 .60332 L
.56674 .60332 L
.56741 .60332 L
.56865 .60332 L
.56996 .60332 L
.57122 .60332 L
.57192 .60332 L
.57256 .60332 L
.57383 .60332 L
.575 .60332 L
.57566 .60332 L
.57636 .60332 L
.57714 .60332 L
.57784 .60332 L
.58054 .60332 L
.58166 .60332 L
.58287 .60332 L
.58356 .60332 L
.58419 .60332 L
.58543 .60332 L
.59058 .60332 L
Mistroke
.59285 .60332 L
.59532 .60332 L
.59645 .60332 L
.59765 .60332 L
.59867 .60332 L
.5998 .60332 L
.60046 .60332 L
.60119 .60332 L
.6025 .60332 L
.60497 .60332 L
.61054 .60332 L
.6206 .60332 L
.66116 .60332 L
.70021 .60332 L
.7417 .60332 L
.78168 .60332 L
.82015 .60332 L
.86106 .60332 L
.90047 .60332 L
.93836 .60332 L
.97444 .60332 L
Mfstroke
.008 w
.22128 .01472 Mdot
.22477 .01472 Mdot
.22827 .0206 Mdot
.23176 .0206 Mdot
.23526 .0206 Mdot
.23875 .0206 Mdot
.24225 .0206 Mdot
.24574 .0206 Mdot
.24924 .0206 Mdot
.25273 .0206 Mdot
.25623 .0206 Mdot
.25972 .0206 Mdot
.26322 .0206 Mdot
.26671 .0206 Mdot
.27021 .0206 Mdot
.2737 .0206 Mdot
.2772 .0206 Mdot
.28069 .0206 Mdot
.28419 .0206 Mdot
.28768 .02649 Mdot
.29118 .02649 Mdot
.29467 .02649 Mdot
.29817 .02649 Mdot
.30166 .02649 Mdot
.30516 .03237 Mdot
.30865 .03237 Mdot
.31215 .03237 Mdot
.31564 .03826 Mdot
.31913 .03826 Mdot
.32263 .03826 Mdot
.32612 .04415 Mdot
.32962 .04415 Mdot
.33311 .05003 Mdot
.33661 .05003 Mdot
.3401 .05003 Mdot
.3436 .05003 Mdot
.34709 .05592 Mdot
.35059 .05592 Mdot
.35408 .05592 Mdot
.35758 .05592 Mdot
.36107 .05592 Mdot
.36457 .0618 Mdot
.36806 .06769 Mdot
.37156 .06769 Mdot
.37505 .06769 Mdot
.37855 .06769 Mdot
.38204 .08535 Mdot
.38554 .09123 Mdot
.38903 .09123 Mdot
.39253 .09712 Mdot
.39602 .10889 Mdot
.39952 .11478 Mdot
.40301 .11478 Mdot
.40651 .12066 Mdot
.41 .12655 Mdot
.4135 .13244 Mdot
.41699 .13244 Mdot
.42049 .15009 Mdot
.42398 .15009 Mdot
.42748 .15598 Mdot
.43097 .17952 Mdot
.43447 .1913 Mdot
.43796 .20307 Mdot
.44146 .21484 Mdot
.44495 .22073 Mdot
.44845 .22073 Mdot
.45194 .2325 Mdot
.45544 .23838 Mdot
.45893 .23838 Mdot
.46243 .23838 Mdot
.46592 .24427 Mdot
.46942 .24427 Mdot
.47291 .24427 Mdot
.47641 .25604 Mdot
.4799 .25604 Mdot
.4834 .26193 Mdot
.48689 .26781 Mdot
.49039 .26781 Mdot
.49388 .2737 Mdot
.49738 .28547 Mdot
.50087 .28547 Mdot
.50437 .28547 Mdot
.50786 .29724 Mdot
.51136 .30313 Mdot
.51485 .3149 Mdot
.51835 .32079 Mdot
.52184 .32668 Mdot
.52534 .33256 Mdot
.52883 .33845 Mdot
.53233 .34433 Mdot
.53582 .36199 Mdot
.53932 .36199 Mdot
.54281 .36199 Mdot
.54631 .36788 Mdot
.5498 .36788 Mdot
.5533 .36788 Mdot
.55679 .37376 Mdot
.56029 .37376 Mdot
.56378 .38554 Mdot
.56728 .39142 Mdot
.57077 .39731 Mdot
.57427 .40319 Mdot
.57776 .40908 Mdot
.58126 .41497 Mdot
.58475 .41497 Mdot
.58825 .41497 Mdot
.59174 .41497 Mdot
.59524 .42674 Mdot
.59873 .43851 Mdot
.60223 .4444 Mdot
.60572 .46205 Mdot
.60922 .46205 Mdot
.61271 .46205 Mdot
.61621 .46794 Mdot
.6197 .46794 Mdot
.6232 .47383 Mdot
.62669 .47383 Mdot
.63019 .47383 Mdot
.63368 .47383 Mdot
.63718 .47383 Mdot
.64067 .47383 Mdot
.64417 .47971 Mdot
.64766 .4856 Mdot
.65116 .49148 Mdot
.65465 .49148 Mdot
.65815 .49148 Mdot
.66164 .49148 Mdot
.66514 .49148 Mdot
.66863 .49737 Mdot
.67213 .49737 Mdot
.67562 .50326 Mdot
.67912 .50326 Mdot
.68261 .50326 Mdot
.68611 .51503 Mdot
.6896 .51503 Mdot
.6931 .51503 Mdot
.69659 .51503 Mdot
.70009 .5268 Mdot
.70358 .5268 Mdot
.70708 .5268 Mdot
.71057 .53269 Mdot
.71407 .53857 Mdot
.71756 .53857 Mdot
.72106 .53857 Mdot
.72455 .55034 Mdot
.72805 .55623 Mdot
.73154 .55623 Mdot
.73504 .56212 Mdot
.73853 .56212 Mdot
.74203 .56212 Mdot
.74552 .56212 Mdot
.74902 .56212 Mdot
.75251 .56212 Mdot
.75601 .56212 Mdot
.7595 .56212 Mdot
.763 .56212 Mdot
.76649 .56212 Mdot
.76999 .56212 Mdot
.77348 .56212 Mdot
.77698 .56212 Mdot
.78047 .56212 Mdot
.78397 .56212 Mdot
.78746 .56212 Mdot
.79096 .56212 Mdot
.79445 .56212 Mdot
.79795 .56212 Mdot
.80144 .56212 Mdot
.80494 .56212 Mdot
.80843 .56212 Mdot
.81193 .57389 Mdot
.81542 .57389 Mdot
.81892 .57389 Mdot
.82241 .57389 Mdot
.82591 .57977 Mdot
.8294 .57977 Mdot
.8329 .57977 Mdot
.83639 .57977 Mdot
.83989 .57977 Mdot
.84338 .57977 Mdot
.84688 .57977 Mdot
.85037 .57977 Mdot
.85387 .57977 Mdot
.85736 .57977 Mdot
.86086 .57977 Mdot
.86435 .57977 Mdot
.86785 .57977 Mdot
.87134 .57977 Mdot
.87484 .57977 Mdot
.87833 .58566 Mdot
.88183 .58566 Mdot
.88532 .58566 Mdot
.88882 .58566 Mdot
.89231 .58566 Mdot
.89581 .58566 Mdot
.8993 .58566 Mdot
.9028 .58566 Mdot
.90629 .59155 Mdot
.90979 .59155 Mdot
.91328 .59155 Mdot
.91678 .59155 Mdot
.92027 .59155 Mdot
.92377 .59155 Mdot
.92726 .59155 Mdot
.93076 .59155 Mdot
.93425 .59155 Mdot
.93775 .59155 Mdot
.94124 .59155 Mdot
.94474 .59155 Mdot
.94823 .59155 Mdot
.95173 .59743 Mdot
.95522 .59743 Mdot
.95872 .59743 Mdot
.96221 .59743 Mdot
.96571 .59743 Mdot
.9692 .60332 Mdot
.9727 .60332 Mdot
.97619 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From (Dialog) In[220]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool003Ioo`<000Aoo`8001eoo`@000=oo`8001eoo`<000Aoo`8001ioo`<000=oo`8001eoo`<000Ao
o`8001ioo`8000Aoo`8002=oo`00=goo00<007ooOol00Woo00@007ooOol001eoo`03001oogoo009o
o`04001oogoo000OOol01000Oomoo`000Woo00<007ooOol077oo00D007ooOomoo`00009oo`03001o
ogoo01eoo`04001oogoo0002Ool00`00Oomoo`0JOol01000Oomoo`000Woo00@007ooOol0029oo`00
=goo00<007ooOol00Woo00@007ooOol001ioo`05001oogooOol00002Ool00`00Oomoo`0MOol01000
Oomoo`000Woo00<007ooOol06Woo10000Woo00@007ooOol001moo`04001oogoo0002Ool00`00Oomo
o`0JOol01000Oomoo`000Woo00@007ooOol0029oo`00=goo00<007ooOol00Woo00@007ooOol001mo
o`04001oogoo0002Ool00`00Oomoo`0KOol20003Ool01000Oomoo`0077oo00<007oo00000goo00@0
07ooOol001aoo`<000=oo`04001oogoo000LOol30003Ool01000Oomoo`008Woo000gOol00`00Oomo
o`02Ool01000Oomoo`0077oo00@007ooOol0009oo`04001oogoo000OOol01000Oomoo`000Woo00<0
07ooOol06Woo00<007oo00000goo00@007ooOol001aoo`03001oogoo00=oo`04001oogoo000LOol0
0`00Oomoo`03Ool01000Oomoo`008Woo000fOol20005Ool2000NOol20004Ool2000MOol30004Ool2
000NOol20004Ool2000MOol40003Ool2000NOol30003Ool2000SOol001Eoo`03001oogoo0?moo`Uo
o`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uo
o`003gooo`004@000Goo000EOol00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04OolC0004Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`06Ool001Eoo`03001o
ogoo02=oo`03001oogoo00iooa4000Aoo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02=o
o`03001oogoo02=oo`03001oogoo02Aoo`005Goo00<007ooOol0A7oo1P00_Woo000EOol00`00Oomo
o`14Ool9002kOol001Eoo`03001oogoo04Uoo`@00;]oo`005Goo00<007ooOol0C7oo1000^7oo000E
Ool2001=Ool4002hOol001Eoo`80051oo`<00;Ioo`005Goo0P00D7oo1P00/goo000EOol2001BOol4
002cOol001Eoo`8005Eoo`H00:ioo`005Goo0P00EGoo1`00[Goo000EOol2001JOol2002]Ool001Eo
o`8005]oo`D00:Uoo`005Goo0P00Fgoo1@00ZGoo000EOol2003oOol:Ool001Eoo`800?moo`Yoo`00
5Goo0P00ogoo2Woo000EOol2001OOol2002XOol001Eoo`03001oo`0005ioo`@00:Ioo`005Goo00<0
07oo0000Ggoo0`00YWoo000EOol00`00Ool0001QOol2002UOol001Eoo`03001oo`00065oo`800:Eo
o`005Goo0`00ogoo2Goo000EOol00`00Ool0001ROol2002TOol001Eoo`03001oo`00069oo`800:Ao
o`005Goo00<007oo0000Hgoo0`00XWoo000EOol00`00Ool0001SOol3002ROol001Eoo`03001oo`00
06Aoo`800:9oo`000Woo0P0017oo0P000goo100017oo00<007oo0000IGoo0P00XGoo00001Goo001o
ogoo00000goo0P0017oo00<007ooOol017oo00<007oo0000IGoo0P00XGoo00001Goo001oogoo0000
2Woo00<007ooOol00goo1000IGoo0`00Wgoo00001Goo001oogoo00002goo00<007ooOol00Woo00@0
07ooOol006Eoo`<009moo`0000Eoo`00Oomoo`0000Qoo`04001oogoo0004Ool01000Oomoo`00ogoo
27oo0002Ool2000:Ool20005Ool01000Oomoo`00ogoo27oo000EOol01000Oomoo`00Igoo0`00WGoo
000EOol01000Oomoo`00Igoo0`00WGoo000EOol01000Oomoo`00JGoo0P00W7oo000EOol01000Oomo
o`00JGoo0P00W7oo000EOol200000goo001oo`3oOol7Ool001Eoo`04001oogoo003oOol8Ool001Eo
o`04001oogoo003oOol8Ool001Eoo`04001oogoo003oOol8Ool001Eoo`05001oogooOol0001YOol2
002KOol001Eoo`05001oogooOol0001YOol2002KOol001Eoo`05001oogooOol0003oOol7Ool001Eo
o`05001oogooOol0003oOol7Ool001Eoo`80009oo`03001oogoo06Qoo`8009Yoo`005Goo00D007oo
Oomoo`0006Yoo`8009Yoo`005Goo00D007ooOomoo`000?moo`Moo`005Goo00D007ooOomoo`0006]o
o`8009Uoo`005Goo00D007ooOomoo`0006]oo`8009Uoo`005Goo00D007ooOomoo`000?moo`Moo`00
5Goo00D007ooOomoo`0006aoo`8009Qoo`005Goo00D007ooOomoo`0006aoo`8009Qoo`005Goo0P00
0Woo00<007ooOol0Jgoo0`00UWoo000EOol00`00Oomoo`02Ool00`00Oomoo`1ZOol3002FOol001Eo
o`03001oogoo009oo`03001oogoo0?moo`Aoo`005Goo00<007ooOol00Woo00<007ooOol0K7oo0P00
UGoo000EOol00`00Oomoo`02Ool00`00Oomoo`1/Ool5002BOol001Eoo`03001oogoo009oo`03001o
ogoo06eoo`@0099oo`000Woo0P0017oo0P0017oo0`0017oo00<007ooOol00Woo00<007ooOol0L7oo
1000Sgoo00001Goo001oogoo00000goo0P001Goo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool0L7oo1000Sgoo00001Goo001oogoo000027oo100017oo0`000Woo00<007ooOol0ogoo17oo0000
1Goo001oogoo000027oo00<007oo00001Goo00<007ooOol00Woo00<007ooOol0LWoo0`00SWoo0000
1Goo001oogoo000027oo00<007oo00001Goo00<007ooOol00Woo00<007ooOol0LWoo0`00SWoo0002
Ool2000:Ool20005Ool00`00Oomoo`02Ool00`00Oomoo`1dOol2002=Ool001Eoo`03001oogoo009o
o`03001oogoo07Aoo`@008]oo`005Goo00<007ooOol00goo00<007ooOol0M7oo0`00Rgoo000EOol0
0`00Oomoo`03Ool00`00Oomoo`1fOol2002:Ool001Eoo`03001oogoo00=oo`03001oogoo07Ioo`80
08Yoo`005Goo0P0017oo00<007ooOol0ogoo0goo000EOol00`00Oomoo`03Ool00`00Oomoo`1gOol4
0027Ool001Eoo`03001oogoo00=oo`03001oogoo07Moo`@008Moo`005Goo00<007ooOol00goo00<0
07ooOol0ogoo0goo000EOol00`00Oomoo`03Ool00`00Oomoo`1jOol20026Ool001Eoo`03001oogoo
00=oo`03001oogoo07Yoo`8008Ioo`005Goo00<007ooOol00goo00<007ooOol0Ngoo0P00QGoo000E
Ool00`00Oomoo`03Ool00`00Oomoo`1kOol20025Ool001Eoo`8000Eoo`03001oogoo0?moo`9oo`00
5Goo00<007ooOol017oo00<007ooOol0Ngoo0P00Q7oo000EOol00`00Oomoo`04Ool00`00Oomoo`1k
Ool20024Ool001Eoo`03001oogoo00Aoo`03001oogoo07aoo`8008=oo`005Goo00<007ooOol017oo
00<007ooOol0O7oo0`00PWoo000EOol00`00Oomoo`04Ool00`00Oomoo`1mOol20022Ool001Eoo`03
001oogoo00Aoo`03001oogoo07ioo`80085oo`005Goo00<007ooOol017oo00<007ooOol0OWoo0P00
PGoo000EOol20005Ool00`00Oomoo`1oOol20020Ool001Eoo`03001oogoo00Aoo`03001oogoo07mo
o`<007moo`005Goo00<007ooOol017oo00<007ooOol0P7oo0P00Ogoo000EOol00`00Oomoo`05Ool0
0`00Oomoo`3oOol1Ool001Eoo`03001oogoo00Eoo`03001oogoo0?moo`5oo`005Goo00<007ooOol0
1Goo00<007ooOol0ogoo0Goo0002Ool20004Ool20004Ool20005Ool00`00Oomoo`05Ool00`00Oomo
o`20Ool4001lOol00005Ool007ooOol00003Ool20003Ool01000Oomoo`0017oo00<007ooOol01Goo
00<007ooOol0P7oo1000O7oo00001Goo001oogoo000027oo00@007ooOol000Aoo`<000Eoo`03001o
ogoo089oo`@007Yoo`0000Eoo`00Oomoo`0000Qoo`<000Eoo`03001oogoo00Eoo`03001oogoo089o
o`H007Qoo`0000Eoo`00Oomoo`0000Qoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo08Eo
o`<007Qoo`000Woo0P002Woo0`0017oo00<007ooOol01Goo00<007ooOol0ogoo0Goo000EOol00`00
Oomoo`05Ool00`00Oomoo`27Ool2001gOol001Eoo`03001oogoo00Eoo`03001oogoo08Moo`8007Mo
o`005Goo00<007ooOol01Goo00<007ooOol0R7oo0P00MWoo000EOol00`00Oomoo`06Ool00`00Oomo
o`27Ool2001fOol001Eoo`8000Moo`03001oogoo08Qoo`8007Eoo`005Goo00<007ooOol01Woo00<0
07ooOol0R7oo0`00M7oo000EOol00`00Oomoo`06Ool00`00Oomoo`29Ool2001dOol001Eoo`03001o
ogoo00Ioo`03001oogoo08Yoo`8007=oo`005Goo00<007ooOol01Woo00<007ooOol0RWoo1P00Kgoo
000EOol00`00Oomoo`06Ool00`00Oomoo`2;Ool5001_Ool001Eoo`03001oogoo00Ioo`03001oogoo
0?moo`005Goo00<007ooOol01Woo00<007ooOol0ogoo000EOol20007Ool00`00Oomoo`2?Ool2001^
Ool001Eoo`03001oogoo00Ioo`03001oogoo08moo`8006ioo`005Goo00<007ooOol01Woo00<007oo
Ool0ogoo000EOol00`00Oomoo`06Ool00`00Oomoo`2@Ool2001]Ool001Eoo`03001oogoo00Moo`03
001oogoo08moo`<006aoo`005Goo00<007ooOol01goo00<007ooOol0T7oo0P00K7oo000EOol00`00
Oomoo`07Ool00`00Oomoo`3nOol001Eoo`03001oogoo00Moo`03001oogoo0?ioo`005Goo0P0027oo
00<007ooOol0oWoo000EOol00`00Oomoo`07Ool00`00Oomoo`2AOol4001YOol001Eoo`03001oogoo
00Moo`03001oogoo095oo`@006Uoo`005Goo00<007ooOol01goo00<007ooOol0Tgoo0`00J7oo000E
Ool00`00Oomoo`07Ool00`00Oomoo`2COol9001ROol001Eoo`03001oogoo00Qoo`03001oogoo09Ao
o`L0069oo`000Woo0P0017oo0P0017oo0P001Goo00<007ooOol027oo00<007ooOol0VWoo0P00HGoo
00001Goo001oogoo00000goo0P000goo00@007ooOol000Aoo`03001oogoo00Qoo`03001oogoo09Yo
o`80065oo`0000Eoo`00Oomoo`0000Qoo`04001oogoo0004Ool30008Ool00`00Oomoo`2KOol2001P
Ool00005Ool007ooOol00009Ool20005Ool00`00Oomoo`08Ool00`00Oomoo`2KOol7001KOol00005
Ool007ooOol00008Ool01000Oomoo`0017oo00<007ooOol02Goo00<007ooOol0Vgoo1P00Fgoo0002
Ool2000:Ool20005Ool00`00Oomoo`09Ool00`00Oomoo`2POol3001IOol001Eoo`03001oogoo00Uo
o`03001oogoo0:1oo`H005Ioo`005Goo00<007ooOol02Goo00<007ooOol0XWoo1000EWoo000EOol0
0`00Oomoo`09Ool00`00Oomoo`3lOol001Eoo`03001oogoo00Yoo`03001oogoo0?]oo`005Goo0P00
2goo00<007ooOol0Y7oo1000Dgoo000EOol00`00Oomoo`0:Ool00`00Oomoo`2TOol4001COol001Eo
o`03001oogoo00Yoo`03001oogoo0?]oo`005Goo00<007ooOol02Woo00<007ooOol0Ygoo1000D7oo
000EOol00`00Oomoo`0;Ool00`00Oomoo`2VOol5001?Ool001Eoo`03001oogoo00]oo`03001oogoo
0:Uoo`8004moo`005Goo00<007ooOol02goo00<007ooOol0ZWoo1000C7oo000EOol00`00Oomoo`0<
Ool00`00Oomoo`2YOol4001<Ool001Eoo`8000eoo`03001oogoo0?Uoo`005Goo00<007ooOol037oo
00<007ooOol0[7oo0P00Bgoo000EOol00`00Oomoo`0=Ool00`00Oomoo`2[Ool2001;Ool001Eoo`03
001oogoo00eoo`03001oogoo0:aoo`<004Uoo`005Goo00<007ooOol03Goo00<007ooOol0[7oo6000
=7oo000EOol00`00Oomoo`0=Ool00`00Oomoo`2^OolF000dOol001Eoo`03001oogoo00ioo`03001o
ogoo0?Moo`005Goo00<007ooOol03Woo00<007ooOol0mgoo000EOol2000@Ool00`00Oomoo`31Ool5
000`Ool001Eoo`03001oogoo011oo`03001oogoo0<1ooa<0029oo`005Goo00<007ooOol047oo00<0
07ooOol0a7oo3`008Woo000EOol00`00Oomoo`0AOol00`00Oomoo`3AOol8000KOol001Eoo`03001o
ogoo019oo`03001oogoo0=1ooaD000ioo`005Goo00<007ooOol04goo0P00egoo3P003Woo000=Ool3
0005Ool00`00Oomoo`0EOol2003ROol60009Ool000ioo`03001oogoo00Aoo`03001oogoo01Moo`D0
0=eoo`H000Uoo`003Woo00<007ooOol017oo0`0077ooi@001goo000>Ool00`00Oomoo`04Ool00`00
Oomoo`3mOol40007Ool000ioo`03001oogoo00Aoo`03001oogoo0?moo`Uoo`003Goo0P001Woo00<0
07ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.65337, -0.07747, 
  0.263085, 0.00624851}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.162698 0.15873 0.0147151 0.588604 [
[.00397 .00222 -6 -9 ]
[.00397 .00222 6 0 ]
[.32143 .00222 -3 -9 ]
[.32143 .00222 3 0 ]
[.48016 .00222 -3 -9 ]
[.48016 .00222 3 0 ]
[.63889 .00222 -3 -9 ]
[.63889 .00222 3 0 ]
[.79762 .00222 -3 -9 ]
[.79762 .00222 3 0 ]
[.95635 .00222 -3 -9 ]
[.95635 .00222 3 0 ]
[.1502 .13244 -18 -4.5 ]
[.1502 .13244 0 4.5 ]
[.1502 .25016 -18 -4.5 ]
[.1502 .25016 0 4.5 ]
[.1502 .36788 -18 -4.5 ]
[.1502 .36788 0 4.5 ]
[.1502 .4856 -18 -4.5 ]
[.1502 .4856 0 4.5 ]
[.1502 .60332 -6 -4.5 ]
[.1502 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00397 .01472 m
.00397 .02097 L
s
[(-1)] .00397 .00222 0 1 Mshowa
.32143 .01472 m
.32143 .02097 L
s
[(1)] .32143 .00222 0 1 Mshowa
.48016 .01472 m
.48016 .02097 L
s
[(2)] .48016 .00222 0 1 Mshowa
.63889 .01472 m
.63889 .02097 L
s
[(3)] .63889 .00222 0 1 Mshowa
.79762 .01472 m
.79762 .02097 L
s
[(4)] .79762 .00222 0 1 Mshowa
.95635 .01472 m
.95635 .02097 L
s
[(5)] .95635 .00222 0 1 Mshowa
.125 Mabswid
.03571 .01472 m
.03571 .01847 L
s
.06746 .01472 m
.06746 .01847 L
s
.09921 .01472 m
.09921 .01847 L
s
.13095 .01472 m
.13095 .01847 L
s
.19444 .01472 m
.19444 .01847 L
s
.22619 .01472 m
.22619 .01847 L
s
.25794 .01472 m
.25794 .01847 L
s
.28968 .01472 m
.28968 .01847 L
s
.35317 .01472 m
.35317 .01847 L
s
.38492 .01472 m
.38492 .01847 L
s
.41667 .01472 m
.41667 .01847 L
s
.44841 .01472 m
.44841 .01847 L
s
.5119 .01472 m
.5119 .01847 L
s
.54365 .01472 m
.54365 .01847 L
s
.5754 .01472 m
.5754 .01847 L
s
.60714 .01472 m
.60714 .01847 L
s
.67063 .01472 m
.67063 .01847 L
s
.70238 .01472 m
.70238 .01847 L
s
.73413 .01472 m
.73413 .01847 L
s
.76587 .01472 m
.76587 .01847 L
s
.82937 .01472 m
.82937 .01847 L
s
.86111 .01472 m
.86111 .01847 L
s
.89286 .01472 m
.89286 .01847 L
s
.9246 .01472 m
.9246 .01847 L
s
.9881 .01472 m
.9881 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.1627 .13244 m
.16895 .13244 L
s
[(0.2)] .1502 .13244 1 0 Mshowa
.1627 .25016 m
.16895 .25016 L
s
[(0.4)] .1502 .25016 1 0 Mshowa
.1627 .36788 m
.16895 .36788 L
s
[(0.6)] .1502 .36788 1 0 Mshowa
.1627 .4856 m
.16895 .4856 L
s
[(0.8)] .1502 .4856 1 0 Mshowa
.1627 .60332 m
.16895 .60332 L
s
[(1)] .1502 .60332 1 0 Mshowa
.125 Mabswid
.1627 .04415 m
.16645 .04415 L
s
.1627 .07358 m
.16645 .07358 L
s
.1627 .10301 m
.16645 .10301 L
s
.1627 .16187 m
.16645 .16187 L
s
.1627 .1913 m
.16645 .1913 L
s
.1627 .22073 m
.16645 .22073 L
s
.1627 .27959 m
.16645 .27959 L
s
.1627 .30902 m
.16645 .30902 L
s
.1627 .33845 m
.16645 .33845 L
s
.1627 .39731 m
.16645 .39731 L
s
.1627 .42674 m
.16645 .42674 L
s
.1627 .45617 m
.16645 .45617 L
s
.1627 .51503 m
.16645 .51503 L
s
.1627 .54446 m
.16645 .54446 L
s
.1627 .57389 m
.16645 .57389 L
s
.25 Mabswid
.1627 0 m
.1627 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.1627 .01472 m
.19489 .12278 L
.23001 .21814 L
.26298 .2904 L
.2947 .34707 L
.32845 .39616 L
.36095 .43451 L
.39549 .46752 L
.42876 .4932 L
.46077 .51331 L
.49483 .53069 L
.52762 .54425 L
.55915 .55489 L
.59272 .56412 L
.62503 .57134 L
.65939 .57756 L
.69248 .58241 L
.7243 .58621 L
.75818 .5895 L
.79078 .59206 L
.82544 .59427 L
.85882 .59599 L
.89095 .59733 L
.92512 .59849 L
.95635 .59935 L
s
.008 w
.02381 .01472 Mdot
.06349 .01472 Mdot
.10317 .01472 Mdot
.14286 .03874 Mdot
.18254 .06877 Mdot
.22222 .1949 Mdot
.2619 .28499 Mdot
.30159 .35106 Mdot
.34127 .41713 Mdot
.38095 .47719 Mdot
.42063 .51323 Mdot
.46032 .54926 Mdot
.5 .56128 Mdot
.53968 .56128 Mdot
.57937 .57329 Mdot
.61905 .57929 Mdot
.65873 .5853 Mdot
.69841 .5853 Mdot
.7381 .59131 Mdot
.77778 .59731 Mdot
.81746 .59731 Mdot
.85714 .59731 Mdot
.89683 .60332 Mdot
.93651 .60332 Mdot
.97619 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From (Dialog) In[220]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool000aoo`<0051oo`<002Qoo`@002Moo`<002Uoo`<002Qoo`<0015oo`003Goo00<007ooOol0D7oo
00<007ooOol0:7oo00<007ooOol0:Woo00<007ooOol09goo00<007ooOol0:Woo00<007ooOol03Woo
0006Ool50002Ool00`00Oomoo`1@Ool00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomoo`0UOol4
000[Ool00`00Oomoo`0>Ool000eoo`03001oogoo051oo`03001oogoo02Yoo`03001oogoo02Ioo`80
02Qoo`03001oo`0002Uoo`<0015oo`003Goo00<007ooOol0D7oo00<007ooOol09goo00@007ooOol0
02Yoo`03001oogoo02Eoo`03001oo`0002Uoo`03001oogoo015oo`0037oo0P00DGoo0P00:Woo0P00
:7oo0`00:Goo0P00:Goo100047oo000fOol00`00Oomoo`3WOol003Ioo`03001oogoo0>Moo`00=Woo
00<007ooOol0igoo000fOol00`00Oomoo`3WOol000Yoool0014000Ioo`002goo00@007ooOomoo`80
009oo`03001oogoo00Aoo`<000Moo`<000Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo
00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo
00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo
00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo
00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo
00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo
00Moo`002goo00<007ooOol0:7oo00<007ooOol0:7oo00<007ooOol0:7oo00<007ooOol0:7oo00<0
07ooOol0:7oo00<007ooOol0:Goo00<007ooOol03goo000fOol2003XOol003Ioo`800>Qoo`00=Woo
0P00j7oo000`Ool20004Ool00`00Ool0003WOol0031oo`8000Aoo`03001oo`000>Moo`00=Woo0`00
igoo000fOol01000Oomoo`00iWoo000fOol01000Oomoo`00iWoo000fOol01000Oomoo`00iWoo000f
Ool01@00Oomoogoo0000iGoo000fOol01@00Oomoogoo0000iGoo000fOol01000Oomoogoo0`00hgoo
000fOol00`00Oomoo`02Ool2003SOol003Ioo`8000=oo`03001oogoo0>9oo`00=Woo00<007ooOol0
0Woo00<007ooOol0hWoo000fOol00`00Oomoo`02Ool00`00Oomoo`3ROol003Ioo`03001oogoo00=o
o`03001oogoo0>5oo`00=Woo00<007ooOol00goo00<007ooOol0hGoo000fOol00`00Oomoo`03Ool0
0`00Oomoo`3QOol003Ioo`03001oogoo00Aoo`03001oogoo0>1oo`00=Woo00<007ooOol017oo00<0
07ooOol0h7oo000fOol20005Ool00`00Oomoo`3POol003Ioo`03001oogoo00Eoo`03001oogoo0=mo
o`00=Woo00<007ooOol01Goo00<007ooOol0ggoo000fOol00`00Oomoo`05Ool00`00Oomoo`3OOol0
03Ioo`03001oogoo00Ioo`03001oogoo0=ioo`00=Woo00<007ooOol01Woo00<007ooOol0gWoo000R
Ool20004Ool20003Ool40005Ool00`00Oomoo`06Ool00`00Oomoo`3NOol0025oo`04001oogoo0003
Ool20004Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`3MOol0025oo`04001oogoo000:
Ool00`00Oomoo`04Ool20008Ool00`00Oomoo`3MOol0025oo`04001oogoo000;Ool00`00Oomoo`03
Ool00`00Oomoo`07Ool00`00Oomoo`3MOol0025oo`04001oogoo0008Ool01000Oomoo`001Goo00<0
07ooOol027oo00<007ooOol0g7oo000ROol2000:Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`3L
Ool003Ioo`03001oogoo00Qoo`03001oogoo0=aoo`00=Woo00<007ooOol02Goo00<007ooOol0fgoo
000fOol00`00Oomoo`09Ool00`00Oomoo`3KOol003Ioo`03001oogoo00Uoo`03001oogoo0=]oo`00
=Woo0P002goo00<007ooOol0fWoo000fOol00`00Oomoo`0:Ool00`00Oomoo`3JOol003Ioo`03001o
ogoo00Yoo`03001oogoo0=Yoo`00=Woo00<007ooOol02goo00<007ooOol0fGoo000fOol00`00Oomo
o`0;Ool00`00Oomoo`3IOol003Ioo`03001oogoo00]oo`03001oogoo0=Uoo`00=Woo00<007ooOol0
37oo00<007ooOol0f7oo000fOol00`00Oomoo`0<Ool00`00Oomoo`3HOol003Ioo`8000eoo`03001o
ogoo0=Qoo`00=Woo00<007ooOol037oo0P00fGoo000fOol00`00Oomoo`0<Ool2003IOol003Ioo`03
001oogoo00eoo`03001oogoo0=Moo`00=Woo00<007ooOol03Woo00<007ooOol0eWoo000fOol00`00
Oomoo`0>Ool00`00Oomoo`3FOol003Ioo`03001oogoo00ioo`03001oogoo0=Ioo`00=Woo00<007oo
Ool03goo00<007ooOol0eGoo000fOol2000@Ool00`00Oomoo`3EOol003Ioo`03001oogoo011oo`03
001oogoo0=Aoo`00=Woo00<007ooOol047oo00<007ooOol0e7oo000fOol00`00Oomoo`0AOol00`00
Oomoo`3COol003Ioo`03001oogoo015oo`03001oogoo0==oo`00=Woo00<007ooOol04Goo00<007oo
Ool0dgoo000ROol20004Ool20004Ool30005Ool00`00Oomoo`0BOol00`00Oomoo`3BOol0025oo`04
001oogoo0003Ool20005Ool00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`3BOol0025oo`04
001oogoo0008Ool40005Ool2000DOol00`00Oomoo`3AOol0025oo`04001oogoo0008Ool00`00Ool0
0006Ool00`00Oomoo`0COol00`00Oomoo`3AOol0025oo`04001oogoo0008Ool00`00Ool00006Ool0
0`00Oomoo`0DOol00`00Oomoo`3@Ool0029oo`8000Yoo`8000Ioo`03001oogoo01Aoo`03001oogoo
0=1oo`00=Woo00<007ooOol05Goo00<007ooOol0cgoo000fOol00`00Oomoo`0EOol00`00Oomoo`3?
Ool003Ioo`03001oogoo01Ioo`03001oogoo0<ioo`00=Woo00<007ooOol05Woo00<007ooOol0cWoo
000fOol2000GOol00`00Oomoo`3>Ool003Ioo`03001oogoo01Moo`800<ioo`00=Woo00<007ooOol0
5goo0P00cWoo000fOol00`00Oomoo`0HOol00`00Oomoo`3<Ool003Ioo`03001oogoo01Qoo`03001o
ogoo0<aoo`00=Woo00<007ooOol06Goo00<007ooOol0bgoo000fOol00`00Oomoo`0JOol00`00Oomo
o`3:Ool003Ioo`03001oogoo01Yoo`03001oogoo0<Yoo`00=Woo0P0077oo00<007ooOol0bGoo000f
Ool00`00Oomoo`0KOol00`00Oomoo`39Ool003Ioo`03001oogoo01aoo`03001oogoo0<Qoo`00=Woo
00<007ooOol07Goo00<007ooOol0agoo000fOol00`00Oomoo`0MOol00`00Oomoo`37Ool003Ioo`03
001oogoo01ioo`03001oogoo0<Ioo`00=Woo00<007ooOol07Woo00<007ooOol0aWoo000fOol00`00
Oomoo`0OOol00`00Oomoo`35Ool003Ioo`80025oo`03001oogoo0<Aoo`00=Woo00<007ooOol087oo
00<007ooOol0a7oo000fOol00`00Oomoo`0QOol00`00Oomoo`33Ool003Ioo`03001oogoo025oo`<0
0<=oo`00=Woo00<007ooOol08Woo0P00`goo000fOol00`00Oomoo`0SOol00`00Oomoo`31Ool0029o
o`8000Aoo`8000Aoo`8000Ioo`03001oogoo02=oo`03001oogoo0<5oo`008Goo00@007ooOol000=o
o`8000=oo`04001oogoo0005Ool00`00Oomoo`0TOol00`00Oomoo`30Ool0025oo`04001oogoo0008
Ool01000Oomoo`001Goo0P009Woo00<007ooOol0_goo000QOol01000Oomoo`0027oo0`001Woo00<0
07ooOol09Goo00<007ooOol0_goo000QOol01000Oomoo`0027oo00<007ooOol01Woo00<007ooOol0
9Woo00<007ooOol0_Woo000ROol2000:Ool30005Ool00`00Oomoo`0VOol00`00Oomoo`2nOol003Io
o`03001oogoo02Moo`03001oogoo0;eoo`00=Woo00<007ooOol0:7oo00<007ooOol0_7oo000fOol0
0`00Oomoo`0XOol00`00Oomoo`2lOol003Ioo`03001oogoo02Uoo`03001oogoo0;]oo`00=Woo0P00
:goo00<007ooOol0^Woo000fOol00`00Oomoo`0ZOol00`00Oomoo`2jOol003Ioo`03001oogoo02]o
o`03001oogoo0;Uoo`00=Woo00<007ooOol0;7oo00<007ooOol0^7oo000fOol00`00Oomoo`0]Ool0
0`00Oomoo`2gOol003Ioo`03001oogoo02eoo`800;Qoo`00=Woo00<007ooOol0;Goo0`00]goo000f
Ool00`00Oomoo`0`Ool00`00Oomoo`2dOol003Ioo`80039oo`03001oogoo0;=oo`00=Woo00<007oo
Ool0<Woo00<007ooOol0/Woo000fOol00`00Oomoo`0cOol00`00Oomoo`2aOol003Ioo`03001oogoo
03Aoo`03001oogoo0;1oo`00=Woo00<007ooOol0=Goo00<007ooOol0[goo000fOol00`00Oomoo`0f
Ool00`00Oomoo`2^Ool003Ioo`03001oogoo03Moo`03001oogoo0:eoo`00=Woo00<007ooOol0>7oo
00<007ooOol0[7oo000fOol2000jOol00`00Oomoo`2[Ool003Ioo`03001oogoo03Yoo`03001oogoo
0:Yoo`00=Woo00<007ooOol0>goo00<007ooOol0ZGoo000fOol00`00Oomoo`0lOol2002YOol003Io
o`03001oogoo03ioo`03001oogoo0:Ioo`00=Woo00<007ooOol0>7oo0P001Goo00<007ooOol0YGoo
000ROol20004Ool20004Ool20006Ool00`00Oomoo`0hOol20006Ool2002UOol0025oo`04001oogoo
0003Ool20003Ool01000Oomoo`001Goo00<007ooOol0@Woo00<007ooOol0XWoo000QOol01000Oomo
o`0027oo00@007ooOol000Eoo`8004Aoo`03001oogoo0:5oo`008Goo00@007ooOol000Uoo`8000Io
o`03001oogoo04Aoo`03001oogoo0:1oo`008Goo00@007ooOol000Qoo`04001oogoo0005Ool00`00
Oomoo`15Ool2002POol0029oo`8000Yoo`8000Ioo`03001oogoo04Moo`03001oogoo09eoo`00=Woo
00<007ooOol0B7oo0P00WGoo000fOol00`00Oomoo`1:Ool00`00Oomoo`2JOol003Ioo`03001oogoo
04]oo`8009Yoo`00=Woo00<007ooOol0@Woo0P002Goo00<007ooOol0Ugoo000fOol20013Ool2000:
Ool2002GOol003Ioo`03001oogoo051oo`8009Eoo`00=Woo00<007ooOol0DWoo0`00TWoo000fOol0
0`00Oomoo`1EOol2002@Ool003Ioo`03001oogoo05Moo`8008ioo`00=Woo00<007ooOol0FGoo0P00
S7oo000fOol00`00Oomoo`1KOol30029Ool003Ioo`03001oogoo05ioo`8008Moo`00=Woo0P00HGoo
0`00Q7oo000fOol00`00Oomoo`1=Ool2000DOol30021Ool003Ioo`03001oogoo04eoo`8001Moo`<0
07ioo`00=Woo00<007ooOol0JGoo0`00Ngoo000fOol00`00Oomoo`1HOol20009Ool20007Ool5001f
Ool003Ioo`03001oogoo05Qoo`8000Uoo`8000aoo`@0079oo`00=Woo00<007ooOol0MGoo1000KWoo
000fOol00`00Oomoo`1]Ool2000:Ool5001YOol003Ioo`8006ioo`8000moo`D006Aoo`00=Woo00<0
07ooOol0N7oo0P002Goo1`00GGoo000fOol00`00Oomoo`1hOol2000@Ool8001EOol003Ioo`03001o
ogoo08=oo`8000Uoo`80009oo`T004aoo`00=Woo00<007ooOol0Pgoo0P002Goo0P002Goo3000@Woo
000fOol00`00Oomoo`2IOol2000:Ool9000iOol002eoo`<000Ioo`03001oogoo0:=oo`8000Uooa/0
01ioo`00;Woo00<007ooOol01Goo00<007ooOol0Xgoo0P002Goo0P002Goo0P003Woo3@004Goo000^
Ool00`00Oomoo`05Ool20035Ool20009Ool20008Ool2000<Ool002ioo`03001oogoo00Eoo`03001o
ogoo0<Aoo`8000Uoo`8000Qoo`8000aoo`00;Woo00<007ooOol01Goo00<007ooOol0igoo000]Ool2
0007Ool00`00Oomoo`3WOol003Ioo`03001oogoo0>Moo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.25701, -0.07747, 
  0.0231708, 0.00624851}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.133668 0.0147151 0.588604 [
[.15748 .00222 -3 -9 ]
[.15748 .00222 3 0 ]
[.29114 .00222 -3 -9 ]
[.29114 .00222 3 0 ]
[.42481 .00222 -3 -9 ]
[.42481 .00222 3 0 ]
[.55848 .00222 -3 -9 ]
[.55848 .00222 3 0 ]
[.69215 .00222 -3 -9 ]
[.69215 .00222 3 0 ]
[.82581 .00222 -3 -9 ]
[.82581 .00222 3 0 ]
[.95948 .00222 -3 -9 ]
[.95948 .00222 3 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15748 .01472 m
.15748 .02097 L
s
[(1)] .15748 .00222 0 1 Mshowa
.29114 .01472 m
.29114 .02097 L
s
[(2)] .29114 .00222 0 1 Mshowa
.42481 .01472 m
.42481 .02097 L
s
[(3)] .42481 .00222 0 1 Mshowa
.55848 .01472 m
.55848 .02097 L
s
[(4)] .55848 .00222 0 1 Mshowa
.69215 .01472 m
.69215 .02097 L
s
[(5)] .69215 .00222 0 1 Mshowa
.82581 .01472 m
.82581 .02097 L
s
[(6)] .82581 .00222 0 1 Mshowa
.95948 .01472 m
.95948 .02097 L
s
[(7)] .95948 .00222 0 1 Mshowa
.125 Mabswid
.05054 .01472 m
.05054 .01847 L
s
.07728 .01472 m
.07728 .01847 L
s
.10401 .01472 m
.10401 .01847 L
s
.13074 .01472 m
.13074 .01847 L
s
.18421 .01472 m
.18421 .01847 L
s
.21094 .01472 m
.21094 .01847 L
s
.23768 .01472 m
.23768 .01847 L
s
.26441 .01472 m
.26441 .01847 L
s
.31788 .01472 m
.31788 .01847 L
s
.34461 .01472 m
.34461 .01847 L
s
.37135 .01472 m
.37135 .01847 L
s
.39808 .01472 m
.39808 .01847 L
s
.45155 .01472 m
.45155 .01847 L
s
.47828 .01472 m
.47828 .01847 L
s
.50501 .01472 m
.50501 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.58521 .01472 m
.58521 .01847 L
s
.61195 .01472 m
.61195 .01847 L
s
.63868 .01472 m
.63868 .01847 L
s
.66541 .01472 m
.66541 .01847 L
s
.71888 .01472 m
.71888 .01847 L
s
.74561 .01472 m
.74561 .01847 L
s
.77235 .01472 m
.77235 .01847 L
s
.79908 .01472 m
.79908 .01847 L
s
.85255 .01472 m
.85255 .01847 L
s
.87928 .01472 m
.87928 .01847 L
s
.90602 .01472 m
.90602 .01847 L
s
.93275 .01472 m
.93275 .01847 L
s
.98622 .01472 m
.98622 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02496 .01474 L
.02602 .01479 L
.02723 .0149 L
.02837 .01505 L
.03041 .01541 L
.03263 .01594 L
.03507 .01669 L
.03765 .01766 L
.04229 .01985 L
.05156 .02577 L
.06177 .0344 L
.08314 .05809 L
.10316 .08524 L
.14125 .14404 L
.18176 .20938 L
.22077 .26974 L
.25829 .32279 L
.29822 .37267 L
.33667 .41402 L
.37752 .45111 L
.41688 .48078 L
.45476 .50438 L
.49504 .5249 L
.53384 .54089 L
.57114 .55336 L
.61086 .56404 L
.64908 .57224 L
.68972 .57916 L
.72886 .58441 L
.76652 .58841 L
.80659 .59177 L
.84516 .5943 L
.88225 .59622 L
.92175 .59783 L
.95948 .59902 L
s
.008 w
.04052 .01472 Mdot
.07393 .02649 Mdot
.10735 .07358 Mdot
.14077 .11478 Mdot
.17419 .1913 Mdot
.2076 .2325 Mdot
.24102 .2737 Mdot
.27444 .33845 Mdot
.30785 .38554 Mdot
.34127 .45617 Mdot
.37469 .47971 Mdot
.4081 .51503 Mdot
.44152 .53269 Mdot
.47494 .54446 Mdot
.50835 .55034 Mdot
.54177 .55623 Mdot
.57519 .55623 Mdot
.6086 .57389 Mdot
.64202 .57977 Mdot
.67544 .57977 Mdot
.70886 .58566 Mdot
.74227 .59155 Mdot
.77569 .59155 Mdot
.80911 .59743 Mdot
.84252 .59743 Mdot
.87594 .59743 Mdot
.90936 .60332 Mdot
.94277 .60332 Mdot
.97619 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From (Dialog) In[220]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool003Moo`<0029oo`@0021oo`<0029oo`<0025oo`<0029oo`80029oo`03001oogoo00]oo`00>7oo
00<007ooOol08Woo00<007ooOol08goo00<007ooOol087oo00<007ooOol08goo00<007ooOol07Woo
00@007ooOol0025oo`03001oogoo00]oo`00>7oo00<007ooOol08goo00<007ooOol08Woo00<007oo
Ool07Woo100097oo00<007ooOol07Woo00@007ooOol0029oo`03001oogoo00Yoo`00>7oo00<007oo
Ool097oo00<007ooOol07goo0P008Goo00<007oo00008Woo0`008Goo0`008goo00<007ooOol02Woo
000hOol00`00Oomoo`0QOol01000Oomoo`008goo00<007ooOol07Woo00<007oo00008Woo00<007oo
Ool08Goo00<007ooOol097oo00<007ooOol02Goo000gOol2000TOol2000QOol3000ROol2000ROol4
000QOol3000POol4000;Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000E
Ool00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`003gooo`004@000Goo000EOol01000
Oomoogoo10001goo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol00Woo000EOol00`00Oomoo`04Ool00`00Oomoo`0JOol00`00Oomoo`0ROol00`00Oomo
o`0QOol00`00Oomoo`0QOol00`00Oomoo`0ROol00`00Oomoo`0QOol00`00Oomoo`0QOol00`00Oomo
o`0:Ool001Eoo`03001oogoo00Eoo`03001oogoo009oo`800?aoo`005Goo00<007ooOol01Woo00@0
07ooOomoo`800?aoo`005Goo00<007ooOol01goo00<007ooOol0oWoo000EOol00`00Oomoo`07Ool0
0`00Oomoo`3nOol001Eoo`03001oogoo00Qoo`03001oogoo0?eoo`005Goo0P002Woo00<007ooOol0
o7oo000EOol00`00Oomoo`0:Ool00`00Oomoo`3kOol001Eoo`03001oogoo00]oo`03001oogoo0?Yo
o`005Goo00<007ooOol037oo00<007ooOol0nGoo000EOol00`00Oomoo`0=Ool00`00Oomoo`3hOol0
01Eoo`03001oogoo00eoo`03001oogoo0?Qoo`005Goo00<007ooOol03Woo00<007ooOol0mgoo000E
Ool00`00Oomoo`0?Ool00`00Oomoo`3fOol001Eoo`80015oo`03001oogoo00800?=oo`005Goo00<0
07ooOol04Goo00@007oo00000?=oo`005Goo00<007ooOol04Woo00<007ooOol0lgoo000EOol00`00
Oomoo`0COol00`00Oomoo`3bOol001Eoo`03001oogoo01=oo`03001oogoo0?9oo`005Goo00<007oo
Ool057oo00<007ooOol0lGoo000EOol00`00Oomoo`0EOol00`00Oomoo`3`Ool001Eoo`03001oogoo
01Eoo`03001oogoo0?1oo`005Goo0P005goo00<007ooOol0kgoo000EOol00`00Oomoo`0FOol00`00
Oomoo`3_Ool001Eoo`03001oogoo01Moo`03001oogoo0>ioo`005Goo00<007ooOol067oo00@007oo
Oomoo`800>Yoo`005Goo00<007ooOol067oo00@007ooOomoo`800>Yoo`005Goo00<007ooOol06Goo
00<007ooOol0k7oo0002Ool20004Ool20003Ool40004Ool00`00Oomoo`0JOol00`00Oomoo`3[Ool0
0005Ool007ooOol00003Ool20004Ool00`00Oomoo`04Ool00`00Oomoo`0JOol00`00Oomoo`3[Ool0
0005Ool007ooOol0000:Ool00`00Oomoo`03Ool3000KOol00`00Oomoo`3ZOol00005Ool007ooOol0
000;Ool00`00Oomoo`02Ool00`00Oomoo`0KOol00`00Oomoo`3ZOol00005Ool007ooOol00008Ool0
1000Oomoo`0017oo00<007ooOol077oo00<007ooOol0jGoo0002Ool2000:Ool20005Ool00`00Oomo
o`0MOol00`00Oomoo`3XOol001Eoo`03001oogoo01eoo`03001oogoo0>Qoo`005Goo00<007ooOol0
7Woo00<007ooOol0igoo000EOol00`00Oomoo`0OOol00`00Oomoo`3VOol001Eoo`03001oogoo01mo
o`03001oogoo0>Ioo`005Goo0P008Goo00<007ooOol0iGoo000EOol00`00Oomoo`0POol00`00Oomo
o`3UOol001Eoo`03001oogoo025oo`03001oogoo0>Aoo`005Goo00<007ooOol08Woo00<007ooOol0
hgoo000EOol00`00Oomoo`0ROol00`00Oomoo`3SOol001Eoo`03001oogoo02=oo`03001oogoo0>9o
o`005Goo00<007ooOol08goo00<007ooOol0hWoo000EOol00`00Oomoo`0TOol00`00Oomoo`3QOol0
01Eoo`8002Ioo`800>5oo`005Goo00<007ooOol09Goo0P00hGoo000EOol00`00Oomoo`0VOol00`00
Oomoo`3OOol001Eoo`03001oogoo02Ioo`03001oogoo0=moo`005Goo00<007ooOol09goo00<007oo
Ool0gWoo000EOol00`00Oomoo`0XOol00`00Oomoo`3MOol001Eoo`03001oogoo02Qoo`03001oogoo
0=eoo`005Goo00<007ooOol0:Goo00<007ooOol0g7oo000EOol2000[Ool00`00Oomoo`3KOol001Eo
o`03001oogoo02Yoo`03001oogoo0=]oo`005Goo00<007ooOol0:goo00<007ooOol0fWoo000EOol0
0`00Oomoo`0/Ool01000Ool00000f7oo000EOol00`00Oomoo`0/Ool01000Ool00000f7oo000EOol0
0`00Oomoo`0]Ool00`00Oomoo`3HOol0009oo`8000Aoo`8000Aoo`<000Aoo`03001oogoo02ioo`03
001oogoo0=Moo`0000Eoo`00Oomoo`0000=oo`8000Eoo`03001oogoo00=oo`03001oogoo02moo`03
001oogoo0=Ioo`0000Eoo`00Oomoo`0000Qoo`@000Aoo`<002moo`03001oogoo0=Ioo`0000Eoo`00
Oomoo`0000Qoo`03001oo`0000Eoo`03001oogoo031oo`03001oogoo0=Eoo`0000Eoo`00Oomoo`00
00Qoo`03001oo`0000Eoo`03001oogoo035oo`03001oogoo0=Aoo`000Woo0P002Woo0P001Goo00<0
07ooOol0<Goo00<007ooOol0e7oo000EOol00`00Oomoo`0bOol00`00Oomoo`3COol001Eoo`03001o
ogoo03=oo`03001oogoo0=9oo`005Goo00<007ooOol0<goo00@007ooOomoo`800<moo`005Goo00<0
07ooOol0=7oo00<007ooOol00P00cgoo000EOol2000fOol00`00Oomoo`3@Ool001Eoo`03001oogoo
03Eoo`03001oogoo0=1oo`005Goo00<007ooOol0=Woo00<007ooOol0cgoo000EOol00`00Oomoo`0g
Ool00`00Oomoo`3>Ool001Eoo`03001oogoo03Moo`03001oogoo0<ioo`005Goo00<007ooOol0>7oo
00<007ooOol0cGoo000EOol00`00Oomoo`0iOol00`00Oomoo`3<Ool001Eoo`03001oogoo03Uoo`03
001oogoo0<aoo`005Goo0P00>goo00<007ooOol0bgoo000EOol00`00Oomoo`0kOol00`00Oomoo`3:
Ool001Eoo`03001oogoo03]oo`03001oogoo0<Yoo`005Goo00<007ooOol0?7oo00<007ooOol0bGoo
000EOol00`00Oomoo`0mOol00`00Oomoo`38Ool001Eoo`03001oogoo03eoo`03001oogoo0<Qoo`00
5Goo00<007ooOol0?Woo00<007ooOol0agoo000EOol00`00Oomoo`0oOol00`00Oomoo`36Ool001Eo
o`80045oo`<00<Eoo`005Goo00<007ooOol0@Goo0P00aGoo000EOol00`00Oomoo`12Ool00`00Oomo
o`33Ool001Eoo`03001oogoo04=oo`03001oogoo0<9oo`005Goo00<007ooOol0@goo00<007ooOol0
`Woo000EOol00`00Oomoo`14Ool00`00Oomoo`31Ool0009oo`8000Aoo`8000Aoo`8000Eoo`03001o
ogoo04Eoo`03001oogoo0<1oo`0000Eoo`00Oomoo`0000=oo`8000=oo`04001oogoo0004Ool00`00
Oomoo`16Ool00`00Oomoo`2oOol00005Ool007ooOol00008Ool01000Oomoo`0017oo0`00Agoo00<0
07ooOol0_Woo00001Goo001oogoo000027oo0`001Goo00<007ooOol0B7oo00<007ooOol0_Goo0000
1Goo001oogoo000027oo00<007ooOol01Goo00<007ooOol0B7oo00<007ooOol0_Goo0002Ool2000:
Ool30004Ool00`00Oomoo`19Ool00`00Oomoo`2lOol001Eoo`03001oogoo04Yoo`800;aoo`005Goo
00<007ooOol0BWoo0P00_7oo000EOol00`00Oomoo`1<Ool00`00Oomoo`2iOol001Eoo`03001oogoo
04eoo`03001oogoo0;Qoo`005Goo0P00CWoo00<007ooOol0^7oo000EOol00`00Oomoo`1>Ool00`00
Oomoo`2gOol001Eoo`03001oogoo04moo`03001oogoo0;Ioo`005Goo00<007ooOol0D7oo00<007oo
Ool0]Goo000EOol00`00Oomoo`1AOol00`00Oomoo`2dOol001Eoo`03001oogoo059oo`800;Aoo`00
5Goo00<007ooOol0E7oo00<007ooOol0/Goo000EOol00`00Oomoo`1EOol00`00Oomoo`2`Ool001Eo
o`8005Moo`03001oogoo0:moo`005Goo00<007ooOol0Egoo00<007ooOol0[Woo000EOol00`00Oomo
o`1HOol00`00Oomoo`2]Ool001Eoo`03001oogoo05Uoo`03001oogoo0:aoo`005Goo00<007ooOol0
FWoo00<007ooOol0Zgoo000EOol00`00Oomoo`1KOol00`00Oomoo`2ZOol001Eoo`03001oogoo05ao
o`03001oogoo0:Uoo`005Goo00<007ooOol0GGoo0P00ZGoo000EOol2001DOol2000:Ool00`00Oomo
o`2VOol001Eoo`03001oogoo05=oo`8000]oo`03001oogoo0:Eoo`005Goo00<007ooOol0HGoo0P00
YGoo000EOol00`00Oomoo`1SOol00`00Oomoo`2ROol001Eoo`03001oogoo06Aoo`800:9oo`005Goo
00<007ooOol0IWoo00<007ooOol0Wgoo0002Ool20004Ool20004Ool20005Ool00`00Oomoo`1LOol2
0009Ool00`00Oomoo`2NOol00005Ool007ooOol00003Ool20003Ool01000Oomoo`0017oo00<007oo
Ool0G7oo0P002Woo0P00WWoo00001Goo001oogoo000027oo00@007ooOol000Aoo`<006Yoo`8009ao
o`0000Eoo`00Oomoo`0000Uoo`8000Eoo`03001oogoo06aoo`03001oogoo09Uoo`0000Eoo`00Oomo
o`0000Qoo`04001oogoo0004Ool00`00Oomoo`1]Ool2002IOol0009oo`8000Yoo`8000Eoo`03001o
ogoo06moo`8009Moo`005Goo00<007ooOol0LGoo00<007ooOol0U7oo000EOol00`00Oomoo`1bOol2
002DOol001Eoo`03001oogoo07Aoo`80099oo`005Goo00<007ooOol0MWoo0P00T7oo000EOol2001V
Ool2000AOol00`00Oomoo`2=Ool001Eoo`03001oogoo06Eoo`80019oo`8008eoo`005Goo00<007oo
Ool0Ngoo0P00Rgoo000EOol00`00Oomoo`1mOol20029Ool001Eoo`03001oogoo06ioo`8000moo`<0
08Ioo`005Goo00<007ooOol0KWoo0P004Woo0`00Pgoo000EOol00`00Oomoo`25Ool30020Ool001Eo
o`03001oogoo08Qoo`<007eoo`005Goo0P00N7oo0P004Woo0`00NWoo000EOol00`00Oomoo`1gOol2
0007Ool2000<Ool3001gOol001Eoo`03001oogoo081oo`8000moo`@007=oo`005Goo00<007ooOol0
RGoo0P001goo0P0000=oo`0000000P00Kgoo000EOol00`00Oomoo`29Ool20007Ool20005Ool3001/
Ool001Eoo`03001oogoo09aoo`@006Qoo`005Goo00<007ooOol0X7oo0`00IGoo000EOol00`00Oomo
o`2SOol3001ROol001Eoo`8009aoo`8000Uoo`P005Yoo`005Goo00<007ooOol0Vgoo0P0027oo0P00
1goo2000DWoo000EOol00`00Oomoo`2UOol20007Ool20006Ool5001=Ool001Eoo`03001oogoo0;Mo
o`80009oo`P004Eoo`005Goo00<007ooOol0]goo0P001goo0P0000=oo`0000002@00>Woo000EOol0
0`00Oomoo`30Ool20007Ool20003Ool:000`Ool000eoo`<000Eoo`03001oogoo0=9oo`8000AooaD0
01]oo`003Woo00<007ooOol017oo00<007ooOol0dWoo0P001goo0P001goo0P001goo3`0037oo000>
Ool00`00Oomoo`04Ool3003]Ool20007Ool20007Ool20007Ool000ioo`03001oogoo00Aoo`03001o
ogoo0>eoo`8000Moo`8000Moo`8000Moo`003Woo00<007ooOol017oo00<007ooOol0ogoo2Goo000=
Ool20006Ool00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.591267, -0.07747, 
  0.0275152, 0.00624851}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "PresentResults"->{
    Cell[1786, 53, 864, 17, 66, "DefinitionBox",
      CellTags->"PresentResults"]},
  "CompareLogL"->{
    Cell[24413, 654, 561, 13, 50, "DefinitionBox",
      CellTags->"CompareLogL"]},
  "PlotLogL"->{
    Cell[31370, 834, 884, 21, 60, "DefinitionBox",
      CellTags->"PlotLogL"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"PresentResults", 78934, 2488},
  {"CompareLogL", 79038, 2491},
  {"PlotLogL", 79138, 2494}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 44, 0, 36, "SubsectionIcon"],
Cell[1786, 53, 864, 17, 66, "DefinitionBox",
  CellTags->"PresentResults"],
Cell[2653, 72, 70, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2748, 76, 194, 4, 27, "Input"],
Cell[2945, 82, 21020, 556, 241, "Output"]
}, Open  ]],
Cell[23980, 641, 324, 6, 36, "Text"],
Cell[24307, 649, 103, 3, 22, "Text"],
Cell[24413, 654, 561, 13, 50, "DefinitionBox",
  CellTags->"CompareLogL"],
Cell[24977, 669, 254, 5, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[25256, 678, 87, 2, 27, "Input"],
Cell[25346, 682, 298, 5, 20, "Output"]
}, Open  ]],
Cell[25659, 690, 296, 5, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[25980, 699, 87, 2, 27, "Input"],
Cell[26070, 703, 311, 5, 23, "Output"]
}, Open  ]],
Cell[26396, 711, 308, 5, 36, "Text"],
Cell[26707, 718, 2233, 47, 70, "DefinitionBox"],
Cell[28943, 767, 398, 7, 36, "Text"],
Cell[29344, 776, 270, 6, 24, "Text"],
Cell[29617, 784, 104, 2, 22, "Text"],
Cell[29724, 788, 203, 4, 22, "Text"],
Cell[29930, 794, 259, 6, 36, "Text"],

Cell[CellGroupData[{
Cell[30214, 804, 299, 6, 28, "Input"],
Cell[30516, 812, 839, 19, 85, "Output"]
}, Open  ]],
Cell[31370, 834, 884, 21, 60, "DefinitionBox",
  CellTags->"PlotLogL"],
Cell[32257, 857, 173, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[32455, 865, 123, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[32603, 871, 19565, 758, 184, 10244, 638, "GraphicsData", "PostScript", \
"Graphics"],
Cell[52171, 1631, 12418, 395, 184, 4149, 288, "GraphicsData", "PostScript", \
"Graphics"],
Cell[64592, 2028, 13465, 434, 184, 4697, 321, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

