(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5344,        133]*)
(*NotebookOutlinePosition[      6364,        167]*)
(*  CellTagsIndexPosition[      6287,        161]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Analysing replicate samples", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"DoReplicates", "[", 
              RowBox[{
              "m", ",", \(p\&_\), ",", " ", \(n\_loci\), ",", 
                " ", \({n\_reps, n\_inds}\), ",", " ", 
                StyleBox["metList",
                  FontSlant->"Italic"], ",", " ", "r"}], 
              "]"}], \(fits\ a\ matrix\ of\ cumulants, \ \[Kappa]\_\(j, k\), \
\ to\ replicate\ samples, \ 
            using\ FindMLE[]\ and\ MetropolisDisequilibrium[]\  . \ \ Assumes\
\ \[Delta]p = 1. \)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"DoReplicates"],

Cell[TextData[{
  "\tDoReplicates[] calculates the equilibrium genotype frequencies in a \
population which receives immigrants at rates ",
  Cell[BoxData[
      \(TraditionalForm\`m\[VeryThinSpace]p\&_, \ m\[VeryThinSpace]q\&_\)]],
  " from source populations fixed for alternative alleles at ",
  Cell[BoxData[
      \(TraditionalForm\`n\_loci . \ \ n\_reps\)]],
  "datasets are then sampled from such a population, using DrawSamples[].  \
These are stored in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(Data\)\([\)\(\(r[m, p\&_]\)[k]\)\)\)]],
  "], where ",
  Cell[BoxData[
      \(TraditionalForm\`\(r[m, p\&_]\)[k]\)]],
  " labels ",
  Cell[BoxData[
      \(TraditionalForm\`k = 1  \[Ellipsis]n\_reps\)]],
  "replicate \"sites\".  For each replicate site, MetropolisDisequilibrium[] \
is called to fit a matrix of cumulants, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\_\(j, k\)\)]],
  " to the sampled data."
}], "Text"],

Cell[TextData[{
  "\tMaximum likelihood estimation is hard to automate.  The key difficulty \
is that the obvious initial state, in which allele frequencies and moments \
(from EstimateMoments[]) are set at their sample values, may be inadmissible \
because it gives negative genotype frequencies.  If these values are to be \
held fixed, then nothing can be done: EstimateMoments[] may indeed give \
inadmissible estimates.  However, if some or all moments or allele \
frequencies are to be fitted, a different starting state can be chosen.  This \
can be done either by deflating those moments that are free to change, or by \
making allele frequencies larger.  DoReplicates[] tries the first method if \
possible.  (This may lead to an underestimate of the moments if the \
Metropolis algorithm is not run for long enough).  If none of the moments can \
be changed, or if deflating them does not give an admissible solution, and if \
allele frequencies are free to change, then DoReplicates[] tries adjusting \
the allele frequencies.  If setting all allele frequencies to the mean \
sampled ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " gives an admissible solution, then they are adjusted towards this value; \
if not, but if setting all allele frequencies to the true value gives an \
admissible solution, then they are adjusted towards this value; finally, \
adjustment towards ",
  Cell[BoxData[
      \(TraditionalForm\`p = \(q = 1\/2\)\)]],
  " is tried.  "
}], "Text"],

Cell[TextData[{
  "\tThis procedure usually gives an admissible starting value, provided that \
some parameters are free to change.  If none of these attempts is successful, \
then a warning message is printed: \"",
  StyleBox["Failed to find a sensible starting point",
    FontSlant->"Italic"],
  "\".  However, even then the Metropolis algorithm may by chance be able to \
find a random change which takes moments or allele frequencies to valid \
values."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{548, 658},
WindowMargins->{{Automatic, -2}, {Automatic, 5}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "DoReplicates"->{
    Cell[1795, 53, 627, 14, 66, "DefinitionBox",
      CellTags->"DoReplicates"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"DoReplicates", 6179, 154}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 53, 0, 36, "SubsectionIcon"],
Cell[1795, 53, 627, 14, 66, "DefinitionBox",
  CellTags->"DoReplicates"],
Cell[2425, 69, 939, 23, 78, "Text"],
Cell[3367, 94, 1488, 25, 204, "Text"],
Cell[4858, 121, 470, 9, 68, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

