(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     67471,       1447]*)
(*NotebookOutlinePosition[    139880,       4048]*)
(*  CellTagsIndexPosition[    139571,       4036]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Fitness", "SubsectionIcon"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Multilocus`Multilocus`;\)\)], "Input",
  CellLabel->"In[1]:=  (19:29:37 on 3/20/01)"],

Cell[BoxData[
    StyleBox[GridBox[{
          {"W", "fitness"},
          {\(W\&_ = \[LeftAngleBracket]W\[RightAngleBracket]\), \(mean\ \
fitness\)},
          {
            "\[DoubleStruckCapitalW]", \(the\ set\ of\ all\ loci\ affecting\ \
fitness\)},
          {\(\[GothicA]\_\[DoubleStruckCapitalU]\ \n
            
            or\ SelectionCoefficient[\[DoubleStruckCapitalU]]\), \(\(the\)\(\ \
\)\(coefficient\)\(\ \)\(describing\)\(\ \)\(selection\)\(\ \)\(on\)\(\ \
\)\(the\)\(\ \)\(set\)\(\ \)\(of\)\(\ \)\(genes\)\(\ \)\)}
          },
        ColumnAlignments->{Left},
        GridFrame->False],
      FontFamily->"Times"]], "DefinitionBox",
  CellTags->{"SelectionCoefficient", "Fitness"}],

Cell[TextData[{
  "The polynomial representation of traits is especially important where the \
trait is relative fitness.  The coefficients in the expansion of relative \
fitness are then the ",
  StyleBox["selection coefficients",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\(\ \)\(W\/W\&_ = \(\[Sum]\_\(\[DoubleStruckCapitalU] \[SubsetEqual] \
\[DoubleStruckCapitalW]\)\(\[GothicA]\_\[DoubleStruckCapitalU]\) \((\[Zeta]\_\
\[DoubleStruckCapitalU] - \[GothicCapitalD]\_\[DoubleStruckCapitalU])\)\ with\
\ a\_\[EmptySet] = 1\)\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "By default, selection coefficients are denoted by ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicA]\_\(\(\[DoubleStruckCapitalU]\)\(\ \)\)\ \
\(\((entered\ as\ \[AliasIndicator]goa\[AliasIndicator])\)\(.\)\)\)]]
}], "Text"],

Cell[BoxData[
    StyleBox[GridBox[{
          {\(MakeFitnessSet[W]\), \(gives\ the\ set\ of\ genes - in - 
              context\ on\ which\ fitness, \ W, \ \(\(depends\)\(.\)\)\)}
          },
        ColumnAlignments->{Left},
        GridFrame->False],
      FontFamily->"Times"]], "DefinitionBox",
  CellTags->"MakeFitnessSet"],

Cell["\<\
Here, additive selection acts on maternal and paternal genes at \
three loci, {i, j, k}:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeFitnessSet[
      1 + s \(\[Sum]\+\(\[Alpha] \[Element] {i, j, k}\)\(\[Gamma]\_\[Alpha]\) \
\((\[Zeta]\_\(\[Alpha]\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\) + \[Zeta]\_\(\[Alpha]\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\)]\)], "Input",
  CellLabel->"In[2]:=  (17:35:21 on 3/19/01)"],

Cell[BoxData[
    \({i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
      i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
      j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
      j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
      k\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
      k\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\)], \
"Output",
  CellLabel->"Out[2]=  (17:35:21 on 3/19/01)"]
}, Open  ]],

Cell[TextData[{
  "The expression may involve either ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_\[DoubleStruckI]\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\[DoubleStruckI]\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeFitnessSet[
      1 + s \(\[Sum]\+\(\[Alpha] \[Element] {i, j, k}\)\(\[Gamma]\_\[Alpha]\) \
\((X\_\(\[Alpha]\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}\) \
+ X\_\(\[Alpha]\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}\))\
\)\)]\)], "Input",
  CellLabel->"In[3]:=  (17:35:41 on 3/19/01)"],

Cell[BoxData[
    \({i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
      i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
      j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
      j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
      k\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
      k\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\)], \
"Output",
  CellLabel->"Out[3]=  (17:35:42 on 3/19/01)"]
}, Open  ]],

Cell["\<\
The set can be evaluated correctly even if the set of genes is not \
defined:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeFitnessSet[
      1 + \(\[Delta]\_\[Alpha]\) \((\[Zeta]\_\(i\_\[GothicCapitalM]\) + \
\[Zeta]\_\(i\_\[GothicCapitalF]\))\) + 
        s \((\[Sum]\+\(\[Alpha] \[Element] S\)\(\[Gamma]\_\[Alpha]\) \((\
\[Zeta]\_\(j\_\[GothicCapitalM]\) + \[Zeta]\_\(j\_\[GothicCapitalF]\))\) \((a \
+ \[Zeta]\_\(\[Alpha]\_\[GothicCapitalM]\) + \[Zeta]\_\(\[Alpha]\_\
\[GothicCapitalF]\))\))\)\^3]\)], "Input",
  CellLabel->"In[4]:=  (17:35:52 on 3/19/01)"],

Cell[BoxData[
    \({i\_\[GothicCapitalF], i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
      j\_\[GothicCapitalM]}\)], "Output",
  CellLabel->"Out[4]=  (17:35:52 on 3/19/01)"]
}, Open  ]],

Cell[TextData[{
  "The set of genes contained in the set S, and in context \
{\[GothicCapitalZ],\[GothicCapitalM],\[GothicCapitalF]} is represented as ",
  Cell[BoxData[
      \(S\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}\)]],
  "."
}], "Text"],

Cell["\<\
A warning is generated if the expressions are not in fact \
polynomial:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeFitnessSet[
      1 + \(\[Delta]\_\[Alpha]\) 
          Log[\[Zeta]\_\(i\_\[GothicCapitalM]\) + \[Zeta]\_\(i\_\
\[GothicCapitalF]\)\ ] + 
        s \((\[Sum]\+\(\[Alpha] \[Element] S\)\(\[Gamma]\_\[Alpha]\) \((\
\[Zeta]\_\(j\_\[GothicCapitalM]\) + \[Zeta]\_\(j\_\[GothicCapitalF]\))\) \((a \
+ \[Zeta]\_\(\[Alpha]\_\[GothicCapitalM]\) + \[Zeta]\_\(\[Alpha]\_\
\[GothicCapitalF]\))\))\)\^3]\)], "Input",
  CellLabel->"In[6]:=  (17:37:30 on 3/19/01)"],

Cell[BoxData[
    \(MakeFitnessSet::"notpolynomial" \(\(:\)\(\ \)\) 
      "\!\(\(\(Log[\(\(\[Zeta]\_\(i\_\[GothicCapitalF]\) + \[Zeta]\_\(i\_\
\[GothicCapitalM]\)\)\)]\)\)\\ \[Delta]\_\[Alpha]\) is not polynomial in \
\!\({\[Zeta]\_\(i\_\[GothicCapitalF]\), \[Zeta]\_\(i\_\[GothicCapitalM]\)}\)"\
\)], "Message",
  CellLabel->"From In[6]:=  (17:37:30 on 3/19/01)"],

Cell[BoxData[
    \({j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\)], "Output",
  CellLabel->"Out[6]=  (17:37:30 on 3/19/01)"]
}, Open  ]],

Cell["\<\
It may still be possible to approximate the selection coefficients \
in terms of a series expansion; but that is best done by hand.\
\>", "Text"],

Cell[TextData[{
  "If there are higher powers of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_\[DoubleStruckI]\ or\ X\_\[DoubleStruckI], \
\ then\ the\ corresponding\ gene - in - 
        context\ \[DoubleStruckI]\ is\ \(\(repeated\)\(:\)\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeFitnessSet[\[Alpha] + \(\[Beta]\_i\) \(X\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM]}\)\) 
          X\_i\_{\[GothicCapitalZ], \[GothicCapitalF]}\%2]\)], "Input",
  CellLabel->"In[2]:=  (18:36:29 on 3/19/01)"],

Cell[BoxData[
    \({i\_{\[GothicCapitalZ], \[GothicCapitalF]}, 
      i\_{\[GothicCapitalZ], \[GothicCapitalF]}, 
      i\_{\[GothicCapitalZ], \[GothicCapitalM]}}\)], "Output",
  CellLabel->"Out[2]=  (18:36:29 on 3/19/01)"]
}, Open  ]],

Cell[TextData[{
  "This is because, with ",
  ButtonBox["multiple alleles",
    ButtonData:>{"Allelic state", None},
    ButtonStyle->"AddOnsLink"],
  ", higher powers are needed to describe the phenotype, and higher-order \
associations are needed to descibe genotype frequencies.  The set of \
coefficients that is needed is just the set of distinct subsets of \
MakeFitnessSet[]."
}], "Text",
  CellTags->"Multiple alleles"],

Cell["\<\
If there are in fact only two alleles, Union[MakeFitnessSet[]] can \
be used to remove unwanted repeats.  However, it is safer to work with the \
expression Expand[W]//.Biallelic[], which removes unnecesary higher powers of \
\[Zeta] and X.\
\>", "Text"],

Cell[BoxData[
    StyleBox[GridBox[{
          {\(MakeSelectionCoefficient[\[DoubleStruckCapitalU], 
              W]\), \(derives\ the\ coefficient\ \(W\&_\) \[GothicA]\_\
\[DoubleStruckCapitalU]\ from\ a\ polynomial\ expression\ W\ for\ the\ \
relative\ fitness\)}
          },
        ColumnAlignments->{Left},
        GridFrame->False],
      FontFamily->"Times"]], "DefinitionBox",
  CellTags->"MakeSelectionCoefficient"],

Cell["\<\
MakeSelectionCoefficient[] does not store results.  Time can be \
saved by storing results: for example, aa[\[DoubleStruckCapitalU]_]:=aa[\
\[DoubleStruckCapitalU]]=MakeSelectionCoefficient[\[DoubleStruckCapitalU],W];\
\
\>", "Text"],

Cell[TextData[{
  "Here, quadratic stabilising selection acts on the additive trait Z, \
towards optimum ",
  Cell[BoxData[
      \(TraditionalForm\`Zopt . \ \ The\ trait\ is\ determined\ by\ loci\ {i, \
\ j, \ k}\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Z = \[Sum]\+\(\[Alpha] \[Element] {i, j}\)\((\[Zeta]\_\(\[Alpha]\_\
\[GothicCapitalM]\) + \[Zeta]\_\(\[Alpha]\_\[GothicCapitalF]\))\); 
    W = 1 - \(s\/2\) \((Z - Zopt)\)\^2\)], "Input",
  CellLabel->"In[16]:=  (11:27:27 on 3/21/01)"],

Cell[BoxData[
    \(1 - 
      1\/2\ s\ \((\(-Zopt\) + \[Zeta]\_\(i\_\[GothicCapitalF]\) + \
\[Zeta]\_\(i\_\[GothicCapitalM]\) + \[Zeta]\_\(j\_\[GothicCapitalF]\) + \
\[Zeta]\_\(j\_\[GothicCapitalM]\))\)\^2\)], "Output",
  CellLabel->"Out[16]=  (11:27:28 on 3/21/01)"]
}, Open  ]],

Cell["This is the mean fitness:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[LeftAngleBracket]W\[RightAngleBracket]\)], "Input",
  CellLabel->"In[72]:=  (10:58:27 on 3/21/01)"],

Cell[BoxData[
    \(1 - \(s\ Zopt\^2\)\/2 + 
      s\ Zopt\ \[GothicCapitalD]\_{i\_\[GothicCapitalF]} + 
      s\ Zopt\ \[GothicCapitalD]\_{i\_\[GothicCapitalM]} + 
      s\ Zopt\ \[GothicCapitalD]\_{j\_\[GothicCapitalF]} + 
      s\ Zopt\ \[GothicCapitalD]\_{j\_\[GothicCapitalM]} - 
      1\/2\ s\ \[GothicCapitalD]\_{i\_\[GothicCapitalF], \
i\_\[GothicCapitalF]} - 
      s\ \[GothicCapitalD]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM]} - 
      s\ \[GothicCapitalD]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF]} - 
      s\ \[GothicCapitalD]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalM]} - 
      1\/2\ s\ \[GothicCapitalD]\_{i\_\[GothicCapitalM], \
i\_\[GothicCapitalM]} - 
      s\ \[GothicCapitalD]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF]} - 
      s\ \[GothicCapitalD]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalM]} - 
      1\/2\ s\ \[GothicCapitalD]\_{j\_\[GothicCapitalF], \
j\_\[GothicCapitalF]} - 
      s\ \[GothicCapitalD]\_{j\_\[GothicCapitalF], j\_\[GothicCapitalM]} - 
      1\/2\ s\ \[GothicCapitalD]\_{j\_\[GothicCapitalM], \
j\_\[GothicCapitalM]}\)], "Output",
  CellLabel->"Out[72]=  (10:58:27 on 3/21/01)"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox[
        RowBox[{"Note", " ", "that", 
          FormBox[\(W\&_\),
            "TraditionalForm"], "can", " ", "be", " ", "brought", " ", "out", 
          " ", "of", " ", "the", " ", "selection", " ", "coefficients"}],
        FontFamily->"Times"], 
      StyleBox[",",
        FontFamily->"Times"], 
      StyleBox[" ",
        FontFamily->"Times"], 
      RowBox[{
        StyleBox["since",
          FontFamily->"Times"], 
        StyleBox[" ",
          FontFamily->"Times"], 
        StyleBox["it",
          FontFamily->"Times"], 
        StyleBox[" ",
          FontFamily->"Times"], 
        StyleBox["is",
          FontFamily->"Times"], 
        StyleBox[" ",
          FontFamily->"Times"], 
        StyleBox["constant",
          FontFamily->"Times"], 
        StyleBox[" ",
          FontFamily->"Times"], 
        StyleBox["over",
          FontFamily->"Times"], 
        StyleBox[" ",
          FontFamily->"Times"], 
        StyleBox[\(genotypes . \ \ It\),
          FontFamily->"Times"], 
        StyleBox[" ",
          FontFamily->"Times"], 
        StyleBox["is",
          FontFamily->"Times"], 
        StyleBox[" ",
          FontFamily->"Times"], 
        StyleBox["much",
          FontFamily->"Times"], 
        StyleBox[" ",
          FontFamily->"Times"], 
        StyleBox["faster",
          FontFamily->"Times"], 
        StyleBox[" ",
          FontFamily->"Times"], 
        StyleBox["to",
          FontFamily->"Times"], 
        StyleBox[" ",
          FontFamily->"Times"], 
        StyleBox["calculate",
          FontFamily->"Times"], 
        StyleBox[
          FormBox[\(\(\[GothicA]\_\[DoubleStruckCapitalU]\)\(=\)\),
            "TraditionalForm"],
          FontFamily->"Times"], 
        StyleBox[
          RowBox[{
            FormBox[\(MakeSelectionCoefficient[\[DoubleStruckCapitalU], W]\),
              "TraditionalForm"], "/", 
            FormBox[\(W\&_\),
              "TraditionalForm"]}],
          FontFamily->"Times"], 
        StyleBox[" ",
          FontFamily->"Times"], 
        StyleBox["than",
          FontFamily->"Times"], 
        StyleBox[" ",
          FontFamily->"Times"], 
        StyleBox["to",
          FontFamily->"Times"], 
        StyleBox[" ",
          FontFamily->"Times"], 
        StyleBox["use",
          FontFamily->"Times"], 
        StyleBox[" ",
          
          FontFamily->
            "Times"], \(MakeSelectionCoefficient[\[DoubleStruckCapitalU], 
          W\/W\&_]\)}]}]], "Text"],

Cell[TextData[{
  "This is the additive selection on gene ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  "  in males, ",
  Cell[BoxData[
      \(TraditionalForm\`W\&_\[VeryThinSpace]\[GothicA]\_{i\_\[GothicCapitalM]\
}\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeSelectionCoefficient[{i\_\[GothicCapitalM]}, W]\)], "Input",
  CellLabel->"In[17]:=  (11:27:43 on 3/21/01)"],

Cell[BoxData[
    \(s\ Zopt\)], "Output",
  CellLabel->"Out[17]=  (11:27:43 on 3/21/01)"]
}, Open  ]],

Cell["\<\
Stabilising selection leads to second-order selection coefficients \
that reduce genetic variances and covariances:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({MakeSelectionCoefficient[{i\_\[GothicCapitalM], i\_\[GothicCapitalM]}, 
        W], MakeSelectionCoefficient[{i\_\[GothicCapitalM], 
          j\_\[GothicCapitalM]}, W]}\)], "Input",
  CellLabel->"In[18]:=  (11:27:45 on 3/21/01)"],

Cell[BoxData[
    \({\(-\(s\/2\)\), \(-s\)}\)], "Output",
  CellLabel->"Out[18]=  (11:27:45 on 3/21/01)"]
}, Open  ]],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicA]\_{} = 1\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(W\&_\[VeryThinSpace]\[GothicA]\_{}\),
            "TraditionalForm"], "=", \(W\&_\)}], TraditionalForm]]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeSelectionCoefficient[{}, 
          W] - \[LeftAngleBracket]W\[RightAngleBracket] // 
      Simplify\)], "Input",
  CellLabel->"In[19]:=  (11:27:48 on 3/21/01)"],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[19]=  (11:27:48 on 3/21/01)"]
}, Open  ]],

Cell[TextData[{
  "Note that this is an arbitrary definition: the contribution of the term ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[GothicA]\_\[DoubleStruckCapitalU]\) \((\[Zeta]\_\
\[DoubleStruckCapitalU] - \[GothicCapitalD]\_\[DoubleStruckCapitalU])\)\)]],
  " with \[DoubleStruckCapitalU]={} is necessarily zero."
}], "Text"],

Cell[TextData[{
  "In general, there may be ",
  ButtonBox["multiple alleles",
    ButtonData:>{"Phenotypes", "Multiple alleles"},
    ButtonStyle->"AddOnsLink"],
  " at each locus.  The genes-in-context must then be repeated \
appropriately:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[DoubleStruckCapitalW] = MakeFitnessSet[W]\)], "Input",
  CellLabel->"In[20]:=  (11:27:54 on 3/21/01)"],

Cell[BoxData[
    \({i\_\[GothicCapitalF], i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
      i\_\[GothicCapitalM], j\_\[GothicCapitalF], j\_\[GothicCapitalF], 
      j\_\[GothicCapitalM], j\_\[GothicCapitalM]}\)], "Output",
  CellLabel->"Out[20]=  (11:27:54 on 3/21/01)"]
}, Open  ]],

Cell["This lists all the selection coefficients:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({\[GothicA]\_#, MakeSelectionCoefficient[#, W]} &\) /@ 
        Union[Sort /@ Subsets[\[DoubleStruckCapitalW]]] // 
      TableForm\)], "Input",
  CellLabel->"In[77]:=  (10:59:24 on 3/21/01)"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(\[GothicA]\_{}\), \(1 - \(s\ Zopt\^2\)\/2 + 
              s\ Zopt\ \[GothicCapitalD]\_{i\_\[GothicCapitalF]} + 
              s\ Zopt\ \[GothicCapitalD]\_{i\_\[GothicCapitalM]} + 
              s\ Zopt\ \[GothicCapitalD]\_{j\_\[GothicCapitalF]} + 
              s\ Zopt\ \[GothicCapitalD]\_{j\_\[GothicCapitalM]} - 
              1\/2\ s\ \[GothicCapitalD]\_{i\_\[GothicCapitalF], i\_\
\[GothicCapitalF]} - 
              s\ \[GothicCapitalD]\_{i\_\[GothicCapitalF], i\_\
\[GothicCapitalM]} - 
              s\ \[GothicCapitalD]\_{i\_\[GothicCapitalF], j\_\
\[GothicCapitalF]} - 
              s\ \[GothicCapitalD]\_{i\_\[GothicCapitalF], j\_\
\[GothicCapitalM]} - 
              1\/2\ s\ \[GothicCapitalD]\_{i\_\[GothicCapitalM], i\_\
\[GothicCapitalM]} - 
              s\ \[GothicCapitalD]\_{i\_\[GothicCapitalM], j\_\
\[GothicCapitalF]} - 
              s\ \[GothicCapitalD]\_{i\_\[GothicCapitalM], j\_\
\[GothicCapitalM]} - 
              1\/2\ s\ \[GothicCapitalD]\_{j\_\[GothicCapitalF], j\_\
\[GothicCapitalF]} - 
              s\ \[GothicCapitalD]\_{j\_\[GothicCapitalF], j\_\
\[GothicCapitalM]} - 
              1\/2\ s\ \[GothicCapitalD]\_{j\_\[GothicCapitalM], j\_\
\[GothicCapitalM]}\)},
          {\(\[GothicA]\_{i\_\[GothicCapitalF]}\), \(s\ Zopt\)},
          {\(\[GothicA]\_{i\_\[GothicCapitalM]}\), \(s\ Zopt\)},
          {\(\[GothicA]\_{j\_\[GothicCapitalF]}\), \(s\ Zopt\)},
          {\(\[GothicA]\_{j\_\[GothicCapitalM]}\), \(s\ Zopt\)},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalF]}\), \(-\(s\/2\)\)},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM]}\), \(-s\)},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF]}\), \(-s\)},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), \(-s\)},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF]}\), \(-s\)},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM]}\), \(-\(s\/2\)\)},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), \(-s\)},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), \(-s\)},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalF]}\), \(-s\)},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM]}\), \(-s\)},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF]}\), \(-\(s\/2\)\)},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), \(-s\)},
          {\(\[GothicA]\_{j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF]}\), \(-s\)},
          {\(\[GothicA]\_{j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM]}\), \(-s\)},
          {\(\[GothicA]\_{j\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), \(-s\)},
          {\(\[GothicA]\_{j\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), \(-\(s\/2\)\)},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalM], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalM], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], i\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalF], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalF], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalM], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM], i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM], 
                  i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[77]//TableForm=  (11:00:31 on 3/21/01)"]
}, Closed]],

Cell[TextData[{
  "The construction ",
  StyleBox["Union[Sort/@Subsets[\[DoubleStruckCapitalW]]] ",
    FontWeight->"Bold"],
  "is needed to remove duplicated sets; it is used internally by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(\[DoubleStruckCapitalU] \[SubsetEqual] \
\[DoubleStruckCapitalW]\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "In general, very many coefficients are needed ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(~\)\(2\^n\))\)\)]],
  ".  In this case, there are 224, but only the first- and secod-order \
coefficients are non-zero."
}], "Text"],

Cell[TextData[{
  "Note: ",
  StyleBox["The number of subsets increases exponentially with the size of \
the set \[DoubleStruckCapitalW], and so including all of them can be \
extremely ",
    FontWeight->"Plain"],
  "slow",
  StyleBox[".  Selection[] does sum over all distinct subsets, using ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(\[DoubleStruckCapitalU] \[SubsetEqual] \
\[DoubleStruckCapitalW]\)\[GothicA]\_\[DoubleStruckCapitalU]\)]],
  StyleBox[".  However, if the coefficients are stored, using ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`aa[\[DoubleStruckCapitalU]_] := \(aa[\
\[DoubleStruckCapitalU]] = 
          MakeSelectionCoefficient[\[DoubleStruckCapitalU], W]\)\)]],
  StyleBox[", it takes very little time to calculate those that are zero.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell["\<\
As a check, we can reconstruct the fitness as a sum over all the \
selection coefficients:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((\[LeftAngleBracket]W\[RightAngleBracket] + \[Sum]\+\(\
\[DoubleStruckCapitalU] \[SubsetEqual] \
\[DoubleStruckCapitalW]\)\(\[GothicA]\_\[DoubleStruckCapitalU]\) \((\((\
\[Product]\+\(\[DoubleStruckI] \[Element] \[DoubleStruckCapitalU]\)\[Zeta]\_\
\[DoubleStruckI])\) - \[GothicCapitalD]\_\[DoubleStruckCapitalU])\))\) - 
          W /. \[GothicA]\_\[DoubleStruckCapitalU]_ :> 
          MakeSelectionCoefficient[\[DoubleStruckCapitalU], W] // 
      Expand\)], "Input",
  CellLabel->"In[21]:=  (11:29:41 on 3/21/01)"],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[21]=  (11:30:47 on 3/21/01)"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Two alleles", "SubsubsectionIcon",
  CellTags->"Two alleles"],

Cell["\<\
If there are just two alleles, labelled 0 or 1, then it is \
important to work with a simplified fitness function that does not include \
unnecessary powers of \[Zeta] and X\
\>", "Text"],

Cell[TextData[{
  "Applying ",
  ButtonBox["Biallelic[]",
    ButtonData:>{"Two alleles", "Biallelic"},
    ButtonStyle->"AddOnsLink"],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(W2 = Expand[W] //. Biallelic[]\)], "Input",
  CellLabel->"In[22]:=  (11:30:53 on 3/21/01)"],

Cell[BoxData[
    \(1 - \(s\ Zopt\^2\)\/2 + s\ Zopt\ \[Zeta]\_\(i\_\[GothicCapitalF]\) - 
      1\/2\ s\ \((\((1 - \[GothicP]\_\(i\_\[GothicCapitalF]\))\)\ \
\[GothicP]\_\(i\_\[GothicCapitalF]\) + \((1 - 
                  2\ \[GothicP]\_\(i\_\[GothicCapitalF]\))\)\ \[Zeta]\_\(i\_\
\[GothicCapitalF]\))\) + s\ Zopt\ \[Zeta]\_\(i\_\[GothicCapitalM]\) - 
      s\ \[Zeta]\_\(i\_\[GothicCapitalF]\)\ \[Zeta]\_\(i\_\[GothicCapitalM]\) \
- 1\/2\ s\ \((\((1 - \[GothicP]\_\(i\_\[GothicCapitalM]\))\)\ \[GothicP]\_\(i\
\_\[GothicCapitalM]\) + \((1 - 
                  2\ \[GothicP]\_\(i\_\[GothicCapitalM]\))\)\ \[Zeta]\_\(i\_\
\[GothicCapitalM]\))\) + s\ Zopt\ \[Zeta]\_\(j\_\[GothicCapitalF]\) - 
      s\ \[Zeta]\_\(i\_\[GothicCapitalF]\)\ \[Zeta]\_\(j\_\[GothicCapitalF]\) \
- s\ \[Zeta]\_\(i\_\[GothicCapitalM]\)\ \[Zeta]\_\(j\_\[GothicCapitalF]\) - 
      1\/2\ s\ \((\((1 - \[GothicP]\_\(j\_\[GothicCapitalF]\))\)\ \
\[GothicP]\_\(j\_\[GothicCapitalF]\) + \((1 - 
                  2\ \[GothicP]\_\(j\_\[GothicCapitalF]\))\)\ \[Zeta]\_\(j\_\
\[GothicCapitalF]\))\) + s\ Zopt\ \[Zeta]\_\(j\_\[GothicCapitalM]\) - 
      s\ \[Zeta]\_\(i\_\[GothicCapitalF]\)\ \[Zeta]\_\(j\_\[GothicCapitalM]\) \
- s\ \[Zeta]\_\(i\_\[GothicCapitalM]\)\ \[Zeta]\_\(j\_\[GothicCapitalM]\) - 
      s\ \[Zeta]\_\(j\_\[GothicCapitalF]\)\ \[Zeta]\_\(j\_\[GothicCapitalM]\) \
- 1\/2\ s\ \((\((1 - \[GothicP]\_\(j\_\[GothicCapitalM]\))\)\ \[GothicP]\_\(j\
\_\[GothicCapitalM]\) + \((1 - 
                  2\ \[GothicP]\_\(j\_\[GothicCapitalM]\))\)\ \[Zeta]\_\(j\_\
\[GothicCapitalM]\))\)\)], "Output",
  CellLabel->"Out[22]=  (11:30:53 on 3/21/01)"]
}, Open  ]],

Cell["Now, repeated genes-in-context are not needed:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[DoubleStruckCapitalW]2 = MakeFitnessSet[W2] // Union\)], "Input",
  CellLabel->"In[23]:=  (11:30:55 on 3/21/01)"],

Cell[BoxData[
    \({i\_\[GothicCapitalF], i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
      j\_\[GothicCapitalM]}\)], "Output",
  CellLabel->"Out[23]=  (11:30:55 on 3/21/01)"]
}, Open  ]],

Cell["This lists all the selection coefficients:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({\[GothicA]\_#, MakeSelectionCoefficient[#, W2]} &\) /@ 
        Subsets[\[DoubleStruckCapitalW]2] // TableForm\)], "Input",
  CellLabel->"In[24]:=  (11:30:57 on 3/21/01)"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(\[GothicA]\_{}\), \(1 - \(s\ Zopt\^2\)\/2 - \(s\ \[GothicP]\_\(i\
\_\[GothicCapitalF]\)\)\/2 + 
              1\/2\ s\ \[GothicP]\_i\_\[GothicCapitalF]\%2 - \(s\ \
\[GothicP]\_\(i\_\[GothicCapitalM]\)\)\/2 + 
              1\/2\ s\ \[GothicP]\_i\_\[GothicCapitalM]\%2 - \(s\ \
\[GothicP]\_\(j\_\[GothicCapitalF]\)\)\/2 + 
              1\/2\ s\ \[GothicP]\_j\_\[GothicCapitalF]\%2 - \(s\ \
\[GothicP]\_\(j\_\[GothicCapitalM]\)\)\/2 + 
              1\/2\ s\ \[GothicP]\_j\_\[GothicCapitalM]\%2 - 
              1\/2\ s\ \[GothicCapitalD]\_{i\_\[GothicCapitalF]} + 
              s\ Zopt\ \[GothicCapitalD]\_{i\_\[GothicCapitalF]} + 
              s\ \[GothicP]\_\(i\_\[GothicCapitalF]\)\ \
\[GothicCapitalD]\_{i\_\[GothicCapitalF]} - 
              1\/2\ s\ \[GothicCapitalD]\_{i\_\[GothicCapitalM]} + 
              s\ Zopt\ \[GothicCapitalD]\_{i\_\[GothicCapitalM]} + 
              s\ \[GothicP]\_\(i\_\[GothicCapitalM]\)\ \
\[GothicCapitalD]\_{i\_\[GothicCapitalM]} - 
              1\/2\ s\ \[GothicCapitalD]\_{j\_\[GothicCapitalF]} + 
              s\ Zopt\ \[GothicCapitalD]\_{j\_\[GothicCapitalF]} + 
              s\ \[GothicP]\_\(j\_\[GothicCapitalF]\)\ \
\[GothicCapitalD]\_{j\_\[GothicCapitalF]} - 
              1\/2\ s\ \[GothicCapitalD]\_{j\_\[GothicCapitalM]} + 
              s\ Zopt\ \[GothicCapitalD]\_{j\_\[GothicCapitalM]} + 
              s\ \[GothicP]\_\(j\_\[GothicCapitalM]\)\ \
\[GothicCapitalD]\_{j\_\[GothicCapitalM]} - 
              s\ \[GothicCapitalD]\_{i\_\[GothicCapitalF], i\_\
\[GothicCapitalM]} - 
              s\ \[GothicCapitalD]\_{i\_\[GothicCapitalF], j\_\
\[GothicCapitalF]} - 
              s\ \[GothicCapitalD]\_{i\_\[GothicCapitalF], j\_\
\[GothicCapitalM]} - 
              s\ \[GothicCapitalD]\_{i\_\[GothicCapitalM], j\_\
\[GothicCapitalF]} - 
              s\ \[GothicCapitalD]\_{i\_\[GothicCapitalM], j\_\
\[GothicCapitalM]} - 
              s\ \[GothicCapitalD]\_{j\_\[GothicCapitalF], j\_\
\[GothicCapitalM]}\)},
          {\(\[GothicA]\_{i\_\[GothicCapitalF]}\), \(\(-\(s\/2\)\) + 
              s\ Zopt + s\ \[GothicP]\_\(i\_\[GothicCapitalF]\)\)},
          {\(\[GothicA]\_{i\_\[GothicCapitalM]}\), \(\(-\(s\/2\)\) + 
              s\ Zopt + s\ \[GothicP]\_\(i\_\[GothicCapitalM]\)\)},
          {\(\[GothicA]\_{j\_\[GothicCapitalF]}\), \(\(-\(s\/2\)\) + 
              s\ Zopt + s\ \[GothicP]\_\(j\_\[GothicCapitalF]\)\)},
          {\(\[GothicA]\_{j\_\[GothicCapitalM]}\), \(\(-\(s\/2\)\) + 
              s\ Zopt + s\ \[GothicP]\_\(j\_\[GothicCapitalM]\)\)},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], 
                  i\_\[GothicCapitalM]}\), \(-s\)},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalF]}\), \(-s\)},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), \(-s\)},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), \(-s\)},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), \(-s\)},
          {\(\[GothicA]\_{j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), \(-s\)},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalM], j\_\[GothicCapitalF], 
                  j\_\[GothicCapitalM]}\), "0"},
          {\(\[GothicA]\_{i\_\[GothicCapitalF], i\_\[GothicCapitalM], 
                  j\_\[GothicCapitalF], j\_\[GothicCapitalM]}\), "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[24]//TableForm=  (11:30:58 on 3/21/01)"]
}, Closed]],

Cell["As a check, we can reconstruct the fitness:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((\[LeftAngleBracket]W2\[RightAngleBracket] + \[Sum]\+\(\
\[DoubleStruckCapitalU] \[SubsetEqual] \[DoubleStruckCapitalW]2\)\(\[GothicA]\
\_\[DoubleStruckCapitalU]\) \((\((\[Product]\+\(\[DoubleStruckI] \[Element] \
\[DoubleStruckCapitalU]\)\[Zeta]\_\[DoubleStruckI])\) - \[GothicCapitalD]\_\
\[DoubleStruckCapitalU])\))\) - W2 /. \[GothicA]\_\[DoubleStruckCapitalU]_ :> 
          MakeSelectionCoefficient[\[DoubleStruckCapitalU], W2] // 
      Expand\)], "Input",
  CellLabel->"In[25]:=  (11:31:06 on 3/21/01)"],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[25]=  (11:31:07 on 3/21/01)"]
}, Open  ]],

Cell["\<\
It is not possible to find selection coefficients in a general way \
when the expression is a sum over an unspecified set of loci:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Z = \[Sum]\+\(\[Alpha] \[Element] S\)\((\[Zeta]\_\(\[Alpha]\_\
\[GothicCapitalM]\) + \[Zeta]\_\(\[Alpha]\_\[GothicCapitalF]\))\); 
    W = 1 + \(s\/2\) \((Z - Z0)\)\^2\)], "Input",
  CellLabel->"In[69]:=  (10:56:38 on 3/21/01)"],

Cell[BoxData[
    \(1 + 
      1\/2\ s\ \((\(-Z0\) + \[Sum]\+\(\[Alpha] \[Element] S\)\((\[Zeta]\_\(\
\[Alpha]\_\[GothicCapitalM]\) + \
\[Zeta]\_\(\[Alpha]\_\[GothicCapitalF]\))\))\)\^2\)], "Output",
  CellLabel->"Out[69]=  (10:56:38 on 3/21/01)"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeSelectionCoefficient[{i\_\[GothicCapitalM]}, W]\)], "Input",
  CellLabel->"In[70]:=  (10:56:40 on 3/21/01)"],

Cell[BoxData[
    \(MakeSelectionCoefficient[{i\_\[GothicCapitalM]}, \[Sum]\+\({\[Alpha]} \
\[Element] {S}\)\(-s\)\ Z0\ \((\[Zeta]\_\(\[Alpha]\_\[GothicCapitalM]\) + \
\[Zeta]\_\(\[Alpha]\_\[GothicCapitalF]\))\)] + 
      MakeSelectionCoefficient[{i\_\[GothicCapitalM]}, \
\[Sum]\+\({\[Alpha]$16697, \[Alpha]$16698} \[Element] {S, S}\)1\/2\ s\ \((\((\
\[Zeta]\_\(\[Alpha]$16697\_\[GothicCapitalF]\) + \[Zeta]\_\(\[Alpha]$16697\_\
\[GothicCapitalM]\))\)\ \((\[Zeta]\_\(\[Alpha]$16698\_\[GothicCapitalF]\) + \
\[Zeta]\_\(\[Alpha]$16698\_\[GothicCapitalM]\))\))\)]\)], "Output",
  CellLabel->"Out[70]=  (10:56:40 on 3/21/01)"]
}, Open  ]],

Cell["Some simplification is attempted, however.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Obsolete notation: Barton & Turelli (1991)", "SubsubsectionIcon",
  CellTags->"Obsolete notation"],

Cell[TextData[{
  "Barton & Turelli (1991) used a slightly different definition for diploid \
relative fitness.  They distinguished selection coefficients between loci \
from the same haplotype and from different haplotypes: \n  ",
  Cell[BoxData[
      \(TraditionalForm\`W\/W\&_\)]],
  " = 1+",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+U\( \[GothicA]\_\(U, \[EmptySet]\)\) \((\
\[Zeta]\_U - c\_U)\)\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+U\( \[GothicA]\_\(\[EmptySet], 
              V\)\) \((\(\[Zeta]\^\[FilledSmallCircle]\)\_V - c\_V)\)\)]],
  "+",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(U, V\)\(\(\[GothicA]\_\(U, 
                V\)\) \((\[Zeta]\_U - 
                c\_U)\)\) \((\(\[Zeta]\^\[FilledSmallCircle]\)\_V - 
              c\_V)\)\)]],
  "  "
}], "Text"],

Cell[TextData[{
  "where the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\^*\)\)\)]],
  "represents a gene from the male parent.  This has the advantage that when \
selection is additive across genomes, the ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicA]\_\(U, V\)\ are\ \(\(zero\)\(.\)\)\)]],
  " However, with multiplicative selection, or random mating among haploids, \
the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[GothicA]\_\(U, V\)\)\(\ \)\(are\)\(\ \)\)\)]],
  "nonzero.  Moreover, it is hard to extend this notation to other cases (for \
example, to pairs of diploids)."
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{821, 677},
WindowMargins->{{9, Automatic}, {Automatic, 21}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "SelectionCoefficient"->{
    Cell[1937, 59, 701, 17, 116, "DefinitionBox",
      CellTags->{"SelectionCoefficient", "Fitness"}]},
  "Fitness"->{
    Cell[1937, 59, 701, 17, 116, "DefinitionBox",
      CellTags->{"SelectionCoefficient", "Fitness"}]},
  "MakeFitnessSet"->{
    Cell[3473, 100, 331, 8, 39, "DefinitionBox",
      CellTags->"MakeFitnessSet"]},
  "Multiple alleles"->{
    Cell[9006, 257, 427, 10, 37, "Text",
      CellTags->"Multiple alleles"]},
  "MakeSelectionCoefficient"->{
    Cell[9703, 276, 426, 10, 42, "DefinitionBox",
      CellTags->"MakeSelectionCoefficient"]},
  "Two alleles"->{
    Cell[56632, 1188, 67, 1, 24, "SubsubsectionIcon",
      CellTags->"Two alleles"]},
  "Obsolete notation"->{
    Cell[65902, 1403, 104, 1, 24, "SubsubsectionIcon",
      CellTags->"Obsolete notation"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"SelectionCoefficient", 138758, 4011},
  {"Fitness", 138878, 4014},
  {"MakeFitnessSet", 139005, 4017},
  {"Multiple alleles", 139114, 4020},
  {"MakeSelectionCoefficient", 139225, 4023},
  {"Two alleles", 139340, 4026},
  {"Obsolete notation", 139452, 4029}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 33, 0, 36, "SubsectionIcon"],
Cell[1775, 53, 46, 0, 28, "MathCaption"],
Cell[1824, 55, 110, 2, 38, "Input"],
Cell[1937, 59, 701, 17, 116, "DefinitionBox",
  CellTags->{"SelectionCoefficient", "Fitness"}],
Cell[2641, 78, 275, 7, 40, "Text"],
Cell[2919, 87, 301, 4, 46, "NumberedEquation"],
Cell[3223, 93, 247, 5, 22, "Text"],
Cell[3473, 100, 331, 8, 39, "DefinitionBox",
  CellTags->"MakeFitnessSet"],
Cell[3807, 110, 119, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3951, 117, 352, 6, 55, "Input"],
Cell[4306, 125, 490, 8, 34, "Output"]
}, Open  ]],
Cell[4811, 136, 228, 8, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5064, 148, 340, 6, 55, "Input"],
Cell[5407, 156, 490, 8, 34, "Output"]
}, Open  ]],
Cell[5912, 167, 108, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6045, 174, 461, 8, 62, "Input"],
Cell[6509, 184, 176, 3, 20, "Output"]
}, Open  ]],
Cell[6700, 190, 261, 6, 22, "Text"],
Cell[6964, 198, 102, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7091, 205, 473, 9, 52, "Input"],
Cell[7567, 216, 365, 6, 25, "Message"],
Cell[7935, 224, 125, 2, 20, "Output"]
}, Open  ]],
Cell[8075, 229, 155, 3, 22, "Text"],
Cell[8233, 234, 271, 6, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[8529, 244, 235, 4, 34, "Input"],
Cell[8767, 250, 224, 4, 21, "Output"]
}, Open  ]],
Cell[9006, 257, 427, 10, 37, "Text",
  CellTags->"Multiple alleles"],
Cell[9436, 269, 264, 5, 36, "Text"],
Cell[9703, 276, 426, 10, 42, "DefinitionBox",
  CellTags->"MakeSelectionCoefficient"],
Cell[10132, 288, 243, 5, 22, "Text"],
Cell[10378, 295, 243, 7, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[10646, 306, 255, 4, 47, "Input"],
Cell[10904, 312, 268, 5, 36, "Output"]
}, Open  ]],
Cell[11187, 320, 48, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[11260, 324, 121, 2, 27, "Input"],
Cell[11384, 328, 1135, 20, 67, "Output"]
}, Open  ]],
Cell[12534, 351, 2524, 82, 56, "Text"],
Cell[15061, 435, 254, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[15340, 448, 132, 2, 27, "Input"],
Cell[15475, 452, 89, 2, 20, "Output"]
}, Open  ]],
Cell[15579, 457, 146, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[15750, 464, 251, 4, 27, "Input"],
Cell[16004, 470, 105, 2, 34, "Output"]
}, Open  ]],
Cell[16124, 475, 300, 11, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[16449, 490, 185, 4, 27, "Input"],
Cell[16637, 496, 83, 2, 20, "Output"]
}, Open  ]],
Cell[16735, 501, 335, 6, 22, "Text"],
Cell[17073, 509, 262, 7, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[17360, 520, 124, 2, 27, "Input"],
Cell[17487, 524, 272, 4, 20, "Output"]
}, Open  ]],
Cell[17774, 531, 65, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[17864, 535, 214, 4, 27, "Input"],
Cell[18081, 541, 36255, 577, 4917, "Output"]
}, Closed]],
Cell[54351, 1121, 333, 9, 33, "Text"],
Cell[54687, 1132, 246, 6, 22, "Text"],
Cell[54936, 1140, 884, 21, 68, "Text"],
Cell[55823, 1163, 121, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[55969, 1170, 540, 9, 62, "Input"],
Cell[56512, 1181, 83, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56632, 1188, 67, 1, 24, "SubsubsectionIcon",
  CellTags->"Two alleles"],
Cell[56702, 1191, 197, 4, 22, "Text"],
Cell[56902, 1197, 160, 6, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[57087, 1207, 111, 2, 27, "Input"],
Cell[57201, 1211, 1625, 24, 95, "Output"]
}, Open  ]],
Cell[58841, 1238, 69, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[58935, 1242, 135, 2, 27, "Input"],
Cell[59073, 1246, 177, 3, 20, "Output"]
}, Open  ]],
Cell[59265, 1252, 65, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[59355, 1256, 194, 3, 27, "Input"],
Cell[59552, 1261, 4019, 75, 365, "Output"]
}, Closed]],
Cell[63586, 1339, 66, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[63677, 1343, 533, 8, 62, "Input"],
Cell[64213, 1353, 83, 2, 20, "Output"]
}, Open  ]],
Cell[64311, 1358, 163, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[64499, 1366, 248, 4, 46, "Input"],
Cell[64750, 1372, 247, 5, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65034, 1382, 132, 2, 27, "Input"],
Cell[65169, 1386, 623, 9, 73, "Output"]
}, Open  ]],
Cell[65807, 1398, 58, 0, 22, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65902, 1403, 104, 1, 24, "SubsubsectionIcon",
  CellTags->"Obsolete notation"],
Cell[66009, 1406, 816, 21, 71, "Text"],
Cell[66828, 1429, 615, 14, 36, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

