(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8662,        246]*)
(*NotebookOutlinePosition[     10194,        296]*)
(*  CellTagsIndexPosition[      9999,        286]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Genes and contexts", "SubsectionIcon",
  CellTags->"Genes and contexts"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(\(i\)\(,\)\(j\)\(\ \)\), \(labels\ a\ gene, \ 
              regardless\ of\ context\)},
            {\(U = {i, \ j, \ k}\), \(a\ set\ of\ genes, \ 
              regardless\ of\ context\)},
            {\(\[DoubleStruckI], \ \[DoubleStruckJ]\), \(a\ gene - 
                in - \(\(context\)\(.\)\(\ \)\)\)},
            {\(\[DoubleStruckI] = 
                i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\), \(a\ gene\ in\ a\ diploid\ adult\ female, \ 
              inherited\ from\ the\ male\ parent\)},
            {\(\[DoubleStruckCapitalU] = {\[DoubleStruckI], \[DoubleStruckJ], \
\[Ellipsis]}\), \(a\ set\ of\ genes - in - context\)},
            {
              StyleBox["\[DoubleStruckCapitalN]",
                FontFamily->"Times"], 
              StyleBox[\(the\ set\ of\ all\ loci\ in\ all\ contexts\),
                FontFamily->"Times"]}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->"Basic notation"],

Cell[TextData[{
  "A set of genes at loci ",
  Cell[BoxData[
      \(TraditionalForm\`i, j, k\)]],
  " is denoted by the set U = {i,j,k}. Genes may be in various ",
  StyleBox["contexts",
    FontSlant->"Italic"],
  ", which are denoted by subscripted vectors.  For example, consider \
diploids which may be either male or female, and each with one genome derived \
from the female sex, and one from the male sex. A gene at locus ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " in a male zygote, inherited from the female parent, is denoted \
\[DoubleStruckI] = ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\)\(.\)\(\ \)\)\)]],
  "The two homologous genes at locus ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(i\_\ \)\(\ \)\(are\)\(\ \)\)\)]],
  "denoted by ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"\[DoubleStruckCapitalU]", "=", 
            RowBox[{
              RowBox[{"{", 
                
                RowBox[{\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\), ",", 
                  
                  FormBox[\(\(\ \)\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\)\),
                    "TraditionalForm"]}], "}"}], "."}]}]}], 
        TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  StyleBox["Note: ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        ButtonBox[\(\(\(\ \)\(\(Kirkpatrick\ et\ al\)\(,\)\)\)\(\ \)\),
          ButtonData:>{"Multilocus references", "Johnson et al."},
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  " refer to a gene-in-context as a '",
  ButtonBox["position",
    ButtonData:>{"Multilocus MS", "position"},
    ButtonStyle->"AddOnsLink"],
  "'."
}], "Text",
  CellTags->"position"],

Cell[BoxData[
    StyleBox[GridBox[{
          {\(\[GothicCapitalM], \ \[GothicCapitalF]\), \(male, \ female\)},
          {\(\[GothicCapitalG], \[GothicCapitalZ], \[GothicCapitalA]\), \
\(gamete, \ zygote, \ adult\ stages\)},
          {GridBox[{
                {
                  "\[Sampi]", \(Stage\ \((used\ by\ Mathematica\ to\ refer\ \
to\ the\ stage)\)\)}
                },
              ColumnAlignments->{Left},
              GridFrame->False], "\[Placeholder]"}
          },
        ColumnAlignments->{Left},
        GridFrame->False],
      FontFamily->"Times"]], "DefinitionBox",
  CellTags->"Stages"],

Cell[TextData[{
  "The ",
  StyleBox["stage",
    FontSlant->"Italic"],
  " in the life cycle must always appear as the first component in the \
context: it defines the components that follow.  The user must define stages \
such as gamete, zygote or adult with the structure required.  This \
flexibility is necesary, because extra structure may need to be specified.  \
For example, a gene at locus ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "  in a diploid male zygote, inherited from the female parent, in a zygote \
at time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", could be denoted ",
  Cell[BoxData[
      \(TraditionalForm\`k\_{\[GothicCapitalZ], t, \[GothicCapitalM], \
\[GothicCapitalF]}\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses the symbol \[Sampi] to refer to the stage (\[AliasIndicator]sa\
\[AliasIndicator], or the full name Stage)."
}], "Text"],

Cell[TextData[{
  "We use the convention that sets of genes are in Roman capitals (e.g. U = \
{i,j,k}}, while sets of genes-in-context are denoted by double-struck letters \
(e.g. ",
  Cell[BoxData[
      FormBox[
        RowBox[{"  ", 
          RowBox[{"\[DoubleStruckCapitalU]", "=", 
            RowBox[{
              RowBox[{"{", 
                
                RowBox[{\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\), ",", 
                  
                  FormBox[\(\(\ \)\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\)\),
                    "TraditionalForm"]}], "}"}], "."}]}]}], 
        TraditionalForm]]],
  "; entered as \[AliasIndicator]dsU\[AliasIndicator]). However, these \
conventions are not required by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".   Special genetical terms such as male (\[GothicCapitalM]), female (\
\[GothicCapitalF]), zygote (\[GothicCapitalZ]) or gamete (\[GothicCapitalG]) \
are denoted by Gothic capitals (entered as \[AliasIndicator]goZ\
\[AliasIndicator] etc). "
}], "Text"],

Cell["\<\
Note that the order of genes, or genes-in-context, is immaterial, \
but the order of the components in the context vector is significant.  We \
discuss the structure of contexts in more detail below, after introducing \
some related concepts.\
\>", "Text"],

Cell[TextData[{
  "The order of the components of each context can be defined as necessary.  \
We use the convention that components are ordered as {stage,time, \
sex,sex-of-origin} for diploids with distinct sexes.  However, variations \
will often be needed: for example, it may not be necessary to distinguish the \
sexes.  Thus, the structure of the context should always be defined \
explicitly.  The one convention that ",
  StyleBox["must",
    FontWeight->"Bold"],
  " be maintained is that the first component gives the stage in the life \
cycle: that determines the order of the remaining components."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(OtherSex[\[GothicCapitalM]]\), \(returns\ \[GothicCapitalF], \ 
            and\ vice\ versa\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"OtherSex"],

Cell[CellGroupData[{

Cell[BoxData[
    \(OtherSex[\[GothicCapitalM]]\)], "Input",
  CellLabel->"In[323]:="],

Cell[BoxData[
    \(\[GothicCapitalF]\)], "Output",
  CellLabel->"Out[323]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{911, 559},
WindowMargins->{{8, Automatic}, {Automatic, 21}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Genes and contexts"->{
    Cell[1739, 51, 78, 1, 36, "SubsectionIcon",
      CellTags->"Genes and contexts"]},
  "Basic notation"->{
    Cell[1820, 54, 1036, 23, 134, "DefinitionBox",
      CellTags->"Basic notation"]},
  "position"->{
    Cell[4188, 116, 475, 14, 24, "Text",
      CellTags->"position"]},
  "Stages"->{
    Cell[4666, 132, 616, 16, 78, "DefinitionBox",
      CellTags->"Stages"]},
  "OtherSex"->{
    Cell[8209, 227, 234, 5, 37, "DefinitionBox",
      CellTags->"OtherSex"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Genes and contexts", 9503, 267},
  {"Basic notation", 9613, 270},
  {"position", 9716, 273},
  {"Stages", 9801, 276},
  {"OtherSex", 9895, 279}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 78, 1, 36, "SubsectionIcon",
  CellTags->"Genes and contexts"],
Cell[1820, 54, 1036, 23, 134, "DefinitionBox",
  CellTags->"Basic notation"],
Cell[2859, 79, 1326, 35, 52, "Text"],
Cell[4188, 116, 475, 14, 24, "Text",
  CellTags->"position"],
Cell[4666, 132, 616, 16, 78, "DefinitionBox",
  CellTags->"Stages"],
Cell[5285, 150, 743, 20, 52, "Text"],
Cell[6031, 172, 197, 5, 24, "Text"],
Cell[6231, 179, 1080, 26, 52, "Text"],
Cell[7314, 207, 266, 5, 36, "Text"],
Cell[7583, 214, 623, 11, 52, "Text"],
Cell[8209, 227, 234, 5, 37, "DefinitionBox",
  CellTags->"OtherSex"],

Cell[CellGroupData[{
Cell[8468, 236, 86, 2, 27, "Input"],
Cell[8557, 240, 77, 2, 20, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

