(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     49816,       1620]*)
(*NotebookOutlinePosition[    122771,       4231]*)
(*  CellTagsIndexPosition[    122378,       4217]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Allele frequencies and covariance between loci", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["AlleleFrequencyTable, AlleleFrequencyMean", "SubsubsectionIcon"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {
              RowBox[{"AlleleFrequencyTable", "[", 
                StyleBox[\(site, alleles\),
                  FontSlant->"Italic"], "]"}], 
              RowBox[{
                RowBox[{
                "gives", " ", "a", " ", "table", " ", "of", " ", "allele", 
                  " ", "frequencies", " ", "for", " ", 
                  RowBox[{
                    StyleBox["site",
                      FontSlant->"Italic"], 
                    StyleBox[".",
                      FontSlant->"Italic"], 
                    StyleBox["  ",
                      FontSlant->"Italic"], "Allows"}], " ", "for", " ", 
                  "missing", " ", "values"}], ",", " ", "\[EmptySet]"}]},
            {
              RowBox[{"AlleleFrequencyMean", "[", 
                RowBox[{
                  StyleBox["site",
                    FontSlant->"Italic"], ",", 
                  StyleBox["alleles",
                    FontSlant->"Italic"]}], "]"}], 
              RowBox[{
                RowBox[{
                "gives", " ", "the", " ", "overall", " ", "mean", " ", 
                  "allele", " ", "frequency", " ", "in", " ", 
                  StyleBox["site",
                    FontSlant->"Italic"]}], 
                ";", \(allows\ for\ missing\ values . \ \ Only\ makes\ sense\ \
if\ the\ alleles\ are\ all\ labelled\ in\ the\ same\ way\)}]}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->{"AlleleFrequencyMean", "AlleleFrequencyTable"}],

Cell["Here are the data:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Data[1063] // TableForm\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {"0"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"0"},
                {"0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"0"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"0"},
                {"0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"0"},
                {"0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"0"},
                {"0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"0"},
                {"0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"0"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"0"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"0"},
                {"0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"0"},
                {"0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "\[EmptySet]", GridBox[{
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{0, 1}, {0, 0}, {0, 1}, {0, 0}, {0}}, {{0, 0}, {0, 0}, {0, 
        0}, {0, 1}, {1}}, {{0, 1}, {0, 0}, {0, 0}, \[EmptySet], {
        1}}}]]], "Output",
  CellLabel->"Out[16]//TableForm="]
}, Open  ]],

Cell["Allele frequencies for 5 biallelic loci:  ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlleleFrequencyTable[1063, 5]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \({{2\/3, 1\/3}, {1, 0}, {5\/6, 1\/6}, {3\/4, 1\/4}, {1\/3, 
        2\/3}}\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlleleFrequencyMean[1063, 5]\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \({19\/25, 6\/25}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell["Allele frequencies for labelled alleles at three loci:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Data[
        s1] = {{{f, s}, {f, m}, {s}}, {{f, f}, {s, m}, {f}}, {{f, 
            f}, \[EmptySet], \[EmptySet]}}; \), "\n", 
    \(Data[s1] // MatrixForm\)}], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\({f, s}\), \({f, m}\), \({s}\)},
            {\({f, f}\), \({s, m}\), \({f}\)},
            {\({f, f}\), "\[EmptySet]", "\[EmptySet]"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[25]//MatrixForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlleleFrequencyTable[s1, {{s, m, f}, 3}] // MatrixForm\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\(1\/6\), "0", \(5\/6\)},
            {\(1\/4\), \(1\/2\), \(1\/4\)},
            {\(1\/2\), "0", \(1\/2\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[27]//MatrixForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlleleFrequencyMean[s1, {{s, m, f}, 3}]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \({1\/4, 1\/6, 7\/12}\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["NetCovariance", "SubsubsectionIcon"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {
              RowBox[{"NetCovariance", "[", 
                StyleBox["site",
                  FontSlant->"Italic"], 
                "]"}], \(gives\ the\ net\ covariance\ between\ each\ locus\ \
and\ the\ others; \ 
              this\ requires\ that\ the\ alleles\ at\ each\ locus\ bear\ \
numerical\ \(\(labels\)\(.\)\)\)}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->{"NetCovariance", "Linkage disequilibrium"}],

Cell["\<\
NetCovariance calculates the covariance matrix across loci, \
allowing for missing values. This only makes sense if the alleles have \
numerical labels, as in the example below.\
\>", "Text"],

Cell["\<\
If there are two alleles at each locus, labelled 0 or 1, then the \
covariance between loci within a haploid genome is the standard measure of \
pairwise linkage disequilibrium.  The covariance betwen diploid genotypes can \
also be used as a simple estimator of linkage disequilibrium.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Data[
        s2] = {{{0, 0}, {0, 1}, {1, 2}}, {{0, 2}, {1, 1}, {1, 0}}, {{0, 
            0}, {2, 1}, {2, 2}}, {{0, 2}, \[EmptySet], {1, 2}}}; 
    Data[s2] // MatrixForm\)], "Input",
  CellLabel->"In[146]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\({0, 0}\), \({0, 1}\), \({1, 2}\)},
            {\({0, 2}\), \({1, 1}\), \({1, 0}\)},
            {\({0, 0}\), \({2, 1}\), \({2, 2}\)},
            {\({0, 2}\), "\[EmptySet]", \({1, 2}\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[146]//MatrixForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlleleFrequencyTable[s2, {{0, 1, 2}, 3}]\)], "Input",
  CellLabel->"In[150]:="],

Cell[BoxData[
    \({{3\/4, 0, 1\/4}, {1\/6, 2\/3, 1\/6}, {1\/8, 3\/8, 1\/2}}\)], "Output",
  CellLabel->"Out[150]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NumberOfIndividualsTable[s2]\)], "Input",
  CellLabel->"In[154]:="],

Cell[BoxData[
    \({4, 3, 4}\)], "Output",
  CellLabel->"Out[154]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NetCovariance[s2] // MatrixForm\)], "Input",
  CellLabel->"In[168]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", "0", \(-\(3\/4\)\)},
            {"0", \(2\/3\), \(1\/3\)},
            {\(-\(3\/4\)\), \(1\/3\), \(19\/16\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[168]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "A more sophisticated approach to estimating multilocus moments is \
described in ",
  ButtonBox["Multilocus`EstimatingD`",
    ButtonData:>{"Introduction to estimating D", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Multilocus`EstimatingD`"],
  ".  Maximum likelihood estimators of pairwise linkage disequilibrium are \
implemented by ",
  ButtonBox["MakePairwiseTable",
    ButtonData:>{"Pairwise tables", "MakePairwiseTable"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"MakePairwiseTable"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["GenotypeFrequencyTable", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"GenotypeFrequencyTable", "[", 
              RowBox[{
                StyleBox["site",
                  FontSlant->"Italic"], ",", 
                StyleBox["alleles",
                  FontSlant->"Italic"]}], 
              "]"}], \(lists\ the\ diploid\ genotype\ frequencies, \ 
            locus\ by\ locus . \ \ Allows\ for\ missing\ values, \ \(\(\
\[EmptySet]\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"GenotypeFrequencyTable"],

Cell["\<\
This generates a random set of 20 observed diploid genotypes, in \
the form {{a,A},{b,B},{c,C}}:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Data[family1] = 
      ObservableGenotype /@ 
        RandomFamily[{{a, b, c}, {A, b, C}}, {{A, B, c}, {A, B, CC}}, 
          20]; \), "\n", 
    \(Transpose /@ Data[family1] // TableForm\)}], "Input",
  CellLabel->"In[105]:=  (6:14:00 on 2/13/01)"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {"A"},
                {"b"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"A"},
                {"B"},
                {"C"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"A"},
                {"b"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"A"},
                {"B"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"},
                {"b"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"A"},
                {"B"},
                {"CC"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"},
                {"b"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"A"},
                {"B"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"A"},
                {"b"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"A"},
                {"B"},
                {"C"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"A"},
                {"b"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"A"},
                {"B"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"A"},
                {"b"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"A"},
                {"B"},
                {"CC"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"},
                {"b"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"A"},
                {"B"},
                {"C"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"},
                {"b"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"A"},
                {"B"},
                {"C"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"},
                {"b"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"A"},
                {"B"},
                {"CC"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"},
                {"b"},
                {"C"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"A"},
                {"B"},
                {"CC"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"A"},
                {"b"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"A"},
                {"B"},
                {"CC"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"},
                {"b"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"A"},
                {"B"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"A"},
                {"b"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"A"},
                {"B"},
                {"C"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"},
                {"b"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"A"},
                {"B"},
                {"C"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"},
                {"b"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"A"},
                {"B"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"},
                {"b"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"A"},
                {"B"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"},
                {"b"},
                {"c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"A"},
                {"B"},
                {"C"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"},
                {"b"},
                {"C"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"A"},
                {"B"},
                {"CC"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"a"},
                {"b"},
                {"C"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"A"},
                {"B"},
                {"CC"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{A, b, c}, {A, B, C}}, {{A, b, c}, {A, B, c}}, {{a, b, 
        c}, {A, B, CC}}, {{a, b, c}, {A, B, c}}, {{A, b, c}, {A, B, C}}, {{A, 
        b, c}, {A, B, c}}, {{A, b, c}, {A, B, CC}}, {{a, b, c}, {A, B, C}}, {{
        a, b, c}, {A, B, C}}, {{a, b, c}, {A, B, CC}}, {{a, b, C}, {A, B, 
        CC}}, {{A, b, c}, {A, B, CC}}, {{a, b, c}, {A, B, c}}, {{A, b, c}, {A,
         B, C}}, {{a, b, c}, {A, B, C}}, {{a, b, c}, {A, B, c}}, {{a, b, c}, {
        A, B, c}}, {{a, b, c}, {A, B, C}}, {{a, b, C}, {A, B, CC}}, {{a, b, 
        C}, {A, B, CC}}}]]], "Output",
  CellLabel->"Out[106]//TableForm=  (6:14:00 on 2/13/01)"]
}, Closed]],

Cell["These are the allele frequencies:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(alleles = {{a, A}, {b, B}, {c, C, CC}}; \), "\n", 
    \(AlleleFrequencyTable[family1, alleles]\)}], "Input",
  CellLabel->"In[107]:=  (6:14:05 on 2/13/01)"],

Cell[BoxData[
    \({{13\/40, 27\/40}, {1\/2, 1\/2}, {23\/40, 1\/4, 7\/40}}\)], "Output",
  CellLabel->"Out[108]=  (6:14:05 on 2/13/01)"]
}, Open  ]],

Cell["\<\
These are the frequencies of the diploid genotypes at each locus:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GenotypeFrequencyTable[family1, alleles]\)], "Input",
  CellLabel->"In[109]:=  (6:14:08 on 2/13/01)"],

Cell[BoxData[
    \({{0, 13\/20, 7\/20}, {0, 1, 0}, {3\/10, 7\/20, 1\/5, 0, 3\/20, 
        0}}\)], "Output",
  CellLabel->"Out[109]=  (6:14:08 on 2/13/01)"]
}, Open  ]],

Cell["\<\
The order of the genotypes is the same as in DiploidTypes[], \
applied to one locus at a time (i.e., DiploidTypes[{{a,A}}]  etc.):\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DiploidTypes[{#}] &\) /@ alleles // TableForm\)], "Input",
  CellLabel->"In[110]:=  (6:14:11 on 2/13/01)"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {"a", "a"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"a", "A"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"A", "A"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
          {GridBox[{
                {"b", "b"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"b", "B"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"B", "B"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
          {GridBox[{
                {"c", "c"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c", "C"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"c", "CC"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"C", "C"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"C", "CC"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"CC", "CC"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{{a, a}}, {{a, A}}, {{A, A}}}, {{{b, b}}, {{b, B}}, {{B, 
        B}}}, {{{c, c}}, {{c, C}}, {{c, CC}}, {{C, C}}, {{C, CC}}, {{CC, 
        CC}}}}]]], "Output",
  CellLabel->"Out[110]//TableForm=  (6:14:11 on 2/13/01)"]
}, Open  ]],

Cell[TextData[{
  "Note that ",
  ButtonBox["ReducedData",
    ButtonData:>{"Simplifying a dataset", "ReducedData"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"ReducedData"],
  " gives the frequencies of the full multilocus genotypes:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ReducedData[family1, alleles]\)], "Input",
  CellLabel->"In[111]:=  (6:14:25 on 2/13/01)"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 4, 4, 2, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 3, 2, 0, 0, 
      0, 0, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[111]=  (6:14:25 on 2/13/01)"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Estimating allele frequencies with null alleles", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["Null alleles", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(NullAllele \[Rule] \[Nu]\), \(is\ an\ option\ for\ \
AlleleFrequencyTable\ which\ allows\ for\ the\ presence\ of\ null\ \
alleles\)},
          {\(MissingData \[Rule] 
              True\), \(interprets\ missing\ data, \ \[EmptySet], \ 
            as\ null\ homozygotes\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"MissingData", "NullAllele"}],

Cell["\<\
This gives the allele frequencies of three diploid loci, each with \
two alleles {0, 1}:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{\(Data[s3]\), "=", 
        RowBox[{"(", GridBox[{
              {\({1, 1}\), \({0, 0}\), \({0, 0}\), \({0, 0}\)},
              {\({0, 0}\), \({0, 1}\), \({0, 1}\), \({0, 0}\)},
              {\({0, 1}\), "\[EmptySet]", \({0, 1}\), \({1, 1}\)},
              {\({0, 0}\), \({0, 1}\), \({0, 1}\), \({1, 1}\)},
              {\({1, 1}\), \({0, 1}\), \({0, 1}\), \({1, 1}\)},
              {\({1, 1}\), \({1, 1}\), \({1, 1}\), \({1, 1}\)}
              }], ")"}]}], ";", \(AlleleFrequencyTable[s3, 4]\)}]], "Input",
  CellLabel->"In[281]:="],

Cell[BoxData[
    \({{5\/12, 7\/12}, {1\/2, 1\/2}, {1\/2, 1\/2}, {1\/3, 2\/3}}\)], "Output",\

  CellLabel->"Out[281]="]
}, Open  ]],

Cell["\<\
This assumes that there are null alleles (labelled \[Nu]) at loci \
1, 3, 4:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlleleFrequencyTable[
      s3, {{\[Nu], 0, 1}, {0, 1}, {0, 1, \[Nu]}, {0, 1, \[Nu]}}, 
      NullAllele \[Rule] \[Nu]]\)], "Input",
  CellLabel->"In[284]:="],

Cell[BoxData[
    \({{0.4893616957706665`, 0.21276595998560757`, 
        0.297872344243726`}, {1\/2, 1\/2}, {0.49999999610616064`, 
        0.49999999610616064`, 
        7.787678784978696`*^-9}, {0.0003332808013773566`, 
        0.0006666727776545146`, 0.9990000464209681`}}\)], "Output",
  CellLabel->"Out[284]="]
}, Open  ]],

Cell["\<\
For locus 1, the null frequency is estimated to be high, because of \
the large apparent homozygote excess.  For locus 3, it is estimated as zero, \
because there is a heterozygote excess.  At locus 4, there are no \
heterozygotes, and so the null is estimated as fixed.  The algorithm stops at \
0.999, because it gets rather slow near fixation.\
\>", "Text"],

Cell["\<\
Note that the position of the null allele in the list is arbitrary, \
and not alllocineed have null alleles.  The list of alleles has to be given \
in full, rather than in the compact form 3.\
\>", "Text"],

Cell["\<\
Missing data can be interpreted as null homozygotes.  In this case, \
high null frequencies are less likely, because then manymore missing values \
would have been seen:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlleleFrequencyTable[
      s3, {{\[Nu], 0, 1}, {0, 1}, {0, 1, \[Nu]}, {0, 1, \[Nu]}}, 
      NullAllele \[Rule] \[Nu], MissingData \[Rule] True]\)], "Input",
  CellLabel->"In[285]:="],

Cell[BoxData[
    \({{0.21673956349499132`, 0.320896740642665`, 
        0.46236369586234366`}, {1\/2, 1\/2}, {0.4999999961235663`, 
        0.4999999961235663`, 7.752867316254757`*^-9}, {0.20804088135496515`, 
        0.47695673840817393`, 0.31500238023686095`}}\)], "Output",
  CellLabel->"Out[285]="]
}, Open  ]],

Cell["There can be multiple alleles:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{\(Data[s4]\), "=", 
        RowBox[{"(", GridBox[{
              {\({1, 1}\), \({a, a}\)},
              {\({0, 0}\), \({a, b}\)},
              {\({0, 1}\), "\[EmptySet]"},
              {\({0, 0}\), \({c, c}\)},
              {\({1, 1}\), \({a, a}\)},
              {\({1, 1}\), \({b, c}\)}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(AlleleFrequencyTable[
      s4, {{0, 1}, {a, b, c}}]\)}], "Input",
  CellLabel->"In[281]:="],

Cell[BoxData[
    \({{5\/12, 7\/12}, {1\/2, 1\/5, 3\/10}}\)], "Output",
  CellLabel->"Out[250]="]
}, Open  ]],

Cell["\<\
The estimated allele frequency allowing for null alleles at the \
second locus is:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlleleFrequencyTable[s4, {{0, 1}, {a, b, c, \[Nu]}}, 
      NullAllele \[Rule] \[Nu]]\)], "Input",
  CellLabel->"In[251]:="],

Cell[BoxData[
    \({{5\/12, 7\/12}, {0.38271093025337466`, 0.19216556429379256`, 
        0.22720387810124368`, 0.19791962735158902`}}\)], "Output",
  CellLabel->"Out[251]="]
}, Open  ]],

Cell["\<\
More complex estimation, for example of linkage disequilibrium, \
have not been modified to allow for the presence of null alleles.  However, \
GenotypeFrequency does allow the probability of finding an allele to be \
calculated assuming nulls.  This assumes Hardy Weinberg proportions and \
linkage equilibrium.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The algorithm", "SubsubsectionIcon"],

Cell[TextData[{
  "Suppose that we observe ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(\[Alpha], \[Beta]\)\)]],
  " of diploid genotype {\[Alpha],\[Beta]},and suspect that there may be null \
alleles segregating.  Let the allele frequencies be ",
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Alpha], p\_\[Nu]\)]],
  ".  Assume first that null homozygotes are identified as missing values.  \
Then, the likelihood is:"
}], "Text"],

Cell[TextData[{
  "Log[L] = ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\[Sum]\+\(\[Alpha] \[NotEqual] \[Beta]\)\(n\_\(\[Alpha], \
\[Beta]\)\) Log[2 \( p\_\[Alpha]\) p\_\[Beta]]\),
            "TraditionalForm"], 
          "+", \(\[Sum]\+\[Alpha]\( n\_\(\[Alpha], \[Alpha]\)\) 
              Log[p\_\[Alpha]\%2 + 2 \( p\_\[Alpha]\) p\_\[Nu]]\), 
          "+", \(\(n\_\[EmptySet]\) Log[p\_\[EmptySet]\%2]\)}], 
        TraditionalForm]]]
}], "InlineFormula"],

Cell["Hence, allele frequencies are estimated from:", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Alpha]\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]Log[L]\/\[PartialD]p\_\[Alpha]\)]],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\(=\)\(\[Lambda]\[VeryThinSpace]p\_\[Alpha] = \[Sum]\+\(\
\[Beta] \[NotEqual] \[Alpha]\)n\_\(\[Alpha], \[Beta]\) + 
                  2  n\_\(\[Alpha], \[Alpha]\)\)\),
            
            "TraditionalForm"], \(\(p\_\[Alpha] + p\_\[Nu]\)\/\(p\_\[Alpha] + 
                2  p\_\[Nu]\)\)}], TraditionalForm]]],
  "   and ",
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Nu]\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]Log[L]\/\[PartialD]p\_\[Nu]\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{"=", 
          RowBox[{\(\[Lambda]\[VeryThinSpace]p\_\[Nu]\), "=", 
            RowBox[{
              RowBox[{
                FormBox[\(2 \[Sum]\_\(\[AliasDelimiter]\[Alpha]\)\),
                  
                  "TraditionalForm"], \(\(\(n\_\(\[Alpha], \[Alpha]\)\) 
                      p\_\[Nu]\)\/\(p\_\[Alpha] + 2  p\_\[Nu]\)\)}], 
              "+", \(2  n\_\[EmptySet]\)}]}]}], TraditionalForm]]]
}], "InlineFormula"],

Cell["\<\
The constant \[Lambda] is determined by the constraint that the sum \
must equal 1:\
\>", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            
            FormBox[\(\[Lambda] = 
                2 \(\[Sum]\+\(\[Beta] \[NotEqual] \[Alpha]\)n\_\(\[Alpha], \
\[Beta]\)\) + 2 \(\[Sum]\+\[Alpha] n\_\(\[Alpha], \[Alpha]\)\)\),
              
              "TraditionalForm"], \(\(p\_\[Alpha] + 
                  p\_\[Nu]\)\/\(p\_\[Alpha] + 2  p\_\[Nu]\)\)}], "+"}], 
        TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(2 \[Sum]\_\(\[AliasDelimiter]\[Alpha]\)\),
              
              "TraditionalForm"], \(\(\(n\_\(\[Alpha], \[Alpha]\)\) 
                  p\_\[Nu]\)\/\(p\_\[Alpha] + 2  p\_\[Nu]\)\)}], 
          "+", \(2  n\_\[EmptySet]\)}], TraditionalForm]]],
  "=",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"2", 
            
            FormBox[\(\[Sum]\+\(\[Beta] \[NotEqual] \[Alpha]\)n\_\(\[Alpha], \
\[Beta]\) + 2 \(\[Sum]\+\[Alpha] n\_\(\[Alpha], \[Alpha]\)\)\),
              "TraditionalForm"]}], "+", \(2  n\_\[EmptySet]\)}], 
        TraditionalForm]]],
  "=2N"
}], "InlineFormula"],

Cell["Hence, the estimates are:", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Alpha]\)]],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\(=\)\(\(p\&~\_\[Alpha]\)(\(N - n\_\[EmptySet]\)\/N) - 
                n\_\(\[Alpha], \[Alpha]\)\/N\)\),
            "TraditionalForm"], \(p\_\[Nu]\/\(p\_\[Alpha] + 2  p\_\[Nu]\)\)}],
         TraditionalForm]]],
  "   and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(p\_\[Nu]\), "=", 
            RowBox[{
              RowBox[{
                
                FormBox[\(\(1\/N\) \((\[Sum]\_\(\[AliasDelimiter]\[Alpha]\)\)\
\),
                  
                  "TraditionalForm"], \(\(\(n\_\(\[Alpha], \[Alpha]\)\) 
                      p\_\[Nu]\)\/\(p\_\[Alpha] + 2  p\_\[Nu]\)\)}], 
              "+", \(n\_\[EmptySet]\)}]}], ")"}], TraditionalForm]]]
}], "InlineFormula"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`p\&~\_\[Alpha]\)]],
  " is the naive estimate obtained by ignoring nulls and missing data, and \
where N includes missing data.."
}], "Text"],

Cell["If missing data are ignored,the likelihood is:", "Text"],

Cell[TextData[{
  "Log[L] = ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\[Sum]\+\(\[Alpha] \[NotEqual] \[Beta]\)\(n\_\(\[Alpha], \
\[Beta]\)\) Log[\(2 \( p\_\[Alpha]\) p\_\[Beta]\)\/\(1 - p\_\[Nu]\%2\)]\),
            "TraditionalForm"], 
          "+", \(\[Sum]\+\[Alpha]\( n\_\(\[Alpha], \[Alpha]\)\) 
              Log[\(p\_\[Alpha]\%2 + 2 \( p\_\[Alpha]\) p\_\[Nu]\)\/\(1 - p\_\
\[Nu]\%2\)]\)}], TraditionalForm]]],
  "= ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{
              
              FormBox[\(\[Sum]\+\(\[Alpha] \[NotEqual] \[Beta]\)\(n\_\(\
\[Alpha], \[Beta]\)\) Log[2 \( p\_\[Alpha]\) p\_\[Beta]]\),
                "TraditionalForm"], 
              "+", \(\[Sum]\+\[Alpha]\( n\_\(\[Alpha], \[Alpha]\)\) 
                  Log[p\_\[Alpha]\%2 + 2 \( p\_\[Alpha]\) p\_\[Nu]]\)}],
            "TraditionalForm"], 
          "-", \(\((N - n\_\[EmptySet])\) Log[1 - p\_\[Nu]\%2]\)}], 
        TraditionalForm]]]
}], "InlineFormula"],

Cell["Hence:", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Alpha]\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]Log[L]\/\[PartialD]p\_\[Alpha]\)]],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\(=\)\(\[Lambda]\[VeryThinSpace]p\_\[Alpha] = \[Sum]\+\(\
\[Beta] \[NotEqual] \[Alpha]\)n\_\(\[Alpha], \[Beta]\) + 
                  2  n\_\(\[Alpha], \[Alpha]\)\)\),
            
            "TraditionalForm"], \(\(p\_\[Alpha] + p\_\[Nu]\)\/\(p\_\[Alpha] + 
                2  p\_\[Nu]\)\)}], TraditionalForm]]],
  "   and ",
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Nu]\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]Log[L]\/\[PartialD]p\_\[Nu]\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{"=", 
          RowBox[{\(\[Lambda]\[VeryThinSpace]p\_\[Nu]\), "=", 
            RowBox[{
              RowBox[{
                FormBox[\(2 \[Sum]\_\[Alpha]\),
                  
                  "TraditionalForm"], \(\(\(n\_\(\[Alpha], \[Alpha]\)\) 
                      p\_\[Nu]\)\/\(p\_\[Alpha] + 2  p\_\[Nu]\)\)}], 
              "+", \(2 \(\( p\_\[Nu]\%2\)(N - n\_\[EmptySet])\)\/\(1 - p\_\
\[Nu]\%2\)\)}]}]}], TraditionalForm]]]
}], "InlineFormula"],

Cell["Summing, we find that:", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = \(2 \(\[Sum]\+\(\[Beta] \[NotEqual] \
\[Alpha]\)n\_\(\[Alpha], \[Beta]\)\) + 
            2 \(\[Sum]\+\[Alpha] n\_\(\[Alpha], \[Alpha]\)\) + 
            2 \(\( p\_\[Nu]\%2\)(N - n\_\[EmptySet])\)\/\(1 - p\_\[Nu]\%2\) = \
\ 2 \((N - n\_\[EmptySet])\)\/\(1 - p\_\[Nu]\%2\)\)\)]]
}], "InlineFormula"],

Cell["which equals 2N in expectation.  The estimates are thus:", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Alpha] = \((1 - 
              p\_\[Nu]\%2)\) \((p\&~\_\[Alpha] - \(n\_\(\[Alpha], \
\[Alpha]\)\/\((N - n\_\[EmptySet])\)\) 
                p\_\[Nu]\/\(p\_\[Alpha] + 2  p\_\[Nu]\))\)\)]],
  "   and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(p\_\[Nu]\), "=", 
          RowBox[{\((1 - p\_\[Nu]\%2)\), 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox[\(\[Sum]\_\[Alpha]\),
                    
                    "TraditionalForm"], \(\(n\_\(\[Alpha], \[Alpha]\)\/\((N - 
                            n\_\[EmptySet])\)\) 
                    p\_\[Nu]\/\(p\_\[Alpha] + 2  p\_\[Nu]\)\)}], 
                "+", \(p\_\[Nu]\%2\/\(1 - p\_\[Nu]\%2\)\)}], ")"}]}]}], 
        TraditionalForm]]]
}], "InlineFormula"],

Cell[TextData[{
  "Given an initial estimate of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(p\_\[Nu] = 0\)\(,\)\)\)]],
  "one can refine the estimate by successive iteration.  "
}], "Text"],

Cell[TextData[{
  "It is not clear whether this procedure converges to a unique solution.  \
Ignoring missing data, we can see that ",
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Nu]\)]],
  " wil increase from a small value if ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(\[Sum]\_\[Alpha]\),
              
              "TraditionalForm"], \(\(n\_\(\[Alpha], \[Alpha]\)\/\((N - 
                      n\_\[EmptySet])\)\) 1\/p\_\[Alpha]\)}], ">", "1"}], 
        TraditionalForm]]],
  " - that is, if there is a net excess of homozygotes over HW.  At the other \
extreme, ",
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Nu]\)]],
  " always decreases from 1.  "
}], "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The frequency of a given genotype", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["GenotypeFrequency", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"GenotypeFrequency", "[", 
              RowBox[{"d", ",", 
                StyleBox["alleles",
                  FontSlant->"Italic"], ",", "p"}], 
              "]"}], \(lists\ the\ diploid\ genotype\ frequency\ for\ each\ \
locus, \ given\ the\ allele\ frequencies\ \(\(p\)\(.\)\)\)},
          {
            RowBox[{"GenotypeFrequency", "[", 
              RowBox[{"d", ",", 
                StyleBox["alleles",
                  FontSlant->"Italic"], ",", "p1", ",", "p2"}], 
              "]"}], \(allows\ different\ pools\ for\ the\ two\ parents\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"GenotypeFrequency"],

Cell["\<\
These are the frequencies of the genotypes at the three loci in \
this diploid individual:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GenotypeFrequency[{{a, b}, {c, c}, {f, f}}, {{a, b}, {c, d, e}, {f, 
          g}}, {{0.1, 0.9}, {0.2, 0.3, 0.5}, {0.35, 0.65}}]\)], "Input",
  CellLabel->"In[258]:="],

Cell[BoxData[
    \({0.18000000000000002`, 0.04000000000000001`, 
      0.12249999999999998`}\)], "Output",
  CellLabel->"Out[258]="]
}, Open  ]],

Cell["This assumes Hardy Weinberg proportions.", "Text"],

Cell["\<\
The product of these is the genotype frequency, assuming linkage \
equilibrium:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Times @@ %\)], "Input",
  CellLabel->"In[259]:="],

Cell[BoxData[
    \(0.0008820000000000002`\)], "Output",
  CellLabel->"Out[259]="]
}, Open  ]],

Cell["\<\
If the indiviudal is a hybrid between parents drawn from different \
populations, the frequency ofheterozygotes is higher:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GenotypeFrequency[{{a, b}, {c, c}}, {{a, b}, {c, d, e}}, {{0.1, 
          0.9}, {0.2, 0.3, 0.5}}, {{0.9, 0.1}, {0.2, 0.3, 0.5}}]\)], "Input",
  CellLabel->"In[324]:="],

Cell[BoxData[
    \({0.8200000000000001`, 0.04000000000000001`}\)], "Output",
  CellLabel->"Out[324]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"GenotypeFrequency", "[", 
              RowBox[{"d", ",", 
                StyleBox["alleles",
                  FontSlant->"Italic"], ",", "p", 
                ",", \(NullAllele \[Rule] \[Nu]\)}], 
              "]"}], \(specifies\ that\ \[Nu]\ represents\ a\ null\ \
allele\)},
          {
            RowBox[{"GenotypeFrequency", "[", 
              RowBox[{"d", ",", 
                StyleBox["alleles",
                  FontSlant->"Italic"], ",", "p", 
                ",", \(NullAllele \[Rule] \[Nu]\), 
                ",", \(MissingData \[Rule] True\)}], 
              "]"}], \(specifies\ that\ missing\ data, \ \[EmptySet], \ 
            are\ to\ be\ interpreted\ as\ null\ homozygotes\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"GenotypeFrequency"],

Cell["Heterozygotes involving a null allele appear as homozygotes:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GenotypeFrequency[{{a, b}, {c, c}}, {{a, b, \[Nu]}, {c, 
          d, \[Nu]}}, {{pa, pb, p\[Nu]}, {pc, pd, p\[Nu]}}, 
      NullAllele \[Rule] \[Nu]]\)], "Input",
  CellLabel->"In[267]:="],

Cell[BoxData[
    \({\(2\ pa\ pb\)\/\(1 - p\[Nu]\^2\), \(pc\^2 + 2\ pc\ p\[Nu]\)\/\(1 - p\
\[Nu]\^2\)}\)], "Output",
  CellLabel->"Out[267]="]
}, Open  ]],

Cell[TextData[{
  "Null homozygotes are assumed to be ignored as missing data, so that \
frequencies must be normalised by ",
  Cell[BoxData[
      \(TraditionalForm\`\((1 - p\[Nu]\^2)\)\)]],
  ". Apparent homozygotes may be real, or may be heterozygotes with the null \
alelel (second term above)."
}], "Text"],

Cell["Missing data can be interpreted as null homozygotes:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GenotypeFrequency[{{a, b}, {c, c}, \[EmptySet]}, {{a, b, \[Nu]}, {c, 
          d, \[Nu]}, {e, f, \[Nu]}}, {{pa, pb, p\[Nu]}, {pc, pd, 
          p\[Nu]}, {pe, pf, p\[Nu]}}, NullAllele \[Rule] \[Nu], 
      MissingData \[Rule] True]\)], "Input",
  CellLabel->"In[268]:="],

Cell[BoxData[
    \({2\ pa\ pb, pc\^2 + 2\ pc\ p\[Nu], p\[Nu]\^2}\)], "Output",
  CellLabel->"Out[268]="]
}, Open  ]],

Cell["\<\
Note that HaploidGenotypeFrequency and DiploidGenotypeFrequency \
take account ofmultilocus linkage disequilibria, assuming an admixture model.\
\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Extracting allele frequency", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"AlleleFrequency", "[", 
              RowBox[{
                StyleBox["locus",
                  FontSlant->"Italic"], ",", 
                StyleBox["allele",
                  FontSlant->"Italic"], ",", 
                StyleBox["alleles",
                  FontSlant->"Italic"], ",", "p"}], "]"}], 
            RowBox[{
              RowBox[{"gives", " ", "the", " ", "frequency", " ", "of", " ", 
                StyleBox["allele",
                  FontSlant->"Italic"]}], 
              StyleBox[",",
                FontSlant->"Italic"], 
              RowBox[{"extracted", " ", "from", " ", "the", " ", "list", 
                StyleBox[" ",
                  FontSlant->"Italic"], 
                StyleBox["p",
                  FontSlant->"Italic"]}]}]},
          {
            RowBox[{"AlleleFrequency", "[", 
              RowBox[{\({a\_1, \ \(a\_2\) \[Ellipsis]}\), ",", 
                StyleBox["alleles",
                  FontSlant->"Italic"], ",", "p"}], 
              "]"}], \(lists\ the\ frequencies\ of\ the\ alelles\ that\ make\ \
up\ a\ haploid\ genotype\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"AlleleFrequency"],

Cell["This finds the allele frequencyof allele a:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlleleFrequency[1, 
      a, {{a, b}, {c, d, e}, {f, g}}, {{0.1, 0.9}, {0.2, 0.3, 0.5}, {0.35, 
          0.65}}]\)], "Input",
  CellLabel->"In[255]:="],

Cell[BoxData[
    \(0.1`\)], "Output",
  CellLabel->"Out[255]="]
}, Open  ]],

Cell["\<\
This list the allele frequencies for the whole haploid \
genotype:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlleleFrequency[{a, d, 
        f}, {{a, b}, {c, d, e}, {f, g}}, {{0.1, 0.9}, {0.2, 0.3, 0.5}, {0.35, 
          0.65}}]\)], "Input",
  CellLabel->"In[256]:="],

Cell[BoxData[
    \({0.1`, 0.3`, 0.35`}\)], "Output",
  CellLabel->"Out[256]="]
}, Open  ]],

Cell["\<\
The product of these is the genotype frequency, assuming linkage \
equilibrium:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Times @@ %\)], "Input",
  CellLabel->"In[257]:="],

Cell[BoxData[
    \(0.0105`\)], "Output",
  CellLabel->"Out[257]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{918, 670},
WindowMargins->{{Automatic, 74}, {8, Automatic}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\[Placeholder]", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->Utilities`Notation`Private`DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "AlleleFrequencyMean"->{
    Cell[1909, 57, 1556, 37, 74, "DefinitionBox",
      CellTags->{"AlleleFrequencyMean", "AlleleFrequencyTable"}]},
  "AlleleFrequencyTable"->{
    Cell[1909, 57, 1556, 37, 74, "DefinitionBox",
      CellTags->{"AlleleFrequencyMean", "AlleleFrequencyTable"}]},
  "NetCovariance"->{
    Cell[8960, 295, 516, 14, 52, "DefinitionBox",
      CellTags->{"NetCovariance", "Linkage disequilibrium"}]},
  "Linkage disequilibrium"->{
    Cell[8960, 295, 516, 14, 52, "DefinitionBox",
      CellTags->{"NetCovariance", "Linkage disequilibrium"}]},
  "GenotypeFrequencyTable"->{
    Cell[12118, 405, 551, 13, 38, "DefinitionBox",
      CellTags->"GenotypeFrequencyTable"]},
  "MissingData"->{
    Cell[28873, 956, 431, 9, 56, "DefinitionBox",
      CellTags->{"MissingData", "NullAllele"}]},
  "NullAllele"->{
    Cell[28873, 956, 431, 9, 56, "DefinitionBox",
      CellTags->{"MissingData", "NullAllele"}]},
  "GenotypeFrequency"->{
    Cell[43061, 1392, 722, 16, 56, "DefinitionBox",
      CellTags->"GenotypeFrequency"],
    Cell[45099, 1463, 869, 20, 58, "DefinitionBox",
      CellTags->"GenotypeFrequency"]},
  "AlleleFrequency"->{
    Cell[47526, 1537, 1251, 30, 56, "DefinitionBox",
      CellTags->"AlleleFrequency"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"AlleleFrequencyMean", 121135, 4184},
  {"AlleleFrequencyTable", 121280, 4187},
  {"NetCovariance", 121418, 4190},
  {"Linkage disequilibrium", 121561, 4193},
  {"GenotypeFrequencyTable", 121704, 4196},
  {"MissingData", 121818, 4199},
  {"NullAllele", 121935, 4202},
  {"GenotypeFrequency", 122059, 4205},
  {"AlleleFrequency", 122263, 4210}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 72, 0, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[1836, 55, 70, 0, 24, "SubsubsectionIcon"],
Cell[1909, 57, 1556, 37, 74, "DefinitionBox",
  CellTags->{"AlleleFrequencyMean", "AlleleFrequencyTable"}],
Cell[3468, 96, 41, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3534, 100, 81, 2, 26, "Input"],
Cell[3618, 104, 3446, 108, 99, "Output"]
}, Open  ]],
Cell[7079, 215, 65, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7169, 219, 87, 2, 26, "Input"],
Cell[7259, 223, 132, 3, 36, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7428, 231, 86, 2, 26, "Input"],
Cell[7517, 235, 74, 2, 36, "Output"]
}, Open  ]],
Cell[7606, 240, 77, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7708, 244, 216, 5, 42, "Input"],
Cell[7927, 251, 300, 8, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8264, 264, 112, 2, 26, "Input"],
Cell[8379, 268, 272, 8, 89, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8688, 281, 97, 2, 26, "Input"],
Cell[8788, 285, 78, 2, 36, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[8915, 293, 42, 0, 20, "SubsubsectionIcon"],
Cell[8960, 295, 516, 14, 52, "DefinitionBox",
  CellTags->{"NetCovariance", "Linkage disequilibrium"}],
Cell[9479, 311, 201, 4, 22, "Text"],
Cell[9683, 317, 310, 5, 36, "Text"],

Cell[CellGroupData[{
Cell[10018, 326, 230, 5, 42, "Input"],
Cell[10251, 333, 354, 9, 79, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10642, 347, 99, 2, 26, "Input"],
Cell[10744, 351, 117, 2, 36, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10898, 358, 87, 2, 26, "Input"],
Cell[10988, 362, 69, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11094, 369, 90, 2, 26, "Input"],
Cell[11187, 373, 280, 8, 89, "Output"]
}, Open  ]],
Cell[11482, 384, 545, 14, 38, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[12064, 403, 51, 0, 20, "SubsubsectionIcon"],
Cell[12118, 405, 551, 13, 38, "DefinitionBox",
  CellTags->"GenotypeFrequencyTable"],
Cell[12672, 420, 127, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[12824, 427, 271, 6, 54, "Input"],
Cell[13098, 435, 10784, 355, 70, "Output"]
}, Closed]],
Cell[23897, 793, 56, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[23978, 797, 178, 3, 54, "Input"],
Cell[24159, 802, 137, 2, 48, "Output"]
}, Open  ]],
Cell[24311, 807, 98, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[24434, 814, 121, 2, 38, "Input"],
Cell[24558, 818, 157, 3, 48, "Output"]
}, Open  ]],
Cell[24730, 824, 163, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[24918, 832, 128, 2, 38, "Input"],
Cell[25049, 836, 2951, 85, 65, "Output"]
}, Open  ]],
Cell[28015, 924, 259, 7, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[28299, 935, 110, 2, 38, "Input"],
Cell[28412, 939, 258, 4, 47, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[28731, 950, 73, 0, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[28829, 954, 41, 0, 24, "SubsubsectionIcon"],
Cell[28873, 956, 431, 9, 56, "DefinitionBox",
  CellTags->{"MissingData", "NullAllele"}],
Cell[29307, 967, 112, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[29444, 974, 580, 11, 104, "Input"],
Cell[30027, 987, 120, 3, 36, "Output"]
}, Open  ]],
Cell[30162, 993, 100, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[30287, 1000, 178, 4, 26, "Input"],
Cell[30468, 1006, 316, 6, 36, "Output"]
}, Open  ]],
Cell[30799, 1015, 370, 6, 36, "Text"],
Cell[31172, 1023, 215, 4, 22, "Text"],
Cell[31390, 1029, 193, 4, 22, "Text"],

Cell[CellGroupData[{
Cell[31608, 1037, 204, 4, 26, "Input"],
Cell[31815, 1043, 303, 5, 36, "Output"]
}, Open  ]],
Cell[32133, 1051, 46, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[32204, 1055, 493, 13, 129, "Input"],
Cell[32700, 1070, 97, 2, 36, "Output"]
}, Open  ]],
Cell[32812, 1075, 106, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[32943, 1082, 144, 3, 26, "Input"],
Cell[33090, 1087, 175, 3, 36, "Output"]
}, Open  ]],
Cell[33280, 1093, 336, 6, 36, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33653, 1104, 42, 0, 20, "SubsubsectionIcon"],
Cell[33698, 1106, 435, 10, 36, "Text"],
Cell[34136, 1118, 497, 13, 25, "InlineFormula"],
Cell[34636, 1133, 61, 0, 22, "Text"],
Cell[34700, 1135, 1194, 32, 30, "InlineFormula"],
Cell[35897, 1169, 107, 3, 22, "Text"],
Cell[36007, 1174, 1150, 34, 30, "InlineFormula"],
Cell[37160, 1210, 41, 0, 22, "Text"],
Cell[37204, 1212, 868, 26, 33, "InlineFormula"],
Cell[38075, 1240, 210, 6, 24, "Text"],
Cell[38288, 1248, 62, 0, 22, "Text"],
Cell[38353, 1250, 1030, 27, 40, "InlineFormula"],
Cell[39386, 1279, 22, 0, 22, "Text"],
Cell[39411, 1281, 1221, 33, 37, "InlineFormula"],
Cell[40635, 1316, 38, 0, 22, "Text"],
Cell[40676, 1318, 374, 8, 37, "InlineFormula"],
Cell[41053, 1328, 72, 0, 22, "Text"],
Cell[41128, 1330, 830, 21, 38, "InlineFormula"],
Cell[41961, 1353, 193, 5, 22, "Text"],
Cell[42157, 1360, 722, 20, 52, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[42928, 1386, 59, 0, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[43012, 1390, 46, 0, 24, "SubsubsectionIcon"],
Cell[43061, 1392, 722, 16, 56, "DefinitionBox",
  CellTags->"GenotypeFrequency"],
Cell[43786, 1410, 114, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[43925, 1417, 187, 3, 42, "Input"],
Cell[44115, 1422, 133, 3, 20, "Output"]
}, Open  ]],
Cell[44263, 1428, 56, 0, 22, "Text"],
Cell[44322, 1430, 103, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[44450, 1437, 69, 2, 26, "Input"],
Cell[44522, 1441, 82, 2, 20, "Output"]
}, Open  ]],
Cell[44619, 1446, 146, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[44790, 1453, 188, 3, 42, "Input"],
Cell[44981, 1458, 103, 2, 20, "Output"]
}, Open  ]],
Cell[45099, 1463, 869, 20, 58, "DefinitionBox",
  CellTags->"GenotypeFrequency"],
Cell[45971, 1485, 76, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[46072, 1489, 208, 4, 26, "Input"],
Cell[46283, 1495, 142, 3, 41, "Output"]
}, Open  ]],
Cell[46440, 1501, 311, 7, 37, "Text"],
Cell[46754, 1510, 68, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[46847, 1514, 291, 5, 42, "Input"],
Cell[47141, 1521, 105, 2, 22, "Output"]
}, Open  ]],
Cell[47261, 1526, 169, 4, 22, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[47467, 1535, 56, 0, 20, "SubsubsectionIcon"],
Cell[47526, 1537, 1251, 30, 56, "DefinitionBox",
  CellTags->"AlleleFrequency"],
Cell[48780, 1569, 59, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[48864, 1573, 172, 4, 26, "Input"],
Cell[49039, 1579, 64, 2, 20, "Output"]
}, Open  ]],
Cell[49118, 1584, 90, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[49233, 1591, 179, 4, 26, "Input"],
Cell[49415, 1597, 79, 2, 20, "Output"]
}, Open  ]],
Cell[49509, 1602, 103, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[49637, 1609, 69, 2, 26, "Input"],
Cell[49709, 1613, 67, 2, 20, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

