(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5652,        163]*)
(*NotebookOutlinePosition[      6820,        200]*)
(*  CellTagsIndexPosition[      6708,        193]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Subsets of loci", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(HaploidSubsets[
              S]\), \(gives\ all\ the\ haploid\ subsets\ based\ on\ loci\ \
listed\ in\ S . \ Stores\ \(\(results\)\(.\)\)\)},
          {\(DiploidSubsets[
              S]\), \(gives\ all\ the\ diploid\ subsets\ based\ on\ loci\ \
listed\ in\ S . \ Stores\ \(\(results\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"DiploidSubsets", "HaploidSubsets"}],

Cell[TextData[{
  "Here are all the subsets of the set of three loci, ",
  Cell[BoxData[
      \(TraditionalForm\`{i, j, k}\)]],
  ", of size two or more:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(HaploidSubsets[{i, j, k}]\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \({{i, j}, {i, k}, {j, k}, {i, j, k}}\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell[TextData[{
  "HaploidSubsets[] is used with functions in ",
  StyleBox["Multilocus`EstimatingD`",
    FontSlant->"Italic"],
  " to construct the set of associations (\"linkage disequilibria\") needed \
to construct genotype frequencies.  Hence, it is defined to include pairs and \
upwards.  HaploidSubsets[] calls ",
  Cell[BoxData[
      \(TraditionalForm\`Subsets[S, 2, Length[S]]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Here is the set of diploid combinations involving three loci, ",
  Cell[BoxData[
      \(TraditionalForm\`{i, j, k}\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DiploidSubsets[{i, j, k}]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \({{i, j}, {i, k}, {i, \(i\^*\)}, {i, \(j\^*\)}, {i, \(k\^*\)}, {j, 
        k}, {j, \(i\^*\)}, {j, \(j\^*\)}, {j, \(k\^*\)}, {k, \(i\^*\)}, {k, \
\(j\^*\)}, {k, \(k\^*\)}, {\(i\^*\), \(j\^*\)}, {\(i\^*\), \(k\^*\)}, {\(j\^*\
\), \(k\^*\)}, {i, j, k}, {i, j, \(i\^*\)}, {i, j, \(j\^*\)}, {i, 
        j, \(k\^*\)}, {i, k, \(i\^*\)}, {i, k, \(j\^*\)}, {i, 
        k, \(k\^*\)}, {i, \(i\^*\), \(j\^*\)}, {i, \(i\^*\), \(k\^*\)}, {i, \
\(j\^*\), \(k\^*\)}, {j, k, \(i\^*\)}, {j, k, \(j\^*\)}, {j, 
        k, \(k\^*\)}, {j, \(i\^*\), \(j\^*\)}, {j, \(i\^*\), \(k\^*\)}, {j, \
\(j\^*\), \(k\^*\)}, {k, \(i\^*\), \(j\^*\)}, {k, \(i\^*\), \(k\^*\)}, {k, \
\(j\^*\), \(k\^*\)}, {\(i\^*\), \(j\^*\), \(k\^*\)}, {i, j, k, \(i\^*\)}, {i, 
        j, k, \(j\^*\)}, {i, j, k, \(k\^*\)}, {i, j, \(i\^*\), \(j\^*\)}, {i, 
        j, \(i\^*\), \(k\^*\)}, {i, j, \(j\^*\), \(k\^*\)}, {i, 
        k, \(i\^*\), \(j\^*\)}, {i, k, \(i\^*\), \(k\^*\)}, {i, 
        k, \(j\^*\), \(k\^*\)}, {i, \(i\^*\), \(j\^*\), \(k\^*\)}, {j, 
        k, \(i\^*\), \(j\^*\)}, {j, k, \(i\^*\), \(k\^*\)}, {j, 
        k, \(j\^*\), \(k\^*\)}, {j, \(i\^*\), \(j\^*\), \(k\^*\)}, {k, \(i\^*\
\), \(j\^*\), \(k\^*\)}, {i, j, k, \(i\^*\), \(j\^*\)}, {i, j, 
        k, \(i\^*\), \(k\^*\)}, {i, j, k, \(j\^*\), \(k\^*\)}, {i, 
        j, \(i\^*\), \(j\^*\), \(k\^*\)}, {i, 
        k, \(i\^*\), \(j\^*\), \(k\^*\)}, {j, 
        k, \(i\^*\), \(j\^*\), \(k\^*\)}, {i, j, 
        k, \(i\^*\), \(j\^*\), \(k\^*\)}}\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " denotes a gene at locus i from the maternal genome, ",
  Cell[BoxData[
      \(TraditionalForm\`\(i\^*\)\)]],
  "a gene at locus ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  "  from the paternal genome.  DiploidSubsets[] calls ",
  Cell[BoxData[
      \(TraditionalForm\`HaploidSubsets[Join[S, changeSex[S]]]\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Note",
    FontWeight->"Bold"],
  ": ",
  "DiploidSubsets",
  " has not been made compatible with the more general multilocus notation, \
using ",
  ButtonBox["genes-in-context",
    ButtonData:>{"Genes and contexts", "Genes and contexts"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"genes-in-context"],
  "."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{245, Automatic}, {Automatic, 46}},
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "DiploidSubsets"->{
    Cell[1783, 53, 462, 9, 84, "DefinitionBox",
      CellTags->{"DiploidSubsets", "HaploidSubsets"}]},
  "HaploidSubsets"->{
    Cell[1783, 53, 462, 9, 84, "DefinitionBox",
      CellTags->{"DiploidSubsets", "HaploidSubsets"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"DiploidSubsets", 6453, 183},
  {"HaploidSubsets", 6579, 186}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 41, 0, 36, "SubsectionIcon"],
Cell[1783, 53, 462, 9, 84, "DefinitionBox",
  CellTags->{"DiploidSubsets", "HaploidSubsets"}],
Cell[2248, 64, 174, 5, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2447, 73, 82, 2, 27, "Input"],
Cell[2532, 77, 93, 2, 20, "Output"]
}, Open  ]],
Cell[2640, 82, 411, 10, 52, "Text"],
Cell[3054, 94, 164, 5, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3243, 103, 82, 2, 27, "Input"],
Cell[3328, 107, 1528, 23, 125, "Output"]
}, Open  ]],
Cell[4871, 133, 408, 13, 36, "Text"],
Cell[5282, 148, 354, 12, 39, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

