(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    264189,       6637]*)
(*NotebookOutlinePosition[    266949,       6710]*)
(*  CellTagsIndexPosition[    266905,       6706]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["MissingData", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(MissingData::usage = "\<MissingData is an option for \
GenotypeFrequency that specifies that missing data,\[EmptySet], are \
interpreted as homozygous null alleles\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NullAllele", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(NullAllele::usage = "\<NullAllele\[Rule]\[Nu] specifies that \[Nu] \
represents a null allele.  This must be listed in the allele list for the \
relevant loci, and the same symbol must be used for all loci\>";\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["GenotypeFrequency", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(GenotypeFrequency::usage = "\<GenotypeFrequency[d,alleleList,pList]  \
lists the diploid genotype frequency for each locus, given the allele \
frequencies p. The allele names are listed in the second argument.  \
NullAllele\[Rule]\[Nu]  specifies that allele \[Nu] is a null allele; null \
heterozygotes appear as homozygotes, and null homozygotes appear as missing \
data.  MissingData\[Rule]True allows missing data to be interpreted as null \
homozygotes and used in estimation; otherwise they are ignored\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[GenotypeFrequency] = {MissingData \[Rule] False, 
          NullAllele \[Rule] None};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(GenotypeFrequency[l_Integer, \[EmptySet], al_List, pl_List, 
          opts___Rule] := \[IndentingNewLine]Module[{na = \(NullAllele /. \
{opts}\) /. Options[
                  GenotypeFrequency], \[IndentingNewLine]md = \(MissingData /. \
{opts}\) /. Options[GenotypeFrequency]}, \[IndentingNewLine]If[
            na === None, \[IndentingNewLine]\[EmptySet], \
\[IndentingNewLine]If[
              MemberQ[al\[LeftDoubleBracket]l\[RightDoubleBracket], 
                  na] \[And] 
                md, \[IndentingNewLine]AlleleFrequency[l, na, al, pl]\^2, \
\[IndentingNewLine]\[EmptySet]]]];\)\), "\[IndentingNewLine]", 
    \(\(GenotypeFrequency[l_Integer, {a_, a_}, al_List, pl_List, 
          opts___Rule] := \[IndentingNewLine]Module[{na = \(NullAllele /. \
{opts}\) /. Options[
                  GenotypeFrequency], \[IndentingNewLine]md = \(MissingData /. \
{opts}\) /. Options[GenotypeFrequency], pn}, \[IndentingNewLine]If[
            MemberQ[al\[LeftDoubleBracket]l\[RightDoubleBracket], 
              na], \[IndentingNewLine]pn = 
              AlleleFrequency[l, na, al, 
                pl]; \[IndentingNewLine]\(AlleleFrequency[l, a, al, pl]\^2 + \
2  AlleleFrequency[l, a, al, pl] pn\)\/If[MemberQ[al\[LeftDoubleBracket]l\
\[RightDoubleBracket], na] \[And] \(! md\), 1 - pn\^2, 1], \
\[IndentingNewLine]AlleleFrequency[l, a, al, pl]\^2]];\)\), "\
\[IndentingNewLine]", 
    \(\(GenotypeFrequency[l_Integer, {a1_, a2_}, al_List, pl_List, 
          opts___Rule] := 
        Module[{na = \(NullAllele /. {opts}\) /. 
                Options[
                  GenotypeFrequency], \[IndentingNewLine]md = \(MissingData /. \
{opts}\) /. Options[
                  GenotypeFrequency]}, \[IndentingNewLine]\(2  \
AlleleFrequency[l, a1, al, pl] AlleleFrequency[l, a2, al, \
pl]\)\/If[MemberQ[al\[LeftDoubleBracket]l\[RightDoubleBracket], na] \[And] \
\(! md\), 1 - pn\^2, 1]];\)\), "\[IndentingNewLine]", 
    \(\(GenotypeFrequency[dg : {\(({_, _} | \[EmptySet])\) ... }, al_List, 
          pl_List, opts___Rule] := \[IndentingNewLine]MapIndexed[
          GenotypeFrequency[#2\[LeftDoubleBracket]1\[RightDoubleBracket], #1, 
              al, pl, opts] &, dg];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AlleleFrequency", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(AlleleFrequency::usage = \
\*"\"\<AlleleFrequency[locus,allele,alleleList,pList] gives the frequency of \
the given allele. Missing data are represented by \[EmptySet] and return a \
frequency of \[EmptySet]. \
AlleleFrequency[{\!\(a\_1\),\[Ellipsis]},alleleList,pList] lists the \
frequencies of all the alleles. (These are assumed to be at successive \
loci,so that {\!\(a\_1\),\[Ellipsis]} is a haploid genotype).\>\"";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AlleleFrequency::badAllele = "\<`1` is not an allele of locus `2`\>";\
\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AlleleFrequency[l_Integer, a_, al_List, pl_List] := 
        Module[{pos = 
              Position[al\[LeftDoubleBracket]l\[RightDoubleBracket], 
                a]}, \[IndentingNewLine]If[
            a === \[EmptySet], \[IndentingNewLine]\[EmptySet], \
\[IndentingNewLine]If[
              pos === {}, \[IndentingNewLine]Message[
                AlleleFrequency::badAllele, a, l]; 
              Indeterminate, \[IndentingNewLine]Extract[
                pl\[LeftDoubleBracket]l\[RightDoubleBracket], 
                pos\[LeftDoubleBracket]1\[RightDoubleBracket]]]]];\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(AlleleFrequency[a_List, al_List, pl_List] := 
        MapIndexed[
          AlleleFrequency[#2\[LeftDoubleBracket]1\[RightDoubleBracket], #1, 
              al, pl] &, a];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Estimating allele frequencies in the presence of nulls", "Subsubsection"],

Cell[TextData[{
  "Suppose that we observe ",
  Cell[BoxData[
      \(TraditionalForm\`n\_\(\[Alpha], \[Beta]\)\)]],
  " of diploid genotype {\[Alpha],\[Beta]},and suspect that there may be null \
alleles segregating.  Let the allele frequencies be ",
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Alpha], p\_\[Nu]\)]],
  ".  Assume first that null homozygotes are identified as missing values.  \
Then, the likelihood is:"
}], "Text"],

Cell[TextData[{
  "Log[L] = ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\[Sum]\+\(\[Alpha] \[NotEqual] \[Beta]\)\(n\_\(\[Alpha], \
\[Beta]\)\) Log[2 \( p\_\[Alpha]\) p\_\[Beta]]\),
            "TraditionalForm"], 
          "+", \(\[Sum]\+\[Alpha]\( n\_\(\[Alpha], \[Alpha]\)\) 
              Log[p\_\[Alpha]\%2 + 2 \( p\_\[Alpha]\) p\_\[Nu]]\), 
          "+", \(\(n\_\[EmptySet]\) Log[p\_\[EmptySet]\%2]\)}], 
        TraditionalForm]]]
}], "InlineFormula"],

Cell["Hence, allele frequencies are estimated from:", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Alpha]\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]Log[L]\/\[PartialD]p\_\[Alpha]\)]],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\(=\)\(\[Lambda]\[VeryThinSpace]p\_\[Alpha] = \[Sum]\+\(\
\[Beta] \[NotEqual] \[Alpha]\)n\_\(\[Alpha], \[Beta]\) + 
                  2  n\_\(\[Alpha], \[Alpha]\)\)\),
            
            "TraditionalForm"], \(\(p\_\[Alpha] + p\_\[Nu]\)\/\(p\_\[Alpha] + 
                2  p\_\[Nu]\)\)}], TraditionalForm]]],
  "   and ",
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Nu]\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]Log[L]\/\[PartialD]p\_\[Nu]\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{"=", 
          RowBox[{\(\[Lambda]\[VeryThinSpace]p\_\[Nu]\), "=", 
            RowBox[{
              RowBox[{
                FormBox[\(2 \[Sum]\_\(\[AliasDelimiter]\[Alpha]\)\),
                  
                  "TraditionalForm"], \(\(\(n\_\(\[Alpha], \[Alpha]\)\) 
                      p\_\[Nu]\)\/\(p\_\[Alpha] + 2  p\_\[Nu]\)\)}], 
              "+", \(2  n\_\[EmptySet]\)}]}]}], TraditionalForm]]]
}], "InlineFormula"],

Cell["\<\
The constant \[Lambda] is determined by the constraint that the sum \
must equal 1:\
\>", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            
            FormBox[\(\[Lambda] = 
                2 \(\[Sum]\+\(\[Beta] \[NotEqual] \[Alpha]\)n\_\(\[Alpha], \
\[Beta]\)\) + 2 \(\[Sum]\+\[Alpha] n\_\(\[Alpha], \[Alpha]\)\)\),
              
              "TraditionalForm"], \(\(p\_\[Alpha] + 
                  p\_\[Nu]\)\/\(p\_\[Alpha] + 2  p\_\[Nu]\)\)}], "+"}], 
        TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(2 \[Sum]\_\(\[AliasDelimiter]\[Alpha]\)\),
              
              "TraditionalForm"], \(\(\(n\_\(\[Alpha], \[Alpha]\)\) 
                  p\_\[Nu]\)\/\(p\_\[Alpha] + 2  p\_\[Nu]\)\)}], 
          "+", \(2  n\_\[EmptySet]\)}], TraditionalForm]]],
  "=",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"2", 
            
            FormBox[\(\[Sum]\+\(\[Beta] \[NotEqual] \[Alpha]\)n\_\(\[Alpha], \
\[Beta]\) + 2 \(\[Sum]\+\[Alpha] n\_\(\[Alpha], \[Alpha]\)\)\),
              "TraditionalForm"]}], "+", \(2  n\_\[EmptySet]\)}], 
        TraditionalForm]]],
  "=2N"
}], "InlineFormula"],

Cell["Hence, the estimates are:", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Alpha]\)]],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\(=\)\(\(p\&~\_\[Alpha]\)(\(N - n\_\[EmptySet]\)\/N) - 
                n\_\(\[Alpha], \[Alpha]\)\/N\)\),
            "TraditionalForm"], \(p\_\[Nu]\/\(p\_\[Alpha] + 2  p\_\[Nu]\)\)}],
         TraditionalForm]]],
  "   and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(p\_\[Nu]\), "=", 
            RowBox[{
              RowBox[{
                
                FormBox[\(\(1\/N\) \((\[Sum]\_\(\[AliasDelimiter]\[Alpha]\)\)\
\),
                  
                  "TraditionalForm"], \(\(\(n\_\(\[Alpha], \[Alpha]\)\) 
                      p\_\[Nu]\)\/\(p\_\[Alpha] + 2  p\_\[Nu]\)\)}], 
              "+", \(n\_\[EmptySet]\)}]}], ")"}], TraditionalForm]]]
}], "InlineFormula"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\&~\)\_\[Alpha]\)]],
  " is the naive estimate obtained by ignoring nulls and missing data, and \
where N includes missing data.."
}], "Text"],

Cell["If missing data are ignored,the likelihood is:", "Text"],

Cell[TextData[{
  "Log[L] = ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\[Sum]\+\(\[Alpha] \[NotEqual] \[Beta]\)\(n\_\(\[Alpha], \
\[Beta]\)\) Log[\(2 \( p\_\[Alpha]\) p\_\[Beta]\)\/\(1 - p\_\[Nu]\%2\)]\),
            "TraditionalForm"], 
          "+", \(\[Sum]\+\[Alpha]\( n\_\(\[Alpha], \[Alpha]\)\) 
              Log[\(p\_\[Alpha]\%2 + 2 \( p\_\[Alpha]\) p\_\[Nu]\)\/\(1 - p\_\
\[Nu]\%2\)]\)}], TraditionalForm]]],
  "= ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{
              
              FormBox[\(\[Sum]\+\(\[Alpha] \[NotEqual] \[Beta]\)\(n\_\(\
\[Alpha], \[Beta]\)\) Log[2 \( p\_\[Alpha]\) p\_\[Beta]]\),
                "TraditionalForm"], 
              "+", \(\[Sum]\+\[Alpha]\( n\_\(\[Alpha], \[Alpha]\)\) 
                  Log[p\_\[Alpha]\%2 + 2 \( p\_\[Alpha]\) p\_\[Nu]]\)}],
            "TraditionalForm"], 
          "-", \(\((N - n\_\[EmptySet])\) Log[1 - p\_\[Nu]\%2]\)}], 
        TraditionalForm]]]
}], "InlineFormula"],

Cell["Hence:", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Alpha]\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]Log[L]\/\[PartialD]p\_\[Alpha]\)]],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\(=\)\(\[Lambda]\[VeryThinSpace]p\_\[Alpha] = \[Sum]\+\(\
\[Beta] \[NotEqual] \[Alpha]\)n\_\(\[Alpha], \[Beta]\) + 
                  2  n\_\(\[Alpha], \[Alpha]\)\)\),
            
            "TraditionalForm"], \(\(p\_\[Alpha] + p\_\[Nu]\)\/\(p\_\[Alpha] + 
                2  p\_\[Nu]\)\)}], TraditionalForm]]],
  "   and ",
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Nu]\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]Log[L]\/\[PartialD]p\_\[Nu]\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{"=", 
          RowBox[{\(\[Lambda]\[VeryThinSpace]p\_\[Nu]\), "=", 
            RowBox[{
              RowBox[{
                FormBox[\(2 \[Sum]\_\[Alpha]\),
                  
                  "TraditionalForm"], \(\(\(n\_\(\[Alpha], \[Alpha]\)\) 
                      p\_\[Nu]\)\/\(p\_\[Alpha] + 2  p\_\[Nu]\)\)}], 
              "+", \(2 \( 
                    p\_\[Nu]\%2\) \((N - n\_\[EmptySet])\)\/\(1 - p\_\[Nu]\%2\
\)\)}]}]}], TraditionalForm]]]
}], "InlineFormula"],

Cell["Summing, we find that:", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = \(2 \(\[Sum]\+\(\[Beta] \[NotEqual] \
\[Alpha]\)n\_\(\[Alpha], \[Beta]\)\) + 
            2 \(\[Sum]\+\[Alpha] n\_\(\[Alpha], \[Alpha]\)\) + 
            2 \( p\_\[Nu]\%2\) \((N - n\_\[EmptySet])\)\/\(1 - p\_\[Nu]\%2\) \
= \ 2 \((N - n\_\[EmptySet])\)\/\(1 - p\_\[Nu]\%2\)\)\)]]
}], "InlineFormula"],

Cell["which equals 2N in expectation.  The estimates are thus:", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Alpha] = \((1 - 
              p\_\[Nu]\%2)\) \((p\&~\_\[Alpha] - \(n\_\(\[Alpha], \
\[Alpha]\)\/\((N - n\_\[EmptySet])\)\) 
                p\_\[Nu]\/\(p\_\[Alpha] + 2  p\_\[Nu]\))\)\)]],
  "   and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(p\_\[Nu]\), "=", 
          RowBox[{\((1 - p\_\[Nu]\%2)\), 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox[\(\[Sum]\_\[Alpha]\),
                    
                    "TraditionalForm"], \(\(n\_\(\[Alpha], \[Alpha]\)\/\((N - 
                            n\_\[EmptySet])\)\) 
                    p\_\[Nu]\/\(p\_\[Alpha] + 2  p\_\[Nu]\)\)}], 
                "+", \(p\_\[Nu]\%2\/\(1 - p\_\[Nu]\%2\)\)}], ")"}]}]}], 
        TraditionalForm]]]
}], "InlineFormula"],

Cell[TextData[{
  "Given an initial estimate of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(p\_\[Nu] = 0\)\(,\)\)\)]],
  "one can refine the estimate by successive iteration.  "
}], "Text"],

Cell[TextData[{
  "It is not clear whether this procedure converges to a unique solution.  \
Ignoring missing data, we can see that ",
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Nu]\)]],
  " wil increase from a small value if ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(\[Sum]\_\[Alpha]\),
              
              "TraditionalForm"], \(\(n\_\(\[Alpha], \[Alpha]\)\/\((N - 
                      n\_\[EmptySet])\)\) 1\/p\_\[Alpha]\)}], ">", "1"}], 
        TraditionalForm]]],
  " - that is, if there is a net excess of homozygotes over HW.  At the other \
extreme, ",
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Nu]\)]],
  " always decreases from 1.  "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AlleleFrequencyTable", "Subsubsection"],

Cell[BoxData[
    \(\(Options[aft] = {NullAllele \[Rule] None, 
          MissingData \[Rule] False};\)\)], "Input"],

Cell[BoxData[
    \(\(aft::badNull = "\<Missing allele `1` is present more than once in \
allele list `2` for locus `3`\>";\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(aft[s_, al_List, opts___Rule]\), ":=", "\[IndentingNewLine]", 
        
        RowBox[{"Module", "[", 
          
          RowBox[{\({j, pp = AlleleFrequencyTable[s, al], gt, ngt, nm, dt, 
              homs, ff, \[IndentingNewLine]ntot = 
                2  NumberOfIndividuals[
                    s], \[IndentingNewLine]na = \(NullAllele /. {opts}\) /. 
                  Options[
                    aft], \[IndentingNewLine]md = \(MissingData /. {opts}\) /. 
                  Options[aft]}\), ",", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
              
              RowBox[{\(na === None\), ",", "\[IndentingNewLine]", "pp", ",", 
                "\[IndentingNewLine]", 
                
                RowBox[{\(dt = \(DiploidTypes[{#}] &\) /@ al\), ";", 
                  "\[IndentingNewLine]", 
                  RowBox[{"gt", "=", 
                    RowBox[{
                      FormBox["GenotypeFrequencyTable",
                        "TraditionalForm"], "[", \(s, al\), "]"}]}], ";", 
                  "\[IndentingNewLine]", \(ngt = NumberOfGenesTable[s]\), ";",
                   "\[IndentingNewLine]", \(Table[\[IndentingNewLine]np = 
                      Position[al\[LeftDoubleBracket]j\[RightDoubleBracket], 
                        na]; \[IndentingNewLine]If[
                      Length[np] > 1, \[IndentingNewLine]Message[
                        aft::badNull, na, al, j]; 
                      Indeterminate, \[IndentingNewLine]If[
                        Length[np] \[Equal] 
                          0, \[IndentingNewLine]pp\[LeftDoubleBracket]
                          j\[RightDoubleBracket], \[IndentingNewLine]homs = \
\(ngt\[LeftDoubleBracket]j\[RightDoubleBracket]*
                                Extract[
                                  gt\[LeftDoubleBracket]
                                    j\[RightDoubleBracket], #] &\) /@ 
                            Position[
                              dt\[LeftDoubleBracket]
                                j\[RightDoubleBracket], {{a_, 
                                  a_}}]; \[IndentingNewLine]If[
                          md, \[IndentingNewLine]nm = 
                            ntot - 
                              ngt\[LeftDoubleBracket]
                                j\[RightDoubleBracket]; \
\[IndentingNewLine]ff[{x__, pn_}] := \(1\/ntot\) 
                              Append[
                                pp\[LeftDoubleBracket]j\[RightDoubleBracket] 
                                    ngt\[LeftDoubleBracket]
                                      j\[RightDoubleBracket] - 
                                  homs*pn\/\({x} + 2  pn\), 
                                nm + homs . \(pn\/\({x} + 
                                        2  pn\)\)], \
\[IndentingNewLine]ff[{x__, pn_}] := \((1 - pn\^2)\) 
                              Append[
                                pp\[LeftDoubleBracket]
                                    j\[RightDoubleBracket] - 
                                  homs\/ngt\[LeftDoubleBracket]j\
\[RightDoubleBracket]*
                                    pn\/\({x} + 2  pn\), \(\(\ \
\)\(pn\^2\)\)\/\(1 - pn\^2\) + \(homs\/ngt\[LeftDoubleBracket]
                                        j\[RightDoubleBracket]\) . \
\(pn\/\({x} + 2  pn\)\)]]; \[IndentingNewLine]FixedPoint[ff, 
                          Append[
                            pp\[LeftDoubleBracket]j\[RightDoubleBracket], 
                            0.001]]]], \[IndentingNewLine]{j, 
                      Length[al]}]\)}]}], "]"}]}], "]"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Working", "Subsubsection"],

Cell[BoxData[
    \(Clear[pn]\)], "Input"],

Cell[BoxData[{\(al = 
        alleleList[s[All, pol]];\), "\n", \(dt = \(DiploidTypes[{#}] &\) /@ 
          al;\), "\n", 
    RowBox[{
      RowBox[{"gt", "=", 
        RowBox[{
          FormBox["GenotypeFrequencyTable",
            "TraditionalForm"], "[", \(s[sika, pol], al\), "]"}]}], 
      ";"}], "\n", \(ngt = 
        NumberOfGenesTable[s[sika, pol]];\), "\[IndentingNewLine]", \(pt = 
        AlleleFrequencyTable[s[sika, pol], al] // N;\), "\n", \(alN = 
        ReplacePart[al, 
          Append[al\[LeftDoubleBracket]1\[RightDoubleBracket], \[Nu]], 
          1];\), "\[IndentingNewLine]", \(ptN = 
        ReplacePart[pt, 
          Append[pt\[LeftDoubleBracket]1\[RightDoubleBracket] \((1 - pn)\), 
            pn], 1];\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(homs = \(ngt\[LeftDoubleBracket]1\[RightDoubleBracket]*
            Extract[gt\[LeftDoubleBracket]1\[RightDoubleBracket], #] &\) /@ 
        Position[
          dt\[LeftDoubleBracket]1\[RightDoubleBracket], {{a_, 
              a_}}]\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 0, 36, 290}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(td = 
      Transpose[{\(Transpose[
              Data[s[sika, 
                  pol]]]\)\[LeftDoubleBracket]1\[RightDoubleBracket]}]\)], \
"Input"],

Cell[BoxData[
    \({{{277, 277}}, {{267, 267}}, {{277, 277}}, {{267, 267}}, {{277, 
          277}}, {{267, 277}}, {{277, 277}}, {{277, 277}}, {{267, 
          267}}, {{277, 277}}, {{277, 277}}, {{277, 277}}, {{277, 
          277}}, {{267, 277}}, {{277, 277}}, {{267, 267}}, {{277, 
          277}}, {{267, 277}}, {{277, 277}}, {{267, 277}}, {{267, 
          277}}, {{267, 277}}, {{267, 277}}, {{253, 277}}, {{267, 
          277}}, {{277, 277}}, {{277, 277}}, {{277, 277}}, {{277, 
          277}}, {{277, 277}}, {{267, 267}}, {\[EmptySet]}, {{267, 
          277}}, {{277, 277}}, {{277, 277}}, {{277, 277}}, {{267, 
          277}}, {{267, 277}}, {{267, 277}}, {{277, 277}}, {{267, 
          267}}, {{267, 277}}, {{267, 277}}, {{277, 277}}, {{267, 
          277}}, {\[EmptySet]}, {{277, 277}}, {{267, 277}}, {{267, 
          277}}, {{267, 267}}, {{277, 277}}, {{267, 277}}, {{267, 
          277}}, {{277, 277}}, {{267, 277}}, {{277, 277}}, {{267, 
          277}}, {{267, 277}}, {{277, 277}}, {{267, 267}}, {{267, 
          267}}, {{277, 277}}, {{277, 277}}, {{277, 277}}, {{277, 
          277}}, {{277, 277}}, {{267, 267}}, {{277, 277}}, {{277, 
          277}}, {{267, 277}}, {{277, 277}}, {\[EmptySet]}, {{277, 
          277}}, {{277, 277}}, {{277, 277}}, {{267, 277}}, {{277, 
          277}}, {{267, 277}}, {{267, 277}}, {{277, 277}}, {{277, 
          277}}, {{267, 277}}, {{267, 277}}, {{267, 277}}, {{277, 
          277}}, {{277, 277}}, {{277, 277}}, {{267, 
          277}}, {\[EmptySet]}, {{277, 277}}, {{267, 277}}, {{277, 
          277}}, {{255, 277}}, {{277, 277}}, {{277, 277}}, {{267, 
          277}}, {{267, 277}}, {{277, 277}}, {{277, 277}}, {{267, 
          277}}, {{277, 277}}, {{267, 277}}, {{277, 277}}, {{277, 
          277}}, {{267, 277}}, {{277, 277}}, {{267, 267}}, {{277, 
          277}}, {{277, 277}}, {\[EmptySet]}, {{277, 277}}, {{277, 
          277}}, {{267, 277}}, {{267, 267}}, {{277, 277}}, {{277, 
          277}}, {{267, 277}}, {{267, 277}}, {{277, 277}}, {{277, 
          277}}, {{277, 277}}, {{267, 277}}, {{267, 267}}, {{277, 
          277}}, {{267, 277}}, {{267, 277}}, {{267, 277}}, {{277, 
          277}}, {{277, 277}}, {{277, 277}}, {{267, 277}}, {{277, 
          277}}, {{277, 277}}, {{267, 267}}, {{277, 277}}, {{277, 
          277}}, {{277, 277}}, {{267, 277}}, {{277, 277}}, {{267, 
          267}}, {{277, 277}}, {{277, 277}}, {{267, 277}}, {{267, 
          267}}, {{267, 277}}, {{267, 267}}, {{277, 277}}, {{267, 
          277}}, {{277, 277}}, {{277, 277}}, {{277, 277}}, {{277, 
          277}}, {{267, 277}}, {{267, 277}}, {{267, 
          277}}, {\[EmptySet]}, {{277, 277}}, {{277, 277}}, {{277, 
          277}}, {{277, 277}}, {{277, 277}}, {{277, 277}}, {{267, 
          277}}, {{277, 277}}, {{277, 277}}, {{277, 277}}, {{267, 
          277}}, {{277, 277}}, {{277, 277}}, {{277, 277}}, {{267, 
          277}}, {{267, 277}}, {{267, 277}}, {{267, 277}}, {{277, 
          277}}, {{277, 277}}, {{277, 277}}, {{267, 267}}, {{267, 
          277}}, {{277, 277}}, {{267, 277}}, {{277, 277}}, {{277, 
          277}}, {{277, 277}}, {{267, 277}}, {{267, 277}}, {{277, 
          277}}, {{277, 277}}, {{277, 277}}, {{277, 277}}, {{277, 
          277}}, {{277, 277}}, {{277, 277}}, {{277, 277}}, {{277, 
          277}}, {{277, 277}}, {{277, 277}}, {{277, 277}}, {{277, 
          277}}, {{267, 277}}, {{277, 277}}, {{277, 277}}, {{277, 
          277}}, {{267, 277}}, {{277, 277}}, {{277, 277}}, {{267, 
          277}}, {{277, 277}}, {{277, 277}}, {{277, 277}}, {{267, 
          277}}, {{277, 277}}, {{267, 277}}, {{277, 277}}, {{277, 
          277}}, {{277, 277}}, {{267, 277}}, {{277, 277}}, {{277, 
          277}}, {{277, 277}}, {{267, 277}}, {{267, 277}}, {{267, 
          277}}, {{277, 277}}, {{277, 277}}, {{277, 277}}, {{267, 
          277}}, {{277, 277}}, {{277, 277}}, {{267, 277}}, {{267, 
          277}}, {{277, 277}}, {{277, 277}}, {{277, 277}}, {{277, 
          277}}, {{277, 277}}, {{267, 277}}, {{255, 277}}, {{255, 
          277}}, {{277, 277}}, {{255, 277}}, {{255, 277}}, {{277, 
          277}}, {{277, 277}}, {{277, 277}}, {{277, 277}}, {{277, 
          277}}, {{255, 267}}, {{277, 277}}, {{277, 277}}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(xx = 
      Plus @@ \((\(Log[
                    GenotypeFrequency[#, {alN\[LeftDoubleBracket]1\
\[RightDoubleBracket]}, {{p251, p253, p255, p263, p267, p277, pn}}, 
                      NullAllele \[Rule] \[Nu]]] &\) /@ 
                td)\) /. \[EmptySet] \[Rule] 1 // First\)], "Input"],

Cell[BoxData[
    \(Log[\(2\ p255\ p267\)\/\(1 - pn\^2\)] + 
      Log[\(2\ p253\ p277\)\/\(1 - pn\^2\)] + 
      5\ Log[\(2\ p255\ p277\)\/\(1 - pn\^2\)] + 
      74\ Log[\(2\ p267\ p277\)\/\(1 - pn\^2\)] + 
      18\ Log[\(p267\^2 + 2\ p267\ pn\)\/\(1 - pn\^2\)] + 
      145\ Log[\(p277\^2 + 2\ p277\ pn\)\/\(1 - pn\^2\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rhs = \(\((#*D[xx, #])\) &\) /@ {p253, p255, p267, p277, pn}\)], "Input"],

Cell[BoxData[
    \({1, 6, 
      p267\ \((75\/p267 + \(18\ \((2\ p267 + 2\ pn)\)\)\/\(p267\^2 + 2\ p267\ \
pn\))\), p277\ \((80\/p277 + \(145\ \((2\ p277 + 2\ pn)\)\)\/\(p277\^2 + 2\ \
p277\ pn\))\), 
      pn\ \((\(162\ pn\)\/\(1 - pn\^2\) + \(18\ \((1 - pn\^2)\)\ \((\(2\ pn\ \
\((p267\^2 + 2\ p267\ pn)\)\)\/\((1 - pn\^2)\)\^2 + \(2\ p267\)\/\(1 - \
pn\^2\))\)\)\/\(p267\^2 + 2\ p267\ pn\) + \(145\ \((1 - pn\^2)\)\ \((\(2\ pn\ \
\((p277\^2 + 2\ p277\ pn)\)\)\/\((1 - pn\^2)\)\^2 + \(2\ p277\)\/\(1 - \
pn\^2\))\)\)\/\(p277\^2 + 2\ p277\ pn\))\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus @@ \((\((1 - 
                pn\^2)\) {pp\[LeftDoubleBracket]2\[RightDoubleBracket], 
              pp\[LeftDoubleBracket]3\[RightDoubleBracket], \ \((pp\
\[LeftDoubleBracket]5\[RightDoubleBracket] - \(36\/488\) 
                    pn\/\(p267 + 2\ \ pn\))\), \ \((pp\[LeftDoubleBracket]6\
\[RightDoubleBracket] - \(290\/488\) 
                    pn\/\(p277 + 2\ \ pn\))\), \ \((\(\(\ \)\(pn\^2\)\)\/\(1 \
- pn\^2\) + 36\/488\ \ \((\ pn\/\(p267 + 2\ \ pn\))\) + 
                  290\/488\ \ \((pn\/\(p277 + 2\ pn\))\))\)})\) // 
      Simplify\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pp\)], "Input"],

Cell[BoxData[
    \({0, 1\/488, 3\/244, 0, 111\/488, 185\/244}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(ff[{x__, pn_}] := \((1 - pn\^2)\) 
          Append[pp - 
              homs\/ngt\[LeftDoubleBracket]1\[RightDoubleBracket]*
                pn\/\({x} + 2  pn\), \(\(\ \)\(pn\^2\)\)\/\(1 - pn\^2\) + \
\(homs\/ngt\[LeftDoubleBracket]1\[RightDoubleBracket]\) . \(pn\/\({x} + 
                      2  pn\)\)];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FixedPoint[ff, Append[pp, 0.01]]\)], "Input"],

Cell[BoxData[
    \({0, 0.0020431860503564384`, 0.01225911630213863`, 0, 
      0.2144631938496866`, 0.7171493170452701`, 
      0.05408518675254823`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pp = \(AlleleFrequencyTable[s[sika, pol], 
          al]\)\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \({0, 1\/488, 3\/244, 0, 111\/488, 185\/244}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(zz = \(\((1 - 
                  pn\^2)\)\/ngt\[LeftDoubleBracket]1\[RightDoubleBracket]\) 
          rhs;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pr = 
      zz /. {p253 \[Rule] 0.01, p255 \[Rule] 0.01, p267 \[Rule] 0.2, 
          p277 \[Rule] 0.7, pn \[Rule] 0.08}\)], "Input"],

Cell[BoxData[
    \({0.0020360655737704917`, 0.012216393442622953`, 0.20971475409836066`, 
      0.6984178421654594`, 0.07761494471978653`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FixedPoint[
      zz /. {p253 \[Rule] #\[LeftDoubleBracket]1\[RightDoubleBracket], 
            p255 \[Rule] #\[LeftDoubleBracket]2\[RightDoubleBracket], 
            p267 \[Rule] #\[LeftDoubleBracket]3\[RightDoubleBracket], 
            p277 \[Rule] #\[LeftDoubleBracket]4\[RightDoubleBracket], 
            pn \[Rule] #\[LeftDoubleBracket]5\[RightDoubleBracket]} &, {0.01, 
        0.01, 0.2, 0.7, 0.08}]\)], "Input"],

Cell[BoxData[
    \({0.0020431860503564384`, 0.01225911630213863`, 0.21446319384968657`, 
      0.7171493170452697`, 0.054085186752548586`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ngt\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \(488\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rhs/\((Plus @@ rhs // Simplify)\)\)], "Input"],

Cell[BoxData[
    \({1\/488\ \((1 - pn\^2)\), 
      3\/244\ \((1 - 
            pn\^2)\), \(3\ \((37\ p267 + 62\ pn)\)\ \((1 - pn\^2)\)\)\/\(488\ \
\((p267 + 2\ pn)\)\), \(\((370\ p277 + 450\ pn)\)\ \((1 - pn\^2)\)\)\/\(488\ \
\((p277 + 2\ pn)\)\), \(-\(\(pn\ \((1 - pn\^2)\)\ \((18\ p277 + 326\ pn + 
                  470\ p277\ pn\^2 + 650\ pn\^3 + 
                  p267\ \((145 + 244\ p277\ pn + 
                        343\ pn\^2)\))\)\)\/\(244\ \((p267 + 
                  2\ pn)\)\ \((p277 + 2\ pn)\)\ \((\(-1\) + 
                  pn\^2)\)\)\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(FindRoot[{\((x - 2)\) y, y\^2 - 2}, {x, 
        1.5}, {y, 1}]\)\)\)], "Input"],

Cell[BoxData[
    \({x \[Rule] 2.0000000000360876`, 
      y \[Rule] 1.4142135623746899`}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(yy = xx /. pn \[Rule] 1 - p255 - p267 - p253 - p277;\)\)], "Input"],

Cell[BoxData[
    \(\(eqs = {D[yy, p255], D[yy, p253], D[yy, p267], 
          D[yy, p277]};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindRoot[
      eqs, {p255, 0.002}, {p267, 0.2}, {p253, 0.01}, {p277, 0.7}]\)], "Input"],

Cell[BoxData[
    \(FindRoot::"cvnwt" \(\(:\)\(\ \)\) 
      "Newton's method failed to converge to the prescribed accuracy after \!\
\(15\) iterations."\)], "Message"],

Cell[BoxData[
    \({p255 \[Rule] 0.02012784514676135`, p267 \[Rule] 20.90428044767073`, 
      p253 \[Rule] \(-22.82924676224247`\), 
      p277 \[Rule] 17.095055130625116`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(yy\)], "Input"],

Cell[BoxData[
    \(Log[\(2\ p255\ p267\)\/\(1 - \((1 - p253 - p255 - p267 - p277)\)\^2\)] \
+ 18\ Log[\(p267\^2 + 2\ p267\ \((1 - p253 - p255 - p267 - p277)\)\)\/\(1 - \
\((1 - p253 - p255 - p267 - p277)\)\^2\)] + 
      Log[\(2\ p253\ p277\)\/\(1 - \((1 - p253 - p255 - p267 - p277)\)\^2\)] \
+ 5\ Log[\(2\ p255\ p277\)\/\(1 - \((1 - p253 - p255 - p267 - p277)\)\^2\)] + 
      74\ Log[\(2\ p267\ p277\)\/\(1 - \((1 - p253 - p255 - p267 - p277)\)\^2\
\)] + 145\ Log[\(2\ \((1 - p253 - p255 - p267 - p277)\)\ p277 + \
p277\^2\)\/\(1 - \((1 - p253 - p255 - p267 - p277)\)\^2\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pt[\([1]\)]\)], "Input"],

Cell[BoxData[
    \({0.`, 0.0020491803278688526`, 0.012295081967213115`, 0.`, 
      0.22745901639344263`, 0.7581967213114754`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NSolve[{D[yy, p255] \[Equal] 0, D[yy, p253] \[Equal] 0, 
          D[yy, p267] \[Equal] 0, D[yy, p277] \[Equal] 0} // N, {p255, p253, 
        p267, p277}]\)], "Input"],

Cell[BoxData[
    \(NSolve[{\(0.5`\ \((\(2.`\ p267\)\/\(\(\(1.`\)\(\[InvisibleSpace]\)\) - \
1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 \
- 1.`\ p277)\)\^2\) - \(4.`\ p255\ p267\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) \
- 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\)\/\((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 \
- 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2)\)\^2)\)\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 \
- 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2)\)\)\/\(p255\ p267\) + \((18.`\ \((\
\(-\(\(2.`\ p267\)\/\(\(\(1.`\)\(\[InvisibleSpace]\)\) - 
                              1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \
p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2\)\)\) - \(2.`\ \((p267\^2 + \
2.`\ p267\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ \
p267 - 1.`\ p277)\))\)\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\
\ p255 - 1.`\ p267 - 1.`\ p277)\)\)\/\((\(\(1.`\)\(\[InvisibleSpace]\)\) - \
1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 \
- 1.`\ p277)\)\^2)\)\^2)\)\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 
                      1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - \
1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2)\))\)/\((p267\^2 + 
                  2.`\ p267\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 
                        1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 
                        1.`\ p277)\))\) - \(150.`\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ \
p277)\)\)\/\(\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2\) \
+ \(2.5`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ \
p277)\)\^2)\)\ \((\(2.`\ p277\)\/\(\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \
\((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\
\ p277)\)\^2\) - \(4.`\ p255\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 \
- 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\ p277\)\/\((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 \
- 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2)\)\^2)\)\)\/\(p255\ p277\) + \
\((145.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 
                      1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - \
1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2)\)\ \((\(-\(\(2.`\ \
p277\)\/\(\(\(1.`\)\(\[InvisibleSpace]\)\) - 
                              1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \
p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2\)\)\) - \(2.`\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\ \
\((2.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ \
p267 - 1.`\ p277)\)\ p277 + p277\^2)\)\)\/\((\(\(1.`\)\(\[InvisibleSpace]\)\) \
- 1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ \
p267 - 1.`\ p277)\)\^2)\)\^2)\))\)/\((2.`\ \
\((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 
                        1.`\ p277)\)\ p277 + p277\^2)\) == 
          0.`, \((18.`\ \((\(-\(\(2.`\ p267\)\/\(\(\(1.`\)\(\[InvisibleSpace]\
\)\) - 1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\
\ p267 - 1.`\ p277)\)\^2\)\)\) - \(2.`\ \((p267\^2 + 2.`\ p267\ \
\((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\
\ p277)\))\)\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - \
1.`\ p267 - 1.`\ p277)\)\)\/\((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \
\((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\
\ p277)\)\^2)\)\^2)\)\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 
                      1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - \
1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2)\))\)/\((p267\^2 + 
                  2.`\ p267\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 
                        1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 
                        1.`\ p277)\))\) - \(160.`\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ \
p277)\)\)\/\(\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2\) \
+ \(0.5`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ \
p277)\)\^2)\)\ \((\(2.`\ p277\)\/\(\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \
\((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\
\ p277)\)\^2\) - \(4.`\ p253\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 \
- 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\ p277\)\/\((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 \
- 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2)\)\^2)\)\)\/\(p253\ p277\) + \
\((145.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 
                      1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - \
1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2)\)\ \((\(-\(\(2.`\ \
p277\)\/\(\(\(1.`\)\(\[InvisibleSpace]\)\) - 
                              1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \
p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2\)\)\) - \(2.`\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\ \
\((2.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ \
p267 - 1.`\ p277)\)\ p277 + p277\^2)\)\)\/\((\(\(1.`\)\(\[InvisibleSpace]\)\) \
- 1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ \
p267 - 1.`\ p277)\)\^2)\)\^2)\))\)/\((2.`\ \
\((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 
                        1.`\ p277)\)\ p277 + p277\^2)\) == 
          0.`, \(0.5`\ \((\(2.`\ p255\)\/\(\(\(1.`\)\(\[InvisibleSpace]\)\) - \
1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 \
- 1.`\ p277)\)\^2\) - \(4.`\ p255\ p267\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) \
- 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\)\/\((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 \
- 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2)\)\^2)\)\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 \
- 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2)\)\)\/\(p255\ p267\) + \((18.`\ \((\
\(-\(\(2.`\ \((p267\^2 + 2.`\ p267\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 
                                        1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 
                                        1.`\ p277)\))\)\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 
                                  1.`\ p277)\)\)\/\((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 \
- 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2)\)\^2\)\) + \(2.`\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ \
p277)\)\)\/\(\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ \
p277)\)\^2\))\)\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 
                      1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - \
1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2)\))\)/\((p267\^2 + 
                  2.`\ p267\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 
                        1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 
                        1.`\ p277)\))\) - \(12.`\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ \
p277)\)\)\/\(\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2\) \
+ \(37.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ \
p277)\)\^2)\)\ \((\(2.`\ p277\)\/\(\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \
\((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\
\ p277)\)\^2\) - \(4.`\ p267\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 \
- 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\ p277\)\/\((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 \
- 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2)\)\^2)\)\)\/\(p267\ p277\) + \
\((145.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 
                      1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - \
1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2)\)\ \((\(-\(\(2.`\ \
p277\)\/\(\(\(1.`\)\(\[InvisibleSpace]\)\) - 
                              1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \
p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2\)\)\) - \(2.`\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\ \
\((2.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ \
p267 - 1.`\ p277)\)\ p277 + p277\^2)\)\)\/\((\(\(1.`\)\(\[InvisibleSpace]\)\) \
- 1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ \
p267 - 1.`\ p277)\)\^2)\)\^2)\))\)/\((2.`\ \
\((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 
                        1.`\ p277)\)\ p277 + p277\^2)\) == 
          0.`, \((18.`\ \((\(-\(\(2.`\ p267\)\/\(\(\(1.`\)\(\[InvisibleSpace]\
\)\) - 1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\
\ p267 - 1.`\ p277)\)\^2\)\)\) - \(2.`\ \((p267\^2 + 2.`\ p267\ \
\((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\
\ p277)\))\)\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - \
1.`\ p267 - 1.`\ p277)\)\)\/\((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \
\((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\
\ p277)\)\^2)\)\^2)\)\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 
                      1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - \
1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2)\))\)/\((p267\^2 + 
                  2.`\ p267\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 
                        1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 
                        1.`\ p277)\))\) - \(2.`\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ \
p277)\)\)\/\(\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2\) \
+ \(0.5`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ \
p277)\)\^2)\)\ \((\(2.`\ p253\)\/\(\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \
\((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\
\ p277)\)\^2\) - \(4.`\ p253\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 \
- 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\ p277\)\/\((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 \
- 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2)\)\^2)\)\)\/\(p253\ p277\) + \(2.5`\
\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \
\((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\
\ p277)\)\^2)\)\ \((\(2.`\ p255\)\/\(\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \
\((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\
\ p277)\)\^2\) - \(4.`\ p255\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 \
- 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\ p277\)\/\((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 \
- 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2)\)\^2)\)\)\/\(p255\ p277\) + \(37.`\
\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \
\((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\
\ p277)\)\^2)\)\ \((\(2.`\ p267\)\/\(\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \
\((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\
\ p277)\)\^2\) - \(4.`\ p267\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 \
- 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\ p277\)\/\((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 \
- 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2)\)\^2)\)\)\/\(p267\ p277\) + \
\((145.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 
                      1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - \
1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2)\)\ \((\(2.`\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ \
p277)\)\)\/\(\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2\) \
- \(2.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ \
p267 - 1.`\ p277)\)\ \((2.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 \
- 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\ p277 + p277\^2)\)\)\/\((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ p253 \
- 1.`\ p255 - 1.`\ p267 - 1.`\ p277)\)\^2)\)\^2)\))\)/\((2.`\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) - 1.`\ p253 - 1.`\ p255 - 1.`\ p267 - 
                        1.`\ p277)\)\ p277 + p277\^2)\) == 0.`}, {p255, p253, 
        p267, p277}]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pt[\([1]\)]\)], "Input"],

Cell[BoxData[
    \({0.`, 0.0020491803278688526`, 0.012295081967213115`, 0.`, 
      0.22745901639344263`, 0.7581967213114754`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(al[\([1]\)]\)], "Input"],

Cell[BoxData[
    \({251, 253, 255, 263, 267, 277}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMinimum[\(xx /. 
          pn \[Rule] 1 - p255 - p267 - p253 - p277\) /. {p255 \[Rule] 
            1\/\(1 + \[ExponentialE]\^\(-z255\)\), 
          p253 \[Rule] 1\/\(1 + \[ExponentialE]\^\(-z253\)\), 
          p267 \[Rule] 1\/\(1 + \[ExponentialE]\^\(-z267\)\), 
          p277 \[Rule] 
            1\/\(1 + \[ExponentialE]\^\(-z277\)\)}, {z255, \(-2\)}, {z267, \
\(-1\)}, {z253, \(-2\)}, {z277, \(-0.5\)}]\)], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(z255\)\" is similar to \
existing symbol \"\!\(p255\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(z253\)\" is similar to \
existing symbol \"\!\(p253\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(z267\)\" is similar to \
existing symbol \"\!\(p267\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(General :: \"spell1\"\) will be suppressed \
during this calculation."\)], "Message"],

Cell[BoxData[
    \(FindMinimum::"fmnum" \(\(:\)\(\ \)\) 
      "Objective function \!\(\(\(-673.8556318843561`\)\) + \
\(\(455.53093477052`\\ \[ImaginaryI]\)\)\) is not real at \!\({z255, z267, \
z253, z277}\) = \!\({\(\(-0.9716037182052368`\)\), \(\(-0.2227645964009286`\)\
\), \(\(-0.8940026395294436`\)\), \(\(-1.4455112828114765`\)\)}\)."\)], \
"Message"],

Cell[BoxData[
    \(FindMinimum[\(xx /. \[InvisibleSpace]pn \[Rule] 
            1 - p255 - p267 - p253 - p277\) /. \[InvisibleSpace]{p255 \[Rule] 
            1\/\(1 + \[ExponentialE]\^\(-z255\)\), 
          p253 \[Rule] 1\/\(1 + \[ExponentialE]\^\(-z253\)\), 
          p267 \[Rule] 1\/\(1 + \[ExponentialE]\^\(-z267\)\), 
          p277 \[Rule] 
            1\/\(1 + \[ExponentialE]\^\(-z277\)\)}, {z255, \(-2\)}, {z267, \
\(-1\)}, {z253, \(-2\)}, {z277, \(-0.5`\)}]\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ll = Plus @@ xx\)], "Input"],

Cell[BoxData[
    \(\(-3119.3269448078836`\) + 
      Log[\(0.0031073636119322763`\ \((1 - pn)\)\^2\)\/\(1 - pn\^2\)] + 
      Log[\(0.0055932545014780975`\ \((1 - pn)\)\^2\)\/\(1 - pn\^2\)] + 
      5\ Log[\(0.01864418167159366`\ \((1 - pn)\)\^2\)\/\(1 - pn\^2\)] + 
      74\ Log[\(0.34491736092448266`\ \((1 - pn)\)\^2\)\/\(1 - pn\^2\)] + 
      18\ Log[\(0.0517376041386724`\ \((1 - pn)\)\^2 + 0.45491803278688525`\ \
\((1 - pn)\)\ pn\)\/\(1 - pn\^2\)] + 
      145\ Log[\(0.5748622682074711`\ \((1 - pn)\)\^2 + 1.5163934426229508`\ \
\((1 - pn)\)\ pn\)\/\(1 - pn\^2\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMinimum[\(-ll\), {pn, 0.1}]\)], "Input"],

Cell[BoxData[
    \({3361.2698530453863`, {pn \[Rule] 0.05371943077501319`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(homs\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 0, 36, 290}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Drop[ptN\[LeftDoubleBracket]1\[RightDoubleBracket], \(-1\)]\)], "Input"],

Cell[BoxData[
    \({0.`\ \((1 - pn)\), 0.0020491803278688526`\ \((1 - pn)\), 
      0.012295081967213115`\ \((1 - pn)\), 0.`\ \((1 - pn)\), 
      0.22745901639344263`\ \((1 - pn)\), 
      0.7581967213114754`\ \((1 - pn)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ll2 = 
      homs . Log[\(Drop[ptN\[LeftDoubleBracket]1\[RightDoubleBracket], \
\(-1\)]\^2 + 2  Drop[ptN\[LeftDoubleBracket]1\[RightDoubleBracket], \(-1\)] \
pn\)\/\(1 - pn\^2\)] - \((Plus @@ hets)\) 
          Log[\(1 - pn\^2\)\/\((1 - pn)\)\^2]\)], "Input"],

Cell[BoxData[
    \(36\ Log[\(0.0517376041386724`\ \((1 - pn)\)\^2 + 0.45491803278688525`\ \
\((1 - pn)\)\ pn\)\/\(1 - pn\^2\)] + 
      290\ Log[\(0.5748622682074711`\ \((1 - pn)\)\^2 + 1.5163934426229508`\ \
\((1 - pn)\)\ pn\)\/\(1 - pn\^2\)] - 
      162\ Log[\(1 - pn\^2\)\/\((1 - pn)\)\^2]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({ll2 - \((\((ll2 - ll)\) /. pn \[Rule] 0)\), ll} /. 
      pn \[Rule] 0.1\)], "Input"],

Cell[BoxData[
    \({\(-3361.4014814890284`\), \(-3361.976450740348`\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cc = \((\((ll2 - ll)\) /. 
            pn \[Rule] 0)\);\)\), "\[IndentingNewLine]", 
    \(\(Plot[{ll2 - cc, ll}, {pn, 0, 0.1}, 
        PlotStyle \[Rule] {Red, Blue}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 9.52381 772.199 0.229642 [
[.21429 .12884 -16 -18 ]
[.21429 .12884 16 0 ]
[.40476 .12884 -16 -18 ]
[.40476 .12884 16 0 ]
[.59524 .12884 -16 -18 ]
[.59524 .12884 16 0 ]
[.78571 .12884 -16 -18 ]
[.78571 .12884 16 0 ]
[.97619 .12884 -12 -18 ]
[.97619 .12884 12 0 ]
[.01131 .02652 -59.0625 -9 ]
[.01131 .02652 0 9 ]
[.01131 .25617 -59.0625 -9 ]
[.01131 .25617 0 9 ]
[.01131 .37099 -47.0625 -9 ]
[.01131 .37099 0 9 ]
[.01131 .48581 -59.0625 -9 ]
[.01131 .48581 0 9 ]
[.01131 .60063 -47.0625 -9 ]
[.01131 .60063 0 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .14134 m
.21429 .14759 L
s
gsave
.21429 .12884 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
1.000 setlinewidth
grestore
.40476 .14134 m
.40476 .14759 L
s
gsave
.40476 .12884 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
1.000 setlinewidth
grestore
.59524 .14134 m
.59524 .14759 L
s
gsave
.59524 .12884 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
1.000 setlinewidth
grestore
.78571 .14134 m
.78571 .14759 L
s
gsave
.78571 .12884 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
1.000 setlinewidth
grestore
.97619 .14134 m
.97619 .14759 L
s
gsave
.97619 .12884 -73 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .14134 m
.07143 .14509 L
s
.11905 .14134 m
.11905 .14509 L
s
.16667 .14134 m
.16667 .14509 L
s
.2619 .14134 m
.2619 .14509 L
s
.30952 .14134 m
.30952 .14509 L
s
.35714 .14134 m
.35714 .14509 L
s
.45238 .14134 m
.45238 .14509 L
s
.5 .14134 m
.5 .14509 L
s
.54762 .14134 m
.54762 .14509 L
s
.64286 .14134 m
.64286 .14509 L
s
.69048 .14134 m
.69048 .14509 L
s
.7381 .14134 m
.7381 .14509 L
s
.83333 .14134 m
.83333 .14509 L
s
.88095 .14134 m
.88095 .14509 L
s
.92857 .14134 m
.92857 .14509 L
s
.25 Mabswid
0 .14134 m
1 .14134 L
s
.02381 .02652 m
.03006 .02652 L
s
gsave
.01131 .02652 -120.062 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3362.5) show
1.000 setlinewidth
grestore
.02381 .25617 m
.03006 .25617 L
s
gsave
.01131 .25617 -120.062 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3361.5) show
1.000 setlinewidth
grestore
.02381 .37099 m
.03006 .37099 L
s
gsave
.01131 .37099 -108.062 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3361) show
1.000 setlinewidth
grestore
.02381 .48581 m
.03006 .48581 L
s
gsave
.01131 .48581 -120.062 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3360.5) show
1.000 setlinewidth
grestore
.02381 .60063 m
.03006 .60063 L
s
gsave
.01131 .60063 -108.062 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3360) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .04949 m
.02756 .04949 L
s
.02381 .07245 m
.02756 .07245 L
s
.02381 .09542 m
.02756 .09542 L
s
.02381 .11838 m
.02756 .11838 L
s
.02381 .16431 m
.02756 .16431 L
s
.02381 .18727 m
.02756 .18727 L
s
.02381 .21024 m
.02756 .21024 L
s
.02381 .2332 m
.02756 .2332 L
s
.02381 .27913 m
.02756 .27913 L
s
.02381 .30209 m
.02756 .30209 L
s
.02381 .32506 m
.02756 .32506 L
s
.02381 .34802 m
.02756 .34802 L
s
.02381 .39395 m
.02756 .39395 L
s
.02381 .41692 m
.02756 .41692 L
s
.02381 .43988 m
.02756 .43988 L
s
.02381 .46284 m
.02756 .46284 L
s
.02381 .50877 m
.02756 .50877 L
s
.02381 .53174 m
.02756 .53174 L
s
.02381 .5547 m
.02756 .5547 L
s
.02381 .57767 m
.02756 .57767 L
s
.02381 .00356 m
.02756 .00356 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .01472 m
.06244 .10811 L
.10458 .19921 L
.14415 .27507 L
.18221 .3396 L
.22272 .39966 L
.26171 .44943 L
.30316 .49409 L
.34309 .52942 L
.3815 .55659 L
.40095 .56787 L
.42237 .57844 L
.44292 .58677 L
.46172 .59287 L
.48113 .59769 L
.49183 .5997 L
.502 .6012 L
.51159 .60224 L
.51695 .60267 L
.52181 .60297 L
.52402 .60307 L
.52636 .60316 L
.52758 .6032 L
.52892 .60324 L
.53015 .60327 L
.53128 .60329 L
.53242 .6033 L
.5335 .60331 L
.53465 .60332 L
.53589 .60332 L
.53698 .60331 L
.53813 .60331 L
.53911 .60329 L
.5402 .60328 L
.54255 .60322 L
.54511 .60314 L
.5478 .60303 L
.55029 .60291 L
.55476 .60262 L
.55954 .60223 L
.57047 .60103 L
.5804 .59957 L
.59959 .59573 L
.62038 .59008 L
.6613 .5746 L
.7007 .55434 L
.73859 .53007 L
.77893 .49923 L
.81776 .4648 L
.85903 .42325 L
Mistroke
.89879 .37854 L
.93704 .33131 L
.97619 .27879 L
Mfstroke
0 0 1 r
.02381 .01472 m
.06244 .06141 L
.10458 .10696 L
.14415 .14489 L
.18221 .17716 L
.22272 .20719 L
.26171 .23207 L
.30316 .2544 L
.34309 .27207 L
.3815 .28565 L
.40095 .29129 L
.42237 .29658 L
.44292 .30074 L
.46172 .30379 L
.48113 .3062 L
.49183 .30721 L
.502 .30796 L
.51159 .30848 L
.51695 .30869 L
.52181 .30884 L
.52402 .30889 L
.52636 .30894 L
.52758 .30896 L
.52892 .30898 L
.53015 .30899 L
.53128 .309 L
.53242 .30901 L
.5335 .30901 L
.53465 .30902 L
.53589 .30902 L
.53698 .30901 L
.53813 .30901 L
.53911 .309 L
.5402 .309 L
.54255 .30897 L
.54511 .30893 L
.5478 .30887 L
.55029 .30881 L
.55476 .30867 L
.55954 .30847 L
.57047 .30787 L
.5804 .30714 L
.59959 .30522 L
.62038 .3024 L
.6613 .29466 L
.7007 .28453 L
.73859 .27239 L
.77893 .25697 L
.81776 .23976 L
.85903 .21898 L
Mistroke
.89879 .19663 L
.93704 .17301 L
.97619 .14675 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00?@3oool00`000000oooo0?ooo`3P0?ooo`00?@3o
ool200000>40oooo000m0?ooo`030000003oool0oooo0>00oooo000=0?ooo`05024Q8@0000000000
04A4A02j^[X00`3oool01@0Q8B40000000000014A4@0^[Zj00@0oooo00D0V9RH0000000000000000
09RHV0020?ooo`03010@40000000000000<0000000H0^[Zj0?ooo`3oool0<S8b0?ooo`14A4@40000
000309RHV03oool0oooo00D0oooo00<0003o0?ooo`3oool0h03oool00100oooo00<0k^k^05EEE@2Y
ZJT01@3oool00`3^k^h0EEEE0:VYZ@020?ooo`0809RHV0000000V9RH0?ooo`2HV9P0000009RHV03o
ool20=gMg@<0oooo00<0QhN7038b<P3oool01`3oool00`2HV9P0000009RHV0060?ooo`030000o`3o
ool0oooo0>00oooo000A0?ooo`030>k^kP0@4100oooo00D0oooo00H0k^k^010@403oool0oooo0000
002HV9P30?ooo`0409RHV0000000oooo0?ooo`80gMgM3@3oool00`2HV9P000000?ooo`050?ooo`03
000000000?l0oooo0>00oooo000B0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0
00001@3oool010000000oooo0?ooo`3oool20=gMg@d0oooo00<000000?ooo`3oool0103oool00`00
0000o`000000o`3P0?ooo`000`3oool8000000D0oooo00<0k^k^06IVIP0b<S801@3oool00`3^k^h0
IVIV038b<P020?ooo`030000003oool0oooo0080oooo00<0V9RH0000003oool00`3oool20=gMg@`0
oooo00<000000?ooo`3oool0103oool010000000oooo0?l000000?oO0?ooo`003`3oool0100Q8B40
0000038b<P3^k^h40?ooo`04024Q8@000000<S8b0>k^kP80oooo00L0000007MgM`3^k^h0oooo09RH
V0000000V9RH00D0oooo00<0QhN70=gMg@3oool02@3oool00`2HV9P000000?ooo`050?ooo`050000
003oool0o`000?ooo`000?l0gP3oool00100oooo00<0EEEE0;Zj^P3oool01@3oool00`1EEED0^[Zj
0?ooo`020?ooo`0304A4A01gMgL0410@0080000000<0V9RH0?ooo`3oool0103oool00`3MgMd0EEEE
0?ooo`080?ooo`0309RHV0000000V9RH00H0oooo00<000000?ooo`3o00000P3oool00`000?l0oooo
0?ooo`3K0?ooo`00403oool00`3^k^h08B4Q0?ooo`050?ooo`030>k^kP0Q8B40oooo0080oooo00<0
^[Zj04A4A03oool01@3oool00`2j^[X0oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
^[Zj0000000000000P0000000`2HV9P0oooo0?ooo`050?ooo`060000003oool0oooo0?l0003oool0
003og@3oool000d0oooo00D0QhN70?ooo`3oool0oooo000000030?ooo`0508N7Q`3oool0oooo0?oo
o`000000103oool00`1EEED0QhN70?ooo`040?ooo`060000002HV9P0oooo0?ooo`2HV9P000001P3o
ool00`0@4100gMgM0?ooo`090?ooo`80000000D0oooo0?l0003oool0oooo0000o`3L0?ooo`003@3o
ool01@1gMgL0QhN70?ooo`1gMgL08B4Q00<0oooo00D0MgMg08N7Q`3oool0MgMg024Q8@050?ooo`80
IVIV00H0gMgM0?ooo`3oool0oooo09RHV000000209RHV0030000002HV9P0oooo00D0oooo00<0QhN7
06IVIP3oool02@3oool01@000000oooo0?ooo`3oool0o`000080oooo00<0003o0?ooo`3oool0f@3o
ool000h0oooo00@0IVIV0000000@4100c<c<103oool0101VIVH00000010@403<c<`60?ooo`040;Zj
^P1EEED0EEEE09RHV080oooo00@0V9RH000000000000V9RH1`3oool00`3MgMd00000000000020000
0003038b<P3oool0oooo00@0oooo00D000000?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0
oooo0=P0oooo000m0?ooo`030000003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`3I
0?ooo`00?@3oool00`000000oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0f@3oool0
03d0oooo0P0000030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0eP3oool003d0
oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0100
oooo00D0V9RH000000000000000009RHV0030?ooo`04038b<P3oool0oooo09RHV0<0000000@0V9RH
0?ooo`3oool0410@1@0000000`2j^[X0oooo0?ooo`0@0?ooo`0509RHV000000000000000002HV9P0
0`3oool0100b<S80oooo0?ooo`2HV9P30000000309RHV03oool0oooo00D0oooo00<000000?ooo`3o
ool0403oool01@2HV9P00000000000000000V9RH00<0oooo00@0<S8b0?ooo`3oool0V9RH0`000000
1@2HV9P0oooo0?ooo`3oool0V9RH00<0000000<0V9RH0?ooo`3oool04@3oool01@2HV9P000000000
00000000V9RH00<0oooo00@0<S8b0?ooo`3oool0V9RH0`0000001@2HV9P0oooo0?ooo`3oool0V9RH
00<0000000<0V9RH0?ooo`3oool05@3oool01@2HV9P00000000000000000V9RH00<0oooo00<0<S8b
0?ooo`3oool01@0000060?ooo`00?@3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool03P3oool01`2HV9P0000009RHV03oool0V9RH0000002HV9P0103o
ool0202HV9P0000009RHV03oool0V9RH0000002HV9P0oooo0P3MgMd30?ooo`0308N7Q`0b<S80oooo
0100oooo00L0V9RH0000002HV9P0oooo09RHV0000000V9RH00@0oooo00L0V9RH0000002HV9P0oooo
09RHV0000000V9RH00H0oooo00<000000?ooo`3oool03`3oool01`2HV9P0000009RHV03oool0V9RH
0000002HV9P0103oool03`2HV9P0000009RHV03oool0V9RH0000002HV9P0oooo09RHV0000000V9RH
0?ooo`2HV9P0000009RHV00A0?ooo`0709RHV0000000V9RH0?ooo`2HV9P0000009RHV0040?ooo`0?
09RHV0000000V9RH0?ooo`2HV9P0000009RHV03oool0V9RH0000002HV9P0oooo09RHV0000000V9RH
01D0oooo00L0V9RH0000002HV9P0oooo09RHV0000000V9RH00L0oooo00<000000?ooo`3oool01P3o
ool003d0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00d0oooo00<0000009RHV03oool00P3oool00`2HV9P000000?ooo`030?ooo`030000002HV9P0
oooo0080oooo00@0V9RH0000003oool0oooo0P3MgMdE0?ooo`030000002HV9P0oooo0080oooo00<0
V9RH0000003oool00`3oool00`000000V9RH0?ooo`020?ooo`0309RHV0000000oooo00D0oooo00<0
00000?ooo`3oool03`3oool00`000000V9RH0?ooo`020?ooo`0309RHV0000000oooo00<0oooo00<0
000009RHV03oool00P3oool01@2HV9P000000?ooo`000000V9RH00<0oooo00<0V9RH0000003oool0
403oool00`000000V9RH0?ooo`020?ooo`0309RHV0000000oooo00<0oooo00<0000009RHV03oool0
0P3oool01@2HV9P000000?ooo`000000V9RH00<0oooo00<0V9RH0000003oool0503oool00`000000
V9RH0?ooo`020?ooo`0309RHV0000000oooo00H0oooo00<000000?ooo`3oool01P3oool003d0oooo
00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00`0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool0oooo0P3MgMdD0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000L000003`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`0Q8B40k^k^0`3oool00`2j
^[X0410@0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`060?ooo`00?@3oool2000000H0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P3MgMdC0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0EEEE08N7
Q`<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`0309RHV0000000oooo
0100oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3<c<`0IVIV0P3oool00`2HV9P000000:VYZ@0E0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`00?@3oool00`00
0000oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool02P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`0308N7Q`3MgMd0oooo0140oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool08B4Q0<c<c002
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00T000000?ooo`000000MgMg0>k^kP3oool0V9RH0000002H
V9P04@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0?ooo`3<c<`0410@0080000000<0ZJVY0?ooo`3oool0503oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool003d0
oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00`3oool00`3MgMd0EEEE0?ooo`0A0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`080000003oool0oooo0>k^
kP0Q8B40k^k^0?ooo`00000A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`030?ooo`050000003oool0A4A407MgM`0@41000P0000000`2HV9P0oooo
0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`080000003oool0c<c<024Q8@27QhL0k^k^0<c<c027QhLF0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`00?@3oool00`00
0000oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo0P000?l90?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0^[Zj
00@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool020000000oooo0?ooo`3oool0^[Zj038b<P3oool00000
4@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool010000000oooo0;Zj^P14A4@F0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0<S8b0:VYZ@<0oooo00<0^[Zj06IV
IP3oool0503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool003d0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00H0oooo00<0000009RHV03oool00P3oool00`2HV9P000000?ooo`030?ooo`03
0000002HV9P0oooo0080oooo00D0V9RH0000003oool0000009RHV0020?ooo`0309RHV0000000oooo
0140oooo00<0000009RHV03oool00P3oool00`2HV9P000000?ooo`030?ooo`030000002HV9P0oooo
0080oooo00<0V9RH0000003oool00`3oool00`27QhL0MgMg0000000A0?ooo`030000002HV9P0oooo
0080oooo00<0V9RH0000003oool00`3oool00`000000V9RH0?ooo`020?ooo`0609RHV0000000oooo
0?ooo`1EEED0QhN75@3oool00`000000V9RH0?ooo`020?ooo`0309RHV0000000oooo00<0oooo00<0
000009RHV03oool00P3oool01@2HV9P000000?ooo`000000V9RH00<0oooo00<0V9RH0000003oool0
503oool00`000000V9RH0?ooo`020?ooo`0309RHV0000000oooo00H0oooo00<000000?ooo`3oool0
1P3oool003d0oooo0P0000080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01@3o
ool01`2HV9P0000009RHV03oool0V9RH0000002HV9P0103oool02P2HV9P0000009RHV03oool0V9RH
0000002HV9P0oooo09RHV000000209RHV0030000002HV9P0oooo0140oooo00L0V9RH0000002HV9P0
oooo09RHV0000000V9RH00@0oooo00L0V9RH0000002HV9P0oooo09RHV0000000V9RH00D0oooo00<0
EEEE0000003oool0403oool01`2HV9P0000009RHV03oool0V9RH0000002HV9P0103oool01`2HV9P0
000009RHV03oool0V9RH0000002HV9P00`3oool206IVIP030=gMg@3oool0oooo0140oooo00L0V9RH
0000002HV9P0oooo09RHV0000000V9RH00@0oooo00l0V9RH0000002HV9P0oooo09RHV0000000V9RH
0?ooo`2HV9P0000009RHV03oool0V9RH0000002HV9P05@3oool01`2HV9P0000009RHV03oool0V9RH
0000002HV9P01@3oool2038b<P030000003oool0oooo00H0oooo000m0?ooo`030000003oool0oooo
00L0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`050?ooo`0509RHV00000000000
0000002HV9P01P3oool01@2HV9P00000000000000000V9RH00<0oooo00@0V9RH000000000000V9RH
503oool01@2HV9P00000000000000000V9RH00H0oooo00D0V9RH000000000000000009RHV0060?oo
o`030>k^kP0Q8B40oooo0140oooo00D0V9RH000000000000000009RHV0060?ooo`0509RHV0000000
00000000002HV9P01@3oool0102j^[X0EEEE05EEE@2HV9PB0?ooo`0509RHV000000000000000002H
V9P01P3oool01@2HV9P00000000000000000V9RH00<0oooo00D0V9RH000000000000000009RHV00G
0?ooo`0509RHV000000000000000002HV9P01P3oool00`3^k^h0V9RH010@40080?ooo`00?@3oool0
0`000000oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0b@3oool0
03d0oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
0<P0oooo000m0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool02`3oool00`000?l0
oooo0?ooo`370?ooo`00>03ooolA000000030?l000000000000000/0000000<0003o000000000000
_`0000070?ooo`00?@3oool00`000000oooo0?ooo`080?ooo`030000003o0000oooo00P0oooo00<0
00000?ooo`3oool00P3oool20000o`<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00X0oooo000m0?ooo`030000003oool0oooo00X0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02L0oooo0P000?l<
0?ooo`00?@3oool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?oo
o`3oool0/`3oool00`000?l0oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0/03oool20000o`l0oooo000m0?ooo`030000
003oool0oooo00/0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`2^0?ooo`030000
o`3oool0oooo00l0oooo000m0?ooo`8000003@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo0:/0oooo0P000?lB0?ooo`00?@3oool00`000000oooo0?ooo`0<0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool0Z@3oool00`000?l0oooo0?ooo`0B0?ooo`00?@3oool00`00
0000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0YP3oool20000
oaD0oooo000m0?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool04@3oool20000oj@0
oooo0P000?lG0?ooo`00?@3oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo01<0oooo
00<0003o0?ooo`3oool0W`3oool20000oaT0oooo000m0?ooo`8000003`3oool00`3o0000oooo0?oo
o`0C0?ooo`80003oWP3oool00`000?l0oooo0?ooo`0I0?ooo`00?@3oool00`000000oooo0?ooo`0>
0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool0V@3oool20000oa`0oooo000m0?oo
o`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool05@3oool20000oiL0oooo0P000?lN0?oo
o`00?@3oool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0oooo01L0oooo00<0003o0?ooo`3o
ool0TP3oool20000ob00oooo000m0?ooo`030000003oool0oooo0100oooo00<0o`000?ooo`3oool0
5`3oool20000oi00oooo0P000?lR0?ooo`00?@3oool200000140oooo00<0o`000?ooo`3oool06@3o
ool00`000?l0oooo0?ooo`2<0?ooo`030000o`3oool0oooo0280oooo000m0?ooo`030000003oool0
oooo0140oooo00<0o`000?ooo`3oool06@3oool20000ohX0oooo0P000?lU0?ooo`00?@3oool00`00
0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool0Q@3oool20000
obL0oooo000m0?ooo`030000003oool0oooo0180oooo00<0o`000?ooo`3oool06`3oool20000oh<0
oooo0P000?lY0?ooo`00?@3oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo01d0oooo
00<0003o0?ooo`3oool0OP3oool20000ob/0oooo000m0?ooo`800000503oool00`3o0000oooo0?oo
o`0M0?ooo`80003oO@3oool00`000?l0oooo0?ooo`0[0?ooo`00?@3oool00`000000oooo0?ooo`0D
0?ooo`030?l0003oool0oooo01h0oooo0P000?mi0?ooo`80003o;P3oool000d0oooo00D08B4Q0000
00000000A4A40;Zj^P030?ooo`05024Q8@000000000004A4A02j^[X0103oool01@2HV9P000000000
00000000V9RH00<0oooo1@0000030?ooo`03038b<P3oool0A4A400@0000000<0V9RH0?ooo`3oool0
1@3oool00`000000oooo0?ooo`0D0?ooo`030?l0003oool0oooo0200oooo0P000?me0?ooo`80003o
<03oool00100oooo00<0k^k^05EEE@2YZJT01@3oool00`3^k^h0EEEE0:VYZ@020?ooo`0709RHV000
0000V9RH0?ooo`2HV9P0000009RHV0040?ooo`030000003oool0oooo00T0oooo00<0V9RH0000002H
V9P01P3oool00`000000oooo0?ooo`0E0?ooo`030?l0003oool0oooo0240oooo00<0003o0?ooo`3o
ool0K`3oool30000oc80oooo000A0?ooo`030>k^kP0@4100oooo00D0oooo00H0k^k^010@403oool0
oooo0000002HV9P30?ooo`0309RHV0000000oooo00<0oooo00<000000?ooo`3oool02P3oool00`2H
V9P000000?ooo`050?ooo`030000003oool0oooo01D0oooo00<0o`000?ooo`3oool08P3oool20000
of`0oooo0`000?le0?ooo`004P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00@0oooo0`00000F0?ooo`030?l0003oool0oooo02<0oooo0P000?mW0?ooo`<0003o>03oool000<0
oooo200000050?ooo`030>k^kP1VIVH0<S8b00D0oooo00<0k^k^06IVIP0b<S800P3oool00`000000
oooo0?ooo`020?ooo`0309RHV0000000oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3oool09@3oool20000of<0
oooo0P000?lk0?ooo`003`3oool0100Q8B400000038b<P3^k^h40?ooo`04024Q8@000000<S8b0>k^
kP80oooo00L0000007MgM`3^k^h0oooo09RHV0000000V9RH00@0oooo00<000000?ooo`3oool02P3o
ool00`2HV9P000000?ooo`050?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3oool09P3o
ool30000oed0oooo0`000?lm0?ooo`00403oool00`1EEED0^[Zj0?ooo`050?ooo`0305EEE@2j^[X0
oooo0080oooo00<0A4A407MgM`0@41000P0000000`2HV9P0oooo0?ooo`030?ooo`030000003oool0
oooo00T0oooo00<0V9RH0000002HV9P01P3oool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0
oooo02T0oooo0P000?mI0?ooo`80003o@03oool00100oooo00<0k^k^024Q8@3oool01@3oool00`3^
k^h08B4Q0?ooo`020?ooo`030;Zj^P14A4@0oooo00P0oooo00<000000?ooo`3oool01@3oool00`2j
^[X00000000000020000000309RHV03oool0oooo00D0oooo00<000000?ooo`3oool0603oool00`3o
0000oooo0?ooo`0Z0?ooo`80003oE@3oool20000od80oooo000=0?ooo`0508N7Q`3oool0oooo0?oo
o`0000000`3oool01@27QhL0oooo0?ooo`3oool0000000@0oooo00<0EEEE08N7Q`3oool01`3oool0
0`000000oooo0?ooo`060?ooo`03010@403MgMd0oooo00T0oooo0P00000I0?ooo`030?l0003oool0
oooo02`0oooo0`000?m?0?ooo`<0003o=`3oool00`3o0000oooo0?ooo`0:0?ooo`003@3oool01@1g
MgL0QhN70?ooo`1gMgL08B4Q00<0oooo00D0MgMg08N7Q`3oool0MgMg024Q8@050?ooo`80IVIV00<0
gMgM0?ooo`3oool00P3oool2038b<P030000003oool0oooo00H0oooo00<0QhN706IVIP3oool02@3o
ool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0oooo02h0oooo0`000?m90?ooo`<0003o>P3o
ool00`3o0000oooo0?ooo`0:0?ooo`003P3oool0101VIVH00000010@403<c<`40?ooo`0406IVIP00
0000410@0<c<c0H0oooo00@0^[Zj05EEE@1EEED0V9RH0P3oool00`3^k^h0V9RH010@40080?ooo`03
0=gMg@00000000000080000000<0<S8b0?ooo`3oool0103oool00`000000oooo0?ooo`0J0?ooo`03
0?l0003oool0oooo0300oooo10000?m20?ooo`<0003o?03oool00`3o0000oooo0?ooo`0;0?ooo`00
?@3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo03@0oooo1@000?lh0?ooo`D0003o
?P3oool00`3o0000oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`0K0?ooo`030?l0003o
ool0oooo03P0oooo10000?l`0?ooo`@0003o@P3oool00`3o0000oooo0?ooo`0=0?ooo`00?@3oool2
000001`0oooo00<0o`000?ooo`3oool0?03oool40000obL0oooo1@000?m60?ooo`030?l0003oool0
oooo00d0oooo000m0?ooo`030000003oool0oooo01`0oooo00<0o`000?ooo`3oool0?`3oool80000
oaH0oooo2@000?m:0?ooo`030?l0003oool0oooo00h0oooo000m0?ooo`030000003oool0oooo01d0
oooo00<0o`000?ooo`3oool0AP3ooolF0000oe80oooo00<0o`000?ooo`3oool03`3oool003d0oooo
00<000000?ooo`3oool07@3oool00`3o0000oooo0?ooo`2]0?ooo`030?l0003oool0oooo0100oooo
000m0?ooo`030000003oool0oooo01h0oooo00<0o`000?ooo`3oool0[03oool00`3o0000oooo0?oo
o`0@0?ooo`00?@3oool00`000000oooo0?ooo`0N0?ooo`030?l0003oool0oooo0:/0oooo00<0o`00
0?ooo`3oool04@3oool003d0oooo0P00000P0?ooo`030?l0003oool0oooo0:T0oooo00<0o`000?oo
o`3oool04P3oool003d0oooo00<000000?ooo`3oool0803oool00`3o0000oooo0?ooo`2W0?ooo`03
0?l0003oool0oooo01<0oooo000m0?ooo`030000003oool0oooo0200oooo00<0o`000?ooo`3oool0
Y`3oool00`3o0000oooo0?ooo`0C0?ooo`00?@3oool00`000000oooo0?ooo`0Q0?ooo`030?l0003o
ool0oooo0:D0oooo00<0o`000?ooo`3oool0503oool003d0oooo00<000000?ooo`3oool08@3oool0
0`3o0000oooo0?ooo`2T0?ooo`030?l0003oool0oooo01D0oooo000m0?ooo`8000008`3oool00`3o
0000oooo0?ooo`2R0?ooo`030?l0003oool0oooo01H0oooo000m0?ooo`030000003oool0oooo02<0
oooo00<0o`000?ooo`3oool0X03oool00`3o0000oooo0?ooo`0G0?ooo`006@3oool01@0Q8B400000
00000014A4@0^[Zj00<0oooo00D08B4Q000000000000A4A40;Zj^P040?ooo`0509RHV00000000000
0000002HV9P00`3oool5000000H0oooo00<000000?ooo`3oool08`3oool00`3o0000oooo0?ooo`2O
0?ooo`030?l0003oool0oooo01P0oooo000L0?ooo`030>k^kP1EEED0ZJVY00D0oooo00<0k^k^05EE
E@2YZJT00P3oool01`2HV9P0000009RHV03oool0V9RH0000002HV9P0103oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3oool0WP3oool00`3o0000oooo0?oo
o`0H0?ooo`007@3oool00`3^k^h0410@0?ooo`050?ooo`060>k^kP0@4100oooo0?ooo`000000V9RH
0`3oool00`2HV9P000000?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
9@3oool00`3o0000oooo0?ooo`2L0?ooo`030?l0003oool0oooo01T0oooo000N0?ooo`030000003o
ool0oooo00D0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo0`00000V0?ooo`030?l0003oool0oooo09X0oooo00<0o`000?ooo`3oool0
6P3oool000l0oooo200000050?ooo`030>k^kP1VIVH0<S8b00D0oooo00<0k^k^06IVIP0b<S800P3o
ool00`000000oooo0?ooo`020?ooo`0309RHV0000000oooo00<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0V0?ooo`030?l0003oool0oooo09T0oooo00<0o`000?ooo`3oool06`3o
ool001/0oooo00@08B4Q0000000b<S80k^k^103oool0100Q8B400000038b<P3^k^h20?ooo`070000
001gMgL0k^k^0?ooo`2HV9P0000009RHV0040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool09`3oool00`3o0000oooo0?ooo`2G0?ooo`030?l0003oool0oooo01`0oooo000L0?ooo`03
05EEE@2j^[X0oooo00D0oooo00<0EEEE0;Zj^P3oool00P3oool00`14A4@0MgMg010@400200000003
09RHV03oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0X0?ooo`03
0?l0003oool0oooo09H0oooo00<0o`000?ooo`3oool0703oool001`0oooo00<0k^k^024Q8@3oool0
1@3oool00`3^k^h08B4Q0?ooo`020?ooo`030;Zj^P14A4@0oooo00P0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0X0?ooo`030?l0003oool0oooo09D0oooo00<0o`000?ooo`3oool0
7@3oool001T0oooo00D0QhN70?ooo`3oool0oooo000000030?ooo`0508N7Q`3oool0oooo0?ooo`00
0000103oool00`1EEED0QhN70?ooo`070?ooo`030000003oool0oooo00H0oooo0P00000Z0?ooo`03
0?l0003oool0oooo09<0oooo00<0o`000?ooo`3oool07P3oool001T0oooo00D0MgMg08N7Q`3oool0
MgMg024Q8@030?ooo`0507MgM`27QhL0oooo07MgM`0Q8B401@3oool206IVIP030=gMg@3oool0oooo
0080oooo0P0b<S800`000000oooo0?ooo`060?ooo`030000003oool0oooo02X0oooo00<0o`000?oo
o`3oool0T@3oool00`3o0000oooo0?ooo`0O0?ooo`006P3oool0101VIVH00000010@403<c<`40?oo
o`0406IVIP000000410@0<c<c0H0oooo00@0^[Zj05EEE@1EEED0V9RH0P3oool00`3^k^h0V9RH010@
40080?ooo`030000003oool0oooo02X0oooo00<0o`000?ooo`3oool0T03oool00`3o0000oooo0?oo
o`0P0?ooo`00?@3oool00`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo08h0oooo00<0o`00
0?ooo`3oool08@3oool003d0oooo00<000000?ooo`3oool0;03oool00`3o0000oooo0?ooo`2<0?oo
o`030?l0003oool0oooo0280oooo000m0?ooo`800000;P3oool00`3o0000oooo0?ooo`2:0?ooo`03
0?l0003oool0oooo02<0oooo000m0?ooo`030000003oool0oooo02h0oooo00<0o`000?ooo`3oool0
R03oool00`3o0000oooo0?ooo`0T0?ooo`00?@3oool00`000000oooo0?ooo`0_0?ooo`030?l0003o
ool0oooo08H0oooo00<0o`000?ooo`3oool09@3oool003d0oooo00<000000?ooo`3oool0;`3oool0
0`3o0000oooo0?ooo`250?ooo`030?l0003oool0oooo02H0oooo000m0?ooo`030000003oool0oooo
0300oooo00<0o`000?ooo`3oool0P`3oool00`3o0000oooo0?ooo`0W0?ooo`00?@3oool200000380
oooo00<0o`000?ooo`3oool0P@3oool00`3o0000oooo0?ooo`0X0?ooo`00?@3oool00`000000oooo
0?ooo`0b0?ooo`030?l0003oool0oooo07l0oooo00<0o`000?ooo`3oool0:@3oool003d0oooo00<0
00000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`1m0?ooo`030?l0003oool0oooo02X0oooo000m
0?ooo`030000003oool0oooo03<0oooo00<0o`000?ooo`3oool0O03oool00`3o0000oooo0?ooo`0[
0?ooo`00?@3oool00`000000oooo0?ooo`0d0?ooo`030?l0003oool0oooo07X0oooo00<0o`000?oo
o`3oool0;03oool003d0oooo0P00000f0?ooo`030?l0003oool0oooo07P0oooo00<0o`000?ooo`3o
ool0;@3oool003d0oooo00<000000?ooo`3oool0=P3oool00`3o0000oooo0?ooo`1e0?ooo`80o`00
<03oool003d0oooo00<000000?ooo`3oool0=`3oool00`3o0000oooo0?ooo`1c0?ooo`030?l0003o
ool0oooo0300oooo000=0?ooo`05024Q8@000000000004A4A02j^[X00`3oool01@0Q8B4000000000
0014A4@0^[Zj00@0oooo00D0V9RH000000000000000009RHV0030?ooo`0509RHV000000000000000
002HV9P00`3oool00`0b<S80oooo04A4A0040000000309RHV03oool0oooo00D0oooo00<000000?oo
o`3oool0>03oool00`3o0000oooo0?ooo`1a0?ooo`030?l0003oool0oooo0340oooo000@0?ooo`03
0>k^kP1EEED0ZJVY00D0oooo00<0k^k^05EEE@2YZJT00P3oool03`2HV9P0000009RHV03oool0V9RH
0000002HV9P0oooo09RHV0000000V9RH0?ooo`2HV9P0000009RHV0080?ooo`0309RHV0000000V9RH
00H0oooo00<000000?ooo`3oool0>@3oool00`3o0000oooo0?ooo`1_0?ooo`030?l0003oool0oooo
0380oooo000A0?ooo`030>k^kP0@4100oooo00D0oooo00H0k^k^010@403oool0oooo0000002HV9P3
0?ooo`0509RHV0000000oooo0000002HV9P00`3oool00`2HV9P000000?ooo`080?ooo`0309RHV000
0000oooo00D0oooo00<000000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`1]0?ooo`030?l0003o
ool0oooo03<0oooo000B0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo000000050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103o
ool3000003/0oooo00<0o`000?ooo`3oool0J`3oool00`3o0000oooo0?ooo`0d0?ooo`000`3oool8
000000D0oooo00<0k^k^06IVIP0b<S801@3oool00`3^k^h0IVIV038b<P020?ooo`030000003oool0
oooo0080oooo00@0V9RH0000003oool000001@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0?03oool20?l006X0oooo00<0o`000?ooo`3oool0=@3o
ool000l0oooo00@08B4Q0000000b<S80k^k^103oool0100Q8B400000038b<P3^k^h20?ooo`090000
001gMgL0k^k^0?ooo`2HV9P0000009RHV03oool0000000D0oooo00<000000?ooo`3oool01`3oool0
0`2HV9P000000?ooo`050?ooo`030000003oool0oooo03h0oooo00<0o`000?ooo`3oool0IP3oool0
0`3o0000oooo0?ooo`0f0?ooo`00403oool00`1EEED0^[Zj0?ooo`050?ooo`0305EEE@2j^[X0oooo
0080oooo00<0A4A407MgM`0@41000P000000102HV9P0oooo0?ooo`0000050?ooo`030000003oool0
oooo00H0oooo00<0V9RH0000002HV9P01P3oool00`000000oooo0?ooo`0o0?ooo`030?l0003oool0
oooo06<0oooo0P3o000i0?ooo`00403oool00`3^k^h08B4Q0?ooo`050?ooo`030>k^kP0Q8B40oooo
0080oooo00<0^[Zj04A4A03oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<0^[Zj0000000000000P0000000`2HV9P0oooo0?ooo`050?ooo`030000003oool0oooo
0400oooo00<0o`000?ooo`3oool0H@3oool00`3o0000oooo0?ooo`0i0?ooo`003@3oool01@27QhL0
oooo0?ooo`3oool0000000<0oooo00D0QhN70?ooo`3oool0oooo000000040?ooo`0305EEE@27QhL0
oooo00@0oooo00<0000009RHV03oool00P3oool00`2HV9P000000?ooo`040?ooo`03010@403MgMd0
oooo00T0oooo0P0000120?ooo`030?l0003oool0oooo05h0oooo0P3o000l0?ooo`003@3oool01@1g
MgL0QhN70?ooo`1gMgL08B4Q00<0oooo00D0MgMg08N7Q`3oool0MgMg024Q8@050?ooo`80IVIV00/0
gMgM0?ooo`3oool0oooo09RHV0000000V9RH0?ooo`2HV9P0000009RHV0050?ooo`0308N7Q`1VIVH0
oooo00T0oooo00<000000?ooo`3oool0@P3oool00`3o0000oooo0?ooo`1L0?ooo`030?l0003oool0
oooo03`0oooo000>0?ooo`0406IVIP000000410@0<c<c0@0oooo00@0IVIV0000000@4100c<c<1P3o
ool0102j^[X0EEEE05EEE@2HV9P20?ooo`0509RHV000000000000000002HV9P01P3oool00`3MgMd0
00000000000200000003038b<P3oool0oooo00@0oooo00<000000?ooo`3oool0@`3oool00`3o0000
oooo0?ooo`1I0?ooo`80o`00?`3oool003d0oooo00<000000?ooo`3oool0A03oool00`3o0000oooo
0?ooo`1G0?ooo`030?l0003oool0oooo03l0oooo000m0?ooo`030000003oool0oooo04D0oooo0P3o
001E0?ooo`80o`00@P3oool003d0oooo0P0000180?ooo`030?l0003oool0oooo0540oooo00<0o`00
0?ooo`3oool0@P3oool003d0oooo00<000000?ooo`3oool0B03oool00`3o0000oooo0?ooo`1?0?oo
o`030?l0003oool0oooo04<0oooo000m0?ooo`030000003oool0oooo04T0oooo0P3o001=0?ooo`80
o`00AP3oool003d0oooo00<000000?ooo`3oool0B`3oool00`3o0000oooo0?ooo`190?ooo`030?l0
003oool0oooo04H0oooo000m0?ooo`030000003oool0oooo04`0oooo00<0o`000?ooo`3oool0A`3o
ool00`3o0000oooo0?ooo`170?ooo`00?@3oool2000004h0oooo0P3o00150?ooo`80o`00BP3oool0
03d0oooo00<000000?ooo`3oool0C`3oool20?l00440oooo0P3o001<0?ooo`00?@3oool00`000000
oooo0?ooo`1A0?ooo`030?l0003oool0oooo03/0oooo0`3o001>0?ooo`00?@3oool00`000000oooo
0?ooo`1B0?ooo`80o`00>@3oool20?l00540oooo000m0?ooo`030000003oool0oooo05@0oooo0`3o
000d0?ooo`80o`00D`3oool003d0oooo0P00001H0?ooo`80o`00<03oool20?l005D0oooo000m0?oo
o`030000003oool0oooo05T0oooo0P3o000[0?ooo`<0o`00E`3oool001T0oooo00D08B4Q00000000
0000A4A40;Zj^P030?ooo`05024Q8@000000000004A4A02j^[X0103oool01@2HV9P0000000000000
0000V9RH00<0oooo00D0V9RH000000000000000009RHV0060?ooo`030000003oool0oooo05/0oooo
0P3o000W0?ooo`80o`00FP3oool001`0oooo00<0k^k^05EEE@2YZJT01@3oool00`3^k^h0EEEE0:VY
Z@020?ooo`0?09RHV0000000V9RH0?ooo`2HV9P0000009RHV03oool0V9RH0000002HV9P0oooo09RH
V0000000V9RH00D0oooo00<000000?ooo`3oool0G@3oool20?l00280oooo0`3o001L0?ooo`007@3o
ool00`3^k^h0410@0?ooo`050?ooo`060>k^kP0@4100oooo0?ooo`000000V9RH0`3oool01@2HV9P0
00000?ooo`000000V9RH00<0oooo00<0V9RH0000003oool0103oool00`000000oooo0?ooo`1O0?oo
o`@0o`006@3oool50?l005l0oooo000N0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo000000050?ooo`030000003oool0oooo00<0oooo0`00001S0?oo
o`P0o`00303oool50?l006@0oooo000?0?ooo`P000001@3oool00`3^k^h0IVIV038b<P050?ooo`03
0>k^kP1VIVH0<S8b0080oooo00<000000?ooo`3oool00P3oool0102HV9P000000?ooo`0000050?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0J`3oool<0?l006T0oooo000K0?ooo`04
024Q8@000000<S8b0>k^kP@0oooo00@08B4Q0000000b<S80k^k^0P3oool02@000000MgMg0>k^kP3o
ool0V9RH0000002HV9P0oooo000000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0h03oool001`0oooo00<0EEEE0;Zj^P3oool01@3oool00`1EEED0^[Zj0?ooo`020?ooo`0304A4
A01gMgL0410@0080000000@0V9RH0?ooo`3oool000001@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0>00oooo000L0?ooo`030>k^kP0Q8B40oooo00D0oooo00<0k^k^024Q8@3oool0
0P3oool00`2j^[X0A4A40?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`3P0?ooo`006@3oool01@27QhL0oooo0?ooo`3oool0000000<0oooo
00D0QhN70?ooo`3oool0oooo000000040?ooo`0305EEE@27QhL0oooo00@0oooo00<0000009RHV03o
ool00P3oool00`2HV9P000000?ooo`3W0?ooo`006@3oool01@1gMgL0QhN70?ooo`1gMgL08B4Q00<0
oooo00D0MgMg08N7Q`3oool0MgMg024Q8@050?ooo`80IVIV00/0gMgM0?ooo`3oool0oooo09RHV000
0000V9RH0?ooo`2HV9P0000009RHV03X0?ooo`006P3oool0101VIVH00000010@403<c<`40?ooo`04
06IVIP000000410@0<c<c0H0oooo00@0^[Zj05EEE@1EEED0V9RH0P3oool01@2HV9P0000000000000
0000V9RH0>T0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0290239, -3362.98, \
0.000469179, 0.019458}}]
}, Open  ]],

Cell[TextData[{
  "Log[L] = ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\[Sum]\+\(\[Alpha] \[NotEqual] \[Beta]\)\(n\_\(\[Alpha], \
\[Beta]\)\) Log[\(2 \( p\_\[Alpha]\) p\_\[Beta]\)\/\(1 - p\_\[Nu]\%2\)]\),
            "TraditionalForm"], 
          "+", \(\[Sum]\+\[Alpha]\( n\_\(\[Alpha], \[Alpha]\)\) 
              Log[\(p\_\[Alpha]\%2 + 2 \( p\_\[Alpha]\) p\_\[Nu]\)\/\(1 - p\_\
\[Nu]\%2\)]\)}], TraditionalForm]]],
  "= ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{
              
              FormBox[\(\[Sum]\+\(\[Alpha] \[NotEqual] \[Beta]\)\(n\_\(\
\[Alpha], \[Beta]\)\) Log[2 \( p\_\[Alpha]\) p\_\[Beta]]\),
                "TraditionalForm"], 
              "+", \(\[Sum]\+\[Alpha]\( n\_\(\[Alpha], \[Alpha]\)\) 
                  Log[p\_\[Alpha]\%2 + 2 \( p\_\[Alpha]\) p\_\[Nu]]\)}],
            "TraditionalForm"], 
          "-", \(\((N - n\_\[EmptySet])\) Log[1 - p\_\[Nu]\%2]\)}], 
        TraditionalForm]]]
}], "InlineFormula"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\ p\_\[Nu]\)]],
  "= ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\[Sum]\+\[Alpha] 2 \( n\_\(\[Alpha], \[Alpha]\)\) 
                p\_\[Nu]\/\(p\_\[Alpha] + 2  p\_\[Nu]\)\),
            "TraditionalForm"], 
          "+", \(2 \( p\_\[Nu]\%2\/\(1 - p\_\[Nu]\%2\)\) \((N - 
                n\_\[EmptySet])\)\)}], TraditionalForm]]],
  "\n\[Lambda] ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(\(p\_\[Alpha]\)\(=\)\),
              "TraditionalForm"], 
            RowBox[{
              FormBox[\(\[Sum]\+\(\[Alpha] \[NotEqual] \[Beta]\)\),
                "TraditionalForm"], 
              FormBox[\(n\_\(\[Alpha], \[Beta]\)\),
                "TraditionalForm"]}]}], "+", 
          RowBox[{"2", \(n\_\(\[Alpha], \[Alpha]\)\), 
            FractionBox[
              RowBox[{
                FormBox["",
                  "TraditionalForm"], "(", \(p\_\[Alpha] + p\_\[Nu]\), 
                ")"}], \(p\_\[Alpha] + 2  p\_\[Nu]\)]}]}], 
        TraditionalForm]]],
  "\n\[Lambda]=",
  Cell[BoxData[
      \(TraditionalForm\`2 \((N - n\_\[EmptySet])\)\/\(1 - p\_\[Nu]\%2\)\)]],
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(p\_\[Alpha]\),
            "TraditionalForm"], "=", 
          RowBox[{
            FormBox[
              RowBox[{"(", 
                FormBox[\(1 - p\_\[Nu]\%2\),
                  "TraditionalForm"], ")"}],
              
              "TraditionalForm"], \((\(p\&~\)\_\[Alpha] - \(n\_\(\[Alpha], \
\[Alpha]\)\/\((N - n\_\[EmptySet])\)\) 
                  p\_\[Nu]\/\(p\_\[Alpha] + 2  p\_\[Nu]\))\)}]}], 
        TraditionalForm]]],
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(p\_\[Nu]\)\(=\)\),
            "TraditionalForm"], 
          RowBox[{"(", 
            FormBox[\(1 - p\_\[Nu]\%2\),
              "TraditionalForm"], ")"}]}], TraditionalForm]]],
  "(",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\[Sum]\+\[Alpha]\( n\_\(\[Alpha], \[Alpha]\)\/\((N - 
                        n\_\[EmptySet])\)\) 
                p\_\[Nu]\/\(p\_\[Alpha] + 2  p\_\[Nu]\)\),
            "TraditionalForm"], "+", \(p\_\[Nu]\%2\/\(1 - p\_\[Nu]\%2\)\)}], 
        TraditionalForm]]],
  ")"
}], "InlineFormula"],

Cell[BoxData[
    \(\(hets = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 2, 10, 0, 0, 0, 0, 
          148, 0};\)\)], "Input"],

Cell[BoxData[
    \(-\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Plot[Plus @@ xx, {pn, 0, 0.1}];\)\), "\[IndentingNewLine]", 
    \(FindMinimum[\(-Plus @@ xx\), {pn, 0, 0.1}]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 9.52381 1544.38 0.459285 [
[.21429 .25547 -16 -18 ]
[.21429 .25547 16 0 ]
[.40476 .25547 -16 -18 ]
[.40476 .25547 16 0 ]
[.59524 .25547 -16 -18 ]
[.59524 .25547 16 0 ]
[.78571 .25547 -16 -18 ]
[.78571 .25547 16 0 ]
[.97619 .25547 -12 -18 ]
[.97619 .25547 12 0 ]
[.01131 .08426 -59.0625 -9 ]
[.01131 .08426 0 9 ]
[.01131 .17612 -59.0625 -9 ]
[.01131 .17612 0 9 ]
[.01131 .35983 -59.0625 -9 ]
[.01131 .35983 0 9 ]
[.01131 .45169 -59.0625 -9 ]
[.01131 .45169 0 9 ]
[.01131 .54354 -59.0625 -9 ]
[.01131 .54354 0 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .26797 m
.21429 .27422 L
s
gsave
.21429 .25547 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
1.000 setlinewidth
grestore
.40476 .26797 m
.40476 .27422 L
s
gsave
.40476 .25547 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
1.000 setlinewidth
grestore
.59524 .26797 m
.59524 .27422 L
s
gsave
.59524 .25547 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
1.000 setlinewidth
grestore
.78571 .26797 m
.78571 .27422 L
s
gsave
.78571 .25547 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
1.000 setlinewidth
grestore
.97619 .26797 m
.97619 .27422 L
s
gsave
.97619 .25547 -73 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .26797 m
.07143 .27172 L
s
.11905 .26797 m
.11905 .27172 L
s
.16667 .26797 m
.16667 .27172 L
s
.2619 .26797 m
.2619 .27172 L
s
.30952 .26797 m
.30952 .27172 L
s
.35714 .26797 m
.35714 .27172 L
s
.45238 .26797 m
.45238 .27172 L
s
.5 .26797 m
.5 .27172 L
s
.54762 .26797 m
.54762 .27172 L
s
.64286 .26797 m
.64286 .27172 L
s
.69048 .26797 m
.69048 .27172 L
s
.7381 .26797 m
.7381 .27172 L
s
.83333 .26797 m
.83333 .27172 L
s
.88095 .26797 m
.88095 .27172 L
s
.92857 .26797 m
.92857 .27172 L
s
.25 Mabswid
0 .26797 m
1 .26797 L
s
.02381 .08426 m
.03006 .08426 L
s
gsave
.01131 .08426 -120.062 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3362.4) show
1.000 setlinewidth
grestore
.02381 .17612 m
.03006 .17612 L
s
gsave
.01131 .17612 -120.062 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3362.2) show
1.000 setlinewidth
grestore
.02381 .35983 m
.03006 .35983 L
s
gsave
.01131 .35983 -120.062 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3361.8) show
1.000 setlinewidth
grestore
.02381 .45169 m
.03006 .45169 L
s
gsave
.01131 .45169 -120.062 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3361.6) show
1.000 setlinewidth
grestore
.02381 .54354 m
.03006 .54354 L
s
gsave
.01131 .54354 -120.062 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3361.4) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .10722 m
.02756 .10722 L
s
.02381 .13019 m
.02756 .13019 L
s
.02381 .15315 m
.02756 .15315 L
s
.02381 .19908 m
.02756 .19908 L
s
.02381 .22205 m
.02756 .22205 L
s
.02381 .24501 m
.02756 .24501 L
s
.02381 .29094 m
.02756 .29094 L
s
.02381 .3139 m
.02756 .3139 L
s
.02381 .33687 m
.02756 .33687 L
s
.02381 .3828 m
.02756 .3828 L
s
.02381 .40576 m
.02756 .40576 L
s
.02381 .42872 m
.02756 .42872 L
s
.02381 .47465 m
.02756 .47465 L
s
.02381 .49762 m
.02756 .49762 L
s
.02381 .52058 m
.02756 .52058 L
s
.02381 .0613 m
.02756 .0613 L
s
.02381 .03833 m
.02756 .03833 L
s
.02381 .01537 m
.02756 .01537 L
s
.02381 .56651 m
.02756 .56651 L
s
.02381 .58947 m
.02756 .58947 L
s
.02381 .61244 m
.02756 .61244 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .10811 L
.10458 .19921 L
.14415 .27507 L
.18221 .3396 L
.22272 .39966 L
.26171 .44943 L
.30316 .49409 L
.34309 .52942 L
.3815 .55659 L
.40095 .56787 L
.42237 .57844 L
.44292 .58677 L
.46172 .59287 L
.48113 .59769 L
.49183 .5997 L
.502 .6012 L
.51159 .60224 L
.51695 .60267 L
.52181 .60297 L
.52402 .60307 L
.52636 .60316 L
.52758 .6032 L
.52892 .60324 L
.53015 .60327 L
.53128 .60329 L
.53242 .6033 L
.5335 .60331 L
.53465 .60332 L
.53589 .60332 L
.53698 .60331 L
.53813 .60331 L
.53911 .60329 L
.5402 .60328 L
.54255 .60322 L
.54511 .60314 L
.5478 .60303 L
.55029 .60291 L
.55476 .60262 L
.55954 .60223 L
.57047 .60103 L
.5804 .59957 L
.59959 .59573 L
.62038 .59008 L
.6613 .5746 L
.7007 .55434 L
.73859 .53007 L
.77893 .49923 L
.81776 .4648 L
.85903 .42325 L
Mistroke
.89879 .37854 L
.93704 .33131 L
.97619 .27879 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00?@3oool00`000000oooo0?oo
o`3P0?ooo`00?@3oool00`000000oooo0?ooo`3P0?ooo`00?@3oool00`000000oooo0?ooo`3P0?oo
o`00?@3oool200000>40oooo000m0?ooo`030000003oool0oooo0>00oooo000m0?ooo`800000h@3o
ool003d0oooo0P00003Q0?ooo`00?@3oool00`000000oooo0000003P0?ooo`00?@3oool300000>00
oooo000m0?ooo`030000003oool000000>00oooo000m0?ooo`040000003oool0oooo00000=l0oooo
000m0?ooo`040000003oool0oooo00000=l0oooo000m0?ooo`050000003oool0oooo0?ooo`000000
gP3oool003d0oooo00D000000?ooo`3oool0oooo0000003N0?ooo`00?@3oool2000000<0oooo00<0
00000?ooo`3oool0f`3oool003d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3K
0?ooo`003@3oool01@0Q8B40000000000014A4@0^[Zj00<0oooo00D08B4Q000000000000A4A40;Zj
^P040?ooo`0509RHV000000000000000002HV9P00P3oool00`0@4100000000000003000000040;Zj
^P3oool0oooo038b<PH0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0=/0oooo000@0?ooo`030>k^kP1EEED0ZJVY00D0oooo00<0k^k^05EEE@2YZJT0
0P3oool0202HV9P0000009RHV03oool0V9RH0000002HV9P0oooo0P3MgMd30?ooo`0308N7Q`0b<S80
oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0=X0oooo000A0?ooo`030>k^kP0@4100oooo00D0oooo00H0k^k^010@403oool0oooo0000002H
V9P30?ooo`0409RHV0000000oooo0?ooo`80gMgM3@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0fP3oool00180oooo00<000000?ooo`3oool01@3o
ool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo0?ooo`80gMgM1`3oool8000000D0
oooo0`0000040?ooo`030000003oool0oooo0=T0oooo00030?ooo`P000001@3oool00`3^k^h0IVIV
038b<P050?ooo`030>k^kP1VIVH0<S8b0080oooo00<000000?ooo`3oool00P3oool00`2HV9P00000
0?ooo`030?ooo`80gMgM1P3oool00`1EEED0QhN70?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3I0?ooo`003`3oool0100Q8B400000038b
<P3^k^h40?ooo`04024Q8@000000<S8b0>k^kP80oooo00L0000007MgM`3^k^h0oooo09RHV0000000
V9RH00D0oooo00<0QhN70=gMg@3oool01@3oool01@0Q8B40c<c<0?ooo`3oool0000000L0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`3H0?ooo`00403oool00`1EEED0^[Zj0?ooo`05
0?ooo`0305EEE@2j^[X0oooo0080oooo00<0A4A407MgM`0@41000P0000000`2HV9P0oooo0?ooo`04
0?ooo`030=gMg@1EEED0oooo00D0oooo00D0k^k^024Q8@3^k^h0oooo000000070?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0f03oool00100oooo00<0k^k^024Q8@3oool01@3oool0
0`3^k^h08B4Q0?ooo`020?ooo`030;Zj^P14A4@0oooo00D0oooo00<0^[Zj0?ooo`3oool00P3oool0
0`000000oooo0?ooo`050?ooo`040;Zj^P0b<S80oooo000000L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`3H0?ooo`003@3oool01@27QhL0oooo0?ooo`3oool0000000<0oooo00D0
QhN70?ooo`3oool0oooo000000040?ooo`0305EEE@27QhL0oooo00@0oooo00H0000009RHV03oool0
oooo09RHV00000080?ooo`0308N7Q`1gMgL0000000L0oooo0P0000070?ooo`030000003oool0oooo
0=L0oooo000=0?ooo`0507MgM`27QhL0oooo07MgM`0Q8B400`3oool01@1gMgL0QhN70?ooo`1gMgL0
8B4Q00D0oooo0P1VIVH01P3MgMd0oooo0?ooo`3oool0V9RH00000080V9RH00<0000009RHV03oool0
203oool00`1EEED000000?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
e`3oool000h0oooo00@0IVIV0000000@4100c<c<103oool0101VIVH00000010@403<c<`60?ooo`04
0;Zj^P1EEED0EEEE09RHV080oooo00@0V9RH000000000000V9RH2P3oool00`3^k^h08B4Q0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0eP3oool003d0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`3F0?ooo`00?@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0=D0oooo000m0?ooo`8000002@3oool00`000000oooo0?ooo`3E0?ooo`00?@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0=D0oooo000m0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0e03oool003d0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`3D0?ooo`00?@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0=<0
oooo000m0?ooo`8000002`3oool00`000000oooo0?ooo`3C0?ooo`00?@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0=80oooo000=0?ooo`05024Q8@000000000004A4A02j^[X00`3o
ool01@0Q8B40000000000014A4@0^[Zj00@0oooo00D0V9RH000000000000000009RHV0020?ooo`03
010@40000000000000<0000000H0^[Zj0?ooo`3oool0<S8b0?ooo`0@4105000000030;Zj^P3oool0
oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3B0?ooo`00403oool00`3^
k^h0EEEE0:VYZ@050?ooo`030>k^kP1EEED0ZJVY0080oooo00P0V9RH0000002HV9P0oooo09RHV000
0000V9RH0?ooo`80gMgM0`3oool00`27QhL0<S8b0?ooo`030?ooo`80gMgM0`3oool00`27QhL0<S8b
0?ooo`050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0d@3oool00140oooo00<0
k^k^010@403oool01@3oool01P3^k^h0410@0?ooo`3oool0000009RHV0<0oooo00@0V9RH0000003o
ool0oooo0P3MgMd90?ooo`80gMgM2P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0=40oooo000B0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000001@3oool01000
0000oooo0?ooo`3oool20=gMg@T0oooo0P3MgMd90?ooo`<000003@3oool00`000000oooo0?ooo`3@
0?ooo`000`3oool8000000D0oooo00<0k^k^06IVIP0b<S801@3oool00`3^k^h0IVIV038b<P020?oo
o`030000003oool0oooo0080oooo00<0V9RH0000003oool00`3oool20=gMg@T0oooo0P3MgMd80?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0d03oool000l0oooo00@08B4Q0000000b
<S80k^k^103oool0100Q8B400000038b<P3^k^h20?ooo`070000001gMgL0k^k^0?ooo`2HV9P00000
09RHV0050?ooo`0308N7Q`3MgMd0oooo00P0oooo00<0QhN70=gMg@3oool01P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0=00oooo000@0?ooo`0305EEE@2j^[X0oooo00D0oooo00<0
EEEE0;Zj^P3oool00P3oool00`14A4@0MgMg010@40020000000309RHV03oool0oooo00@0oooo00<0
gMgM05EEE@3oool0203oool00`3MgMd0EEEE0?ooo`060?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0c`3oool00100oooo00<0k^k^024Q8@3oool01@3oool00`3^k^h08B4Q0?ooo`02
0?ooo`030;Zj^P14A4@0oooo00D0oooo00<0^[Zj0?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030;Zj^P3oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0<l0oooo000=0?ooo`0508N7Q`3oool0oooo0?ooo`0000000`3oool0
1@27QhL0oooo0?ooo`3oool0000000@0oooo00<0EEEE08N7Q`3oool0103oool01P000000V9RH0?oo
o`3oool0V9RH000000D0oooo00H0000009RHV03oool0oooo09RHV00000070?ooo`800000403oool0
0`000000oooo0?ooo`3>0?ooo`003@3oool01@1gMgL0QhN70?ooo`1gMgL08B4Q00<0oooo00D0MgMg
08N7Q`3oool0MgMg024Q8@050?ooo`80IVIV00H0gMgM0?ooo`3oool0oooo09RHV000000209RHV003
0000002HV9P0oooo00@0oooo00H0V9RH0000002HV9P0V9RH0000002HV9P70?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool02@3oool01@2HV9P00000000000000000V9RH00<0oooo00@0
<S8b0?ooo`3oool0V9RH0`000000102HV9P0oooo0?ooo`0@4105000000030;Zj^P3oool0oooo0100
oooo00D0V9RH000000000000000009RHV0030?ooo`04038b<P3oool0oooo09RHV0<0000000<0V9RH
0?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`0509RHV000000000000000002HV9P00`3o
ool0100b<S80oooo0?ooo`2HV9P30000000509RHV03oool0oooo0?ooo`2HV9P00`0000000`2HV9P0
oooo0?ooo`0A0?ooo`0509RHV000000000000000002HV9P00`3oool0100b<S80oooo0?ooo`2HV9P3
0000000509RHV03oool0oooo0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`0E0?ooo`0509RHV000
000000000000002HV9P00`3oool00`0b<S80oooo0?ooo`05000000H0oooo000>0?ooo`0406IVIP00
0000410@0<c<c0@0oooo00@0IVIV0000000@4100c<c<1P3oool0102j^[X0EEEE05EEE@2HV9P20?oo
o`0409RHV0000000000009RHV0L0oooo00@0V9RH000000000000V9RH203oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00L0oooo00L0V9RH0000002HV9P0oooo09RHV0000000V9RH00@0
oooo00P0V9RH0000002HV9P0oooo09RHV0000000V9RH0?ooo`80gMgM0`3oool00`27QhL0<S8b0?oo
o`0@0?ooo`0709RHV0000000V9RH0?ooo`2HV9P0000009RHV0040?ooo`0709RHV0000000V9RH0?oo
o`2HV9P0000009RHV0060?ooo`030000003oool0oooo00l0oooo00L0V9RH0000002HV9P0oooo09RH
V0000000V9RH00@0oooo00l0V9RH0000002HV9P0oooo09RHV0000000V9RH0?ooo`2HV9P0000009RH
V03oool0V9RH0000002HV9P04@3oool01`2HV9P0000009RHV03oool0V9RH0000002HV9P0103oool0
3`2HV9P0000009RHV03oool0V9RH0000002HV9P0oooo09RHV0000000V9RH0?ooo`2HV9P0000009RH
V00E0?ooo`0709RHV0000000V9RH0?ooo`2HV9P0000009RHV0070?ooo`030000003oool0oooo00H0
oooo000m0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01`3oool00`000000V9RH
0?ooo`020?ooo`0309RHV0000000oooo00<0oooo00<0000009RHV03oool00P3oool0102HV9P00000
0?ooo`3oool20=gMgAD0oooo00<0000009RHV03oool00P3oool00`2HV9P000000?ooo`030?ooo`03
0000002HV9P0oooo0080oooo00<0V9RH0000003oool01@3oool00`000000oooo0?ooo`0?0?ooo`03
0000002HV9P0oooo0080oooo00<0V9RH0000003oool00`3oool00`000000V9RH0?ooo`020?ooo`05
09RHV0000000oooo0000002HV9P00`3oool00`2HV9P000000?ooo`0@0?ooo`030000002HV9P0oooo
0080oooo00<0V9RH0000003oool00`3oool00`000000V9RH0?ooo`020?ooo`0509RHV0000000oooo
0000002HV9P00`3oool00`2HV9P000000?ooo`0D0?ooo`030000002HV9P0oooo0080oooo00<0V9RH
0000003oool01P3oool00`000000oooo0?ooo`060?ooo`00?@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P3MgMdD0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000L000003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000050?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`0Q8B40k^k^0`3oool00`2j^[X0410@0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`00?@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool20=gMgA<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`1EEED0QhN70`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000@0oooo00<0
V9RH0000003oool0403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool010000000oooo0<c<c01VIVH20?ooo`0309RHV0000000ZJVY01D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
000m0?ooo`8000004`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
QhN70=gMg@3oool04@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`0Q8B40c<c<0080oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool02@000000oooo0000001gMgL0k^k^0?ooo`2HV9P0000009RHV00A0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`050000003oool0
oooo0<c<c00@41000P0000000`2YZJT0oooo0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`00?@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`3MgMd0EEEE0?ooo`0A
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`080000003oool0oooo0>k^kP0Q8B40k^k^0?ooo`00000A0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`050000003oool0A4A407Mg
M`0@41000P0000000`2HV9P0oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`080000003oool0c<c<024Q8@27QhL0k^k^0<c<
c027QhLF0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`00?@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`2j^[X0103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`080000003oool0oooo0?ooo`2j^[X0
<S8b0?ooo`00000A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0^[Zj04A4A1H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`0b<S80ZJVY0`3o
ool00`2j^[X0IVIV0?ooo`0D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`060?ooo`00?@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00<0oooo00<0000009RHV03oool00P3oool00`2HV9P000000?ooo`030?ooo`030000002HV9P0
oooo0080oooo00D0V9RH0000003oool0000009RHV0020?ooo`0309RHV0000000oooo0140oooo00<0
000009RHV03oool00P3oool00`2HV9P000000?ooo`030?ooo`030000002HV9P0oooo0080oooo00<0
V9RH0000003oool00`3oool00`27QhL0MgMg0000000A0?ooo`030000002HV9P0oooo0080oooo00<0
V9RH0000003oool00`3oool00`000000V9RH0?ooo`020?ooo`0609RHV0000000oooo0?ooo`1EEED0
QhN75@3oool00`000000V9RH0?ooo`020?ooo`0309RHV0000000oooo00<0oooo00<0000009RHV03o
ool00P3oool01@2HV9P000000?ooo`000000V9RH00<0oooo00<0V9RH0000003oool0503oool00`00
0000V9RH0?ooo`020?ooo`0309RHV0000000oooo00H0oooo00<000000?ooo`3oool01P3oool003d0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`030?ooo`0709RHV0000000V9RH0?oo
o`2HV9P0000009RHV0040?ooo`0:09RHV0000000V9RH0?ooo`2HV9P0000009RHV03oool0V9RH0000
0080V9RH00<0000009RHV03oool04@3oool01`2HV9P0000009RHV03oool0V9RH0000002HV9P0103o
ool01`2HV9P0000009RHV03oool0V9RH0000002HV9P01@3oool00`1EEED000000?ooo`0@0?ooo`07
09RHV0000000V9RH0?ooo`2HV9P0000009RHV0040?ooo`0709RHV0000000V9RH0?ooo`2HV9P00000
09RHV0030?ooo`80IVIV00<0gMgM0?ooo`3oool04@3oool01`2HV9P0000009RHV03oool0V9RH0000
002HV9P0103oool03`2HV9P0000009RHV03oool0V9RH0000002HV9P0oooo09RHV0000000V9RH0?oo
o`2HV9P0000009RHV00E0?ooo`0709RHV0000000V9RH0?ooo`2HV9P0000009RHV0050?ooo`80<S8b
00<000000?ooo`3oool01P3oool003d0oooo0P00000F0?ooo`030000003oool0oooo00<0oooo00D0
V9RH000000000000000009RHV0060?ooo`0509RHV000000000000000002HV9P00`3oool0102HV9P0
00000000002HV9PD0?ooo`0509RHV000000000000000002HV9P01P3oool01@2HV9P0000000000000
0000V9RH00H0oooo00<0k^k^024Q8@3oool04@3oool01@2HV9P00000000000000000V9RH00H0oooo
00D0V9RH000000000000000009RHV0050?ooo`040;Zj^P1EEED0EEEE09RHV180oooo00D0V9RH0000
00000000000009RHV0060?ooo`0509RHV000000000000000002HV9P00`3oool01@2HV9P000000000
00000000V9RH01L0oooo00D0V9RH000000000000000009RHV0060?ooo`030>k^kP2HV9P0410@00P0
oooo000m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0b03oool003d0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`370?ooo`00?@3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo0<L0oooo000m0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0aP3oool003P0ooooh@0000070?ooo`00?@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`00?@3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool02P3o
ool003d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0
oooo00X0oooo000m0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0]@3oool00`00
0000oooo0?ooo`0;0?ooo`00?@3oool2000001/0oooo00<000000?ooo`3oool0]03oool00`000000
oooo0?ooo`0<0?ooo`00?@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0;80oooo
00<000000?ooo`3oool03@3oool003d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`2b0?ooo`030000003oool0oooo00d0oooo000m0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0/03oool00`000000oooo0?ooo`0>0?ooo`00?@3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0:h0oooo00<000000?ooo`3oool03`3oool003d0oooo0P00000N0?ooo`03
0000003oool0oooo0:d0oooo00<000000?ooo`3oool0403oool003d0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0100oooo000m0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0A0?ooo`00?@3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool04P3oool0
03d0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo
01<0oooo000m0?ooo`8000008@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo01<0
oooo000m0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0Y@3oool00`000000oooo
0?ooo`0D0?ooo`003@3oool01@0Q8B40000000000014A4@0^[Zj00<0oooo00D08B4Q000000000000
A4A40;Zj^P040?ooo`0509RHV000000000000000002HV9P00`3oool5000000<0oooo00@0<S8b0?oo
o`3oool0V9RH0`0000000`2HV9P0oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0Y03oool00`000000oooo0?ooo`0E0?ooo`00403oool00`3^k^h0EEEE0:VYZ@050?oo
o`030>k^kP1EEED0ZJVY0080oooo00L0V9RH0000002HV9P0oooo09RHV0000000V9RH00@0oooo00<0
00000?ooo`3oool01@3oool01`2HV9P0000009RHV03oool0V9RH0000002HV9P01P3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool05P3oool00140oooo
00<0k^k^010@403oool01@3oool01P3^k^h0410@0?ooo`3oool0000009RHV0<0oooo00<0V9RH0000
003oool00`3oool00`000000oooo0?ooo`050?ooo`030000002HV9P0oooo0080oooo00<0V9RH0000
003oool01@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0:00oooo00<000000?oo
o`3oool05`3oool00180oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`0Q8B40k^k^0?ooo`020?oo
o`030;Zj^P0@4100oooo00D0oooo0`00000S0?ooo`030000003oool0oooo09l0oooo00<000000?oo
o`3oool0603oool000<0oooo200000050?ooo`030>k^kP1VIVH0<S8b00D0oooo00<0k^k^06IVIP0b
<S800P3oool00`000000oooo0?ooo`020?ooo`0309RHV0000000oooo00<0oooo00<000000?ooo`3o
ool01@3oool01`3<c<`0IVIV0?ooo`3oool0V9RH0000002YZJT01P3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0603oool000l0oooo00@08B4Q0000
000b<S80k^k^103oool0100Q8B400000038b<P3^k^h20?ooo`070000001gMgL0k^k^0?ooo`2HV9P0
000009RHV0040?ooo`030000003oool0oooo00H0oooo00D0c<c<010@4000000000000:VYZ@070?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0I0?oo
o`00403oool00`1EEED0^[Zj0?ooo`050?ooo`0305EEE@2j^[X0oooo0080oooo00<0A4A407MgM`0@
41000P0000000`2HV9P0oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00H0c<c<024Q8@27
QhL0k^k^0<c<c027QhL70?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0VP3oool0
0`000000oooo0?ooo`0J0?ooo`00403oool00`3^k^h08B4Q0?ooo`050?ooo`030>k^kP0Q8B40oooo
0080oooo00<0^[Zj04A4A03oool0203oool00`000000oooo0?ooo`050?ooo`03038b<P2YZJT0oooo
0080oooo00<0^[Zj06IVIP3oool01@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
09T0oooo00<000000?ooo`3oool06`3oool000d0oooo00D0QhN70?ooo`3oool0oooo000000030?oo
o`0508N7Q`3oool0oooo0?ooo`000000103oool00`1EEED0QhN70?ooo`070?ooo`030000003oool0
oooo00D0oooo00<0000009RHV03oool00P3oool00`2HV9P000000?ooo`050?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0L0?ooo`003@3oool01@1g
MgL0QhN70?ooo`1gMgL08B4Q00<0oooo00D0MgMg08N7Q`3oool0MgMg024Q8@050?ooo`80IVIV00<0
gMgM0?ooo`3oool00P3oool2038b<P030000003oool0oooo00D0oooo00L0V9RH0000002HV9P0oooo
09RHV0000000V9RH00H0oooo0P00000Y0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3o
ool0703oool000h0oooo00@0IVIV0000000@4100c<c<103oool0101VIVH00000010@403<c<`60?oo
o`040;Zj^P1EEED0EEEE09RHV080oooo00<0k^k^09RHV00@4100203oool01@2HV9P0000000000000
0000V9RH00L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`2E0?ooo`030000003o
ool0oooo01d0oooo000m0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0T`3oool0
0`000000oooo0?ooo`0N0?ooo`00?@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
0940oooo00<000000?ooo`3oool07`3oool003d0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`2@0?ooo`030000003oool0oooo0200oooo000m0?ooo`800000;03oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo0240oooo000m0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`0R0?ooo`00?@3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool08`3oool003d0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo02@0oooo000m0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0U0?ooo`00
?@3oool200000300oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0V0?ooo`00?@3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool09`3o
ool000d0oooo00D08B4Q000000000000A4A40;Zj^P030?ooo`05024Q8@000000000004A4A02j^[X0
103oool01@2HV9P00000000000000000V9RH00<0oooo1@0000030?ooo`04038b<P3oool0oooo09RH
V0<0000000<0V9RH0?ooo`3oool01@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
0840oooo00<000000?ooo`3oool0:03oool00100oooo00<0k^k^05EEE@2YZJT01@3oool00`3^k^h0
EEEE0:VYZ@020?ooo`0709RHV0000000V9RH0?ooo`2HV9P0000009RHV0040?ooo`030000003oool0
oooo00D0oooo00L0V9RH0000002HV9P0oooo09RHV0000000V9RH00H0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo000A0?ooo`030>k^kP0@
4100oooo00D0oooo00H0k^k^010@403oool0oooo0000002HV9P30?ooo`0309RHV0000000oooo00<0
oooo00<000000?ooo`3oool01@3oool00`000000V9RH0?ooo`020?ooo`0309RHV0000000oooo00D0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo02X0
oooo000B0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000001@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`<00000<`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo02/0
oooo00030?ooo`P000001@3oool00`3^k^h0IVIV038b<P050?ooo`030>k^kP1VIVH0<S8b0080oooo
00<000000?ooo`3oool00P3oool00`2HV9P000000?ooo`030?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00P3oool00`2HV9P000000?ooo`050?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0/0?ooo`003`3oool0100Q8B400000038b
<P3^k^h40?ooo`04024Q8@000000<S8b0>k^kP80oooo00L0000007MgM`3^k^h0oooo09RHV0000000
V9RH00@0oooo00<000000?ooo`3oool01@3oool01`000000MgMg0>k^kP3oool0V9RH0000002HV9P0
1P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
;@3oool00100oooo00<0EEEE0;Zj^P3oool01@3oool00`1EEED0^[Zj0?ooo`020?ooo`0304A4A01g
MgL0410@0080000000<0V9RH0?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`0304A4A01g
MgL0410@0080000000<0V9RH0?ooo`3oool01@3oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo07D0oooo0P00000`0?ooo`00403oool00`3^k^h08B4Q0?ooo`050?ooo`030>k^kP0Q8B40
oooo0080oooo00<0^[Zj04A4A03oool0203oool00`000000oooo0?ooo`050?ooo`030;Zj^P14A4@0
oooo00X0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0
oooo0300oooo000=0?ooo`0508N7Q`3oool0oooo0?ooo`0000000`3oool01@27QhL0oooo0?ooo`3o
ool0000000@0oooo00<0EEEE08N7Q`3oool01`3oool00`000000oooo0?ooo`060?ooo`0305EEE@27
QhL0oooo00T0oooo0P00000i0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0<@3o
ool000d0oooo00D0MgMg08N7Q`3oool0MgMg024Q8@030?ooo`0507MgM`27QhL0oooo07MgM`0Q8B40
1@3oool206IVIP030=gMg@3oool0oooo0080oooo0P0b<S800`000000oooo0?ooo`070?ooo`80IVIV
00<0gMgM0?ooo`3oool01P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo06l0oooo
00<000000?ooo`3oool0<P3oool000h0oooo00@0IVIV0000000@4100c<c<103oool0101VIVH00000
010@403<c<`60?ooo`040;Zj^P1EEED0EEEE09RHV080oooo00<0k^k^09RHV00@41002P3oool0102j
^[X0EEEE05EEE@2HV9P60?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0K@3oool0
0`000000oooo0?ooo`0c0?ooo`00?@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
06/0oooo00<000000?ooo`3oool0=03oool003d0oooo00<000000?ooo`3oool0?03oool2000006X0
oooo00<000000?ooo`3oool0=@3oool003d0oooo0P00000o0?ooo`030000003oool0oooo06H0oooo
00<000000?ooo`3oool0=P3oool003d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`1S0?ooo`800000>@3oool003d0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1Q
0?ooo`030000003oool0oooo03T0oooo000m0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0G`3oool00`000000oooo0?ooo`0j0?ooo`00?@3oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo05`0oooo0P00000m0?ooo`00?@3oool2000004@0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`0m0?ooo`00?@3oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0?P3oool003d0oooo00<000000?ooo`3oool0A@3oool2
000005L0oooo00<000000?ooo`3oool0?`3oool000d0oooo00D08B4Q000000000000A4A40;Zj^P03
0?ooo`05024Q8@000000000004A4A02j^[X0103oool01@2HV9P00000000000000000V9RH00<0oooo
1@0000030?ooo`03038b<P3oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo0580oooo0P0000120?ooo`00403oool00`3^k^h0EEEE0:VY
Z@050?ooo`030>k^kP1EEED0ZJVY0080oooo00L0V9RH0000002HV9P0oooo09RHV0000000V9RH00@0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`120?ooo`004@3oool00`3^k^h0410@
0?ooo`050?ooo`060>k^kP0@4100oooo0?ooo`000000V9RH0`3oool00`2HV9P000000?ooo`030?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`190?oo
o`800000CP3oool2000004D0oooo000B0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo200000050?oo
o`<00000B`3oool00`000000oooo0?ooo`190?ooo`800000A`3oool000<0oooo200000050?ooo`03
0>k^kP1VIVH0<S8b00D0oooo00<0k^k^06IVIP0b<S800P3oool00`000000oooo0?ooo`020?ooo`03
09RHV0000000oooo00<0oooo00<000000?ooo`3oool01@3oool00`1EEED0QhN70?ooo`020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo04L0oooo000?0?ooo`04024Q8@000000<S8b0>k^kP@0oooo00@08B4Q0000000b
<S80k^k^0P3oool01`000000MgMg0>k^kP3oool0V9RH0000002HV9P0103oool00`000000oooo0?oo
o`060?ooo`05024Q8@3<c<`0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`1=0?ooo`800000
A@3oool2000004X0oooo000@0?ooo`0305EEE@2j^[X0oooo00D0oooo00<0EEEE0;Zj^P3oool00P3o
ool00`14A4@0MgMg010@40020000000309RHV03oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool01@3^k^h08B4Q0>k^kP3oool0000000L0oooo00<000000?ooo`3oool0C`3oool200000440oooo
0P00001<0?ooo`00403oool00`3^k^h08B4Q0?ooo`050?ooo`030>k^kP0Q8B40oooo0080oooo00<0
^[Zj04A4A03oool0203oool00`000000oooo0?ooo`070?ooo`040;Zj^P0b<S80oooo000000L0oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0k0?ooo`<00000CP3oool000d0oooo00D0
QhN70?ooo`3oool0oooo000000030?ooo`0508N7Q`3oool0oooo0?ooo`000000103oool00`1EEED0
QhN70?ooo`070?ooo`030000003oool0oooo00P0oooo00<0QhN707MgM`0000001`3oool2000005<0
oooo0P00000i0?ooo`800000D@3oool000d0oooo00D0MgMg08N7Q`3oool0MgMg024Q8@030?ooo`05
07MgM`27QhL0oooo07MgM`0Q8B401@3oool206IVIP030=gMg@3oool0oooo0080oooo0P0b<S800`00
0000oooo0?ooo`090?ooo`0305EEE@000000oooo00H0oooo00<000000?ooo`3oool0E03oool30000
03@0oooo0P00001C0?ooo`003P3oool0101VIVH00000010@403<c<`40?ooo`0406IVIP000000410@
0<c<c0H0oooo00@0^[Zj05EEE@1EEED0V9RH0P3oool00`3^k^h0V9RH010@400;0?ooo`030>k^kP0Q
8B40oooo00H0oooo00<000000?ooo`3oool0E`3oool200000300oooo0P00001E0?ooo`00?@3oool0
0`000000oooo0?ooo`1I0?ooo`800000:`3oool3000005L0oooo000m0?ooo`030000003oool0oooo
05/0oooo0P00000W0?ooo`800000FP3oool003d0oooo0P00001N0?ooo`8000008P3oool3000005`0
oooo000m0?ooo`030000003oool0oooo05l0oooo1000000I0?ooo`D00000G`3oool003d0oooo00<0
00000?ooo`3oool0H`3oool8000000`0oooo1@00001T0?ooo`00?@3oool00`000000oooo0?ooo`1[
0?ooo``00000J@3oool003d0oooo00<000000?ooo`3oool0h03oool003d0oooo0P00003Q0?ooo`00
?@3oool00`000000oooo0?ooo`3P0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0290239, -3362.76, \
0.000469179, 0.00972898}}],

Cell[BoxData[
    \({3361.2698531217516`, {pn \[Rule] 0.053705050736184694`}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(homs = \(ngt\[LeftDoubleBracket]1\[RightDoubleBracket]*
            Extract[gt\[LeftDoubleBracket]1\[RightDoubleBracket], #] &\) /@ 
        Position[
          dt\[LeftDoubleBracket]1\[RightDoubleBracket], {{a_, 
              a_}}]\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 0, 36, 290}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ngt\[LeftDoubleBracket]1\[RightDoubleBracket]*
      gt\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 2, 10, 0, 0, 0, 36, 148, 
      290}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(Clear[pn]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pn = 0.001; 
    p0 = pt\[LeftDoubleBracket]1\[RightDoubleBracket] \((1 - pn)\) // 
        N\)], "Input"],

Cell[BoxData[
    \({0.`, 0.0020471311475409835`, 0.012282786885245901`, 0.`, 
      0.22723155737704917`, 0.7574385245901639`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[IndentingNewLine]\(p0 = \((1 - 
              pn\^2)\) \((pt\[LeftDoubleBracket]1\[RightDoubleBracket] - \
\(2\/ngt\[LeftDoubleBracket]1\[RightDoubleBracket]\) homs*
                pn\/\(p0 + 2  pn\))\);\)\), "\[IndentingNewLine]", 
    \(pn = \(\((1 - 
            pn\^2)\) \((\(2\/ngt\[LeftDoubleBracket]1\[RightDoubleBracket]\) 
              homs . \(pn\/\(p0 + 2  pn\)\) + 
            pn\^2\/\(1 - pn\^2\))\)\(\[IndentingNewLine]\)\)\)}], "Input"],

Cell[BoxData[
    \(0.0022124723250903137`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[Plus @@ xx]\)], "Input"],

Cell[BoxData[
    \(\(-3254.0541703280137`\) + 
      81\ Log[\(\(\(1.`\)\(\[InvisibleSpace]\)\) - 1.`\ pn\)\/\(1 + pn\)] + 
      18\ Log[\(\(\(0.1283236994219653`\)\(\[InvisibleSpace]\)\) + 1.`\ \
pn\)\/\(1 + pn\)] + 
      145\ Log[\(\(\(0.6105610561056105`\)\(\[InvisibleSpace]\)\) + 1.`\ pn\)\
\/\(1 + pn\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[%, pn] // Simplify\)], "Input"],

Cell[BoxData[
    \(\(234.1588202750911`\ \((\(-0.05371939251722853`\) + pn)\)\ \
\((\(\(0.3286036977922718`\)\(\[InvisibleSpace]\)\) + pn)\)\)\/\(\((\(-1.`\) \
+ pn)\)\ \((\(\(0.1283236994219653`\)\(\[InvisibleSpace]\)\) + pn)\)\ \
\((\(\(0.6105610561056105`\)\(\[InvisibleSpace]\)\) + pn)\)\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) + pn)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[% \[Equal] 0, pn]\)], "Input"],

Cell[BoxData[
    \({{pn \[Rule] \(-0.3286036977922718`\)}, {pn \[Rule] 
          0.05371939251722852`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[\((\(-1.`\) + 
              pn)\)\ \((\(\(0.1283236994219653`\)\(\[InvisibleSpace]\)\) + 
              pn)\)\ \((\(\(0.6105610561056105`\)\(\[InvisibleSpace]\)\) + 
              pn)\)\ \((\(\(1.`\)\(\[InvisibleSpace]\)\) + pn)\) - 
        234.1588202750911`\ \((\(-0.05371939251722853`\) + 
              pn)\)\ \((\(\(0.3286036977922718`\)\(\[InvisibleSpace]\)\) + 
              pn)\)]\)], "Input"],

Cell[BoxData[
    \(1.`\ \((\(-15.106633241758784`\) + 
          pn)\)\ \((\(-0.052380233080612446`\) + 
          pn)\)\ \((\(\(0.329165763149564`\)\(\[InvisibleSpace]\)\) + 
          pn)\)\ \((\(\(15.568732467217409`\)\(\[InvisibleSpace]\)\) + 
          pn)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(234.1588202750911`\ \((\(-0.05371939251722853`\) + pn)\)\ \
\((\(\(0.3286036977922718`\)\(\[InvisibleSpace]\)\) + pn)\)\)\/\(\((\(-1.`\) \
+ pn)\)\ \((\(\(0.1283236994219653`\)\(\[InvisibleSpace]\)\) + pn)\)\ \
\((\(\(0.6105610561056105`\)\(\[InvisibleSpace]\)\) + pn)\)\ \((\(\(1.`\)\(\
\[InvisibleSpace]\)\) + pn)\)\) /. pn -> 15.106633241758784`\)], "Input"],

Cell[BoxData[
    \(0.9999999999999998`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[IndentingNewLine]\(p0 = \((1 - 
              pn\^2)\) \((pt\[LeftDoubleBracket]1\[RightDoubleBracket] - \
\(2\/ngt\[LeftDoubleBracket]1\[RightDoubleBracket]\) homs*
                pn\/\(p0 + 2  pn\))\);\)\), "\[IndentingNewLine]", 
    \(pn = \(\((1 - 
            pn\^2)\) \((\(2\/ngt\[LeftDoubleBracket]1\[RightDoubleBracket]\) 
              homs . \(pn\/\(p0 + 2  pn\)\) + 
            pn\^2\/\(1 - pn\^2\))\)\(\[IndentingNewLine]\)\)\)}], "Input"],

Cell[BoxData[
    \(0.9883201020526757`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`p\_\[Alpha] = \((1 - 
              p\_\[Nu]\%2)\) \((\(p\&~\)\_\[Alpha] - \(n\_\(\[Alpha], \
\[Alpha]\)\/\((N - n\_\[EmptySet])\)\) 
                p\_\[Nu]\/\(p\_\[Alpha] + 2  p\_\[Nu]\))\)\)]],
  "   and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(p\_\[Nu]\), "=", 
          RowBox[{\((1 - p\_\[Nu]\%2)\), 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox[\(\[Sum]\_\[Alpha]\),
                    
                    "TraditionalForm"], \(\(n\_\(\[Alpha], \[Alpha]\)\/\((N - 
                            n\_\[EmptySet])\)\) 
                    p\_\[Nu]\/\(p\_\[Alpha] + 2  p\_\[Nu]\)\)}], 
                "+", \(p\_\[Nu]\%2\/\(1 - p\_\[Nu]\%2\)\)}], ")"}]}]}], 
        TraditionalForm]]]
}], "InlineFormula"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Plot[{\((1 - 
                  pn\^2)\) \((\(2\/ngt\[LeftDoubleBracket]1\
\[RightDoubleBracket]\) homs . \(pn\/\(p0 + 2  pn\)\) + 
                  pn\^2\/\(1 - pn\^2\))\) - pn}, {pn, 0.9, 
          1}];\)\(\[IndentingNewLine]\)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-8.54762 9.52381 0.024639 306.245 [
[.02381 .01214 -12 -18 ]
[.02381 .01214 12 0 ]
[.21429 .01214 -16 -18 ]
[.21429 .01214 16 0 ]
[.40476 .01214 -16 -18 ]
[.40476 .01214 16 0 ]
[.59524 .01214 -16 -18 ]
[.59524 .01214 16 0 ]
[.78571 .01214 -16 -18 ]
[.78571 .01214 16 0 ]
[.96369 .17776 -48 -9 ]
[.96369 .17776 0 9 ]
[.96369 .33088 -40 -9 ]
[.96369 .33088 0 9 ]
[.96369 .48401 -48 -9 ]
[.96369 .48401 0 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .02464 m
.02381 .03089 L
s
gsave
.02381 .01214 -73 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
1.000 setlinewidth
grestore
.21429 .02464 m
.21429 .03089 L
s
gsave
.21429 .01214 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.92) show
1.000 setlinewidth
grestore
.40476 .02464 m
.40476 .03089 L
s
gsave
.40476 .01214 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.94) show
1.000 setlinewidth
grestore
.59524 .02464 m
.59524 .03089 L
s
gsave
.59524 .01214 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.96) show
1.000 setlinewidth
grestore
.78571 .02464 m
.78571 .03089 L
s
gsave
.78571 .01214 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.98) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .02464 m
.07143 .02839 L
s
.11905 .02464 m
.11905 .02839 L
s
.16667 .02464 m
.16667 .02839 L
s
.2619 .02464 m
.2619 .02839 L
s
.30952 .02464 m
.30952 .02839 L
s
.35714 .02464 m
.35714 .02839 L
s
.45238 .02464 m
.45238 .02839 L
s
.5 .02464 m
.5 .02839 L
s
.54762 .02464 m
.54762 .02839 L
s
.64286 .02464 m
.64286 .02839 L
s
.69048 .02464 m
.69048 .02839 L
s
.7381 .02464 m
.7381 .02839 L
s
.83333 .02464 m
.83333 .02839 L
s
.88095 .02464 m
.88095 .02839 L
s
.92857 .02464 m
.92857 .02839 L
s
.25 Mabswid
0 .02464 m
1 .02464 L
s
.97619 .17776 m
.98244 .17776 L
s
gsave
.96369 .17776 -109 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0005) show
1.000 setlinewidth
grestore
.97619 .33088 m
.98244 .33088 L
s
gsave
.96369 .33088 -101 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
1.000 setlinewidth
grestore
.97619 .48401 m
.98244 .48401 L
s
gsave
.96369 .48401 -109 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0015) show
1.000 setlinewidth
grestore
.125 Mabswid
.97619 .05526 m
.97994 .05526 L
s
.97619 .08589 m
.97994 .08589 L
s
.97619 .11651 m
.97994 .11651 L
s
.97619 .14714 m
.97994 .14714 L
s
.97619 .20839 m
.97994 .20839 L
s
.97619 .23901 m
.97994 .23901 L
s
.97619 .26964 m
.97994 .26964 L
s
.97619 .30026 m
.97994 .30026 L
s
.97619 .36151 m
.97994 .36151 L
s
.97619 .39213 m
.97994 .39213 L
s
.97619 .42276 m
.97994 .42276 L
s
.97619 .45338 m
.97994 .45338 L
s
.97619 .51463 m
.97994 .51463 L
s
.97619 .54526 m
.97994 .54526 L
s
.97619 .57588 m
.97994 .57588 L
s
.97619 .60651 m
.97994 .60651 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .55129 L
.10458 .49723 L
.14415 .44901 L
.18221 .40497 L
.22272 .36063 L
.26171 .32043 L
.30316 .28038 L
.34309 .2444 L
.3815 .21223 L
.42237 .18062 L
.46172 .15277 L
.49955 .12837 L
.53984 .10497 L
.57861 .08498 L
.61984 .06644 L
.65954 .05125 L
.69774 .03911 L
.73838 .02887 L
.77751 .02162 L
.79892 .01874 L
.80873 .01768 L
.81909 .01673 L
.82867 .01602 L
.83917 .01542 L
.84378 .01521 L
.84873 .01503 L
.85339 .0149 L
.85765 .01481 L
.85993 .01477 L
.86245 .01474 L
.86372 .01473 L
.86438 .01473 L
.86509 .01472 L
.86638 .01472 L
.86756 .01472 L
.86866 .01472 L
.86983 .01472 L
.87093 .01472 L
.87194 .01473 L
.87312 .01474 L
.8744 .01475 L
.87673 .01478 L
.87923 .01482 L
.88198 .01488 L
.88753 .01504 L
.89268 .01523 L
.89749 .01545 L
.9079 .01606 L
.91778 .01681 L
Mistroke
.93631 .01867 L
.95616 .0213 L
.97456 .02434 L
.97619 .02464 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00303oool01@2HV9P00000000000000000V9RH00<0oooo00H0<S8b0?ooo`0b<S808B4Q06IV
IP3MgMdP0?ooo`0509RHV000000000000000002HV9P00`3oool01P0b<S80oooo038b<P0Q8B40IVIV
0=gMg@@0oooo00<0410@0000000000000`0000000`2j^[X0oooo0?ooo`0G0?ooo`0509RHV0000000
00000000002HV9P00`3oool01P0b<S80oooo038b<P0Q8B40IVIV0=gMg@T0oooo00<000000?ooo`3o
ool0603oool01@2HV9P00000000000000000V9RH00<0oooo00H0<S8b0?ooo`0b<S808B4Q06IVIP3M
gMd50?ooo`0509RHV000000000000000002HV9P06P3oool01@2HV9P00000000000000000V9RH00<0
oooo00H0<S8b0?ooo`0b<S808B4Q06IVIP3MgMd50?ooo`0509RHV000000000000000002HV9P0>03o
ool000/0oooo00L0V9RH0000002HV9P0oooo09RHV0000000V9RH00D0oooo00@0^[Zj07MgM`000000
MgMg7P3oool01`2HV9P0000009RHV03oool0V9RH0000002HV9P01@3oool0102j^[X0MgMg0000001g
MgL30?ooo`80gMgM0`3oool00`27QhL0<S8b0?ooo`0G0?ooo`0709RHV0000000V9RH0?ooo`2HV9P0
000009RHV0050?ooo`040;Zj^P1gMgL0000007MgM`P0oooo00<000000?ooo`3oool05`3oool01`2H
V9P0000009RHV03oool0V9RH0000002HV9P01@3oool0102j^[X0MgMg0000001gMgL30?ooo`0709RH
V0000000V9RH0?ooo`2HV9P0000009RHV00H0?ooo`0709RHV0000000V9RH0?ooo`2HV9P0000009RH
V0050?ooo`040;Zj^P1gMgL0000007MgM`<0oooo00L0V9RH0000002HV9P0oooo09RHV0000000V9RH
03L0oooo000;0?ooo`030000002HV9P0oooo0080oooo00<0V9RH0000003oool01P3oool00`3MgMd0
8B4Q06IVIP0M0?ooo`030000002HV9P0oooo0080oooo00<0V9RH0000003oool01P3oool00`3MgMd0
8B4Q06IVIP030?ooo`80gMgM703oool00`000000V9RH0?ooo`020?ooo`0309RHV0000000oooo00H0
oooo00<0gMgM024Q8@1VIVH01`3oool00`000000oooo0?ooo`0G0?ooo`030000002HV9P0oooo0080
oooo00<0V9RH0000003oool01P3oool00`3MgMd08B4Q06IVIP020?ooo`030000002HV9P0oooo0080
oooo00<0V9RH0000003oool05`3oool00`000000V9RH0?ooo`020?ooo`0309RHV0000000oooo00H0
oooo00<0gMgM024Q8@1VIVH00P3oool00`000000V9RH0?ooo`020?ooo`0309RHV0000000oooo03H0
oooo000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`3^k^h00000
0;Zj^P0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`3^k^h00000
0;Zj^P030?ooo`80gMgM6`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo
00@0k^k^0000002j^[X0oooo2000000G0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01P3oool01@3^k^h000000;Zj^P3oool0000000D0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00H0k^k^0000002j^[X0oooo024Q8@3^
k^h30?ooo`030;Zj^P0@4100oooo03H0oooo000;0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool01P2HV9P0000000000014A4@0IVIV05EEEA`0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`0609RHV0000000000004A4A01VIVH0EEEE103oool20=gM
gAX0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`0909RHV00000000000
04A4A01VIVH0EEEE0?ooo`1EEED0QhN700<0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00P0V9RH000000000000A4A406IVIP1EEED0oooo
000000@0oooo00<0V9RH0000003oool05`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00T0V9RH000000000000A4A406IVIP1EEED0oooo0<c<c01VIVH00P3oool00`2HV9P0
00000:VYZ@0g0?ooo`002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00L0V9RH0000002HV9P0oooo0>k^kP2HV9P0410@01`0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`0709RHV0000000V9RH0?ooo`3^k^h0V9RH010@40050?ooo`0308N7Q`3M
gMd0oooo01P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`0709RHV000
0000V9RH0?ooo`3^k^h0V9RH010@40020?ooo`05024Q8@3<c<`0oooo0?ooo`0000006@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00l0V9RH0000002HV9P0oooo0>k^kP2H
V9P0410@0?ooo`000000MgMg0>k^kP3oool0V9RH0000002HV9P0603oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00L0V9RH0000002HV9P0oooo0>k^kP2HV9P0410@0080oooo
00D0c<c<010@4000000000000:VYZ@0h0?ooo`002`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00<0000009RHV03oool00`3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000V9RH0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<0gMgM05EEE@3oool0603oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00<0000009RHV03oool00`3oool020000000oooo0?ooo`3^k^h08B4Q0>k^
kP3oool000006@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
09RHV03oool00`3oool01@000000oooo04A4A01gMgL0410@0080000000<0V9RH0?ooo`3oool05`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0000009RHV03oool00`3o
ool020000000oooo0<c<c00Q8B40QhN70>k^kP3<c<`0QhN7>03oool000/0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0;Zj^P040?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00P000000?ooo`3o
ool0oooo0;Zj^P0b<S80oooo000001T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`2j^[X0A4A47@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool010000000oooo
038b<P2YZJT30?ooo`030;Zj^P1VIVH0oooo03H0oooo000;0?ooo`030000002HV9P0oooo0080oooo
00<0V9RH0000003oool00`3oool00`000000V9RH0?ooo`020?ooo`0309RHV0000000oooo01/0oooo
00<0000009RHV03oool00P3oool00`2HV9P000000?ooo`030?ooo`030000002HV9P0oooo0080oooo
00D0V9RH0000003oool0000009RHV0020?ooo`0309RHV0000000oooo01P0oooo00<0000009RHV03o
ool00P3oool00`2HV9P000000?ooo`030?ooo`030000002HV9P0oooo0080oooo00<0V9RH0000003o
ool00`3oool00`27QhL0MgMg0000000I0?ooo`030000002HV9P0oooo0080oooo00<0V9RH0000003o
ool00`3oool00`000000V9RH0?ooo`020?ooo`0609RHV0000000oooo0?ooo`1EEED0QhN7703oool0
0`000000V9RH0?ooo`020?ooo`0309RHV0000000oooo00<0oooo00<0000009RHV03oool00P3oool0
1@2HV9P000000?ooo`000000V9RH00<0oooo00<0V9RH0000003oool09@3oool00`000000oooo0?oo
o`0>0?ooo`002`3oool01`2HV9P0000009RHV03oool0V9RH0000002HV9P0103oool01`2HV9P00000
09RHV03oool0V9RH0000002HV9P0703oool01`2HV9P0000009RHV03oool0V9RH0000002HV9P0103o
ool02P2HV9P0000009RHV03oool0V9RH0000002HV9P0oooo09RHV000000209RHV0030000002HV9P0
oooo01P0oooo00L0V9RH0000002HV9P0oooo09RHV0000000V9RH00@0oooo00L0V9RH0000002HV9P0
oooo09RHV0000000V9RH00D0oooo00<0EEEE0000003oool0603oool01`2HV9P0000009RHV03oool0
V9RH0000002HV9P0103oool01`2HV9P0000009RHV03oool0V9RH0000002HV9P00`3oool206IVIP03
0=gMg@3oool0oooo01P0oooo00L0V9RH0000002HV9P0oooo09RHV0000000V9RH00@0oooo00l0V9RH
0000002HV9P0oooo09RHV0000000V9RH0?ooo`2HV9P0000009RHV03oool0V9RH0000002HV9P09P3o
ool00`000000oooo0?ooo`0>0?ooo`00303oool01@2HV9P00000000000000000V9RH00H0oooo00D0
V9RH000000000000000009RHV00N0?ooo`0509RHV000000000000000002HV9P01P3oool01@2HV9P0
0000000000000000V9RH00<0oooo00@0V9RH000000000000V9RH6`3oool01@2HV9P0000000000000
0000V9RH00H0oooo00D0V9RH000000000000000009RHV0060?ooo`030>k^kP0Q8B40oooo01T0oooo
00D0V9RH000000000000000009RHV0060?ooo`0509RHV000000000000000002HV9P01@3oool0102j
^[X0EEEE05EEE@2HV9PI0?ooo`0509RHV000000000000000002HV9P01P3oool01@2HV9P000000000
00000000V9RH00<0oooo00D0V9RH000000000000000009RHV00W0?ooo`030000003oool0oooo00h0
oooo003o0?oooa00oooo00<000000?ooo`3oool03P3oool00>X0oooo4`00000B0?ooo`030000003o
ool0oooo00h0oooo003N0?ooo``000004`3oool;000000L0oooo00<000000?ooo`3oool03P3oool0
0=P0oooo1P00000Z0?ooo`D000000P3oool00`000000oooo0?ooo`0>0?ooo`003`3ooooo000000P0
00002P3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00L0oooo1@00000:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
3P3oool00</0oooo0`0000110?ooo`030000003oool0oooo00h0oooo00380?ooo`<00000A03oool0
0`000000oooo0?ooo`0>0?ooo`00a03oool4000004L0oooo00<000000?ooo`3oool03P3oool00<40
oooo0`00001;0?ooo`030000003oool0oooo00h0oooo002n0?ooo`<00000CP3oool00`000000oooo
0?ooo`0>0?ooo`00^`3oool300000540oooo00<000000?ooo`3oool03P3oool00;P0oooo0`00001D
0?ooo`8000003`3oool00;D0oooo0`00001G0?ooo`030000003oool0oooo00h0oooo002b0?ooo`<0
0000FP3oool00`000000oooo0?ooo`0>0?ooo`00/03oool2000005d0oooo00<000000?ooo`3oool0
3P3oool00:h0oooo0P00001O0?ooo`030000003oool0oooo00h0oooo002[0?ooo`<00000H@3oool0
0`000000oooo0?ooo`0>0?ooo`00Z@3oool2000006@0oooo00<000000?ooo`3oool03P3oool00:L0
oooo0P00001V0?ooo`030000003oool0oooo00h0oooo002U0?ooo`800000J03oool2000000l0oooo
002S0?ooo`800000JP3oool00`000000oooo0?ooo`0>0?ooo`00X@3oool2000006`0oooo00<00000
0?ooo`3oool03P3oool009l0oooo0P00001^0?ooo`030000003oool0oooo00h0oooo002M0?ooo`80
0000L03oool00`000000oooo0?ooo`0>0?ooo`00V`3oool200000780oooo00<000000?ooo`3oool0
3P3oool009T0oooo0P00001d0?ooo`030000003oool0oooo00h0oooo002H0?ooo`030000003oool0
oooo07@0oooo00<000000?ooo`3oool03P3oool009H0oooo0P00001g0?ooo`8000003`3oool009@0
oooo0P00001i0?ooo`030000003oool0oooo00h0oooo002C0?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool03P3oool00940oooo0P00001l0?ooo`030000003oool0oooo00h0oooo002?
0?ooo`800000OP3oool00`000000oooo0?ooo`0>0?ooo`00SP3oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo00h0oooo002<0?ooo`800000P@3oool00`000000oooo0?ooo`0>0?ooo`00
RP3oool2000008<0oooo00<000000?ooo`3oool03P3oool008T0oooo00<000000?ooo`3oool0P`3o
ool2000000l0oooo00270?ooo`800000QP3oool00`000000oooo0?ooo`0>0?ooo`00QP3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo00h0oooo00250?ooo`030000003oool0oooo08L0
oooo00<000000?ooo`3oool03P3oool008@0oooo00<000000?ooo`3oool0R03oool00`000000oooo
0?ooo`0>0?ooo`00PP3oool2000005/0oooo00D0V9RH000000000000000009RHV0030?ooo`04038b
<P3oool0oooo09RHV0<0000000D0V9RH0?ooo`3oool0oooo09RHV0030000000509RHV03oool0oooo
0?ooo`2HV9P00`000000102HV9P0oooo0?ooo`14A4@40000000309RHV03oool0oooo00H0oooo00<0
00000?ooo`3oool03P3oool00840oooo00<000000?ooo`3oool0FP3oool01`2HV9P0000009RHV03o
ool0V9RH0000002HV9P0103oool05`2HV9P0000009RHV03oool0V9RH0000002HV9P0oooo09RHV000
0000V9RH0?ooo`2HV9P0000009RHV03oool0V9RH0000002HV9P0oooo09RHV0000000V9RH00D0oooo
00<0V9RH0000002HV9P01`3oool00`000000oooo0?ooo`0>0?ooo`00P03oool00`000000oooo0?oo
o`1K0?ooo`030000002HV9P0oooo0080oooo00<0V9RH0000003oool00`3oool00`000000V9RH0?oo
o`020?ooo`0509RHV0000000oooo0000002HV9P00`3oool01@2HV9P000000?ooo`000000V9RH00<0
oooo00<0V9RH0000003oool01@3oool00`2HV9P000000?ooo`060?ooo`030000003oool0oooo00h0
oooo001o0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001@3oool00`000000oooo
000000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool2000000l0oooo
001m0?ooo`800000G`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000050?ooo`030000003oool0000000D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo001l
0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001@3oool00`000000oooo00000005
0?ooo`030000003oool0oooo00@0oooo00<0V9RH0000003oool01P3oool00`000000oooo0?ooo`0>
0?ooo`00N`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000D0oooo00<000000?oo
o`0000001@3oool00`000000oooo0?ooo`030?ooo`0309RHV0000000V9RH00L0oooo00<000000?oo
o`3oool03P3oool007T0oooo0P00001S0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000D0oooo00<000000?ooo`00
00001@3oool00`000000oooo0;Zj^P040000000309RHV03oool0oooo00H0oooo00<000000?ooo`3o
ool03P3oool007P0oooo00<000000?ooo`3oool0H`3oool00`000000V9RH0?ooo`020?ooo`0309RH
V0000000oooo00<0oooo00<0000009RHV03oool00P3oool01@2HV9P000000?ooo`000000V9RH00<0
oooo00D0V9RH0000003oool0000009RHV0030?ooo`0609RHV0000000oooo0?ooo`0@4100gMgM2`3o
ool00`000000oooo0?ooo`0>0?ooo`00MP3oool2000006H0oooo00L0V9RH0000002HV9P0oooo09RH
V0000000V9RH00@0oooo01L0V9RH0000002HV9P0oooo09RHV0000000V9RH0?ooo`2HV9P0000009RH
V03oool0V9RH0000002HV9P0oooo09RHV0000000V9RH0?ooo`2HV9P0000009RHV0020?ooo`0308N7
Q`1VIVH0oooo00X0oooo00<000000?ooo`3oool03P3oool007D0oooo00<000000?ooo`3oool0I`3o
ool01@2HV9P00000000000000000V9RH00H0oooo00D0V9RH000000000000000009RHV0030?ooo`05
09RHV000000000000000002HV9P00`3oool01@2HV9P00000000000000000V9RH00<0oooo00<0gMgM
0000000000000P0000000`0b<S80oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo001d0?oo
o`030000003oool0oooo09P0oooo0P00000?0?ooo`00LP3oool2000009/0oooo00<000000?ooo`3o
ool03P3oool00740oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0>0?ooo`00L03o
ool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo00h0oooo001_0?ooo`030000003oool0
oooo09d0oooo00<000000?ooo`3oool03P3oool006d0oooo0P00002P0?ooo`030000003oool0oooo
00h0oooo001/0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool03P3oool006/0oooo
00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0>0?ooo`00JP3oool00`000000oooo0?oo
o`2R0?ooo`8000003`3oool006P0oooo0P00002U0?ooo`030000003oool0oooo00h0oooo001W0?oo
o`030000003oool0oooo0:D0oooo00<000000?ooo`3oool03P3oool006H0oooo00<000000?ooo`3o
ool0YP3oool00`000000oooo0?ooo`0>0?ooo`00I@3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo00h0oooo001T0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool03P3o
ool006<0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0>0?ooo`00HP3oool00`00
0000oooo0?ooo`2Z0?ooo`030000003oool0oooo00h0oooo001Q0?ooo`030000003oool0oooo0:/0
oooo0P00000?0?ooo`00H03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo00h0oooo
001O0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool03P3oool005d0oooo0P00002`
0?ooo`030000003oool0oooo00h0oooo001L0?ooo`030000003oool0oooo0;00oooo00<000000?oo
o`3oool03P3oool005/0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0>0?ooo`00
FP3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo00h0oooo001I0?ooo`030000003o
ool0oooo0;<0oooo00<000000?ooo`3oool03P3oool005P0oooo00<000000?ooo`3oool0]03oool2
000000l0oooo001G0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool03P3oool005H0
oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0>0?ooo`00E@3oool00`000000oooo
0?ooo`2g0?ooo`030000003oool0oooo00h0oooo001D0?ooo`030000003oool0oooo0;P0oooo00<0
00000?ooo`3oool03P3oool005<0oooo00<000000?ooo`3oool0T@3oool01@2HV9P0000000000000
0000V9RH00<0oooo00@0<S8b0?ooo`3oool0V9RH0`0000001@2HV9P0oooo0?ooo`3oool0V9RH00<0
000000@0V9RH0?ooo`3oool0oooo1@0000080?ooo`030000003oool0oooo00h0oooo001C0?ooo`03
0000003oool0oooo0900oooo00L0V9RH0000002HV9P0oooo09RHV0000000V9RH00@0oooo00l0V9RH
0000002HV9P0oooo09RHV0000000V9RH0?ooo`2HV9P0000009RHV03oool0V9RH0000002HV9P0103o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo001B0?ooo`030000003oool0
oooo0940oooo00<0000009RHV03oool00P3oool00`2HV9P000000?ooo`030?ooo`030000002HV9P0
oooo0080oooo00D0V9RH0000003oool0000009RHV0030?ooo`0309RHV0000000oooo00<0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`00D@3oool00`000000oooo0?ooo`2B
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08
0?ooo`8000003`3oool00500oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?oo
o`00C`3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo001>0?ooo`030000
003oool0oooo09D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool004d0oooo00<000000?ooo`3oool0UP3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0>0?ooo`00C03oool00`000000oooo0?ooo`2G0?ooo`030000002HV9P0
oooo0080oooo00<0V9RH0000003oool00`3oool00`000000V9RH0?ooo`020?ooo`0509RHV0000000
oooo0000002HV9P00`3oool00`2HV9P000000?ooo`030?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool03P3oool004/0oooo00<000000?ooo`3oool0V03oool01`2HV9P0000009RHV03o
ool0V9RH0000002HV9P0103oool03`2HV9P0000009RHV03oool0V9RH0000002HV9P0oooo09RHV000
0000V9RH0?ooo`2HV9P0000009RHV0020?ooo`80<S8b00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0>0?ooo`00BP3oool00`000000oooo0?ooo`2J0?ooo`0509RHV000000000000000002H
V9P01P3oool01@2HV9P00000000000000000V9RH00<0oooo00D0V9RH000000000000000009RHV003
0?ooo`030>k^kP2HV9P0410@00X0oooo00<000000?ooo`3oool03P3oool004T0oooo00<000000?oo
o`3oool0``3oool2000000l0oooo00190?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3o
ool03P3oool004P0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0>0?ooo`00A`3o
ool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00160?ooo`030000003oool0
oooo0<H0oooo00<000000?ooo`3oool03P3oool004D0oooo00<000000?ooo`3oool0a`3oool00`00
0000oooo0?ooo`0>0?ooo`00A03oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00h0
oooo00140?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool03P3oool004<0oooo00<0
00000?ooo`3oool0b@3oool2000000l0oooo00120?ooo`030000003oool0oooo0<X0oooo00<00000
0?ooo`3oool03P3oool00440oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0>0?oo
o`00@03oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00h0oooo000o0?ooo`030000
003oool0oooo0<d0oooo00<000000?ooo`3oool03P3oool003l0oooo00<000000?ooo`3oool0c@3o
ool00`000000oooo0?ooo`0>0?ooo`00?P3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0
oooo00h0oooo000m0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool03P3oool003`0
oooo00<000000?ooo`3oool0d03oool2000000l0oooo000k0?ooo`030000003oool0oooo0=40oooo
00<000000?ooo`3oool03P3oool003X0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?oo
o`0>0?ooo`00>@3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00h0oooo000h0?oo
o`030000003oool0oooo0=@0oooo00<000000?ooo`3oool03P3oool003L0oooo00<000000?ooo`3o
ool0e@3oool00`000000oooo0?ooo`0>0?ooo`00=P3oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo00h0oooo000e0?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool03P3o
ool003D0oooo00<000000?ooo`3oool0e`3oool2000000l0oooo000d0?ooo`030000003oool0oooo
0=P0oooo00<000000?ooo`3oool03P3oool003<0oooo00<000000?ooo`3oool0f@3oool00`000000
oooo0?ooo`0>0?ooo`00<P3oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo00h0oooo
000a0?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3oool03P3oool00300oooo00<00000
0?ooo`3oool0[03oool01@2HV9P00000000000000000V9RH00<0oooo00@0<S8b0?ooo`3oool0V9RH
0`0000001@2HV9P0oooo0?ooo`3oool0V9RH00<0000000@0V9RH0?ooo`3oool0oooo1@0000020?oo
o`0304A4A000000000000080000000<0V9RH0?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?oo
o`00;`3oool00`000000oooo0?ooo`2/0?ooo`0709RHV0000000V9RH0?ooo`2HV9P0000009RHV004
0?ooo`0?09RHV0000000V9RH0?ooo`2HV9P0000009RHV03oool0V9RH0000002HV9P0oooo09RHV000
0000V9RH00@0oooo00<000000?ooo`3oool01P3oool00`2HV9P0000009RHV0070?ooo`030000003o
ool0oooo00h0oooo000_0?ooo`030000003oool0oooo0:`0oooo00<0000009RHV03oool00P3oool0
0`2HV9P000000?ooo`030?ooo`030000002HV9P0oooo0080oooo00D0V9RH0000003oool0000009RH
V0030?ooo`0309RHV0000000oooo00<0oooo00<000000?ooo`3oool01`3oool00`2HV9P000000?oo
o`060?ooo`030000003oool0oooo00h0oooo000^0?ooo`030000003oool0oooo0:d0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01@3oool2000000l0oooo000]0?ooo`030000003oool0oooo0:h0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`00;03oool00`000000oooo0?ooo`2_0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`03
09RHV0000000oooo00H0oooo00<000000?ooo`3oool03P3oool002/0oooo00<000000?ooo`3oool0
/03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`2HV9P0000009RHV0070?ooo`030000003oool0oooo00h0oooo000Z0?ooo`030000003o
ool0oooo0;40oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<0^[Zj0000000000000P0000000`2HV9P0oooo0?ooo`060?ooo`030000003o
ool0oooo00h0oooo000Z0?ooo`030000003oool0oooo0;40oooo00<0000009RHV03oool00P3oool0
0`2HV9P000000?ooo`030?ooo`030000002HV9P0oooo0080oooo00D0V9RH0000003oool0000009RH
V0030?ooo`0309RHV0000000oooo00<0oooo00<000000?ooo`3oool00`3oool00`0@4100gMgM0?oo
o`0:0?ooo`030000003oool0oooo00h0oooo000Y0?ooo`030000003oool0oooo0;80oooo00L0V9RH
0000002HV9P0oooo09RHV0000000V9RH00@0oooo00l0V9RH0000002HV9P0oooo09RHV0000000V9RH
0?ooo`2HV9P0000009RHV03oool0V9RH0000002HV9P00P3oool2038b<P030000003oool0oooo00<0
oooo00<0QhN706IVIP3oool02P3oool00`000000oooo0?ooo`0>0?ooo`00:03oool00`000000oooo
0?ooo`2d0?ooo`0509RHV000000000000000002HV9P01P3oool01@2HV9P00000000000000000V9RH
00<0oooo00D0V9RH000000000000000009RHV0030?ooo`030>k^kP2HV9P0410@00D0oooo00<0gMgM
0000000000000P0000000`0b<S80oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo000W0?oo
o`030000003oool0oooo0>D0oooo0P00000?0?ooo`009P3oool00`000000oooo0?ooo`3V0?ooo`03
0000003oool0oooo00h0oooo000V0?ooo`030000003oool0oooo0>H0oooo00<000000?ooo`3oool0
3P3oool002D0oooo00<000000?ooo`3oool0i`3oool00`000000oooo0?ooo`0>0?ooo`00903oool0
0`000000oooo0?ooo`3X0?ooo`030000003oool0oooo00h0oooo000S0?ooo`030000003oool0oooo
0>T0oooo00<000000?ooo`3oool03P3oool002<0oooo00<000000?ooo`3oool0j@3oool00`000000
oooo0?ooo`0>0?ooo`008P3oool00`000000oooo0?ooo`3Z0?ooo`030000003oool0oooo00h0oooo
000Q0?ooo`030000003oool0oooo0>/0oooo0P00000?0?ooo`00803oool00`000000oooo0?ooo`3/
0?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo0>d0oooo00<000000?oo
o`3oool03P3oool001l0oooo00<000000?ooo`3oool0k@3oool00`000000oooo0?ooo`0>0?ooo`00
7P3oool00`000000oooo0?ooo`3^0?ooo`030000003oool0oooo00h0oooo000M0?ooo`030000003o
ool0oooo0>l0oooo00<000000?ooo`3oool03P3oool001`0oooo00<000000?ooo`3oool0l03oool0
0`000000oooo0?ooo`0>0?ooo`00703oool00`000000oooo0?ooo`3`0?ooo`030000003oool0oooo
00h0oooo000K0?ooo`030000003oool0oooo0?40oooo0P00000?0?ooo`006P3oool00`000000oooo
0?ooo`3b0?ooo`030000003oool0oooo00h0oooo000J0?ooo`030000003oool0oooo0?80oooo00<0
00000?ooo`3oool03P3oool001T0oooo00<000000?ooo`3oool0l`3oool00`000000oooo0?ooo`0>
0?ooo`00603oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo00h0oooo000G0?ooo`03
0000003oool0oooo0?D0oooo00<000000?ooo`3oool03P3oool001L0oooo00<000000?ooo`3oool0
m@3oool00`000000oooo0?ooo`0>0?ooo`005P3oool00`000000oooo0?ooo`3f0?ooo`030000003o
ool0oooo00h0oooo000E0?ooo`030000003oool0oooo0?L0oooo0P00000?0?ooo`00o`3oool@0?oo
o`030000003oool0oooo00h0oooo003o0?oooa00oooo00<000000?ooo`3oool03P3oool00?l0oooo
403oool00`000000oooo0?ooo`0>0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.891409, -0.000264889, \
0.000400277, 1.24481*^-5}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pn = 0.001;\)\), "\[IndentingNewLine]", 
    \(\(\((1 - 
          pn\^2)\) \((\(2\/ngt\[LeftDoubleBracket]1\[RightDoubleBracket]\) 
            homs . \(pn\/\(p0 + 2  pn\)\) + 
          pn\^2\/\(1 - pn\^2\))\)\(\[IndentingNewLine]\)\)\)}], "Input"],

Cell[BoxData[
    \(0.002207436178304767`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pn = %;\)\), "\[IndentingNewLine]", 
    \(\(\((1 - 
          pn\^2)\) \((\(2\/ngt\[LeftDoubleBracket]1\[RightDoubleBracket]\) 
            homs . \(pn\/\(p0 + 2  pn\)\) + 
          pn\^2\/\(1 - pn\^2\))\)\(\[IndentingNewLine]\)\)\)}], "Input"],

Cell[BoxData[
    \(0.22793299214056553`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pn = %;\)\), "\[IndentingNewLine]", 
    \(\(\((1 - 
          pn\^2)\) \((\(2\/ngt\[LeftDoubleBracket]1\[RightDoubleBracket]\) 
            homs . \(pn\/\(p0 + 2  pn\)\) + 
          pn\^2\/\(1 - pn\^2\))\)\(\[IndentingNewLine]\)\)\)}], "Input"],

Cell[BoxData[
    \(0.3287439922811551`\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(pn = %;\)\), "\[IndentingNewLine]", 
    \(\(\((1 - 
          pn\^2)\) \((\(2\/ngt\[LeftDoubleBracket]1\[RightDoubleBracket]\) 
            homs . \(pn\/\(p0 + 2  pn\)\) + 
          pn\^2\/\(1 - pn\^2\))\)\(\[IndentingNewLine]\)\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(td = 
      DeleteCases[\(Transpose[
            Data[s[sika, 
                pol]]]\)\[LeftDoubleBracket]1\[RightDoubleBracket], \
\[EmptySet]]\)], "Input"],

Cell[BoxData[
    \({{277, 277}, {267, 267}, {277, 277}, {267, 267}, {277, 277}, {267, 
        277}, {277, 277}, {277, 277}, {267, 267}, {277, 277}, {277, 
        277}, {277, 277}, {277, 277}, {267, 277}, {277, 277}, {267, 
        267}, {277, 277}, {267, 277}, {277, 277}, {267, 277}, {267, 
        277}, {267, 277}, {267, 277}, {253, 277}, {267, 277}, {277, 
        277}, {277, 277}, {277, 277}, {277, 277}, {277, 277}, {267, 
        267}, {267, 277}, {277, 277}, {277, 277}, {277, 277}, {267, 
        277}, {267, 277}, {267, 277}, {277, 277}, {267, 267}, {267, 
        277}, {267, 277}, {277, 277}, {267, 277}, {277, 277}, {267, 
        277}, {267, 277}, {267, 267}, {277, 277}, {267, 277}, {267, 
        277}, {277, 277}, {267, 277}, {277, 277}, {267, 277}, {267, 
        277}, {277, 277}, {267, 267}, {267, 267}, {277, 277}, {277, 
        277}, {277, 277}, {277, 277}, {277, 277}, {267, 267}, {277, 
        277}, {277, 277}, {267, 277}, {277, 277}, {277, 277}, {277, 
        277}, {277, 277}, {267, 277}, {277, 277}, {267, 277}, {267, 
        277}, {277, 277}, {277, 277}, {267, 277}, {267, 277}, {267, 
        277}, {277, 277}, {277, 277}, {277, 277}, {267, 277}, {277, 
        277}, {267, 277}, {277, 277}, {255, 277}, {277, 277}, {277, 
        277}, {267, 277}, {267, 277}, {277, 277}, {277, 277}, {267, 
        277}, {277, 277}, {267, 277}, {277, 277}, {277, 277}, {267, 
        277}, {277, 277}, {267, 267}, {277, 277}, {277, 277}, {277, 
        277}, {277, 277}, {267, 277}, {267, 267}, {277, 277}, {277, 
        277}, {267, 277}, {267, 277}, {277, 277}, {277, 277}, {277, 
        277}, {267, 277}, {267, 267}, {277, 277}, {267, 277}, {267, 
        277}, {267, 277}, {277, 277}, {277, 277}, {277, 277}, {267, 
        277}, {277, 277}, {277, 277}, {267, 267}, {277, 277}, {277, 
        277}, {277, 277}, {267, 277}, {277, 277}, {267, 267}, {277, 
        277}, {277, 277}, {267, 277}, {267, 267}, {267, 277}, {267, 
        267}, {277, 277}, {267, 277}, {277, 277}, {277, 277}, {277, 
        277}, {277, 277}, {267, 277}, {267, 277}, {267, 277}, {277, 
        277}, {277, 277}, {277, 277}, {277, 277}, {277, 277}, {277, 
        277}, {267, 277}, {277, 277}, {277, 277}, {277, 277}, {267, 
        277}, {277, 277}, {277, 277}, {277, 277}, {267, 277}, {267, 
        277}, {267, 277}, {267, 277}, {277, 277}, {277, 277}, {277, 
        277}, {267, 267}, {267, 277}, {277, 277}, {267, 277}, {277, 
        277}, {277, 277}, {277, 277}, {267, 277}, {267, 277}, {277, 
        277}, {277, 277}, {277, 277}, {277, 277}, {277, 277}, {277, 
        277}, {277, 277}, {277, 277}, {277, 277}, {277, 277}, {277, 
        277}, {277, 277}, {277, 277}, {267, 277}, {277, 277}, {277, 
        277}, {277, 277}, {267, 277}, {277, 277}, {277, 277}, {267, 
        277}, {277, 277}, {277, 277}, {277, 277}, {267, 277}, {277, 
        277}, {267, 277}, {277, 277}, {277, 277}, {277, 277}, {267, 
        277}, {277, 277}, {277, 277}, {277, 277}, {267, 277}, {267, 
        277}, {267, 277}, {277, 277}, {277, 277}, {277, 277}, {267, 
        277}, {277, 277}, {277, 277}, {267, 277}, {267, 277}, {277, 
        277}, {277, 277}, {277, 277}, {277, 277}, {277, 277}, {267, 
        277}, {255, 277}, {255, 277}, {277, 277}, {255, 277}, {255, 
        277}, {277, 277}, {277, 277}, {277, 277}, {277, 277}, {277, 
        277}, {255, 267}, {277, 277}, {277, 277}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(u11 = 
        GenotypeFrequency[1, {267, 267}, {{267, 277, \[Nu]}}, {{p1, p2, pn}}, 
          NullAllele \[Rule] \[Nu]];\)\), "\[IndentingNewLine]", 
    \(\(u12 = 
        GenotypeFrequency[1, {267, 277}, {{267, 277, \[Nu]}}, {{p1, p2, pn}}, 
          NullAllele \[Rule] \[Nu]];\)\), "\[IndentingNewLine]", 
    \(\(u22 = 
        GenotypeFrequency[1, {277, 277}, {{267, 277, \[Nu]}}, {{p1, p2, pn}}, 
          NullAllele \[Rule] \[Nu]];\)\), "\[IndentingNewLine]", 
    \(u11 + u12 + u22 /. pn -> 1 - p1 - p2 // Simplify\)}], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(gt[\([1]\)] ngt[\([1]\)]\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 2, 10, 0, 0, 0, 36, 148, 
      290}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
        36\ Log[u11] + 148  Log[u12] + 
            290  Log[u22] /. {p1 \[Rule] 0.25 \((1 - pn)\), 
            p2 \[Rule] 0.75 \((1 - pn)\)}, {pn, 0, 0.1}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 9.52381 142.457 0.347437 [
[.21429 -0.00493 -16 -18 ]
[.21429 -0.00493 16 0 ]
[.40476 -0.00493 -16 -18 ]
[.40476 -0.00493 16 0 ]
[.59524 -0.00493 -16 -18 ]
[.59524 -0.00493 16 0 ]
[.78571 -0.00493 -16 -18 ]
[.78571 -0.00493 16 0 ]
[.97619 -0.00493 -12 -18 ]
[.97619 -0.00493 12 0 ]
[.01131 .09443 -59.0625 -9 ]
[.01131 .09443 0 9 ]
[.01131 .18129 -51.0625 -9 ]
[.01131 .18129 0 9 ]
[.01131 .26815 -59.0625 -9 ]
[.01131 .26815 0 9 ]
[.01131 .35501 -39.0625 -9 ]
[.01131 .35501 0 9 ]
[.01131 .44186 -59.0625 -9 ]
[.01131 .44186 0 9 ]
[.01131 .52872 -51.0625 -9 ]
[.01131 .52872 0 9 ]
[.01131 .61558 -59.0625 -9 ]
[.01131 .61558 0 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .00757 m
.21429 .01382 L
s
gsave
.21429 -0.00493 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
1.000 setlinewidth
grestore
.40476 .00757 m
.40476 .01382 L
s
gsave
.40476 -0.00493 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
1.000 setlinewidth
grestore
.59524 .00757 m
.59524 .01382 L
s
gsave
.59524 -0.00493 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
1.000 setlinewidth
grestore
.78571 .00757 m
.78571 .01382 L
s
gsave
.78571 -0.00493 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
1.000 setlinewidth
grestore
.97619 .00757 m
.97619 .01382 L
s
gsave
.97619 -0.00493 -73 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .00757 m
.07143 .01132 L
s
.11905 .00757 m
.11905 .01132 L
s
.16667 .00757 m
.16667 .01132 L
s
.2619 .00757 m
.2619 .01132 L
s
.30952 .00757 m
.30952 .01132 L
s
.35714 .00757 m
.35714 .01132 L
s
.45238 .00757 m
.45238 .01132 L
s
.5 .00757 m
.5 .01132 L
s
.54762 .00757 m
.54762 .01132 L
s
.64286 .00757 m
.64286 .01132 L
s
.69048 .00757 m
.69048 .01132 L
s
.7381 .00757 m
.7381 .01132 L
s
.83333 .00757 m
.83333 .01132 L
s
.88095 .00757 m
.88095 .01132 L
s
.92857 .00757 m
.92857 .01132 L
s
.25 Mabswid
0 .00757 m
1 .00757 L
s
.02381 .09443 m
.03006 .09443 L
s
gsave
.01131 .09443 -120.062 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(409.75) show
1.000 setlinewidth
grestore
.02381 .18129 m
.03006 .18129 L
s
gsave
.01131 .18129 -112.062 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(409.5) show
1.000 setlinewidth
grestore
.02381 .26815 m
.03006 .26815 L
s
gsave
.01131 .26815 -120.062 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(409.25) show
1.000 setlinewidth
grestore
.02381 .35501 m
.03006 .35501 L
s
gsave
.01131 .35501 -100.062 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(409) show
1.000 setlinewidth
grestore
.02381 .44186 m
.03006 .44186 L
s
gsave
.01131 .44186 -120.062 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(408.75) show
1.000 setlinewidth
grestore
.02381 .52872 m
.03006 .52872 L
s
gsave
.01131 .52872 -112.062 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(408.5) show
1.000 setlinewidth
grestore
.02381 .61558 m
.03006 .61558 L
s
gsave
.01131 .61558 -120.062 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(408.25) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .02494 m
.02756 .02494 L
s
.02381 .04231 m
.02756 .04231 L
s
.02381 .05968 m
.02756 .05968 L
s
.02381 .07706 m
.02756 .07706 L
s
.02381 .1118 m
.02756 .1118 L
s
.02381 .12917 m
.02756 .12917 L
s
.02381 .14654 m
.02756 .14654 L
s
.02381 .16391 m
.02756 .16391 L
s
.02381 .19866 m
.02756 .19866 L
s
.02381 .21603 m
.02756 .21603 L
s
.02381 .2334 m
.02756 .2334 L
s
.02381 .25077 m
.02756 .25077 L
s
.02381 .28552 m
.02756 .28552 L
s
.02381 .30289 m
.02756 .30289 L
s
.02381 .32026 m
.02756 .32026 L
s
.02381 .33763 m
.02756 .33763 L
s
.02381 .37238 m
.02756 .37238 L
s
.02381 .38975 m
.02756 .38975 L
s
.02381 .40712 m
.02756 .40712 L
s
.02381 .42449 m
.02756 .42449 L
s
.02381 .45924 m
.02756 .45924 L
s
.02381 .47661 m
.02756 .47661 L
s
.02381 .49398 m
.02756 .49398 L
s
.02381 .51135 m
.02756 .51135 L
s
.02381 .5461 m
.02756 .5461 L
s
.02381 .56347 m
.02756 .56347 L
s
.02381 .58084 m
.02756 .58084 L
s
.02381 .59821 m
.02756 .59821 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.20959 0 m
.22272 .03608 L
.26171 .1326 L
.30316 .22417 L
.34309 .30208 L
.3815 .36784 L
.42237 .42825 L
.46172 .47745 L
.49955 .51673 L
.53984 .55018 L
.57861 .57448 L
.59975 .58456 L
.61984 .5921 L
.62942 .59501 L
.63964 .59762 L
.64922 .59962 L
.65803 .60108 L
.66293 .60173 L
.66831 .60232 L
.67372 .60277 L
.67668 .60296 L
.67944 .6031 L
.68069 .60315 L
.68205 .6032 L
.68326 .60324 L
.68453 .60327 L
.68568 .60329 L
.68694 .60331 L
.68809 .60332 L
.68917 .60332 L
.69045 .60331 L
.69109 .60331 L
.69179 .6033 L
.69304 .60328 L
.6942 .60326 L
.69681 .60318 L
.69828 .60313 L
.69961 .60307 L
.70446 .60278 L
.70959 .60236 L
.7188 .60132 L
.7287 .59976 L
.73959 .59755 L
.75904 .59229 L
.77993 .5848 L
.82121 .56449 L
.86097 .53818 L
.89921 .50678 L
.93991 .46695 L
.97619 .42602 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00F`3oool01@2HV9P00000000000000000V9RH00<0oooo00@0<S8b0?ooo`3oool0V9RH0`00
0000102HV9P0oooo0?ooo`0@4105000000030;Zj^P3oool0oooo0100oooo00D0V9RH000000000000
000009RHV0030?ooo`04038b<P3oool0oooo09RHV0<0000000<0V9RH0?ooo`3oool01@3oool00`00
0000oooo0?ooo`0@0?ooo`0509RHV000000000000000002HV9P00`3oool0100b<S80oooo0?ooo`2H
V9P30000000509RHV03oool0oooo0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`0A0?ooo`0509RH
V000000000000000002HV9P00`3oool0100b<S80oooo0?ooo`2HV9P30000000509RHV03oool0oooo
0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`0E0?ooo`0509RHV000000000000000002HV9P00`3o
ool00`0b<S80oooo0?ooo`05000000H0oooo001J0?ooo`0709RHV0000000V9RH0?ooo`2HV9P00000
09RHV0040?ooo`0809RHV0000000V9RH0?ooo`2HV9P0000009RHV03oool20=gMg@<0oooo00<0QhN7
038b<P3oool0403oool01`2HV9P0000009RHV03oool0V9RH0000002HV9P0103oool01`2HV9P00000
09RHV03oool0V9RH0000002HV9P01P3oool00`000000oooo0?ooo`0?0?ooo`0709RHV0000000V9RH
0?ooo`2HV9P0000009RHV0040?ooo`0?09RHV0000000V9RH0?ooo`2HV9P0000009RHV03oool0V9RH
0000002HV9P0oooo09RHV0000000V9RH0140oooo00L0V9RH0000002HV9P0oooo09RHV0000000V9RH
00@0oooo00l0V9RH0000002HV9P0oooo09RHV0000000V9RH0?ooo`2HV9P0000009RHV03oool0V9RH
0000002HV9P05@3oool01`2HV9P0000009RHV03oool0V9RH0000002HV9P01`3oool00`000000oooo
0?ooo`060?ooo`00FP3oool00`000000V9RH0?ooo`020?ooo`0309RHV0000000oooo00<0oooo00<0
000009RHV03oool00P3oool0102HV9P000000?ooo`3oool20=gMgAD0oooo00<0000009RHV03oool0
0P3oool00`2HV9P000000?ooo`030?ooo`030000002HV9P0oooo0080oooo00<0V9RH0000003oool0
1@3oool00`000000oooo0?ooo`0?0?ooo`030000002HV9P0oooo0080oooo00<0V9RH0000003oool0
0`3oool00`000000V9RH0?ooo`020?ooo`0509RHV0000000oooo0000002HV9P00`3oool00`2HV9P0
00000?ooo`0@0?ooo`030000002HV9P0oooo0080oooo00<0V9RH0000003oool00`3oool00`000000
V9RH0?ooo`020?ooo`0509RHV0000000oooo0000002HV9P00`3oool00`2HV9P000000?ooo`0D0?oo
o`030000002HV9P0oooo0080oooo00<0V9RH0000003oool01P3oool00`000000oooo0?ooo`060?oo
o`00FP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`3oool20=gMgA@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001`00000?0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0000000D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool010000000oooo024Q8@3^k^h3
0?ooo`030;Zj^P0@4100oooo01@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo001J0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P3MgMdC0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`040000003oool0EEEE08N7Q`<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo00000004
0?ooo`0309RHV0000000oooo0100oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3<c<`0IVIV0P3oool00`2HV9P000000:VY
Z@0E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`00FP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`0308N7Q`3MgMd0oooo0140oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`3oool08B4Q0<c<c0020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00T000000?ooo`000000MgMg
0>k^kP3oool0V9RH0000002HV9P04@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3<c<`0410@0080000000<0ZJVY
0?ooo`3oool0503oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01P3oool005X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`3MgMd0EEEE0?ooo`0A0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`080000003oool0oooo0>k^kP0Q8B40k^k^0?ooo`00000A0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`050000003oool0A4A407MgM`0@
41000P0000000`2HV9P0oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`080000003oool0c<c<024Q8@27QhL0k^k^0<c<c027
QhLF0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`00FP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0;Zj^P040?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00P00000
0?ooo`3oool0oooo0;Zj^P0b<S80oooo00000140oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`2j^[X0A4A45P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01000
0000oooo038b<P2YZJT30?ooo`030;Zj^P1VIVH0oooo01@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo001J0?ooo`030000002HV9P0oooo
0080oooo00<0V9RH0000003oool00`3oool00`000000V9RH0?ooo`020?ooo`0509RHV0000000oooo
0000002HV9P00P3oool00`2HV9P000000?ooo`0A0?ooo`030000002HV9P0oooo0080oooo00<0V9RH
0000003oool00`3oool00`000000V9RH0?ooo`020?ooo`0309RHV0000000oooo00<0oooo00<0QhN7
07MgM`0000004@3oool00`000000V9RH0?ooo`020?ooo`0309RHV0000000oooo00<0oooo00<00000
09RHV03oool00P3oool01P2HV9P000000?ooo`3oool0EEEE08N7QaD0oooo00<0000009RHV03oool0
0P3oool00`2HV9P000000?ooo`030?ooo`030000002HV9P0oooo0080oooo00D0V9RH0000003oool0
000009RHV0030?ooo`0309RHV0000000oooo01@0oooo00<0000009RHV03oool00P3oool00`2HV9P0
00000?ooo`060?ooo`030000003oool0oooo00H0oooo001J0?ooo`0709RHV0000000V9RH0?ooo`2H
V9P0000009RHV0040?ooo`0:09RHV0000000V9RH0?ooo`2HV9P0000009RHV03oool0V9RH00000080
V9RH00<0000009RHV03oool04@3oool01`2HV9P0000009RHV03oool0V9RH0000002HV9P0103oool0
1`2HV9P0000009RHV03oool0V9RH0000002HV9P01@3oool00`1EEED000000?ooo`0@0?ooo`0709RH
V0000000V9RH0?ooo`2HV9P0000009RHV0040?ooo`0709RHV0000000V9RH0?ooo`2HV9P0000009RH
V0030?ooo`80IVIV00<0gMgM0?ooo`3oool04@3oool01`2HV9P0000009RHV03oool0V9RH0000002H
V9P0103oool03`2HV9P0000009RHV03oool0V9RH0000002HV9P0oooo09RHV0000000V9RH0?ooo`2H
V9P0000009RHV00E0?ooo`0709RHV0000000V9RH0?ooo`2HV9P0000009RHV0050?ooo`80<S8b00<0
00000?ooo`3oool01P3oool005/0oooo00D0V9RH000000000000000009RHV0060?ooo`0509RHV000
000000000000002HV9P00`3oool0102HV9P000000000002HV9PD0?ooo`0509RHV000000000000000
002HV9P01P3oool01@2HV9P00000000000000000V9RH00H0oooo00<0k^k^024Q8@3oool04@3oool0
1@2HV9P00000000000000000V9RH00H0oooo00D0V9RH000000000000000009RHV0050?ooo`040;Zj
^P1EEED0EEEE09RHV180oooo00D0V9RH000000000000000009RHV0060?ooo`0509RHV00000000000
0000002HV9P00`3oool01@2HV9P00000000000000000V9RH01L0oooo00D0V9RH0000000000000000
09RHV0060?ooo`030>k^kP2HV9P0410@00P0oooo003o0?ooob40oooo003o0?ooob40oooo000m0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool0]P3oool003d0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`2f0?ooo`00>03ooooQ000000L0oooo000m0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`00?@3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0;D0oooo000m0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0]03oool003d0oooo0P00000Z0?ooo`030000003oool0oooo0;@0
oooo000m0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0]03oool003d0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`2c0?ooo`00?@3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo0;<0oooo000m0?ooo`800000;03oool00`000000oooo0?ooo`2b0?oo
o`00?@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0;80oooo000m0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0/P3oool003d0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`2a0?ooo`00?@3oool2000002d0oooo00<000000?ooo`3oool0/@3oool0
03d0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2`0?ooo`00?@3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo0;00oooo000m0?ooo`800000;P3oool00`000000oooo
0?ooo`2`0?ooo`004P3oool01@000000oooo0?ooo`3oool0V9RH00<0000000L0V9RH0?ooo`3oool0
<S8b024Q8@1VIVH0gMgM00D0oooo00H0<S8b0?ooo`3oool0oooo0:VYZ@14A4@40?ooo`0304A4A000
000000000080000000<0V9RH0?ooo`3oool01@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo0:l0oooo000B0?ooo`0:0000003oool0oooo09RHV0000000V9RH0?ooo`2HV9P0000009RH
V080oooo00@0^[Zj07MgM`000000MgMg2@3oool00`000000k^k^0?ooo`060?ooo`0309RHV0000000
V9RH00H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2_0?ooo`004P3oool01@00
0000oooo0?ooo`000000V9RH00<0oooo00<0V9RH0000003oool00`3oool00`3MgMd08B4Q06IVIP08
0?ooo`0304A4A02HV9P0oooo00L0oooo00<0V9RH0000003oool01@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo0:h0oooo000=0?ooo`T000001@3oool00`000000oooo0?ooo`030?oo
o`030>k^kP000000^[Zj00L0oooo00<0V9RH04A4A03oool0203oool00`000000oooo0?ooo`040?oo
o`<00000;`3oool00`000000oooo0?ooo`2^0?ooo`000`3oool800000080oooo00<0EEEE08N7Q`3o
ool00P3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo09RHV080000000<0A4A4
06IVIP1EEED01`3oool00`3^k^h000000?ooo`080?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`2]0?ooo`003P3oool01@0Q8B40c<c<0?ooo`3oool0
00000080oooo00<000000?ooo`3oool00`3oool02@000000oooo09RHV0000000V9RH0?ooo`3^k^h0
V9RH010@40080?ooo`0304A4A02YZJT0oooo00H0oooo00<0V9RH0000003oool01@3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo0:d0oooo000>0?ooo`050>k^kP0Q8B40k^k^0?ooo`00
00000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0000009RHV0@0oooo00<000000?oo
o`3oool01P3oool00`2HV9P0EEEE0?ooo`050?ooo`0309RHV0000000V9RH00H0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`2]0?ooo`003`3oool0102j^[X0<S8b0?ooo`0000020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`060?oo
o`050>k^kP000000oooo0?ooo`2j^[X0100000000`2HV9P0oooo0?ooo`050?ooo`800000<P3oool0
0`000000oooo0?ooo`2/0?ooo`00403oool00`27QhL0MgMg000000020?ooo`030000002HV9P0oooo
0080oooo00D0V9RH0000003oool0000009RHV0030?ooo`0309RHV0000000oooo00<0oooo00<0MgMg
0=gMg@3oool00P3oool01P0b<S80ZJVY0?ooo`3oool0410@0=gMg@X0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2/0?ooo`004@3oool04`1EEED000000?ooo`3oool0V9RH0000002H
V9P0oooo09RHV0000000V9RH0?ooo`2HV9P0000009RHV03oool0V9RH0000002HV9P0103oool00`27
QhL0A4A40?ooo`020?ooo`0608N7Q`1EEED0oooo0?ooo`27QhL0IVIV2P3oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo0:/0oooo000A0?ooo`030>k^kP0Q8B40oooo0080oooo00D0V9RH
000000000000000009RHV0030?ooo`0509RHV000000000000000002HV9P01@3oool00`3MgMd00000
0000000300000004010@403oool0oooo0=gMg@@0000000<0<S8b0?ooo`3oool0103oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo0:/0oooo000m0?ooo`800000<`3oool00`000000oooo
0?ooo`2[0?ooo`00?@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0:X0oooo000m
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0ZP3oool003d0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`2Y0?ooo`00?@3oool2000003D0oooo00<000000?ooo`3o
ool0Z@3oool003d0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`2X0?ooo`00?@3o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:P0oooo000m0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool0Z03oool003d0oooo0P00000g0?ooo`030000003oool0oooo
0:L0oooo000J0?ooo`050000003oool0oooo0?ooo`2HV9P00`0000001`2HV9P0oooo0?ooo`0b<S80
8B4Q06IVIP3MgMd01@3oool00`0b<S80oooo04A4A0040000000309RHV03oool0oooo00D0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`2W0?ooo`006P3oool02P000000oooo0?ooo`2H
V9P0000009RHV03oool0V9RH0000002HV9P20?ooo`040;Zj^P1gMgL0000007MgM`X0oooo00<0V9RH
0000002HV9P01P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:H0oooo000J0?oo
o`050000003oool0oooo0000002HV9P00`3oool00`2HV9P000000?ooo`030?ooo`030=gMg@0Q8B40
IVIV00X0oooo00<0V9RH0000003oool01@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo0:H0oooo000E0?ooo`T000001@3oool00`000000oooo0?ooo`030?ooo`030>k^kP000000^[Zj
00X0oooo00<000000?ooo`3oool0103oool3000003P0oooo00<000000?ooo`3oool0Y@3oool000/0
oooo200000020?ooo`0305EEE@27QhL0oooo0080oooo00@000000?ooo`3oool000001@3oool01000
0000oooo0?ooo`2HV9P20000000304A4A01VIVH0EEEE00X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0:D0oooo000F0?ooo`05024Q8@3<c<`0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`090000003oool0V9RH0000002HV9P0oooo
0>k^kP2HV9P0410@00T0oooo00<0V9RH0000003oool01@3oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo0:@0oooo000F0?ooo`050>k^kP0Q8B40k^k^0?ooo`0000000P3oool00`000000
oooo0?ooo`030?ooo`040000003oool0000009RHV0@0oooo00<000000?ooo`3oool01P3oool00`2H
V9P0000009RHV0060?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0Y03oool001L0
oooo00@0^[Zj038b<P3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool00000
00D0oooo00<000000?ooo`3oool00P3oool00`2j^[X00000000000020000000309RHV03oool0oooo
00D0oooo0P00000k0?ooo`030000003oool0oooo0:<0oooo000H0?ooo`0308N7Q`1gMgL000000080
oooo00<0000009RHV03oool00P3oool01@2HV9P000000?ooo`000000V9RH00<0oooo00<0V9RH0000
003oool0103oool00`0@4100gMgM0?ooo`090?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0X`3oool001T0oooo01<0EEEE0000003oool0oooo09RHV0000000V9RH0?ooo`2HV9P00000
09RHV03oool0V9RH0000002HV9P0oooo09RHV0000000V9RH00D0oooo00<0QhN706IVIP3oool02@3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0:<0oooo000I0?ooo`030>k^kP0Q8B40
oooo0080oooo00D0V9RH000000000000000009RHV0030?ooo`0509RHV000000000000000002HV9P0
1P3oool00`3MgMd000000000000200000003038b<P3oool0oooo00@0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`2R0?ooo`00?@3oool2000003`0oooo00<000000?ooo`3oool0XP3o
ool003d0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Q0?ooo`00?@3oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo0:40oooo000m0?ooo`800000?P3oool00`000000
oooo0?ooo`2P0?ooo`00?@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0:00oooo
000m0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0W`3oool003d0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`2O0?ooo`00?@3oool200000400oooo00<000000?oo
o`3oool0WP3oool00180oooo00D000000?ooo`3oool0oooo09RHV0030000000709RHV03oool0oooo
038b<P0Q8B40IVIV0=gMg@050?ooo`03038b<P3oool0410@00D0000000<0^[Zj0?ooo`14A4@01000
00000`2HV9P0oooo0?ooo`050?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0WP3o
ool00180oooo00X000000?ooo`3oool0V9RH0000002HV9P0oooo09RHV0000000V9RH0P3oool0102j
^[X0MgMg0000001gMgL60?ooo`80gMgM0`3oool00`27QhL0<S8b0?ooo`040?ooo`0309RHV0000000
V9RH00H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2M0?ooo`004P3oool01@00
0000oooo0?ooo`000000V9RH00<0oooo00<0V9RH0000003oool00`3oool00`3MgMd08B4Q06IVIP06
0?ooo`80gMgM2P3oool00`2HV9P000000?ooo`050?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool0W@3oool000d0oooo2@0000050?ooo`030000003oool0oooo00<0oooo00<0k^k^0000
002j^[X01P3oool20=gMg@X0oooo00<000000?ooo`3oool0103oool300000440oooo00<000000?oo
o`3oool0W03oool000<0oooo200000020?ooo`0305EEE@27QhL0oooo0080oooo00@000000?ooo`3o
ool000001@3oool010000000oooo0?ooo`2HV9P20000000304A4A01VIVH0EEEE00L0oooo0P3MgMd9
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`2L
0?ooo`003P3oool01@0Q8B40c<c<0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool0
2@000000oooo09RHV0000000V9RH0?ooo`3^k^h0V9RH010@40080?ooo`0308N7Q`3MgMd0oooo00H0
oooo00<0V9RH0000003oool01@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo09/0
oooo000>0?ooo`050>k^kP0Q8B40k^k^0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0000009RHV0@0oooo00<000000?ooo`3oool01P3oool00`3MgMd0EEEE0?ooo`050?oo
o`0309RHV0000000V9RH00H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`2K0?oo
o`003`3oool0102j^[X0<S8b0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`0000001@3oool00`000000oooo0?ooo`020?ooo`030;Zj^P3oool0oooo0080oooo00@000000?oo
o`3oool0^[Zj100000000`2HV9P0oooo0?ooo`050?ooo`800000A03oool00`000000oooo0?ooo`2J
0?ooo`00403oool00`27QhL0MgMg000000020?ooo`030000002HV9P0oooo0080oooo00D0V9RH0000
003oool0000009RHV0030?ooo`0309RHV0000000oooo00<0oooo00H0000009RHV03oool0oooo09RH
V00000030?ooo`03010@403MgMd0oooo00T0oooo00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`2J0?ooo`004@3oool04`1EEED000000?ooo`3oool0V9RH0000002HV9P0oooo09RHV0000000
V9RH0?ooo`2HV9P0000009RHV03oool0V9RH0000002HV9P0103oool01P2HV9P0000009RHV02HV9P0
000009RHV0<0oooo00<0QhN706IVIP3oool02@3oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo09T0oooo000A0?ooo`030>k^kP0Q8B40oooo0080oooo00D0V9RH000000000000000009RH
V0030?ooo`0509RHV000000000000000002HV9P01P3oool0102HV9P000000000002HV9P40?ooo`03
0=gMg@00000000000080000000<0<S8b0?ooo`3oool0103oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo09T0oooo000m0?ooo`800000AP3oool00`000000oooo0?ooo`2H0?ooo`00?@3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo09P0oooo000m0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool0U`3oool003d0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`2G0?ooo`00?@3oool2000004P0oooo00<000000?ooo`3oool0UP3oool003d0oooo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`2F0?ooo`00?@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo09D0oooo000m0?ooo`030000003oool0oooo04P0oooo00<00000
0?ooo`3oool0U@3oool003d0oooo0P00001:0?ooo`030000003oool0oooo09@0oooo000V0?ooo`05
0000003oool0oooo0?ooo`2HV9P00`0000001`2HV9P0oooo0?ooo`0b<S808B4Q06IVIP3MgMd0203o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo09<0oooo000V0?ooo`0:0000003oool0
oooo09RHV0000000V9RH0?ooo`2HV9P0000009RHV080oooo00@0^[Zj07MgM`000000MgMg1`3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo09<0oooo000V0?ooo`050000003oool0oooo
0000002HV9P00`3oool00`2HV9P000000?ooo`030?ooo`030=gMg@0Q8B40IVIV00H0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`2B0?ooo`008@3oool9000000D0oooo00<000000?oo
o`3oool00`3oool00`3^k^h000000;Zj^P050?ooo`<00000B`3oool00`000000oooo0?ooo`2B0?oo
o`005`3oool800000080oooo00<0EEEE08N7Q`3oool00P3oool010000000oooo0?ooo`0000050?oo
o`040000003oool0oooo09RHV080000000<0A4A406IVIP1EEED01@3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo0940oooo000R0?ooo`05024Q8@3<c<`0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`090000003oool0V9RH0000002HV9P0oooo0>k^kP2HV9P0410@00D0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`2A0?ooo`008P3oool01@3^k^h08B4Q
0>k^kP3oool000000080oooo00<000000?ooo`3oool00`3oool010000000oooo0000002HV9P40?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`2@0?oo
o`008`3oool0102j^[X0<S8b0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`0000001@3oool00`000000oooo0?ooo`030?ooo`800000CP3oool00`000000oooo0?ooo`2@0?oo
o`00903oool00`27QhL0MgMg000000020?ooo`030000002HV9P0oooo0080oooo00D0V9RH0000003o
ool0000009RHV0030?ooo`0309RHV0000000oooo00@0oooo00<000000?ooo`3oool0CP3oool00`00
0000oooo0?ooo`2?0?ooo`009@3oool04`1EEED000000?ooo`3oool0V9RH0000002HV9P0oooo09RH
V0000000V9RH0?ooo`2HV9P0000009RHV03oool0V9RH0000002HV9P01@3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo08h0oooo000U0?ooo`030>k^kP0Q8B40oooo0080oooo00D0V9RH
000000000000000009RHV0030?ooo`0509RHV000000000000000002HV9P01P3oool200000540oooo
00<000000?ooo`3oool0S@3oool003d0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?oo
o`2=0?ooo`00?@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo08`0oooo000m0?oo
o`030000003oool0oooo0580oooo00<000000?ooo`3oool0R`3oool003d0oooo0P00001D0?ooo`03
0000003oool0oooo08X0oooo000m0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
R@3oool003d0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`290?ooo`00?@3oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo08P0oooo000m0?ooo`800000E`3oool00`00
0000oooo0?ooo`270?ooo`004P3oool01@000000oooo0?ooo`3oool0V9RH00<0000000D0V9RH0?oo
o`3oool0oooo09RHV0030000000509RHV03oool0oooo0?ooo`0b<S800`3oool00`2YZJT0A4A40?oo
o`030?ooo`0304A4A000000000000080000000<0V9RH0?ooo`3oool01@3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool02P3oool00180oooo01800000
0?ooo`3oool0V9RH0000002HV9P0oooo09RHV0000000V9RH0?ooo`2HV9P0000009RHV03oool0V9RH
0000002HV9P70?ooo`030000003^k^h0oooo00H0oooo00<0V9RH0000002HV9P01P3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool02`3oool00180oooo
00D000000?ooo`3oool0000009RHV0030?ooo`0509RHV0000000oooo0000002HV9P00`3oool00`2H
V9P000000?ooo`060?ooo`0304A4A02HV9P0oooo00L0oooo00<0V9RH0000003oool01@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0303oool000d0
oooo2@0000050?ooo`040000003oool08B4Q0>k^kP<0oooo00<0^[Zj010@403oool01P3oool00`2H
V9P0A4A40?ooo`080?ooo`030000003oool0oooo00@0oooo0`00001I0?ooo`030000003oool0oooo
07@0oooo00<000000?ooo`3oool03@3oool000<0oooo200000020?ooo`0305EEE@27QhL0oooo0080
oooo00@000000?ooo`3oool000001@3oool010000000oooo0<c<c01VIVH20?ooo`0309RHV0000000
ZJVY00L0oooo00<0k^k^0000003oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo05X0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0>0?ooo`003P3oool01@0Q
8B40c<c<0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3<
c<`0410@0080000000<0ZJVY0?ooo`3oool01`3oool00`14A4@0ZJVY0?ooo`060?ooo`0309RHV000
0000oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1a0?ooo`030000003o
ool0oooo00l0oooo000>0?ooo`050>k^kP0Q8B40k^k^0?ooo`0000000P3oool00`000000oooo0?oo
o`030?ooo`080000003oool0c<c<024Q8@27QhL0k^k^0<c<c027QhL90?ooo`0309RHV01EEED0oooo
00D0oooo00<0V9RH0000002HV9P01P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
06l0oooo00<000000?ooo`3oool0403oool000l0oooo00@0^[Zj038b<P3oool000000P3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0<S8b0:VYZ@<0oooo00<0^[Zj06IVIP3oool01`3oool0
1@3^k^h000000?ooo`3oool0^[Zj00@0000000<0V9RH0?ooo`3oool01@3oool2000005d0oooo00<0
00000?ooo`3oool0K@3oool00`000000oooo0?ooo`0A0?ooo`00403oool00`27QhL0MgMg00000002
0?ooo`030000002HV9P0oooo0080oooo00D0V9RH0000003oool0000009RHV0030?ooo`0309RHV000
0000oooo00<0oooo00<0MgMg0=gMg@3oool00P3oool01P0b<S80ZJVY0?ooo`3oool0410@0=gMg@X0
oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0180
oooo000A0?ooo`0C05EEE@000000oooo0?ooo`2HV9P0000009RHV03oool0V9RH0000002HV9P0oooo
09RHV0000000V9RH0?ooo`2HV9P0000009RHV0040?ooo`0308N7Q`14A4@0oooo0080oooo00H0QhN7
05EEE@3oool0oooo08N7Q`1VIVH:0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0
JP3oool00`000000oooo0?ooo`0C0?ooo`004@3oool00`3^k^h08B4Q0?ooo`020?ooo`0509RHV000
000000000000002HV9P00`3oool01@2HV9P00000000000000000V9RH00D0oooo00<0gMgM00000000
00000`000000100@4100oooo0?ooo`3MgMd400000003038b<P3oool0oooo00@0oooo00<000000?oo
o`3oool0GP3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo01@0oooo000m0?ooo`80
0000H03oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo01D0oooo000m0?ooo`030000
003oool0oooo0600oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0F0?ooo`00?@3o
ool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool05`3o
ool003d0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0
oooo01P0oooo000m0?ooo`800000I03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
01T0oooo000m0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0G03oool00`000000
oooo0?ooo`0J0?ooo`00?@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool06`3oool003d0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`1G0?ooo`8000007P3oool003d0oooo0P00001X0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool07P3oool001X0oooo00D000000?ooo`3oool0oooo09RHV0030000000509RHV03oool0
oooo0?ooo`2HV9P00`0000001`2HV9P0oooo0?ooo`3oool0<S8b0?ooo`14A4@0100000000`2HV9P0
oooo0?ooo`050?ooo`030000003oool0oooo06P0oooo0P00001D0?ooo`030000003oool0oooo01l0
oooo000J0?ooo`0B0000003oool0oooo09RHV0000000V9RH0?ooo`2HV9P0000009RHV03oool0V9RH
0000002HV9P0oooo09RHV0000000V9RH203oool00`2HV9P0000009RHV0060?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0P0?ooo`006P3oool01@00
0000oooo0?ooo`000000V9RH00<0oooo00D0V9RH0000003oool0000009RHV0030?ooo`0309RHV000
0000oooo00P0oooo00<0V9RH0000003oool01@3oool00`000000oooo0?ooo`1[0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool08@3oool001D0oooo2@0000050?ooo`040000003oool0
8B4Q0>k^kP<0oooo00<0^[Zj010@403oool02@3oool00`000000oooo0?ooo`040?ooo`<00000K03o
ool2000004d0oooo00<000000?ooo`3oool08P3oool000/0oooo200000020?ooo`0305EEE@27QhL0
oooo0080oooo00@000000?ooo`3oool000001@3oool010000000oooo0<c<c01VIVH20?ooo`0309RH
V0000000ZJVY00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1^0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool08`3oool001H0oooo00D08B4Q0<c<c03oool0oooo
000000020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0c<c<010@400200000003
0:VYZ@3oool0oooo00P0oooo00<0V9RH0000003oool01@3oool00`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo04H0oooo0P00000V0?ooo`005P3oool01@3^k^h08B4Q0>k^kP3oool000000080
oooo00<000000?ooo`3oool00`3oool020000000oooo0<c<c00Q8B40QhN70>k^kP3<c<`0QhN72@3o
ool00`2HV9P0000009RHV0060?ooo`800000L@3oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo02H0oooo000G0?ooo`040;Zj^P0b<S80oooo00000080oooo00<000000?ooo`3oool00`3o
ool010000000oooo038b<P2YZJT30?ooo`030;Zj^P1VIVH0oooo00<0oooo00<0^[Zj000000000000
0P0000000`2HV9P0oooo0?ooo`050?ooo`030000003oool0oooo0740oooo0P0000120?ooo`800000
:@3oool001P0oooo00<0QhN707MgM`0000000P3oool00`000000V9RH0?ooo`020?ooo`0509RHV000
0000oooo0000002HV9P00`3oool00`2HV9P000000?ooo`040?ooo`03010@403MgMd0oooo00T0oooo
00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo02T0oooo
000I0?ooo`0C05EEE@000000oooo0?ooo`2HV9P0000009RHV03oool0V9RH0000002HV9P0oooo09RH
V0000000V9RH0?ooo`2HV9P0000009RHV0050?ooo`0308N7Q`1VIVH0oooo00T0oooo00<000000?oo
o`3oool0M03oool2000003`0oooo0P00000/0?ooo`006@3oool00`3^k^h08B4Q0?ooo`020?ooo`05
09RHV000000000000000002HV9P00`3oool01@2HV9P00000000000000000V9RH00H0oooo00<0gMgM
0000000000000P0000000`0b<S80oooo0?ooo`040?ooo`800000M`3oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo02`0oooo000m0?ooo`030000003oool0oooo07L0oooo0P00000f0?oo
o`800000;`3oool003d0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0a0?ooo`80
0000<@3oool003d0oooo00<000000?ooo`3oool0NP3oool2000002h0oooo0`00000c0?ooo`00?@3o
ool2000007d0oooo0P00000Z0?ooo`800000=P3oool003d0oooo00<000000?ooo`3oool0OP3oool2
000002H0oooo0P00000h0?ooo`00?@3oool00`000000oooo0?ooo`200?ooo`<00000803oool30000
03X0oooo000m0?ooo`030000003oool0oooo08<0oooo1000000I0?ooo`<00000?@3oool003d0oooo
0P0000280?ooo`@000003`3oool600000400oooo000B0?ooo`050000003oool0oooo0?ooo`2HV9P0
0`0000001@2HV9P0oooo0?ooo`3oool0V9RH00<0000000L0V9RH0?ooo`3oool0oooo038b<P3oool0
410@00D0000000<0^[Zj0?ooo`14A4@0100000000`2HV9P0oooo0?ooo`050?ooo`030000003oool0
oooo08/0oooo3`0000160?ooo`004P3oool04P000000oooo0?ooo`2HV9P0000009RHV03oool0V9RH
0000002HV9P0oooo09RHV0000000V9RH0?ooo`2HV9P0000009RHV0@0oooo0P3MgMd30?ooo`0308N7
Q`0b<S80oooo00@0oooo00<0V9RH0000002HV9P01P3oool00`000000oooo0?ooo`3P0?ooo`004P3o
ool01@000000oooo0?ooo`000000V9RH00<0oooo00D0V9RH0000003oool0000009RHV0030?ooo`03
09RHV0000000oooo00@0oooo0P3MgMd:0?ooo`0309RHV0000000oooo00D0oooo00<000000?ooo`3o
ool0h03oool000d0oooo2@0000050?ooo`040000003oool08B4Q0>k^kP<0oooo00<0^[Zj010@403o
ool01@3oool20=gMg@X0oooo00<000000?ooo`3oool0103oool300000>00oooo00030?ooo`P00000
0P3oool00`1EEED0QhN70?ooo`020?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3<
c<`0IVIV0P3oool00`2HV9P000000:VYZ@070?ooo`80gMgM2@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0>00oooo000>0?ooo`05024Q8@3<c<`0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0<c<c00@41000P0000000`2YZJT0oooo0?ooo`07
0?ooo`0308N7Q`3MgMd0oooo00H0oooo00<0V9RH0000003oool0j03oool000h0oooo00D0k^k^024Q
8@3^k^h0oooo000000020?ooo`030000003oool0oooo00<0oooo00P000000?ooo`3<c<`08B4Q08N7
Q`3^k^h0c<c<08N7Q`T0oooo00<0gMgM05EEE@3oool01@3oool00`2HV9P0000009RHV03Y0?ooo`00
3`3oool0102j^[X0<S8b0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`0b
<S80ZJVY0`3oool00`2j^[X0IVIV0?ooo`030?ooo`030;Zj^P3oool0oooo0080oooo00@000000?oo
o`3oool0^[Zj100000000`2HV9P0oooo0?ooo`3X0?ooo`00403oool00`27QhL0MgMg000000020?oo
o`030000002HV9P0oooo0080oooo00D0V9RH0000003oool0000009RHV0030?ooo`0309RHV0000000
oooo00<0oooo00H0000009RHV03oool0oooo09RHV00000030?ooo`03010@403MgMd0oooo0>`0oooo
000A0?ooo`0C05EEE@000000oooo0?ooo`2HV9P0000009RHV03oool0V9RH0000002HV9P0oooo09RH
V0000000V9RH0?ooo`2HV9P0000009RHV0040?ooo`0609RHV0000000V9RH09RHV0000000V9RH0`3o
ool00`27QhL0IVIV0?ooo`3/0?ooo`004@3oool00`3^k^h08B4Q0?ooo`020?ooo`0509RHV0000000
00000000002HV9P00`3oool01@2HV9P00000000000000000V9RH00H0oooo00@0V9RH000000000000
V9RH103oool00`3MgMd000000000000200000003038b<P3oool0oooo0>L0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0290239, -410.339, \
0.000469179, 0.012861}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ll = 
      Plus @@ Log[\(GenotypeFrequency[1, #, alN, ptN, 
                NullAllele \[Rule] \[Nu]] &\) /@ td]\)], "Input"],

Cell[BoxData[
    \(Log[\(0.0010218489892984543`\ \((1 - pn)\)\^2\)\/\(1 - pn\^2\)] + 
      6\ Log[\(0.0032699167657550534`\ \((1 - pn)\)\^2\)\/\(1 - pn\^2\)] + 
      74\ Log[\(0.35969084423305586`\ \((1 - pn)\)\^2\)\/\(1 - pn\^2\)] + 
      18\ Log[\(0.05620169441141498`\ \((1 - pn)\)\^2 + 0.47413793103448276`\ \
\((1 - pn)\)\ pn\)\/\(1 - pn\^2\)] + 
      145\ Log[\(0.5755053507728893`\ \((1 - pn)\)\^2 + 1.5172413793103448`\ \
\((1 - pn)\)\ pn\)\/\(1 - pn\^2\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ll /. pn \[Rule] 0.9999\)], "Input"],

Cell[BoxData[
    \(\(-985.03674775746`\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(Plot[ll, {pn, 0, 0.1}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Data[s[sika, pol]]\)\[LeftDoubleBracket]\(-2\), 
      13\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \({145, 157}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(alN\[LeftDoubleBracket]13\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \({143, 145, 155, 157, 159}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ptN\[LeftDoubleBracket]13\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \({0.02813852813852814`, 0.`, 0.6796536796536796`, 0.29004329004329005`, 
      0.0021645021645021645`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AlleleFrequencyTable[s[sika, pol], 
        alN]\)\[LeftDoubleBracket]13\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \({8\/243, 1\/81, 323\/486, 70\/243, 1\/486}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GenotypeFrequency[
      13, \(Data[s[sika, pol]]\)\[LeftDoubleBracket]\(-2\), 
        13\[RightDoubleBracket], alN, ptN, 
      NullAllele \[Rule] \[Nu]]\)], "Input"],

Cell[BoxData[
    \(0.`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MapIndexed[
      GenotypeFrequency[#2\[LeftDoubleBracket]1\[RightDoubleBracket], #1, 
          alN, ptN, NullAllele \[Rule] \[Nu]] &, \(Data[
          s[sika, pol]]\)\[LeftDoubleBracket]\(-2\)\[RightDoubleBracket]]\)], \
"Input"],

Cell[BoxData[
    \({0.6622040385669531`, 0.9749488030506321`, 0.00007305135510263717`, 
      0.995802732857849`, 5.027247682438818`*^-6, 0.9832638937928113`, 
      0.9254927095016825`, 0.995802732857849`, 0.9379678341925005`, 
      0.9584245462891038`, 0.9747378626831371`, \[EmptySet], 0.`, 
      0.8084881011228021`, 0.`, 0.03515625`, 0.8505799378574961`, 0.`, 
      0.9871107684304399`, 0.008368053103594378`, 0.004393814474451528`, 
      0.016453640279641267`, 0.8428474330908833`, 0.9543155497493114`, 
      0.9584245462891038`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[%]\)], "Input"],

Cell[BoxData[
    \(250\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(xx\)], "Input"],

Cell[BoxData[
    \(Indeterminate\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(Clear[pn]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Plot[{\((1 - 
                  pn\^2)\) \((\(2\/ngt\[LeftDoubleBracket]1\
\[RightDoubleBracket]\) homs . \(pn\/\(p0 + 2  pn\)\) + 
                  pn\^2\/\(1 - pn\^2\))\) - pn}, {pn, 0.9, 
          1}];\)\(\[IndentingNewLine]\)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-8.54762 9.52381 0.024639 306.245 [
[.02381 .01214 -12 -18 ]
[.02381 .01214 12 0 ]
[.21429 .01214 -16 -18 ]
[.21429 .01214 16 0 ]
[.40476 .01214 -16 -18 ]
[.40476 .01214 16 0 ]
[.59524 .01214 -16 -18 ]
[.59524 .01214 16 0 ]
[.78571 .01214 -16 -18 ]
[.78571 .01214 16 0 ]
[.96369 .17776 -48 -9 ]
[.96369 .17776 0 9 ]
[.96369 .33088 -40 -9 ]
[.96369 .33088 0 9 ]
[.96369 .48401 -48 -9 ]
[.96369 .48401 0 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .02464 m
.02381 .03089 L
s
gsave
.02381 .01214 -73 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
1.000 setlinewidth
grestore
.21429 .02464 m
.21429 .03089 L
s
gsave
.21429 .01214 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.92) show
1.000 setlinewidth
grestore
.40476 .02464 m
.40476 .03089 L
s
gsave
.40476 .01214 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.94) show
1.000 setlinewidth
grestore
.59524 .02464 m
.59524 .03089 L
s
gsave
.59524 .01214 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.96) show
1.000 setlinewidth
grestore
.78571 .02464 m
.78571 .03089 L
s
gsave
.78571 .01214 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.98) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .02464 m
.07143 .02839 L
s
.11905 .02464 m
.11905 .02839 L
s
.16667 .02464 m
.16667 .02839 L
s
.2619 .02464 m
.2619 .02839 L
s
.30952 .02464 m
.30952 .02839 L
s
.35714 .02464 m
.35714 .02839 L
s
.45238 .02464 m
.45238 .02839 L
s
.5 .02464 m
.5 .02839 L
s
.54762 .02464 m
.54762 .02839 L
s
.64286 .02464 m
.64286 .02839 L
s
.69048 .02464 m
.69048 .02839 L
s
.7381 .02464 m
.7381 .02839 L
s
.83333 .02464 m
.83333 .02839 L
s
.88095 .02464 m
.88095 .02839 L
s
.92857 .02464 m
.92857 .02839 L
s
.25 Mabswid
0 .02464 m
1 .02464 L
s
.97619 .17776 m
.98244 .17776 L
s
gsave
.96369 .17776 -109 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0005) show
1.000 setlinewidth
grestore
.97619 .33088 m
.98244 .33088 L
s
gsave
.96369 .33088 -101 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
1.000 setlinewidth
grestore
.97619 .48401 m
.98244 .48401 L
s
gsave
.96369 .48401 -109 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0015) show
1.000 setlinewidth
grestore
.125 Mabswid
.97619 .05526 m
.97994 .05526 L
s
.97619 .08589 m
.97994 .08589 L
s
.97619 .11651 m
.97994 .11651 L
s
.97619 .14714 m
.97994 .14714 L
s
.97619 .20839 m
.97994 .20839 L
s
.97619 .23901 m
.97994 .23901 L
s
.97619 .26964 m
.97994 .26964 L
s
.97619 .30026 m
.97994 .30026 L
s
.97619 .36151 m
.97994 .36151 L
s
.97619 .39213 m
.97994 .39213 L
s
.97619 .42276 m
.97994 .42276 L
s
.97619 .45338 m
.97994 .45338 L
s
.97619 .51463 m
.97994 .51463 L
s
.97619 .54526 m
.97994 .54526 L
s
.97619 .57588 m
.97994 .57588 L
s
.97619 .60651 m
.97994 .60651 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .55129 L
.10458 .49723 L
.14415 .44901 L
.18221 .40497 L
.22272 .36063 L
.26171 .32043 L
.30316 .28038 L
.34309 .2444 L
.3815 .21223 L
.42237 .18062 L
.46172 .15277 L
.49955 .12837 L
.53984 .10497 L
.57861 .08498 L
.61984 .06644 L
.65954 .05125 L
.69774 .03911 L
.73838 .02887 L
.77751 .02162 L
.79892 .01874 L
.80873 .01768 L
.81909 .01673 L
.82867 .01602 L
.83917 .01542 L
.84378 .01521 L
.84873 .01503 L
.85339 .0149 L
.85765 .01481 L
.85993 .01477 L
.86245 .01474 L
.86372 .01473 L
.86438 .01473 L
.86509 .01472 L
.86638 .01472 L
.86756 .01472 L
.86866 .01472 L
.86983 .01472 L
.87093 .01472 L
.87194 .01473 L
.87312 .01474 L
.8744 .01475 L
.87673 .01478 L
.87923 .01482 L
.88198 .01488 L
.88753 .01504 L
.89268 .01523 L
.89749 .01545 L
.9079 .01606 L
.91778 .01681 L
Mistroke
.93631 .01867 L
.95616 .0213 L
.97456 .02434 L
.97619 .02464 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00303oool01@2HV9P00000000000000000V9RH00<0oooo00H0<S8b0?ooo`0b<S808B4Q06IV
IP3MgMdP0?ooo`0509RHV000000000000000002HV9P00`3oool01P0b<S80oooo038b<P0Q8B40IVIV
0=gMg@@0oooo00<0410@0000000000000`0000000`2j^[X0oooo0?ooo`0G0?ooo`0509RHV0000000
00000000002HV9P00`3oool01P0b<S80oooo038b<P0Q8B40IVIV0=gMg@T0oooo00<000000?ooo`3o
ool0603oool01@2HV9P00000000000000000V9RH00<0oooo00H0<S8b0?ooo`0b<S808B4Q06IVIP3M
gMd50?ooo`0509RHV000000000000000002HV9P06P3oool01@2HV9P00000000000000000V9RH00<0
oooo00H0<S8b0?ooo`0b<S808B4Q06IVIP3MgMd50?ooo`0509RHV000000000000000002HV9P0>03o
ool000/0oooo00L0V9RH0000002HV9P0oooo09RHV0000000V9RH00D0oooo00@0^[Zj07MgM`000000
MgMg7P3oool01`2HV9P0000009RHV03oool0V9RH0000002HV9P01@3oool0102j^[X0MgMg0000001g
MgL30?ooo`80gMgM0`3oool00`27QhL0<S8b0?ooo`0G0?ooo`0709RHV0000000V9RH0?ooo`2HV9P0
000009RHV0050?ooo`040;Zj^P1gMgL0000007MgM`P0oooo00<000000?ooo`3oool05`3oool01`2H
V9P0000009RHV03oool0V9RH0000002HV9P01@3oool0102j^[X0MgMg0000001gMgL30?ooo`0709RH
V0000000V9RH0?ooo`2HV9P0000009RHV00H0?ooo`0709RHV0000000V9RH0?ooo`2HV9P0000009RH
V0050?ooo`040;Zj^P1gMgL0000007MgM`<0oooo00L0V9RH0000002HV9P0oooo09RHV0000000V9RH
03L0oooo000;0?ooo`030000002HV9P0oooo0080oooo00<0V9RH0000003oool01P3oool00`3MgMd0
8B4Q06IVIP0M0?ooo`030000002HV9P0oooo0080oooo00<0V9RH0000003oool01P3oool00`3MgMd0
8B4Q06IVIP030?ooo`80gMgM703oool00`000000V9RH0?ooo`020?ooo`0309RHV0000000oooo00H0
oooo00<0gMgM024Q8@1VIVH01`3oool00`000000oooo0?ooo`0G0?ooo`030000002HV9P0oooo0080
oooo00<0V9RH0000003oool01P3oool00`3MgMd08B4Q06IVIP020?ooo`030000002HV9P0oooo0080
oooo00<0V9RH0000003oool05`3oool00`000000V9RH0?ooo`020?ooo`0309RHV0000000oooo00H0
oooo00<0gMgM024Q8@1VIVH00P3oool00`000000V9RH0?ooo`020?ooo`0309RHV0000000oooo03H0
oooo000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`3^k^h00000
0;Zj^P0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`3^k^h00000
0;Zj^P030?ooo`80gMgM6`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo
00@0k^k^0000002j^[X0oooo2000000G0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01P3oool01@3^k^h000000;Zj^P3oool0000000D0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00H0k^k^0000002j^[X0oooo024Q8@3^
k^h30?ooo`030;Zj^P0@4100oooo03H0oooo000;0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool01P2HV9P0000000000014A4@0IVIV05EEEA`0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`0609RHV0000000000004A4A01VIVH0EEEE103oool20=gM
gAX0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`0909RHV00000000000
04A4A01VIVH0EEEE0?ooo`1EEED0QhN700<0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00P0V9RH000000000000A4A406IVIP1EEED0oooo
000000@0oooo00<0V9RH0000003oool05`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00T0V9RH000000000000A4A406IVIP1EEED0oooo0<c<c01VIVH00P3oool00`2HV9P0
00000:VYZ@0g0?ooo`002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00L0V9RH0000002HV9P0oooo0>k^kP2HV9P0410@01`0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`0709RHV0000000V9RH0?ooo`3^k^h0V9RH010@40050?ooo`0308N7Q`3M
gMd0oooo01P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`0709RHV000
0000V9RH0?ooo`3^k^h0V9RH010@40020?ooo`05024Q8@3<c<`0oooo0?ooo`0000006@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00l0V9RH0000002HV9P0oooo0>k^kP2H
V9P0410@0?ooo`000000MgMg0>k^kP3oool0V9RH0000002HV9P0603oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00L0V9RH0000002HV9P0oooo0>k^kP2HV9P0410@0080oooo
00D0c<c<010@4000000000000:VYZ@0h0?ooo`002`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00<0000009RHV03oool00`3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000V9RH0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<0gMgM05EEE@3oool0603oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00<0000009RHV03oool00`3oool020000000oooo0?ooo`3^k^h08B4Q0>k^
kP3oool000006@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
09RHV03oool00`3oool01@000000oooo04A4A01gMgL0410@0080000000<0V9RH0?ooo`3oool05`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0000009RHV03oool00`3o
ool020000000oooo0<c<c00Q8B40QhN70>k^kP3<c<`0QhN7>03oool000/0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0;Zj^P040?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00P000000?ooo`3o
ool0oooo0;Zj^P0b<S80oooo000001T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`2j^[X0A4A47@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool010000000oooo
038b<P2YZJT30?ooo`030;Zj^P1VIVH0oooo03H0oooo000;0?ooo`030000002HV9P0oooo0080oooo
00<0V9RH0000003oool00`3oool00`000000V9RH0?ooo`020?ooo`0309RHV0000000oooo01/0oooo
00<0000009RHV03oool00P3oool00`2HV9P000000?ooo`030?ooo`030000002HV9P0oooo0080oooo
00D0V9RH0000003oool0000009RHV0020?ooo`0309RHV0000000oooo01P0oooo00<0000009RHV03o
ool00P3oool00`2HV9P000000?ooo`030?ooo`030000002HV9P0oooo0080oooo00<0V9RH0000003o
ool00`3oool00`27QhL0MgMg0000000I0?ooo`030000002HV9P0oooo0080oooo00<0V9RH0000003o
ool00`3oool00`000000V9RH0?ooo`020?ooo`0609RHV0000000oooo0?ooo`1EEED0QhN7703oool0
0`000000V9RH0?ooo`020?ooo`0309RHV0000000oooo00<0oooo00<0000009RHV03oool00P3oool0
1@2HV9P000000?ooo`000000V9RH00<0oooo00<0V9RH0000003oool09@3oool00`000000oooo0?oo
o`0>0?ooo`002`3oool01`2HV9P0000009RHV03oool0V9RH0000002HV9P0103oool01`2HV9P00000
09RHV03oool0V9RH0000002HV9P0703oool01`2HV9P0000009RHV03oool0V9RH0000002HV9P0103o
ool02P2HV9P0000009RHV03oool0V9RH0000002HV9P0oooo09RHV000000209RHV0030000002HV9P0
oooo01P0oooo00L0V9RH0000002HV9P0oooo09RHV0000000V9RH00@0oooo00L0V9RH0000002HV9P0
oooo09RHV0000000V9RH00D0oooo00<0EEEE0000003oool0603oool01`2HV9P0000009RHV03oool0
V9RH0000002HV9P0103oool01`2HV9P0000009RHV03oool0V9RH0000002HV9P00`3oool206IVIP03
0=gMg@3oool0oooo01P0oooo00L0V9RH0000002HV9P0oooo09RHV0000000V9RH00@0oooo00l0V9RH
0000002HV9P0oooo09RHV0000000V9RH0?ooo`2HV9P0000009RHV03oool0V9RH0000002HV9P09P3o
ool00`000000oooo0?ooo`0>0?ooo`00303oool01@2HV9P00000000000000000V9RH00H0oooo00D0
V9RH000000000000000009RHV00N0?ooo`0509RHV000000000000000002HV9P01P3oool01@2HV9P0
0000000000000000V9RH00<0oooo00@0V9RH000000000000V9RH6`3oool01@2HV9P0000000000000
0000V9RH00H0oooo00D0V9RH000000000000000009RHV0060?ooo`030>k^kP0Q8B40oooo01T0oooo
00D0V9RH000000000000000009RHV0060?ooo`0509RHV000000000000000002HV9P01@3oool0102j
^[X0EEEE05EEE@2HV9PI0?ooo`0509RHV000000000000000002HV9P01P3oool01@2HV9P000000000
00000000V9RH00<0oooo00D0V9RH000000000000000009RHV00W0?ooo`030000003oool0oooo00h0
oooo003o0?oooa00oooo00<000000?ooo`3oool03P3oool00>X0oooo4`00000B0?ooo`030000003o
ool0oooo00h0oooo003N0?ooo``000004`3oool;000000L0oooo00<000000?ooo`3oool03P3oool0
0=P0oooo1P00000Z0?ooo`D000000P3oool00`000000oooo0?ooo`0>0?ooo`003`3ooooo000000P0
00002P3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00L0oooo1@00000:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
3P3oool00</0oooo0`0000110?ooo`030000003oool0oooo00h0oooo00380?ooo`<00000A03oool0
0`000000oooo0?ooo`0>0?ooo`00a03oool4000004L0oooo00<000000?ooo`3oool03P3oool00<40
oooo0`00001;0?ooo`030000003oool0oooo00h0oooo002n0?ooo`<00000CP3oool00`000000oooo
0?ooo`0>0?ooo`00^`3oool300000540oooo00<000000?ooo`3oool03P3oool00;P0oooo0`00001D
0?ooo`8000003`3oool00;D0oooo0`00001G0?ooo`030000003oool0oooo00h0oooo002b0?ooo`<0
0000FP3oool00`000000oooo0?ooo`0>0?ooo`00/03oool2000005d0oooo00<000000?ooo`3oool0
3P3oool00:h0oooo0P00001O0?ooo`030000003oool0oooo00h0oooo002[0?ooo`<00000H@3oool0
0`000000oooo0?ooo`0>0?ooo`00Z@3oool2000006@0oooo00<000000?ooo`3oool03P3oool00:L0
oooo0P00001V0?ooo`030000003oool0oooo00h0oooo002U0?ooo`800000J03oool2000000l0oooo
002S0?ooo`800000JP3oool00`000000oooo0?ooo`0>0?ooo`00X@3oool2000006`0oooo00<00000
0?ooo`3oool03P3oool009l0oooo0P00001^0?ooo`030000003oool0oooo00h0oooo002M0?ooo`80
0000L03oool00`000000oooo0?ooo`0>0?ooo`00V`3oool200000780oooo00<000000?ooo`3oool0
3P3oool009T0oooo0P00001d0?ooo`030000003oool0oooo00h0oooo002H0?ooo`030000003oool0
oooo07@0oooo00<000000?ooo`3oool03P3oool009H0oooo0P00001g0?ooo`8000003`3oool009@0
oooo0P00001i0?ooo`030000003oool0oooo00h0oooo002C0?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool03P3oool00940oooo0P00001l0?ooo`030000003oool0oooo00h0oooo002?
0?ooo`800000OP3oool00`000000oooo0?ooo`0>0?ooo`00SP3oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo00h0oooo002<0?ooo`800000P@3oool00`000000oooo0?ooo`0>0?ooo`00
RP3oool2000008<0oooo00<000000?ooo`3oool03P3oool008T0oooo00<000000?ooo`3oool0P`3o
ool2000000l0oooo00270?ooo`800000QP3oool00`000000oooo0?ooo`0>0?ooo`00QP3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo00h0oooo00250?ooo`030000003oool0oooo08L0
oooo00<000000?ooo`3oool03P3oool008@0oooo00<000000?ooo`3oool0R03oool00`000000oooo
0?ooo`0>0?ooo`00PP3oool2000005/0oooo00D0V9RH000000000000000009RHV0030?ooo`04038b
<P3oool0oooo09RHV0<0000000D0V9RH0?ooo`3oool0oooo09RHV0030000000509RHV03oool0oooo
0?ooo`2HV9P00`000000102HV9P0oooo0?ooo`14A4@40000000309RHV03oool0oooo00H0oooo00<0
00000?ooo`3oool03P3oool00840oooo00<000000?ooo`3oool0FP3oool01`2HV9P0000009RHV03o
ool0V9RH0000002HV9P0103oool05`2HV9P0000009RHV03oool0V9RH0000002HV9P0oooo09RHV000
0000V9RH0?ooo`2HV9P0000009RHV03oool0V9RH0000002HV9P0oooo09RHV0000000V9RH00D0oooo
00<0V9RH0000002HV9P01`3oool00`000000oooo0?ooo`0>0?ooo`00P03oool00`000000oooo0?oo
o`1K0?ooo`030000002HV9P0oooo0080oooo00<0V9RH0000003oool00`3oool00`000000V9RH0?oo
o`020?ooo`0509RHV0000000oooo0000002HV9P00`3oool01@2HV9P000000?ooo`000000V9RH00<0
oooo00<0V9RH0000003oool01@3oool00`2HV9P000000?ooo`060?ooo`030000003oool0oooo00h0
oooo001o0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001@3oool00`000000oooo
000000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool2000000l0oooo
001m0?ooo`800000G`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000050?ooo`030000003oool0000000D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo001l
0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001@3oool00`000000oooo00000005
0?ooo`030000003oool0oooo00@0oooo00<0V9RH0000003oool01P3oool00`000000oooo0?ooo`0>
0?ooo`00N`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000D0oooo00<000000?oo
o`0000001@3oool00`000000oooo0?ooo`030?ooo`0309RHV0000000V9RH00L0oooo00<000000?oo
o`3oool03P3oool007T0oooo0P00001S0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000D0oooo00<000000?ooo`00
00001@3oool00`000000oooo0;Zj^P040000000309RHV03oool0oooo00H0oooo00<000000?ooo`3o
ool03P3oool007P0oooo00<000000?ooo`3oool0H`3oool00`000000V9RH0?ooo`020?ooo`0309RH
V0000000oooo00<0oooo00<0000009RHV03oool00P3oool01@2HV9P000000?ooo`000000V9RH00<0
oooo00D0V9RH0000003oool0000009RHV0030?ooo`0609RHV0000000oooo0?ooo`0@4100gMgM2`3o
ool00`000000oooo0?ooo`0>0?ooo`00MP3oool2000006H0oooo00L0V9RH0000002HV9P0oooo09RH
V0000000V9RH00@0oooo01L0V9RH0000002HV9P0oooo09RHV0000000V9RH0?ooo`2HV9P0000009RH
V03oool0V9RH0000002HV9P0oooo09RHV0000000V9RH0?ooo`2HV9P0000009RHV0020?ooo`0308N7
Q`1VIVH0oooo00X0oooo00<000000?ooo`3oool03P3oool007D0oooo00<000000?ooo`3oool0I`3o
ool01@2HV9P00000000000000000V9RH00H0oooo00D0V9RH000000000000000009RHV0030?ooo`05
09RHV000000000000000002HV9P00`3oool01@2HV9P00000000000000000V9RH00<0oooo00<0gMgM
0000000000000P0000000`0b<S80oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo001d0?oo
o`030000003oool0oooo09P0oooo0P00000?0?ooo`00LP3oool2000009/0oooo00<000000?ooo`3o
ool03P3oool00740oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0>0?ooo`00L03o
ool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo00h0oooo001_0?ooo`030000003oool0
oooo09d0oooo00<000000?ooo`3oool03P3oool006d0oooo0P00002P0?ooo`030000003oool0oooo
00h0oooo001/0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool03P3oool006/0oooo
00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0>0?ooo`00JP3oool00`000000oooo0?oo
o`2R0?ooo`8000003`3oool006P0oooo0P00002U0?ooo`030000003oool0oooo00h0oooo001W0?oo
o`030000003oool0oooo0:D0oooo00<000000?ooo`3oool03P3oool006H0oooo00<000000?ooo`3o
ool0YP3oool00`000000oooo0?ooo`0>0?ooo`00I@3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo00h0oooo001T0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool03P3o
ool006<0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0>0?ooo`00HP3oool00`00
0000oooo0?ooo`2Z0?ooo`030000003oool0oooo00h0oooo001Q0?ooo`030000003oool0oooo0:/0
oooo0P00000?0?ooo`00H03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo00h0oooo
001O0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool03P3oool005d0oooo0P00002`
0?ooo`030000003oool0oooo00h0oooo001L0?ooo`030000003oool0oooo0;00oooo00<000000?oo
o`3oool03P3oool005/0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0>0?ooo`00
FP3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo00h0oooo001I0?ooo`030000003o
ool0oooo0;<0oooo00<000000?ooo`3oool03P3oool005P0oooo00<000000?ooo`3oool0]03oool2
000000l0oooo001G0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool03P3oool005H0
oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0>0?ooo`00E@3oool00`000000oooo
0?ooo`2g0?ooo`030000003oool0oooo00h0oooo001D0?ooo`030000003oool0oooo0;P0oooo00<0
00000?ooo`3oool03P3oool005<0oooo00<000000?ooo`3oool0T@3oool01@2HV9P0000000000000
0000V9RH00<0oooo00@0<S8b0?ooo`3oool0V9RH0`0000001@2HV9P0oooo0?ooo`3oool0V9RH00<0
000000@0V9RH0?ooo`3oool0oooo1@0000080?ooo`030000003oool0oooo00h0oooo001C0?ooo`03
0000003oool0oooo0900oooo00L0V9RH0000002HV9P0oooo09RHV0000000V9RH00@0oooo00l0V9RH
0000002HV9P0oooo09RHV0000000V9RH0?ooo`2HV9P0000009RHV03oool0V9RH0000002HV9P0103o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo001B0?ooo`030000003oool0
oooo0940oooo00<0000009RHV03oool00P3oool00`2HV9P000000?ooo`030?ooo`030000002HV9P0
oooo0080oooo00D0V9RH0000003oool0000009RHV0030?ooo`0309RHV0000000oooo00<0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`00D@3oool00`000000oooo0?ooo`2B
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08
0?ooo`8000003`3oool00500oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?oo
o`00C`3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo001>0?ooo`030000
003oool0oooo09D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool004d0oooo00<000000?ooo`3oool0UP3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0>0?ooo`00C03oool00`000000oooo0?ooo`2G0?ooo`030000002HV9P0
oooo0080oooo00<0V9RH0000003oool00`3oool00`000000V9RH0?ooo`020?ooo`0509RHV0000000
oooo0000002HV9P00`3oool00`2HV9P000000?ooo`030?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool03P3oool004/0oooo00<000000?ooo`3oool0V03oool01`2HV9P0000009RHV03o
ool0V9RH0000002HV9P0103oool03`2HV9P0000009RHV03oool0V9RH0000002HV9P0oooo09RHV000
0000V9RH0?ooo`2HV9P0000009RHV0020?ooo`80<S8b00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0>0?ooo`00BP3oool00`000000oooo0?ooo`2J0?ooo`0509RHV000000000000000002H
V9P01P3oool01@2HV9P00000000000000000V9RH00<0oooo00D0V9RH000000000000000009RHV003
0?ooo`030>k^kP2HV9P0410@00X0oooo00<000000?ooo`3oool03P3oool004T0oooo00<000000?oo
o`3oool0``3oool2000000l0oooo00190?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3o
ool03P3oool004P0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0>0?ooo`00A`3o
ool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00160?ooo`030000003oool0
oooo0<H0oooo00<000000?ooo`3oool03P3oool004D0oooo00<000000?ooo`3oool0a`3oool00`00
0000oooo0?ooo`0>0?ooo`00A03oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00h0
oooo00140?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool03P3oool004<0oooo00<0
00000?ooo`3oool0b@3oool2000000l0oooo00120?ooo`030000003oool0oooo0<X0oooo00<00000
0?ooo`3oool03P3oool00440oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0>0?oo
o`00@03oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00h0oooo000o0?ooo`030000
003oool0oooo0<d0oooo00<000000?ooo`3oool03P3oool003l0oooo00<000000?ooo`3oool0c@3o
ool00`000000oooo0?ooo`0>0?ooo`00?P3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0
oooo00h0oooo000m0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool03P3oool003`0
oooo00<000000?ooo`3oool0d03oool2000000l0oooo000k0?ooo`030000003oool0oooo0=40oooo
00<000000?ooo`3oool03P3oool003X0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?oo
o`0>0?ooo`00>@3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00h0oooo000h0?oo
o`030000003oool0oooo0=@0oooo00<000000?ooo`3oool03P3oool003L0oooo00<000000?ooo`3o
ool0e@3oool00`000000oooo0?ooo`0>0?ooo`00=P3oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo00h0oooo000e0?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool03P3o
ool003D0oooo00<000000?ooo`3oool0e`3oool2000000l0oooo000d0?ooo`030000003oool0oooo
0=P0oooo00<000000?ooo`3oool03P3oool003<0oooo00<000000?ooo`3oool0f@3oool00`000000
oooo0?ooo`0>0?ooo`00<P3oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo00h0oooo
000a0?ooo`030000003oool0oooo0=/0oooo00<000000?ooo`3oool03P3oool00300oooo00<00000
0?ooo`3oool0[03oool01@2HV9P00000000000000000V9RH00<0oooo00@0<S8b0?ooo`3oool0V9RH
0`0000001@2HV9P0oooo0?ooo`3oool0V9RH00<0000000@0V9RH0?ooo`3oool0oooo1@0000020?oo
o`0304A4A000000000000080000000<0V9RH0?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?oo
o`00;`3oool00`000000oooo0?ooo`2/0?ooo`0709RHV0000000V9RH0?ooo`2HV9P0000009RHV004
0?ooo`0?09RHV0000000V9RH0?ooo`2HV9P0000009RHV03oool0V9RH0000002HV9P0oooo09RHV000
0000V9RH00@0oooo00<000000?ooo`3oool01P3oool00`2HV9P0000009RHV0070?ooo`030000003o
ool0oooo00h0oooo000_0?ooo`030000003oool0oooo0:`0oooo00<0000009RHV03oool00P3oool0
0`2HV9P000000?ooo`030?ooo`030000002HV9P0oooo0080oooo00D0V9RH0000003oool0000009RH
V0030?ooo`0309RHV0000000oooo00<0oooo00<000000?ooo`3oool01`3oool00`2HV9P000000?oo
o`060?ooo`030000003oool0oooo00h0oooo000^0?ooo`030000003oool0oooo0:d0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01@3oool2000000l0oooo000]0?ooo`030000003oool0oooo0:h0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`00;03oool00`000000oooo0?ooo`2_0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`03
09RHV0000000oooo00H0oooo00<000000?ooo`3oool03P3oool002/0oooo00<000000?ooo`3oool0
/03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`2HV9P0000009RHV0070?ooo`030000003oool0oooo00h0oooo000Z0?ooo`030000003o
ool0oooo0;40oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<0^[Zj0000000000000P0000000`2HV9P0oooo0?ooo`060?ooo`030000003o
ool0oooo00h0oooo000Z0?ooo`030000003oool0oooo0;40oooo00<0000009RHV03oool00P3oool0
0`2HV9P000000?ooo`030?ooo`030000002HV9P0oooo0080oooo00D0V9RH0000003oool0000009RH
V0030?ooo`0309RHV0000000oooo00<0oooo00<000000?ooo`3oool00`3oool00`0@4100gMgM0?oo
o`0:0?ooo`030000003oool0oooo00h0oooo000Y0?ooo`030000003oool0oooo0;80oooo00L0V9RH
0000002HV9P0oooo09RHV0000000V9RH00@0oooo00l0V9RH0000002HV9P0oooo09RHV0000000V9RH
0?ooo`2HV9P0000009RHV03oool0V9RH0000002HV9P00P3oool2038b<P030000003oool0oooo00<0
oooo00<0QhN706IVIP3oool02P3oool00`000000oooo0?ooo`0>0?ooo`00:03oool00`000000oooo
0?ooo`2d0?ooo`0509RHV000000000000000002HV9P01P3oool01@2HV9P00000000000000000V9RH
00<0oooo00D0V9RH000000000000000009RHV0030?ooo`030>k^kP2HV9P0410@00D0oooo00<0gMgM
0000000000000P0000000`0b<S80oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo000W0?oo
o`030000003oool0oooo0>D0oooo0P00000?0?ooo`009P3oool00`000000oooo0?ooo`3V0?ooo`03
0000003oool0oooo00h0oooo000V0?ooo`030000003oool0oooo0>H0oooo00<000000?ooo`3oool0
3P3oool002D0oooo00<000000?ooo`3oool0i`3oool00`000000oooo0?ooo`0>0?ooo`00903oool0
0`000000oooo0?ooo`3X0?ooo`030000003oool0oooo00h0oooo000S0?ooo`030000003oool0oooo
0>T0oooo00<000000?ooo`3oool03P3oool002<0oooo00<000000?ooo`3oool0j@3oool00`000000
oooo0?ooo`0>0?ooo`008P3oool00`000000oooo0?ooo`3Z0?ooo`030000003oool0oooo00h0oooo
000Q0?ooo`030000003oool0oooo0>/0oooo0P00000?0?ooo`00803oool00`000000oooo0?ooo`3/
0?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo0>d0oooo00<000000?oo
o`3oool03P3oool001l0oooo00<000000?ooo`3oool0k@3oool00`000000oooo0?ooo`0>0?ooo`00
7P3oool00`000000oooo0?ooo`3^0?ooo`030000003oool0oooo00h0oooo000M0?ooo`030000003o
ool0oooo0>l0oooo00<000000?ooo`3oool03P3oool001`0oooo00<000000?ooo`3oool0l03oool0
0`000000oooo0?ooo`0>0?ooo`00703oool00`000000oooo0?ooo`3`0?ooo`030000003oool0oooo
00h0oooo000K0?ooo`030000003oool0oooo0?40oooo0P00000?0?ooo`006P3oool00`000000oooo
0?ooo`3b0?ooo`030000003oool0oooo00h0oooo000J0?ooo`030000003oool0oooo0?80oooo00<0
00000?ooo`3oool03P3oool001T0oooo00<000000?ooo`3oool0l`3oool00`000000oooo0?ooo`0>
0?ooo`00603oool00`000000oooo0?ooo`3d0?ooo`030000003oool0oooo00h0oooo000G0?ooo`03
0000003oool0oooo0?D0oooo00<000000?ooo`3oool03P3oool001L0oooo00<000000?ooo`3oool0
m@3oool00`000000oooo0?ooo`0>0?ooo`005P3oool00`000000oooo0?ooo`3f0?ooo`030000003o
ool0oooo00h0oooo000E0?ooo`030000003oool0oooo0?L0oooo0P00000?0?ooo`00o`3oool@0?oo
o`030000003oool0oooo00h0oooo003o0?oooa00oooo00<000000?ooo`3oool03P3oool00?l0oooo
403oool00`000000oooo0?ooo`0>0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.891409, -0.000264889, \
0.000400277, 1.24481*^-5}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pn = 0.001;\)\), "\[IndentingNewLine]", 
    \(\(\((1 - 
          pn\^2)\) \((\(2\/ngt\[LeftDoubleBracket]1\[RightDoubleBracket]\) 
            homs . \(pn\/\(p0 + 2  pn\)\) + 
          pn\^2\/\(1 - pn\^2\))\)\(\[IndentingNewLine]\)\)\)}], "Input"],

Cell[BoxData[
    \(0.002207436178304767`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pn = %;\)\), "\[IndentingNewLine]", 
    \(\(\((1 - 
          pn\^2)\) \((\(2\/ngt\[LeftDoubleBracket]1\[RightDoubleBracket]\) 
            homs . \(pn\/\(p0 + 2  pn\)\) + 
          pn\^2\/\(1 - pn\^2\))\)\(\[IndentingNewLine]\)\)\)}], "Input"],

Cell[BoxData[
    \(0.3866691738834167`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pn = %;\)\), "\[IndentingNewLine]", 
    \(\(\((1 - 
          pn\^2)\) \((\(2\/ngt\[LeftDoubleBracket]1\[RightDoubleBracket]\) 
            homs . \(pn\/\(p0 + 2  pn\)\) + 
          pn\^2\/\(1 - pn\^2\))\)\(\[IndentingNewLine]\)\)\)}], "Input"],

Cell[BoxData[
    \(0.3287439922811551`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pn = %;\)\), "\[IndentingNewLine]", 
    \(\(\((1 - 
          pn\^2)\) \((\(2\/ngt\[LeftDoubleBracket]1\[RightDoubleBracket]\) 
            homs . \(pn\/\(p0 + 2  pn\)\) + 
          pn\^2\/\(1 - pn\^2\))\)\(\[IndentingNewLine]\)\)\)}], "Input"],

Cell[BoxData[
    \(0.40312491644213666`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(at = AlleleFrequencyTable[s[sika, pol], al]\)], "Input"],

Cell[BoxData[
    \({{0, 1\/488, 3\/244, 0, 111\/488, 185\/244}, {0, 122\/125, 0, 0, 
        1\/100, 1\/250, 1\/500, 0, 1\/125, 0}, {0, 0, 0, 2\/245, 6\/245, 0, 
        1\/70, 1\/14, 1\/245, 1\/490, 429\/490}, {0, 49\/50, 0, 7\/500, 
        3\/500, 0}, {0, 0, 1\/470, 0, 6\/235, 1\/470, 0, 0, 0, 1\/235, 0, 
        28\/47, 133\/470, 41\/470}, {243\/250, 9\/500, 0, 0, 0, 1\/500, 0, 
        3\/500, 1\/500, 0, 0, 0}, {79\/83, 0, 4\/83, 0}, {0, 3\/500, 
        497\/500}, {1\/100, 3\/125, 0, 477\/500, 0, 0, 0, 0, 0, 0, 0, 1\/250, 
        1\/500, 3\/500, 0}, {0, 0, 0, 0, 0, 3\/125, 9\/500, 0, 479\/500, 0, 
        0}, {0, 0, 5\/248, 1\/248, 1\/496, 0, 483\/496}, {21\/496, 
        475\/496}, {8\/243, 1\/81, 323\/486, 70\/243, 1\/486}, {0, 0, 0, 
        1\/125, 11\/500, 1\/125, 0, 0, 441\/500, 2\/25, 0, 0, 0}, {1\/500, 0, 
        0, 0, 0, 0, 0, 0, 1\/500, 1\/250, 0, 124\/125, 0}, {28\/39, 89\/468, 
        43\/468}, {0, 75\/83, 0, 0, 0, 7\/498, 19\/249, 0, 0, 1\/249, 1\/498, 
        0}, {7\/496, 0, 0, 1\/124, 1\/124, 3\/496, 469\/496, 
        9\/496}, {119\/122, 0, 7\/488, 0, 0, 3\/488, 0, 1\/244, 0}, {3\/250, 
        3\/125, 241\/250, 0}, {3\/470, 11\/470, 0, 1\/94, 45\/47, 
        1\/470}, {9\/500, 4\/125, 19\/20}, {449\/500, 0, 3\/500, 9\/125, 0, 
        3\/125, 0, 0, 0, 0, 0, 0, 0, 0}, {481\/500, 0, 0, 0, 1\/500, 0, 0, 0, 
        0, 1\/500, 0, 0, 0, 0, 0, 1\/500, 1\/500, 0, 0, 0, 1\/250, 3\/250, 
        1\/500, 3\/250, 0, 0, 0, 0, 0}, {1\/500, 4\/125, 
        483\/500}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(alN = 
      ReplacePart[al, 
        Append[al\[LeftDoubleBracket]1\[RightDoubleBracket], \[Nu]], 
        1]\)], "Input"],

Cell[BoxData[
    \({{251, 253, 255, 263, 267, 277, \[Nu]}, {122, 126, 128, 130, 132, 134, 
        136, 140, 142, 144}, {190, 198, 202, 204, 206, 208, 210, 212, 214, 
        216, 218}, {118, 128, 130, 132, 134, 136}, {120, 122, 126, 128, 130, 
        132, 134, 136, 138, 140, 142, 146, 162, 182}, {115, 123, 125, 127, 
        129, 131, 135, 137, 139, 141, 147, 163}, {89, 91, 97, 99}, {227, 233, 
        239}, {163, 165, 167, 175, 177, 179, 183, 187, 189, 191, 193, 201, 
        203, 205, 207}, {151, 155, 157, 159, 161, 171, 173, 179, 197, 209, 
        215}, {93, 95, 99, 101, 103, 105, 107}, {128, 144}, {143, 145, 155, 
        157, 159}, {191, 193, 195, 197, 199, 201, 205, 207, 213, 215, 221, 
        223, 225}, {101, 103, 105, 107, 111, 113, 115, 117, 119, 121, 127, 
        129, 139}, {105, 106, 109}, {120, 128, 132, 134, 136, 138, 140, 142, 
        144, 146, 148, 154}, {115, 121, 123, 129, 131, 133, 139, 
        241 + W}, {144, 146, 150, 152, 154, 156, 158, 160, 162}, {139, 147, 
        159, 193}, {94, 100, 102, 104, 108, 110}, {89, 91, 93}, {157, 163, 
        165, 169, 171, 173, 175, 177, 179, 181, 183, 185, 187, 189}, {181, 
        182, 183, 185, 186, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 
        198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 211, 
        212}, {126, 142, 144}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ptN = 
      ReplacePart[pt, 
        Append[pt\[LeftDoubleBracket]1\[RightDoubleBracket] \((1 - pn)\), 
          pn], 1]\)], "Input"],

Cell[BoxData[
    \({{0.`\ \((1 - pn)\), 0.0021551724137931034`\ \((1 - pn)\), 
        0.0021551724137931034`\ \((1 - pn)\), 0.`\ \((1 - pn)\), 
        0.23706896551724138`\ \((1 - pn)\), 
        0.7586206896551724`\ \((1 - pn)\), pn}, {0.`, 0.9873949579831933`, 
        0.`, 0.`, 0.004201680672268907`, 0.`, 0.`, 0.`, 
        0.008403361344537815`, 0.`}, {0.`, 0.`, 0.`, 0.008547008547008548`, 
        0.008547008547008548`, 0.`, 0.008547008547008548`, 
        0.057692307692307696`, 0.004273504273504274`, 0.`, 
        0.9123931623931624`}, {0.`, 0.9978991596638656`, 0.`, 
        0.0021008403361344537`, 0.`, 0.`}, {0.`, 0.`, 0.002242152466367713`, 
        0.`, 0.002242152466367713`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 
        0.6165919282511211`, 0.289237668161435`, 
        0.08968609865470852`}, {0.9915966386554622`, 0.0021008403361344537`, 
        0.`, 0.`, 0.`, 0.`, 0.`, 0.004201680672268907`, 
        0.0021008403361344537`, 0.`, 0.`, 0.`}, {0.9620253164556962`, 0.`, 
        0.0379746835443038`, 0.`}, {0.`, 0.0021008403361344537`, 
        0.9978991596638656`}, {0.01050420168067227`, 0.01050420168067227`, 
        0.`, 0.9684873949579832`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 
        0.0021008403361344537`, 0.0021008403361344537`, 
        0.0063025210084033615`, 0.`}, {0.`, 0.`, 0.`, 0.`, 0.`, 
        0.01680672268907563`, 0.004201680672268907`, 0.`, 
        0.9789915966386554`, 0.`, 0.`}, {0.`, 0.`, 0.00847457627118644`, 
        0.00423728813559322`, 0.`, 0.`, 
        0.9872881355932204`}, {0.027426160337552744`, 
        0.9725738396624473`}, {0.02813852813852814`, 0.`, 
        0.6796536796536796`, 0.29004329004329005`, 
        0.0021645021645021645`}, {0.`, 0.`, 0.`, 0.0063025210084033615`, 
        0.0021008403361344537`, 0.008403361344537815`, 0.`, 0.`, 
        0.8991596638655462`, 0.08403361344537816`, 0.`, 0.`, 0.`}, {0.`, 0.`, 
        0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 1.`, 
        0.`}, {0.7455357142857143`, 0.1875`, 0.06696428571428571`}, {0.`, 
        0.9222689075630253`, 0.`, 0.`, 0.`, 0.`, 0.07352941176470588`, 0.`, 
        0.`, 0.004201680672268907`, 0.`, 0.`}, {0.014830508474576272`, 0.`, 
        0.`, 0.`, 0.`, 0.`, 0.9703389830508474`, 
        0.014830508474576272`}, {0.9935344827586207`, 0.`, 0.`, 0.`, 0.`, 
        0.00646551724137931`, 0.`, 0.`, 0.`}, {0.`, 0.004201680672268907`, 
        0.9957983193277311`, 0.`}, {0.004484304932735426`, 
        0.002242152466367713`, 0.`, 0.011210762331838564`, 
        0.9798206278026906`, 0.002242152466367713`}, {0.012605042016806723`, 
        0.008403361344537815`, 0.9789915966386554`}, {0.9180672268907563`, 
        0.`, 0.0063025210084033615`, 0.07352941176470588`, 0.`, 
        0.0021008403361344537`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 
        0.`}, {0.976890756302521`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 
        0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 
        0.004201680672268907`, 0.004201680672268907`, 0.0021008403361344537`, 
        0.012605042016806723`, 0.`, 0.`, 0.`, 0.`, 
        0.`}, {0.0021008403361344537`, 0.018907563025210083`, 
        0.9789915966386554`}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(dsN = 
      ReplacePart[\(Data[
            s[sika, pol]]\)\[LeftDoubleBracket]1\[RightDoubleBracket], {277, 
          277}, 1]\)], "Input"],

Cell[BoxData[
    \({{277, 277}, {126, 126}, {206, 218}, {128, 128}, {126, 162}, {115, 
        115}, {89, 89}, {239, 239}, {175, 175}, {197, 197}, {107, 107}, {144, 
        144}, {155, 155}, {213, 213}, {129, 129}, {105, 105}, {128, 
        128}, {139, 139}, {144, 144}, {159, 159}, {108, 108}, {93, 93}, {157, 
        157}, {181, 181}, {144, 144}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GenotypeFrequency[dsN, alN, ptN, NullAllele \[Rule] \[Nu], 
      MissingData \[Rule] True]\)], "Input"],

Cell[BoxData[
    \(1.7026805652208365`*^-6\ \((0.5755053507728893`\/\((1 - pn)\)\^2 + \
\(1.5172413793103448`\ pn\)\/\(1 - pn\))\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MapIndexed[
      GenotypeFrequency[#2\[LeftDoubleBracket]1\[RightDoubleBracket], #1, 
          alN, ptN, NullAllele \[Rule] \[Nu], MissingData \[Rule] True] &, 
      dsN]\)], "Input"],

Cell[BoxData[
    \({0.5755053507728893`\/\((1 - pn)\)\^2 + \(1.5172413793103448`\ \
pn\)\/\(1 - pn\), 0.9749488030506321`, 0.015596464314413033`, 
      0.995802732857849`, 0.0012970299020692152`, 0.9832638937928113`, 
      0.9254927095016825`, 0.995802732857849`, 0.9379678341925005`, 
      0.9584245462891038`, 0.9747378626831371`, 0.9458998735957557`, 
      0.46192912426678656`, 0.8084881011228021`, 1.`, 0.5558235012755103`, 
      0.8505799378574961`, 0.9415577420281528`, 0.9871107684304399`, 
      0.9916142927759339`, 0.9600484626676589`, 0.9584245462891038`, 
      0.8428474330908833`, 0.9543155497493114`, 
      0.9584245462891038`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(dsN[\([3]\)]\)], "Input"],

Cell[BoxData[
    \({206, 218}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GenotypeFrequency[3, {206, 218}, alN, ptN, 
      NullAllele \[Rule] \[Nu]]\)], "Input"],

Cell[BoxData[
    \(0.015596464314413033`\/\(1 - pn\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(alN\[LeftDoubleBracket]4\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \({118, 128, 130, 132, 134, 136}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MapIndexed[
      gf[#2\[LeftDoubleBracket]1\[RightDoubleBracket], #1] &, \(Data[
          s[sika, pol]]\)\[LeftDoubleBracket]1\[RightDoubleBracket]]\)], \
"Input"],

Cell[BoxData[
    \({gf[1, {277, 277}], gf[2, {126, 126}], gf[3, {206, 218}], 
      gf[4, {128, 128}], gf[5, {126, 162}], gf[6, {115, 115}], 
      gf[7, {89, 89}], gf[8, {239, 239}], gf[9, {175, 175}], 
      gf[10, {197, 197}], gf[11, {107, 107}], gf[12, {144, 144}], 
      gf[13, {155, 155}], gf[14, {213, 213}], gf[15, {129, 129}], 
      gf[16, {105, 105}], gf[17, {128, 128}], gf[18, {139, 139}], 
      gf[19, {144, 144}], gf[20, {159, 159}], gf[21, {108, 108}], 
      gf[22, {93, 93}], gf[23, {157, 157}], gf[24, {181, 181}], 
      gf[25, {144, 144}]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GenotypeFrequency[
      ReplacePart[\(Data[
            s[sika, pol]]\)\[LeftDoubleBracket]1\[RightDoubleBracket], \
\[EmptySet], 2], al, pt]\)], "Input"],

Cell[BoxData[
    \(1.0050802389576445`*^-6\ \[EmptySet]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GenotypeFrequency[ReplacePart[dd, \[EmptySet], 1], al, pt]\)], "Input"],

Cell[BoxData[
    \(5.5597824307082395`*^-6\ \[EmptySet]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GenotypeFrequency[x : {\(({_, _} | \[EmptySet])\) ... }, al, 
      pt]\)], "Input"],

Cell[BoxData[
    \(4.2177659819165945`*^-6\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(dd // Depth\)], "Input"],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Data[s[sika, pol]]\)\[LeftDoubleBracket]1\[RightDoubleBracket] // 
      Depth\)], "Input"],

Cell[BoxData[
    \(3\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?Depth\)\)], "Input"],

Cell[BoxData[
    \("Depth[expr] gives the maximum number of indices needed to specify any \
part of expr, plus one."\)], "Print"]
}, Open  ]],

Cell[BoxData[{
    \(\(Clear[ff];\)\), "\[IndentingNewLine]", 
    \(\(ff[x : {\(({_, _} | \[EmptySet])\) ... }] := 
        dip[x];\)\), "\[IndentingNewLine]", 
    \(\(ff[x_List] := hap;\)\[IndentingNewLine]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ff[dd]\)], "Input"],

Cell[BoxData[
    \(hap\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatchQ[\(Data[
          s[sika, pol]]\)\[LeftDoubleBracket]1\[RightDoubleBracket], {\(({_, \
_} | \[EmptySet])\) ... }]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{959, 682},
WindowMargins->{{Automatic, 66}, {16, Automatic}},
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\[Placeholder]", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 64, 1, 42, "Subsubsection",
  InitializationCell->True],
Cell[1806, 54, 232, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[2075, 63, 63, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[2141, 66, 276, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[2454, 76, 70, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[2527, 79, 579, 9, 107, "Input",
  InitializationCell->True],
Cell[3109, 90, 158, 3, 27, "Input",
  InitializationCell->True],
Cell[3270, 95, 2242, 39, 426, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5549, 139, 68, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[5620, 142, 489, 9, 91, "Input",
  InitializationCell->True],
Cell[6112, 153, 136, 3, 27, "Input",
  InitializationCell->True],
Cell[6251, 158, 637, 13, 107, "Input",
  InitializationCell->True],
Cell[6891, 173, 236, 5, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[7164, 183, 79, 0, 28, "Subsubsection"],
Cell[7246, 185, 435, 10, 46, "Text"],
Cell[7684, 197, 497, 13, 25, "InlineFormula"],
Cell[8184, 212, 61, 0, 30, "Text"],
Cell[8248, 214, 1194, 32, 30, "InlineFormula"],
Cell[9445, 248, 107, 3, 30, "Text"],
Cell[9555, 253, 1150, 34, 30, "InlineFormula"],
Cell[10708, 289, 41, 0, 30, "Text"],
Cell[10752, 291, 868, 26, 33, "InlineFormula"],
Cell[11623, 319, 214, 6, 30, "Text"],
Cell[11840, 327, 62, 0, 30, "Text"],
Cell[11905, 329, 1030, 27, 40, "InlineFormula"],
Cell[12938, 358, 22, 0, 30, "Text"],
Cell[12963, 360, 1243, 34, 37, "InlineFormula"],
Cell[14209, 396, 38, 0, 30, "Text"],
Cell[14250, 398, 375, 8, 37, "InlineFormula"],
Cell[14628, 408, 72, 0, 30, "Text"],
Cell[14703, 410, 830, 21, 38, "InlineFormula"],
Cell[15536, 433, 193, 5, 30, "Text"],
Cell[15732, 440, 722, 20, 60, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16491, 465, 45, 0, 42, "Subsubsection"],
Cell[16539, 467, 116, 2, 27, "Input"],
Cell[16658, 471, 138, 2, 27, "Input"],
Cell[16799, 475, 3629, 67, 453, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20465, 547, 32, 0, 42, "Subsubsection"],
Cell[20500, 549, 42, 1, 27, "Input"],
Cell[20545, 552, 749, 16, 123, "Input"],

Cell[CellGroupData[{
Cell[21319, 572, 266, 5, 27, "Input"],
Cell[21588, 579, 55, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21680, 585, 169, 5, 27, "Input"],
Cell[21852, 592, 4222, 63, 461, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[26111, 660, 312, 6, 56, "Input"],
Cell[26426, 668, 338, 6, 84, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26801, 679, 93, 1, 27, "Input"],
Cell[26897, 682, 564, 9, 113, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27498, 696, 585, 10, 103, "Input"],
Cell[28086, 708, 35, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28158, 714, 35, 1, 27, "Input"],
Cell[28196, 717, 76, 1, 42, "Output"]
}, Open  ]],
Cell[28287, 721, 344, 6, 47, "Input"],

Cell[CellGroupData[{
Cell[28656, 731, 65, 1, 27, "Input"],
Cell[28724, 734, 164, 3, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28925, 742, 133, 2, 27, "Input"],
Cell[29061, 746, 76, 1, 42, "Output"]
}, Open  ]],
Cell[29152, 750, 143, 3, 47, "Input"],

Cell[CellGroupData[{
Cell[29320, 757, 153, 3, 27, "Input"],
Cell[29476, 762, 153, 2, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29666, 769, 439, 7, 27, "Input"],
Cell[30108, 778, 153, 2, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30298, 785, 78, 1, 27, "Input"],
Cell[30379, 788, 37, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30453, 794, 66, 1, 27, "Input"],
Cell[30522, 797, 574, 10, 87, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31133, 812, 126, 2, 47, "Input"],
Cell[31262, 816, 103, 2, 26, "Output"]
}, Open  ]],
Cell[31380, 821, 89, 1, 27, "Input"],
Cell[31472, 824, 107, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[31604, 830, 108, 2, 27, "Input"],
Cell[31715, 834, 168, 3, 21, "Message"],
Cell[31886, 839, 188, 3, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32111, 847, 35, 1, 27, "Input"],
Cell[32149, 850, 591, 8, 124, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32777, 863, 44, 1, 27, "Input"],
Cell[32824, 866, 141, 2, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33002, 873, 188, 3, 27, "Input"],
Cell[33193, 878, 13143, 184, 1410, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[46373, 1067, 44, 1, 24, "Input"],
Cell[46420, 1070, 141, 2, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46598, 1077, 44, 1, 27, "Input"],
Cell[46645, 1080, 64, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46746, 1086, 446, 8, 82, "Input"],
Cell[47195, 1096, 181, 3, 21, "Message"],
Cell[47379, 1101, 181, 3, 21, "Message"],
Cell[47563, 1106, 181, 3, 21, "Message"],
Cell[47747, 1111, 167, 3, 21, "Message"],
Cell[47917, 1116, 360, 6, 35, "Message"],
Cell[48280, 1124, 484, 8, 67, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[48801, 1137, 48, 1, 24, "Input"],
Cell[48852, 1140, 587, 9, 87, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49476, 1154, 64, 1, 27, "Input"],
Cell[49543, 1157, 90, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49670, 1163, 37, 1, 27, "Input"],
Cell[49710, 1166, 55, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49802, 1172, 92, 1, 27, "Input"],
Cell[49897, 1175, 239, 4, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50173, 1184, 279, 5, 47, "Input"],
Cell[50455, 1191, 308, 5, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50800, 1201, 106, 2, 27, "Input"],
Cell[50909, 1205, 85, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51031, 1211, 207, 4, 43, "Input"],
Cell[51241, 1217, 39662, 997, 186, 11501, 645, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[90918, 2217, 1030, 27, 40, "InlineFormula"],
Cell[91951, 2246, 2377, 71, 145, "InlineFormula"],
Cell[94331, 2319, 122, 2, 27, "Input"],
Cell[94456, 2323, 34, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[94515, 2328, 146, 2, 43, "Input"],
Cell[94664, 2332, 37555, 925, 186, 10639, 588, "GraphicsData", "PostScript", \
"Graphics"],
Cell[132222, 3259, 91, 1, 26, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[132350, 3265, 266, 5, 24, "Input"],
Cell[132619, 3272, 55, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[132711, 3278, 130, 2, 27, "Input"],
Cell[132844, 3282, 110, 2, 26, "Output"]
}, Open  ]],
Cell[132969, 3287, 42, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[133036, 3292, 126, 3, 27, "Input"],
Cell[133165, 3297, 141, 2, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[133343, 3304, 477, 8, 120, "Input"],
Cell[133823, 3314, 56, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[133916, 3320, 57, 1, 27, "Input"],
Cell[133976, 3323, 326, 6, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[134339, 3334, 53, 1, 27, "Input"],
Cell[134395, 3337, 355, 5, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[134787, 3347, 56, 1, 27, "Input"],
Cell[134846, 3350, 119, 2, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[135002, 3357, 431, 7, 43, "Input"],
Cell[135436, 3366, 278, 5, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[135751, 3376, 383, 5, 44, "Input"],
Cell[136137, 3383, 53, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[136227, 3389, 477, 8, 120, "Input"],
Cell[136707, 3399, 53, 1, 26, "Output"]
}, Open  ]],
Cell[136775, 3403, 834, 21, 38, "InlineFormula"],

Cell[CellGroupData[{
Cell[137634, 3428, 270, 5, 65, "Input"],
Cell[137907, 3435, 31232, 760, 186, 8185, 471, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[169176, 4200, 273, 5, 83, "Input"],
Cell[169452, 4207, 55, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[169544, 4213, 269, 5, 83, "Input"],
Cell[169816, 4220, 54, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[169907, 4226, 269, 5, 83, "Input"],
Cell[170179, 4233, 53, 1, 26, "Output"]
}, Open  ]],
Cell[170247, 4237, 269, 5, 83, "Input"],

Cell[CellGroupData[{
Cell[170541, 4246, 178, 5, 27, "Input"],
Cell[170722, 4253, 3394, 49, 371, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[174153, 4307, 563, 10, 72, "Input"],
Cell[174719, 4319, 35, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[174791, 4325, 57, 1, 27, "Input"],
Cell[174851, 4328, 110, 2, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[174998, 4335, 201, 4, 27, "Input"],
Cell[175202, 4341, 41388, 1048, 186, 12611, 688, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[216627, 5394, 146, 3, 27, "Input"],
Cell[216776, 5399, 483, 7, 87, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[217296, 5411, 56, 1, 27, "Input"],
Cell[217355, 5414, 55, 1, 26, "Output"]
}, Open  ]],
Cell[217425, 5418, 60, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[217510, 5423, 113, 2, 27, "Input"],
Cell[217626, 5427, 44, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[217707, 5433, 79, 1, 27, "Input"],
Cell[217789, 5436, 59, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[217885, 5442, 79, 1, 27, "Input"],
Cell[217967, 5445, 135, 2, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[218139, 5452, 128, 2, 27, "Input"],
Cell[218270, 5456, 76, 1, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[218383, 5462, 188, 4, 27, "Input"],
Cell[218574, 5468, 37, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[218648, 5474, 252, 5, 27, "Input"],
Cell[218903, 5481, 555, 8, 43, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[219495, 5494, 42, 1, 27, "Input"],
Cell[219540, 5497, 37, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[219614, 5503, 35, 1, 27, "Input"],
Cell[219652, 5506, 47, 1, 26, "Output"]
}, Open  ]],
Cell[219714, 5510, 42, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[219781, 5515, 270, 5, 65, "Input"],
Cell[220054, 5522, 31232, 760, 186, 8185, 471, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[251323, 6287, 273, 5, 80, "Input"],
Cell[251599, 6294, 55, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[251691, 6300, 269, 5, 83, "Input"],
Cell[251963, 6307, 53, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[252053, 6313, 269, 5, 83, "Input"],
Cell[252325, 6320, 53, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[252415, 6326, 269, 5, 83, "Input"],
Cell[252687, 6333, 54, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[252778, 6339, 76, 1, 27, "Input"],
Cell[252857, 6342, 1520, 21, 314, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[254414, 6368, 143, 4, 24, "Input"],
Cell[254560, 6374, 1352, 18, 161, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[255949, 6397, 155, 4, 24, "Input"],
Cell[256107, 6403, 3156, 48, 266, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[259300, 6456, 162, 4, 24, "Input"],
Cell[259465, 6462, 366, 5, 56, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[259868, 6472, 124, 2, 24, "Input"],
Cell[259995, 6476, 145, 2, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[260177, 6483, 206, 4, 27, "Input"],
Cell[260386, 6489, 664, 10, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[261087, 6504, 45, 1, 27, "Input"],
Cell[261135, 6507, 44, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[261216, 6513, 108, 2, 27, "Input"],
Cell[261327, 6517, 70, 1, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[261434, 6523, 78, 1, 27, "Input"],
Cell[261515, 6526, 64, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[261616, 6532, 185, 4, 27, "Input"],
Cell[261804, 6538, 577, 9, 86, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[262418, 6552, 175, 4, 27, "Input"],
Cell[262596, 6558, 70, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[262703, 6564, 91, 1, 27, "Input"],
Cell[262797, 6567, 70, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[262904, 6573, 104, 2, 27, "Input"],
Cell[263011, 6577, 57, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[263105, 6583, 44, 1, 27, "Input"],
Cell[263152, 6586, 35, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[263224, 6592, 113, 2, 27, "Input"],
Cell[263340, 6596, 35, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[263412, 6602, 43, 1, 27, "Input"],
Cell[263458, 6605, 130, 2, 22, "Print"]
}, Open  ]],
Cell[263603, 6610, 223, 4, 75, "Input"],

Cell[CellGroupData[{
Cell[263851, 6618, 39, 1, 27, "Input"],
Cell[263893, 6621, 37, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[263967, 6627, 153, 3, 27, "Input"],
Cell[264123, 6632, 38, 1, 26, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

