(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     42735,       1032]*)
(*NotebookOutlinePosition[    115754,       3647]*)
(*  CellTagsIndexPosition[    115313,       3632]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Life cycle with migration", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["Setting up\[Ellipsis]", "SubsubsectionIcon",
  CellTags->"Setting up"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Multilocus`Multilocus`;\)\)], "Input",
  CellLabel->"In[1]:="],

Cell["A simple life cycle is defined using:", "MathCaption"],

Cell[BoxData[{
    \(\(DefineContext[\[GothicCapitalG], {Deme, \ Sex}];\)\), "\n", 
    \(\(DefineContext[\[GothicCapitalG]m, {Deme, \ Sex}];\)\), "\n", 
    \(\(DefineContext[\[GothicCapitalZ], {Deme, Sex, 
          SexOfOrigin}];\)\), "\n", 
    \(\(DefineContext[\[GothicCapitalJ], {Deme, Sex, 
          SexOfOrigin}];\)\), "\n", 
    \(\(DefineContext[\[GothicCapitalA], {Deme, Sex, 
          SexOfOrigin}];\)\), "\n", 
    \(\(DefineContext[\(\[GothicCapitalG]\^*\), {\ Deme, Sex}];\)\)}], "Input",\

  CellLabel->"In[2]:="],

Cell["\<\
The stage \[GothicCapitalG]m is defined so as to allow possible \
migration of haploids; the stage \[GothicCapitalJ] similarly allows for \
migration of diploids.\
\>", "Text"],

Cell["\<\
Assume no selection by specifying that no genes affect \
fitness:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(\[DoubleStruckCapitalW] = {};\)\)], "Input",
  CellLabel->"In[8]:="],

Cell[TextData[{
  "One could just drop the stage \[GothicCapitalA], and go directly from \
\[GothicCapitalJ] to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[GothicCapitalG]\^*\) . \ \ However, \ 
      the\ default\ rules\ assume\ that\ there\ is\ selection, \ \(\(and\)\(\ \
\)\(so\)\(\ \)\(it\)\(\ \)\(is\)\(\ \)\(easier\)\(\ \)\(just\)\(\ \)\(to\)\(\ \
\)\)\)]],
  "keep the extra stage."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Migration of juvenile diploids", "SubsubsectionIcon",
  CellTags->"Juvenile diploid migration"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["rules",
                FontSlant->"Italic"], 
              "=", \((Recombination[]\[Vee]SymmetricRecombination[]\[Vee]\
Selection[{\[GothicCapitalJ], \[GothicCapitalA]}, \[GothicA], \
\[DoubleStruckCapitalW]]\[Vee]Migration[{1, 
                        2} &]\[Vee]UnionOfGametes[]\[Vee]RandomUnion[\
\[GothicCapitalG]]\[Vee]ReferencePointSame[\[GothicCapitalG], {\
\[GothicCapitalA], \[GothicCapitalJ], \
\[GothicCapitalZ]}]\[Vee]ReferencePointZero[{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalG]}])\)}], \(the\ complete\ set\ of\ rules\ required\ to\ \
relate\ the\ new\ gamete\ pool\ \(\[GothicCapitalG]\^*\) 
              to\ the\ old\ gamete\ pool\ \[GothicCapitalG]\)},
          {
            
            RowBox[{\(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}, k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}}\), "//.",
               
              StyleBox["rules",
                
                FontSlant->
                  "Italic"]}], \(applying\ the\ rules\ repeatedly\ gives\ an\ \
expression\ in\ terms\ of\ the\ linkage\ disequilibria\ in\ the\ initial\ \
gamete\ pool\ \(\[GothicCapitalG]\^*\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"Complete rules"],

Cell[TextData[{
  "Different rules can be joined to give a set of rules that transforms the \
",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicM]\_\[DoubleStruckI]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_\[DoubleStruckCapitalU]\)]],
  " at any stage to expressions involving only genotype frequencies in the \
initial gamete pool, \[GothicCapitalG]:"
}], "Text"],

Cell[BoxData[
    \(\(rules = \
\((Recombination[]\[Vee]SymmetricRecombination[]\[Vee]Selection[{\
\[GothicCapitalJ], \[GothicCapitalA]}, \[GothicA], \[DoubleStruckCapitalW]]\
\[Vee]Migration[{1, 
                  2} &]\[Vee]UnionOfGametes[]\[Vee]RandomUnion[\
\[GothicCapitalG]]\[Vee]ReferencePointSame[\[GothicCapitalG], {\
\[GothicCapitalA], \[GothicCapitalJ], \
\[GothicCapitalZ]}]\[Vee]ReferencePointZero[{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalG]}])\);\)\)], "Input",
  CellLabel->"In[15]:=  (19:43:27 on 3/14/01)"],

Cell[TextData[{
  "The rules are joined using \[Vee] (entered as \[AliasIndicator]v\
\[AliasIndicator]).  Recombination is assumed to be symmetric \
(SymmetricRecombination[]); the reference points in zygotes, juveniles and \
adults are the same as in the initial gamete pool (ReferencePointSame[\
\[GothicCapitalG],{\[GothicCapitalA],\[GothicCapitalZ]}]); the reference \
point in the gamete pools is equal to the local mean, so that single-locus ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[Ellipsis]}} = 0\)]],
  " (",
  Cell[BoxData[
      \(ReferencePointZero[{\(\[GothicCapitalG]\^*\), \[GothicCapitalG]}]\)],
    FontFamily->"Times"],
  "); selection is between juveniles and adults \
(Selection[{\[GothicCapitalJ], \[GothicCapitalA]}, \[GothicA],\
\[DoubleStruckCapitalW]]); migration is between two demes (",
  "Migration[{1,2}&]), ",
  "and there is random union of gametes (UnionOfGametes[], RandomUnion[\
\[GothicCapitalG]])."
}], "Text"],

Cell[TextData[{
  "Note: ",
  StyleBox["If a list of rules of this sort is not applied as expected, see ",
    
    FontWeight->"Plain"],
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Applying rules"},
    ButtonStyle->"AddOnsLink"],
  StyleBox[".",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell["\<\
The rules must be applied repeatedly until there is no further \
change (//.). \
\>", "Text"],

Cell[" The within-genome association in deme 1 is:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(d2 = 
      Simplify /@ 
        Collect[\(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), 1, \
\[GothicCapitalF]}, j\_{\(\[GothicCapitalG]\^*\), 1, \[GothicCapitalF]}} //. 
              rules\) /. {\[GothicR]\_\({}, {i, j}\) -> \(1 - r\_\(i, \
j\)\)\/2, \[GothicR]\_\({i}, {j}\) -> 
                r\_\(i, j\)\/2, \ \[CapitalMu]\_\(1, 1\) -> 
                1 - mig, \[CapitalMu]\_\(1, 2\) -> mig}, mig]\)], "Input",
  CellLabel->"In[80]:=  (9:40:03 on 3/14/01)"],

Cell[BoxData[
    \(\(-\(1\/4\)\)\ mig\^2\ \((\[GothicM]\_\(i\_{\[GothicCapitalG], 1, \
\[GothicCapitalF]}\) + \[GothicM]\_\(i\_{\[GothicCapitalG], 1, \
\[GothicCapitalM]}\) - \[GothicM]\_\(i\_{\[GothicCapitalG], 2, \
\[GothicCapitalF]}\) - \[GothicM]\_\(i\_{\[GothicCapitalG], 2, \
\[GothicCapitalM]}\))\)\ \((\[GothicM]\_\(j\_{\[GothicCapitalG], 1, \
\[GothicCapitalF]}\) + \[GothicM]\_\(j\_{\[GothicCapitalG], 1, \
\[GothicCapitalM]}\) - \[GothicM]\_\(j\_{\[GothicCapitalG], 2, \
\[GothicCapitalF]}\) - \[GothicM]\_\(j\_{\[GothicCapitalG], 2, \
\[GothicCapitalM]}\))\) - 
      1\/2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], 1, \[GothicCapitalF]}, \
j\_{\[GothicCapitalG], 1, \[GothicCapitalF]}}\ \((\(-1\) + r\_\(i, j\))\) - 
      1\/2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], 1, \[GothicCapitalM]}, \
j\_{\[GothicCapitalG], 1, \[GothicCapitalM]}}\ \((\(-1\) + r\_\(i, j\))\) - 
      1\/4\ \[GothicM]\_\(i\_{\[GothicCapitalG], 1, \[GothicCapitalF]}\)\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], 1, \[GothicCapitalF]}\)\ \((\(-1\) + 
            r\_\(i, j\))\) + 
      1\/4\ \[GothicM]\_\(i\_{\[GothicCapitalG], 1, \[GothicCapitalM]}\)\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], 1, \[GothicCapitalF]}\)\ \((\(-1\) + 
            r\_\(i, j\))\) + 
      1\/4\ \[GothicM]\_\(i\_{\[GothicCapitalG], 1, \[GothicCapitalF]}\)\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], 1, \[GothicCapitalM]}\)\ \((\(-1\) + 
            r\_\(i, j\))\) - 
      1\/4\ \[GothicM]\_\(i\_{\[GothicCapitalG], 1, \[GothicCapitalM]}\)\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], 1, \[GothicCapitalM]}\)\ \((\(-1\) + 
            r\_\(i, j\))\) - 
      1\/4\ \[GothicM]\_\(i\_{\[GothicCapitalG], 1, \[GothicCapitalF]}\)\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], 1, \[GothicCapitalF]}\)\ r\_\(i, j\) + 
      1\/4\ \[GothicM]\_\(i\_{\[GothicCapitalG], 1, \[GothicCapitalM]}\)\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], 1, \[GothicCapitalF]}\)\ r\_\(i, j\) + 
      1\/4\ \[GothicM]\_\(i\_{\[GothicCapitalG], 1, \[GothicCapitalF]}\)\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], 1, \[GothicCapitalM]}\)\ r\_\(i, j\) - 
      1\/4\ \[GothicM]\_\(i\_{\[GothicCapitalG], 1, \[GothicCapitalM]}\)\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], 1, \[GothicCapitalM]}\)\ r\_\(i, j\) + 
      1\/4\ mig\ \((2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], 2, \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], 2, \[GothicCapitalF]}} + 
            2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], 2, \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], 2, \[GothicCapitalM]}} + 
            2\ \[GothicM]\_\(i\_{\[GothicCapitalG], 1, \[GothicCapitalM]}\)\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], 1, \[GothicCapitalF]}\) - \
\[GothicM]\_\(i\_{\[GothicCapitalG], 2, \[GothicCapitalF]}\)\ \[GothicM]\_\(j\
\_{\[GothicCapitalG], 1, \[GothicCapitalF]}\) - \[GothicM]\_\(i\_{\
\[GothicCapitalG], 2, \[GothicCapitalM]}\)\ \[GothicM]\_\(j\_{\
\[GothicCapitalG], 1, \[GothicCapitalF]}\) + 
            2\ \[GothicM]\_\(i\_{\[GothicCapitalG], 1, \[GothicCapitalF]}\)\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], 1, \[GothicCapitalM]}\) - \
\[GothicM]\_\(i\_{\[GothicCapitalG], 2, \[GothicCapitalF]}\)\ \[GothicM]\_\(j\
\_{\[GothicCapitalG], 1, \[GothicCapitalM]}\) - \[GothicM]\_\(i\_{\
\[GothicCapitalG], 2, \[GothicCapitalM]}\)\ \[GothicM]\_\(j\_{\
\[GothicCapitalG], 1, \[GothicCapitalM]}\) - \[GothicM]\_\(i\_{\
\[GothicCapitalG], 1, \[GothicCapitalF]}\)\ \[GothicM]\_\(j\_{\
\[GothicCapitalG], 2, \[GothicCapitalF]}\) - \[GothicM]\_\(i\_{\
\[GothicCapitalG], 1, \[GothicCapitalM]}\)\ \[GothicM]\_\(j\_{\
\[GothicCapitalG], 2, \[GothicCapitalF]}\) + 
            2\ \[GothicM]\_\(i\_{\[GothicCapitalG], 2, \[GothicCapitalF]}\)\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], 2, \[GothicCapitalF]}\) - \
\[GothicM]\_\(i\_{\[GothicCapitalG], 1, \[GothicCapitalF]}\)\ \[GothicM]\_\(j\
\_{\[GothicCapitalG], 2, \[GothicCapitalM]}\) - \[GothicM]\_\(i\_{\
\[GothicCapitalG], 1, \[GothicCapitalM]}\)\ \[GothicM]\_\(j\_{\
\[GothicCapitalG], 2, \[GothicCapitalM]}\) + 
            2\ \[GothicM]\_\(i\_{\[GothicCapitalG], 2, \[GothicCapitalM]}\)\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], 2, \[GothicCapitalM]}\) + 
            
            2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], 1, \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], 1, \[GothicCapitalF]}}\ \((\(-1\) \
+ r\_\(i, j\))\) + 
            2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], 1, \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], 1, \[GothicCapitalM]}}\ \((\(-1\) \
+ r\_\(i, j\))\) - 
            2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], 2, \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], 2, \[GothicCapitalF]}}\ r\_\(i, \
j\) - 2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], 2, \[GothicCapitalM]}, \
j\_{\[GothicCapitalG], 2, \[GothicCapitalM]}}\ r\_\(i, j\) + 
            2\ \[GothicM]\_\(i\_{\[GothicCapitalG], 1, \[GothicCapitalF]}\)\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], 1, \[GothicCapitalF]}\)\ r\_\(i, j\) - 
            2\ \[GothicM]\_\(i\_{\[GothicCapitalG], 1, \[GothicCapitalM]}\)\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], 1, \[GothicCapitalF]}\)\ r\_\(i, j\) - 
            2\ \[GothicM]\_\(i\_{\[GothicCapitalG], 1, \[GothicCapitalF]}\)\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], 1, \[GothicCapitalM]}\)\ r\_\(i, j\) + 
            2\ \[GothicM]\_\(i\_{\[GothicCapitalG], 1, \[GothicCapitalM]}\)\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], 1, \[GothicCapitalM]}\)\ r\_\(i, j\) - 
            2\ \[GothicM]\_\(i\_{\[GothicCapitalG], 2, \[GothicCapitalF]}\)\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], 2, \[GothicCapitalF]}\)\ r\_\(i, j\) + 
            2\ \[GothicM]\_\(i\_{\[GothicCapitalG], 2, \[GothicCapitalM]}\)\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], 2, \[GothicCapitalF]}\)\ r\_\(i, j\) + 
            2\ \[GothicM]\_\(i\_{\[GothicCapitalG], 2, \[GothicCapitalF]}\)\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], 2, \[GothicCapitalM]}\)\ r\_\(i, j\) - 
            2\ \[GothicM]\_\(i\_{\[GothicCapitalG], 2, \[GothicCapitalM]}\)\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], 2, \[GothicCapitalM]}\)\ r\_\(i, \
j\))\)\)], "Output",
  CellLabel->"Out[80]=  (9:40:05 on 3/14/01)"]
}, Closed]],

Cell["\<\
Here, migration and recombination rates have been simplified.\
\>", \
"Text"],

Cell["\<\
This can be simplified by writing the means, \[GothicM], in terms \
of the difference between the demes, \[CapitalDelta], the difference between \
the sexes, \[Delta], and the interaction between sex and deme, \
\[Epsilon]:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(changeVariables = {\[GothicM]\_\(a_\_{\[GothicCapitalG], 1, \
\[GothicCapitalM]}\) -> 
            mn - \[CapitalDelta]\_a\/2 - \[Delta]\_a\/2 + \[Epsilon]\/4, \
\[GothicM]\_\(a_\_{\[GothicCapitalG], 2, \[GothicCapitalM]}\) -> 
            mn + \[CapitalDelta]\_a\/2 - \[Delta]\_a\/2 - \[Epsilon]\/4, \
\[GothicM]\_\(a_\_{\[GothicCapitalG], 1, \[GothicCapitalF]}\) -> 
            mn - \[CapitalDelta]\_a\/2 + \[Delta]\_a\/2 - \[Epsilon]\/4, \
\[GothicM]\_\(a_\_{\[GothicCapitalG], 2, \[GothicCapitalF]}\) -> 
            mn + \[CapitalDelta]\_a\/2 + \[Delta]\_a\/2 + \
\[Epsilon]\/4};\)\)], "Input",
  CellLabel->"In[14]:=  (19:43:24 on 3/14/01)"],

Cell["With some simplification by hand:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ssn = Simplify /@ Collect[d2 /. changeVariables, mig]\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(\(\(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], 1, \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], 1, \[GothicCapitalF]}}\  + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], 1, \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], 1, \[GothicCapitalM]}}\)\/2\) \((1 - r\_\(i, j\))\) + 
      1\/2\ mig\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalG], 2, \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], 2, \[GothicCapitalF]}} + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], 2, \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], 2, \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], 1, \[GothicCapitalF]}, j\_{\[GothicCapitalG], 1, \
\[GothicCapitalF]}} - \[GothicCapitalD]\_{i\_{\[GothicCapitalG], 1, \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], 1, \[GothicCapitalM]}})\)\ \((1 - 
            r\_\(i, j\))\) + \(1\/16\) \((\((\[Epsilon]\^2 + 
                4\ \[Delta]\_i\ \[Delta]\_j)\) - 
            2  \[Epsilon]\ \((\[Delta]\_i + \[Delta]\_j)\)\ \ \((1 - 
                  2  mig)\)\ )\) \((1 - 2\ r\_\(i, j\))\) + 
      mig \((1 - 
            mig)\)\ \[CapitalDelta]\_i\ \[CapitalDelta]\_j\)\)\)], "Output",
  CellLabel->"Out[58]=  (9:19:42 on 3/14/01)",
  CellTags->"diploid juvenile eqn"]
}, Open  ]],

Cell[TextData[{
  "With no migration, the disequilibrium is just the mean across the two \
sexes, deflated by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\((1 - 
            r\_\(i, j\))\)\ \((first\ term)\) . \ \ Migration\ mixes\ \
disequilibria\ \((second\ term)\)\)\(,\)\(\ \)\(and\)\(\ \)\)\)]],
  "generates disequilibria if there are differences in mean between the sexes \
and between the demes (last two terms).  "
}], "Text"],

Cell["\<\
 The differences \[Delta], \[CapitalDelta], \[Epsilon] change as:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify /@ 
      Collect[\(\({\(1\/2\) \((\[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), 1, \
\[GothicCapitalF]}\) + \[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), 2, \
\[GothicCapitalF]}\) - \[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), 1, \
\[GothicCapitalM]}\) - \[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), 2, \
\[GothicCapitalM]}\))\), \(1\/2\) \((\[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\
\), 2, \[GothicCapitalF]}\) - \[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), 1, \
\[GothicCapitalF]}\) + \[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), 2, \
\[GothicCapitalM]}\) - \[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), 1, \
\[GothicCapitalM]}\))\), \((\[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), 2, \
\[GothicCapitalF]}\) - \[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), 1, \
\[GothicCapitalF]}\) - \[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), 2, \
\[GothicCapitalM]}\) + \[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), 1, \
\[GothicCapitalM]}\))\)} //. 
              rules\) /. {\[CapitalMu]\_\(1, 1\) -> 
                1 - mig, \[CapitalMu]\_\(1, 2\) -> 
                mig, \[CapitalMu]\_\(2, 1\) -> mig}\) /. changeVariables, 
        mig]\)], "Input",
  CellLabel->"In[79]:=  (9:40:02 on 3/14/01)"],

Cell[BoxData[
    \({0, \((1 - 2\ mig)\)\ \[CapitalDelta]\_i, 0}\)], "Output",
  CellLabel->"Out[79]=  (9:40:02 on 3/14/01)"]
}, Open  ]],

Cell["\<\
Because the sexes are equivalent, one generation of migration \
erases all diferences between them (\[Delta], \[Epsilon]).\
\>", "Text"],

Cell["\<\
If the sexes are assumed equivalent, the pairwise disequilibrium \
has a simple form:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(d2 /. SymmetricSexes[]\) /. 
          changeVariables\) /. {\[Delta]\__ -> 0, \[Epsilon] -> 0} // 
      Simplify\)], "Input",
  CellLabel->"In[88]:=  (19:08:24 on 3/14/01)"],

Cell[BoxData[
    \(\(\(\ \)\(\((1 - 
            r\_\(i, j\))\) \((\((1 - 
                  mig)\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], 1, \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], 1, \[GothicCapitalF]}} + 
            mig\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], 2, \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], 2, \[GothicCapitalF]}})\) + 
      mig \((1 - 
            mig)\)\ \[CapitalDelta]\_i\ \[CapitalDelta]\_j\)\)\)], "Output",
  CellLabel->"Out[88]=  (19:08:24 on 3/14/01)"]
}, Open  ]],

Cell["\<\
Assuming equivalent sexes, the cross-genome association in adults \
is:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(d2 = 
      Simplify /@ 
        Collect[\(\(\[GothicCapitalD]\_{i\_{\[GothicCapitalA], 1, \
\[GothicCapitalF], \[GothicCapitalF]}, j\_{\[GothicCapitalA], 1, \
\[GothicCapitalF], \[GothicCapitalM]}} //. 
                rules\) /. {\[GothicR]\_\({}, {i, j}\) -> \(1 - r\_\(i, j\)\)\
\/2, \[GothicR]\_\({i}, {j}\) -> r\_\(i, j\)\/2, \ \[CapitalMu]\_\(1, 1\) -> 
                  1 - mig, \[CapitalMu]\_\(1, 2\) -> mig}\) /. 
            SymmetricSexes[], mig]\)], "Input",
  CellLabel->"In[17]:=  (19:43:51 on 3/14/01)"],

Cell[BoxData[
    \(mig\ \((\[GothicM]\_\(i\_{\[GothicCapitalG], 1, \[GothicCapitalF]}\) - \
\[GothicM]\_\(i\_{\[GothicCapitalG], 2, \[GothicCapitalF]}\))\)\ \
\((\[GothicM]\_\(j\_{\[GothicCapitalG], 1, \[GothicCapitalF]}\) - \
\[GothicM]\_\(j\_{\[GothicCapitalG], 2, \[GothicCapitalF]}\))\)\)], "Output",
  CellLabel->"Out[17]=  (19:43:51 on 3/14/01)"]
}, Open  ]],

Cell["\<\
This is built up within the generation by migration; it has the \
effect of reducing the rate of decay of linkage disequilibrium.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Cytonuclear associations", "SubsubsectionIcon",
  CellTags->"Cytonuclear associations"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["rules",
                FontSlant->"Italic"], 
              "=", \((Recombination[]\[Vee]NonMendelian[
                    CytoplasmicLoci -> {i}]\[Vee]SymmetricRecombination[]\
\[Vee]Selection[{\[GothicCapitalJ], \[GothicCapitalA]}, \[GothicA], \
\[DoubleStruckCapitalW]]\[Vee]Migration[{1, 
                        2} &]\[Vee]UnionOfGametes[]\[Vee]RandomUnion[\
\[GothicCapitalG]]\[Vee]ReferencePointSame[\[GothicCapitalG], {\
\[GothicCapitalA], \[GothicCapitalJ], \
\[GothicCapitalZ]}]\[Vee]ReferencePointZero[{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalG]}])\)}], \(a\ modified\ set\ of\ rules\ that\ includes\ a\ \
cytoplasmically\ inherited\ locus . \ i . \)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"Cytonuclear rules"],

Cell[TextData[{
  "Including the rule ",
  ButtonBox["NonMendelian",
    ButtonData:>{"Non-Mendelian inheritance", "Cytoplasmic inheritance"},
    ButtonStyle->"AddOnsLink"],
  "[CytoplasmicLoci -> {i}] simplifies recombination rates to represent \
cytoplasmic inheritance.  This rule ",
  StyleBox["must",
    FontWeight->"Bold"],
  " appear before SymmetricRecombination[]."
}], "Text"],

Cell[BoxData[
    \(\(rules = \((Recombination[]\[Vee]NonMendelian[
              CytoplasmicLoci -> \
{i}]\[Vee]SymmetricRecombination[]\[Vee]Selection[{\[GothicCapitalJ], \
\[GothicCapitalA]}, \[GothicA], \[DoubleStruckCapitalW]]\[Vee]Migration[{1, 
                  2} &]\[Vee]UnionOfGametes[]\[Vee]RandomUnion[\
\[GothicCapitalG]]\[Vee]ReferencePointSame[\[GothicCapitalG], {\
\[GothicCapitalA], \[GothicCapitalJ], \
\[GothicCapitalZ]}]\[Vee]ReferencePointZero[{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalG]}])\);\)\)], "Input",
  CellLabel->"In[9]:=  (19:28:54 on 3/14/01)"],

Cell[" The cytonuclear association in deme 1 is:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(d2 = 
      Simplify /@ 
        Collect[\(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), 1, \
\[GothicCapitalF]}, j\_{\(\[GothicCapitalG]\^*\), 1, \[GothicCapitalF]}} //. 
              rules\) /. {\[CapitalMu]\_\(1, 1\) -> 
                1 - mig, \[CapitalMu]\_\(1, 2\) -> mig}, mig]\)], "Input",
  CellLabel->"In[10]:=  (19:29:10 on 3/14/01)"],

Cell[BoxData[
    \(1\/2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], 1, \[GothicCapitalF]}, \
j\_{\[GothicCapitalG], 1, \[GothicCapitalF]}} + 
      1\/2\ mig\ \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalG], 1, \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], 1, \[GothicCapitalF]}}\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], 2, \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], 2, \[GothicCapitalF]}} + \((\[GothicM]\_\(i\_{\
\[GothicCapitalG], 1, \[GothicCapitalF]}\) - \[GothicM]\_\(i\_{\
\[GothicCapitalG], 2, \[GothicCapitalF]}\))\)\ \((\[GothicM]\_\(j\_{\
\[GothicCapitalG], 1, \[GothicCapitalF]}\) + \[GothicM]\_\(j\_{\
\[GothicCapitalG], 1, \[GothicCapitalM]}\) - \[GothicM]\_\(j\_{\
\[GothicCapitalG], 2, \[GothicCapitalF]}\) - \[GothicM]\_\(j\_{\
\[GothicCapitalG], 2, \[GothicCapitalM]}\))\))\) + 
      1\/2\ mig\^2\ \((\[GothicM]\_\(i\_{\[GothicCapitalG], 1, \
\[GothicCapitalF]}\) - \[GothicM]\_\(i\_{\[GothicCapitalG], 2, \
\[GothicCapitalF]}\))\)\ \((\(-\[GothicM]\_\(j\_{\[GothicCapitalG], 1, \
\[GothicCapitalF]}\)\) - \[GothicM]\_\(j\_{\[GothicCapitalG], 1, \
\[GothicCapitalM]}\) + \[GothicM]\_\(j\_{\[GothicCapitalG], 2, \
\[GothicCapitalF]}\) + \[GothicM]\_\(j\_{\[GothicCapitalG], 2, \
\[GothicCapitalM]}\))\)\)], "Output",
  CellLabel->"Out[10]=  (19:29:11 on 3/14/01)"]
}, Closed]],

Cell["Here, migration rates have been simplified.", "Text"],

Cell["\<\
This can be simplified by writing the means, \[GothicM], in terms \
of the difference between the demes, \[CapitalDelta], the difference between \
the sexes, \[Delta], and the interaction between sex and deme, \[Epsilon], as \
above:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(changeVariables = {\[GothicM]\_\(a_\_{\[GothicCapitalG], 1, \
\[GothicCapitalM]}\) -> 
            mn - \[CapitalDelta]\_a\/2 - \[Delta]\_a\/2 + \[Epsilon]\/4, \
\[GothicM]\_\(a_\_{\[GothicCapitalG], 2, \[GothicCapitalM]}\) -> 
            mn + \[CapitalDelta]\_a\/2 - \[Delta]\_a\/2 - \[Epsilon]\/4, \
\[GothicM]\_\(a_\_{\[GothicCapitalG], 1, \[GothicCapitalF]}\) -> 
            mn - \[CapitalDelta]\_a\/2 + \[Delta]\_a\/2 - \[Epsilon]\/4, \
\[GothicM]\_\(a_\_{\[GothicCapitalG], 2, \[GothicCapitalF]}\) -> 
            mn + \[CapitalDelta]\_a\/2 + \[Delta]\_a\/2 + \
\[Epsilon]\/4};\)\)], "Input",
  CellLabel->"In[12]:=  (19:29:43 on 3/14/01)"],

Cell["With some simplification by hand:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify /@ Collect[d2 /. changeVariables, mig]\)], "Input",
  CellLabel->"In[13]:=  (19:29:45 on 3/14/01)"],

Cell[BoxData[
    \(1\/2\ \((\((1 - 
                  mig)\) \[GothicCapitalD]\_{i\_{\[GothicCapitalG], 1, \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], 1, \[GothicCapitalF]}} + \ 
            mig\ \ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], 2, \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], 2, \[GothicCapitalF]}})\) + 
      1\/2\ mig \((1 - mig)\)\ \((\[Epsilon] + 
            2\ \[CapitalDelta]\_i)\)\ \[CapitalDelta]\_j\)], "Output",
  CellLabel->"Out[13]=  (19:29:45 on 3/14/01)"]
}, Open  ]],

Cell[TextData[{
  "The cytonuclear association in deme 1 is a mixture of the initial \
associations in demes 1 and 2, and is reduced by a factor ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  " (first term).  It is augmented by mixing of populations (last term)."
}], "Text"],

Cell[TextData[{
  ButtonBox["Sex linkage",
    ButtonData:>{"Sex linkage", None},
    ButtonStyle->"AddOnsLink"],
  " can be represented in a similar way."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Migration of haploid gametes", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["rules",
                FontSlant->"Italic"], 
              "=", \((Recombination[]\[Vee]SymmetricRecombination[]\[Vee]\
Selection[]\[Vee]UnionOfGametes[{\[GothicCapitalG]m, \
\[GothicCapitalZ]}]\[Vee]RandomUnion[\[GothicCapitalG]m]\[Vee]Migration[{\
\[GothicCapitalG], \[GothicCapitalG]m}, 
                    MigrationRate, {1, 
                        2} &]\[Vee]ReferencePointSame[\[GothicCapitalG], {\
\[GothicCapitalA], \[GothicCapitalJ], \
\[GothicCapitalZ]}]\[Vee]ReferencePointZero[{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalG], \[GothicCapitalG]m}])\)}], \(rules\ that\ represent\ \
migration\ of\ haploid\ gametes\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"Cytonuclear rules"],

Cell["\<\
These rules represent migration of haploid gametes between stages \
\[GothicCapitalG] and \[GothicCapitalG]m:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(rules = \
\((Recombination[]\[Vee]SymmetricRecombination[]\[Vee]Selection[]\[Vee]\
UnionOfGametes[{\[GothicCapitalG]m, \[GothicCapitalZ]}]\[Vee]RandomUnion[\
\[GothicCapitalG]m]\[Vee]Migration[{\[GothicCapitalG], \[GothicCapitalG]m}, 
              MigrationRate, {1, 
                  2} &]\[Vee]ReferencePointSame[\[GothicCapitalG], {\
\[GothicCapitalA], \[GothicCapitalJ], \
\[GothicCapitalZ]}]\[Vee]ReferencePointZero[{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalG], \[GothicCapitalG]m}])\);\)\)], "Input",
  CellLabel->"In[31]:=  (19:51:12 on 3/14/01)"],

Cell["This is the linkage disequilibrium in gametes:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(d2 = 
      Simplify /@ 
        Collect[\(\(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), 1, \
\[GothicCapitalF]}, j\_{\(\[GothicCapitalG]\^*\), 1, \[GothicCapitalF]}} //. 
                rules\) /. {\[GothicR]\_\({}, {i, j}\) -> \(1 - r\_\(i, j\)\)\
\/2, \[GothicR]\_\({i}, {j}\) -> r\_\(i, j\)\/2, \ \[CapitalMu]\_\(1, 1\) -> 
                  1 - mig, \[CapitalMu]\_\(1, 2\) -> mig}\) /. 
            changeVariables, mig]\)], "Input",
  CellLabel->"In[37]:=  (19:58:54 on 3/14/01)"],

Cell[BoxData[
    \(\(1\/2\) \((\[GothicCapitalD]\_{i\_{\[GothicCapitalG], 1, \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], 1, \[GothicCapitalF]}}\  + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], 1, \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], 1, \[GothicCapitalM]}})\) \((1 - 
            r\_\(i, j\))\) + \(1\/16\) \((\[Epsilon] - 
            2\ \[Delta]\_i)\)\ \((\[Epsilon] - 2\ \[Delta]\_j)\)\ \((1 - 
            2\ r\_\(i, j\))\) + \ 
      mig\/2\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalG], 2, \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], 2, \[GothicCapitalF]}} + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], 2, \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], 2, \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], 1, \[GothicCapitalF]}, j\_{\[GothicCapitalG], 1, \
\[GothicCapitalF]}} - \ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], 1, \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], 1, \[GothicCapitalM]}}\ )\) \((1 - 
            r\_\(i, j\))\) + \(mig\/4\) \((\[Delta]\_i + \[Delta]\_j)\)\ \((\
\[Epsilon] - 2\ \[Epsilon]\ r\_\(i, j\))\) + 
      mig \((1 - 
            mig)\)\ \((\[CapitalDelta]\_i\ \[CapitalDelta]\_j\ \((1 - 
                  r\_\(i, j\))\) + 
            1\/4\ \[Epsilon]\^2\ r\_\(i, j\))\)\)], "Output",
  CellLabel->"Out[33]=  (19:51:44 on 3/14/01)"]
}, Open  ]],

Cell[TextData[{
  "The difference between this and the expression with",
  Cell[BoxData[
      FormBox[
        ButtonBox[\(\(\ \)\(diploid\ migration\)\),
          ButtonData:>"diploid juvenile eqn",
          ButtonStyle->"Hyperlink"], TraditionalForm]]],
  " is:"
}], "MathCaption"],

Cell[BoxData[
    \(\(\(r\_\(i, j\)\)\(\ \)\(mig\)\(\ \)\((1 - 
          mig)\) \((\ \[CapitalDelta]\_i\ \[CapitalDelta]\_j - \
\[Epsilon]\^2\/4)\)\(\ \)\)\)], "Output",
  CellLabel->"Out[39]=  (20:01:45 on 3/14/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Relation with Asmussen and Orive (",
  ButtonBox["2000",
    ButtonData:>{"Multilocus references", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  ")"
}], "SubsubsectionIcon",
  CellTags->"Asmussen and Orive 2000"],

Cell[TextData[{
  "Asmussen and Orive  (",
  ButtonBox["2000",
    ButtonData:>{"Multilocus references", "Asmussen and Orive 2000"},
    ButtonStyle->"AddOnsLink"],
  ") consider a nuclear locus (n), a paternally inherited chloroplast locus \
(c), and a maternally inherited mitochondrial locus (m); this system is found \
in conifers.  These forms of inheritance will be denoted here by \
CytoplasmicLoci\[Rule]{m}, ",
  "PaternalLoci",
  "->{c}."
}], "Text"],

Cell["\<\
Pollen migration occurs at a rate M, and seed migration at a rate \
m; these occur between stages \[GothicCapitalG] and \[GothicCapitalG]m, and \
\[GothicCapitalZ] and \[GothicCapitalJ], respectively.   There is no \
emigration: this is a continent-island model.\
\>", "Text"],

Cell["\<\
It is convenient to define analogous functions to \
MigrationRate:\
\>", "MathCaption"],

Cell[BoxData[{
    \(Mp[1, 1] = 1 - M; Mp[1, 2] = M; Mp[2, 1] = 0; 
    Mp[2, 2] = 1;\), "\[IndentingNewLine]", 
    \(ms[1, 1] = 1 - m; ms[1, 2] = m; ms[2, 1] = 0; ms[2, 2] = 1;\)}], "Input",\

  CellLabel->"In[68]:=  (15:56:32 on 3/21/01)"],

Cell["\<\
This changes variables, such that \[CapitalDelta] refers to \
differences between demes, and \[Delta] to differences between the sexes; \
\[Epsilon] is the interaction:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(changeVariables = {\[GothicM]\_\(a_\_{\[GothicCapitalG], 1, \
\[GothicCapitalM]}\) -> 
            mn - \[CapitalDelta]\_a\/2 - \[Delta]\_a\/2 + \[Epsilon]\/4, \
\[GothicM]\_\(a_\_{\[GothicCapitalG], 2, \[GothicCapitalM]}\) -> 
            mn + \[CapitalDelta]\_a\/2 - \[Delta]\_a\/2 - \[Epsilon]\/4, \
\[GothicM]\_\(a_\_{\[GothicCapitalG], 1, \[GothicCapitalF]}\) -> 
            mn - \[CapitalDelta]\_a\/2 + \[Delta]\_a\/2 - \[Epsilon]\/4, \
\[GothicM]\_\(a_\_{\[GothicCapitalG], 2, \[GothicCapitalF]}\) -> 
            mn + \[CapitalDelta]\_a\/2 + \[Delta]\_a\/2 + \
\[Epsilon]\/4};\)\)], "Input",
  CellLabel->"In[73]:=  (15:59:48 on 3/21/01)"],

Cell["These are the rules that define the life cycle:", "MathCaption"],

Cell[BoxData[
    \(\(rules = \((Recombination[]\[Vee]NonMendelian[
              CytoplasmicLoci \[Rule] {m}, 
              PaternalLoci \[Rule] \
{c}]\[Vee]SymmetricRecombination[]\[Vee]Selection[{\[GothicCapitalJ], \
\[GothicCapitalA]}, \[GothicA], \[DoubleStruckCapitalW]]\[Vee]Migration[{\
\[GothicCapitalZ], \[GothicCapitalJ]}, 
              ms, {1, 2} &]\[Vee]UnionOfGametes[{\[GothicCapitalG]m, \
\[GothicCapitalZ]}]\[Vee]RandomUnion[\[GothicCapitalG]m]\[Vee]Migration[{\
\[GothicCapitalG], \[GothicCapitalG]m}, 
              Mp, {1, 2} &]\[Vee]ReferencePointSame[\[GothicCapitalG], {\
\[GothicCapitalA], \[GothicCapitalJ], \
\[GothicCapitalZ]}]\[Vee]ReferencePointZero[{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalG], \[GothicCapitalG]m}])\);\)\)], "Input",
  CellLabel->"In[70]:=  (15:56:33 on 3/21/01)"],

Cell["\<\
This is the pairwise association between chloroplast and \
mitochondrial genes in new female gametes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[GothicCapitalD]\_{m\_{\(\[GothicCapitalG]\^*\), 1, \
\[GothicCapitalF]}, c\_{\(\[GothicCapitalG]\^*\), 1, \[GothicCapitalF]}} //. 
          rules\) /. changeVariables // Simplify\)], "Input",
  CellLabel->"In[75]:=  (16:04:39 on 3/21/01)"],

Cell[BoxData[
    \(\(\(\ \)\(\((1 - 
          m)\)\ m\ \((1 - M)\)\^2\ \((\ \[CapitalDelta]\_c - \[Epsilon]\/2)\)\
\ \((\ \[CapitalDelta]\_m + \[Epsilon]\/2)\)\)\)\)], "Output",
  CellLabel->"Out[75]=  (16:04:39 on 3/21/01)"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[GothicCapitalD]\_{m\_{\[GothicCapitalA], 1, \[GothicCapitalF], \
\[GothicCapitalF]}, c\_{\[GothicCapitalA], 1, \[GothicCapitalF], \
\[GothicCapitalM]}} //. rules\) /. changeVariables // Simplify\)], "Input",
  CellLabel->"In[119]:=  (19:51:12 on 3/21/01)"],

Cell[BoxData[
    \(\(\(\ \)\(\((M\^2 + 
          m\ \((1 - 
                M\^2)\))\)\ \ \((\ \[CapitalDelta]\_c - \[Epsilon]\/2)\)\ \((\
\ \[CapitalDelta]\_m + \[Epsilon]\/2)\)\)\)\)], "Output",
  CellLabel->"Out[119]=  (19:51:12 on 3/21/01)"]
}, Open  ]],

Cell[TextData[{
  "This corresponds to Asmussen & Orive's (2000) Eq. 24, with the assumption \
that immigrant seeds are in linkage equilibrium (A&O's d=0).  The last two \
factors above correspond to the differences in allele frequency between demes \
for males at the chloroplast locus ",
  Cell[BoxData[
      \(\((\ \[CapitalDelta]\_c - \[Epsilon]\/2)\)\)]],
  " and for females at the mitochondrial locus.  The factor (1-M) is omitted \
in A&O, because their Eq. 24 does not include pollen dispersal."
}], "Text"],

Cell["This is the three-way association  in new female gametes:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[GothicCapitalD]\_{m\_{\(\[GothicCapitalG]\^*\), 1, \
\[GothicCapitalF]}, n\_{\(\[GothicCapitalG]\^*\), 1, \[GothicCapitalF]}, c\_{\
\(\[GothicCapitalG]\^*\), 1, \[GothicCapitalF]}} //. rules\) /. 
        changeVariables // Simplify\)], "Input",
  CellLabel->"In[76]:=  (16:11:24 on 3/21/01)"],

Cell[BoxData[
    \(\(\(\ \)\(\((1 - 
          m)\)\ m\ \((1 - M)\)\^2\ \((\(\[GothicCapitalD]\_{m\_{\
\[GothicCapitalG], 2, \[GothicCapitalF]}, n\_{\[GothicCapitalG], 2, \
\[GothicCapitalF]}} - \[GothicCapitalD]\_{m\_{\[GothicCapitalG], 1, \
\[GothicCapitalF]}, n\_{\[GothicCapitalG], 1, \[GothicCapitalF]}}\)\/2\ \((\ \
\[CapitalDelta]\_c - \[Epsilon]\/2)\) + \((\ \[CapitalDelta]\_m + \
\[Epsilon]\/2)\)\ \((\(\[GothicCapitalD]\_{n\_{\[GothicCapitalG], 2, \
\[GothicCapitalM]}, c\_{\[GothicCapitalG], 2, \[GothicCapitalM]}} - \
\[GothicCapitalD]\_{n\_{\[GothicCapitalG], 1, \[GothicCapitalM]}, c\_{\
\[GothicCapitalG], 1, \[GothicCapitalM]}}\)\/2)\) + \((1 - 
                2\ m\ \((1 - M)\) - 
                2\ M)\)\ \((\ \[CapitalDelta]\_c - \[Epsilon]\/2)\)\ \((\ \
\[CapitalDelta]\_m + \[Epsilon]\/2)\) \[CapitalDelta]\_n)\)\)\)\)], "Output",
  CellLabel->"Out[76]=  (16:11:33 on 3/21/01)"]
}, Open  ]],

Cell["This corresponds in the same way to A&O's Eq. 28.", "Text"],

Cell["\<\
The above is not really an adequate comparison.  I have assumed no \
selfing, in which case the associations between c and m in the seed \
population are zero.  Thus, the formulae above correspond only because A&O \
gave only the changes due to seed dispersal - the simpler case.  In their \
Appendix, the effects of pollen dispersal are given; but the formulae are \
trivial with no selfing.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Relation with Kirkpatrick et al.", "SubsubsectionIcon",
  CellTags->"Multilocus MS"],

Cell[TextData[{
  ButtonBox["Kirkpatrick et al.",
    ButtonData:>{"Multilocus MS", "DAPrimeCentered"},
    ButtonStyle->"AddOnsLink"],
  " give a general equation for the change in linkage disequilibrium due to \
migration from deme M into deme R:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{"\[IndentingNewLine]", 
        RowBox[{
          
          RowBox[{\(D\_\[DoubleStruckCapitalA]\%\(\(\ \)\(\('\)\(\ \
\)\('\)\)\)\), "   ", "=", "   ", 
            
            RowBox[{\(\[Sum]\_\(\[DoubleStruckCapitalU] \[SubsetEqual] \
\[DoubleStruckCapitalA]\)\), 
              
              RowBox[{\(\((\(-m\))\)\^\(\(|\)\(\[DoubleStruckCapitalU]\)\(|\)\
\)\), " ", \(d\_\[DoubleStruckCapitalU]\), " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{\((1\  - \ m)\), 
                      
                      SubsuperscriptBox[
                        "D", \(\[DoubleStruckCapitalA]\\\
\[DoubleStruckCapitalU]\), 
                        RowBox[{" ", 
                          StyleBox["R",
                            FontSlant->"Plain"]}]]}], "  ", "+", "  ", 
                    RowBox[{"m", " ", 
                      
                      RowBox[{\(\[Sum]\_\(\[DoubleStruckCapitalV] \
\[SubsetEqual] \[DoubleStruckCapitalA]\\\[DoubleStruckCapitalU]\)\), 
                        RowBox[{\(d\_\[DoubleStruckCapitalV]\), " ", 
                          
                          SubsuperscriptBox[
                            "D", \(\((\[DoubleStruckCapitalA]\\\
\[DoubleStruckCapitalU])\)\\\[DoubleStruckCapitalV]\), 
                            StyleBox["M",
                              FontSlant->"Plain"]]}]}]}]}], ")"}]}]}]}], " ", 
          ","}]}], TraditionalForm]]]], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"DAPrimeCentered"],

Cell["where", "Text",
  CellMargins->{{18, 24.3125}, {Inherited, Inherited}}],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{"\[IndentingNewLine]", 
        RowBox[{\(d\_\[DoubleStruckCapitalU]\), "   ", "=", "   ", 
          RowBox[{\(\[Product]\+i\[Epsilon]\[DoubleStruckCapitalU]\), 
            RowBox[{"(", 
              RowBox[{
                SubsuperscriptBox["p", "\[DoubleStruckI]", 
                  StyleBox["M",
                    FontSlant->"Plain"]], "  ", "-", "  ", 
                SubsuperscriptBox["p", "\[DoubleStruckI]", 
                  StyleBox["R",
                    FontSlant->"Plain"]]}], ")"}]}]}]}], 
      TraditionalForm]]]], "NumberedEquation",
  CellMargins->{{18.1875, 24.375}, {Inherited, Inherited}},
  CellTags->"dAProductDefn"],

Cell["\<\
The packages cannot give this general formula, because the rule \
Migration[] is defined to apply only to appropriate lists of \
genes-in-context:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_\[DoubleStruckCapitalA] /. 
      Migration[{R, M} &]\)], "Input",
  CellLabel->"In[11]:=  (18:48:12 on 3/15/01)"],

Cell[BoxData[
    \(\[GothicCapitalD]\_\[DoubleStruckCapitalA]\)], "Output",
  CellLabel->"Out[11]=  (18:48:12 on 3/15/01)"]
}, Open  ]],

Cell["\<\
The packages agree with the general formula in this two-locus \
example:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[GothicCapitalD]\_{i\_{\[GothicCapitalJ], R, \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalJ], R, \[GothicCapitalM], \
\[GothicCapitalM]}} //. 
          Migration[{R, 
                  M} &]\[Vee]ReferencePointZero[{\[GothicCapitalZ], \
\[GothicCapitalJ]}]\) //. {\[CapitalMu]\_\(R, R\) -> 
            1 - m, \[CapitalMu]\_\(R, M\) -> m, 
          a_\_{\[GothicCapitalZ], dm_, \[GothicCapitalM], \[GothicCapitalM]} -> 
            a\_dm, \[GothicM]\_\(i_\_R\) -> \[CapitalDelta]\_i + \[GothicM]\_\
\(i\_M\)} // Simplify\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(m\ \[GothicCapitalD]\_{i\_M, j\_M} - \((\(-1\) + 
            m)\)\ \((\[GothicCapitalD]\_{i\_R, j\_R} + 
            m\ \[CapitalDelta]\_i\ \[CapitalDelta]\_j)\)\)], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell[TextData[{
  "This can be seen by evaluating the general formula using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[Sum]\+\(\[DoubleStruckCapitalU] \[SubsetEqual] \
\[DoubleStruckCapitalA]\)\(\((\(-m\))\)\^Length[\[DoubleStruckCapitalU]]\) \
\(d\_\[DoubleStruckCapitalU]\) \((\((1\  - \ 
                          m)\) \((\[GothicCapitalD]\_\(\[DoubleStruckCapitalA]\
\[Backslash]\[DoubleStruckCapitalU]\) /. 
                          M \[Rule] 
                            R)\) + \ \ m \(\[Sum]\+\(\[DoubleStruckCapitalV] \
\[SubsetEqual] \
\[DoubleStruckCapitalA]\[Backslash]\[DoubleStruckCapitalU]\)\(d\_\
\[DoubleStruckCapitalV]\) \[GothicCapitalD]\_\(\[DoubleStruckCapitalA]\
\[Backslash]\((\[DoubleStruckCapitalV]\[Vee]\[DoubleStruckCapitalU])\)\)\))\) \
/. \[DoubleStruckCapitalA] \[Rule] {i\_M, j\_M}\) /. 
          d\_s_List \[Rule] \[Product]\+\(i \[Element] \
s\)\[CapitalDelta]\_i\) /. \[GothicCapitalD]\_{_} \[Rule] 0 // 
      Simplify\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \(m\ \[GothicCapitalD]\_{i\_M, j\_M} - \((\(-1\) + 
            m)\)\ \((\[GothicCapitalD]\_{i\_R, j\_R} + 
            m\ \[CapitalDelta]\_\(i\_M\)\ \[CapitalDelta]\_\(j\_M\))\)\)], \
"Output",
  CellLabel->"Out[24]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{945, 699},
WindowMargins->{{63, Automatic}, {Automatic, 5}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\[Placeholder]", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->Utilities`Notation`Private`DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
0@00D01804P000000]X2:?oQon82n@96D005:0?l0040D01804P000000]X2:000
0000I0000000000000000BL?00400@00000000000000000B0002I0000aP00000
8W800@0100<00P0000000000oW`10000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Setting up"->{
    Cell[1815, 55, 76, 1, 24, "SubsubsectionIcon",
      CellTags->"Setting up"]},
  "Juvenile diploid migration"->{
    Cell[3455, 108, 101, 1, 24, "SubsubsectionIcon",
      CellTags->"Juvenile diploid migration"]},
  "Complete rules"->{
    Cell[3559, 111, 1335, 28, 118, "DefinitionBox",
      CellTags->"Complete rules"]},
  "diploid juvenile eqn"->{
    Cell[15062, 345, 1218, 19, 123, "Output",
      CellTags->"diploid juvenile eqn"]},
  "Cytonuclear associations"->{
    Cell[20442, 476, 93, 1, 20, "SubsubsectionIcon",
      CellTags->"Cytonuclear associations"]},
  "Cytonuclear rules"->{
    Cell[20538, 479, 858, 17, 82, "DefinitionBox",
      CellTags->"Cytonuclear rules"],
    Cell[26410, 619, 822, 17, 70, "DefinitionBox",
      CellTags->"Cytonuclear rules"]},
  "Asmussen and Orive 2000"->{
    Cell[30428, 713, 247, 7, 20, "SubsubsectionIcon",
      CellTags->"Asmussen and Orive 2000"]},
  "Multilocus MS"->{
    Cell[37160, 881, 90, 1, 24, "SubsubsectionIcon",
      CellTags->"Multilocus MS"]},
  "DAPrimeCentered"->{
    Cell[37517, 892, 1607, 36, 45, "NumberedEquation",
      CellTags->"DAPrimeCentered"]},
  "dAProductDefn"->{
    Cell[39207, 933, 704, 15, 44, "NumberedEquation",
      CellTags->"dAProductDefn"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Setting up", 114045, 3596},
  {"Juvenile diploid migration", 114162, 3599},
  {"Complete rules", 114285, 3602},
  {"diploid juvenile eqn", 114401, 3605},
  {"Cytonuclear associations", 114521, 3608},
  {"Cytonuclear rules", 114645, 3611},
  {"Asmussen and Orive 2000", 114855, 3616},
  {"Multilocus MS", 114975, 3619},
  {"DAPrimeCentered", 115086, 3622},
  {"dAProductDefn", 115199, 3625}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 51, 0, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[1815, 55, 76, 1, 24, "SubsubsectionIcon",
  CellTags->"Setting up"],
Cell[1894, 58, 46, 0, 28, "MathCaption"],
Cell[1943, 60, 87, 2, 26, "Input"],
Cell[2033, 64, 60, 0, 28, "MathCaption"],
Cell[2096, 66, 532, 11, 106, "Input"],
Cell[2631, 79, 186, 4, 22, "Text"],
Cell[2820, 85, 96, 3, 28, "MathCaption"],
Cell[2919, 90, 90, 2, 26, "Input"],
Cell[3012, 94, 406, 9, 22, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3455, 108, 101, 1, 24, "SubsubsectionIcon",
  CellTags->"Juvenile diploid migration"],
Cell[3559, 111, 1335, 28, 118, "DefinitionBox",
  CellTags->"Complete rules"],
Cell[4897, 141, 401, 10, 22, "Text"],
Cell[5301, 153, 526, 10, 54, "Input"],
Cell[5830, 165, 996, 20, 69, "Text"],
Cell[6829, 187, 308, 11, 24, "Text"],
Cell[7140, 200, 103, 3, 22, "Text"],
Cell[7246, 205, 67, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7338, 209, 489, 9, 72, "Input"],
Cell[7830, 220, 6027, 90, 70, "Output"]
}, Closed]],
Cell[13872, 313, 87, 3, 18, "Text"],
Cell[13962, 318, 254, 5, 28, "MathCaption"],
Cell[14219, 325, 670, 11, 87, "Input"],
Cell[14892, 338, 56, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[14973, 342, 86, 1, 26, "Input"],
Cell[15062, 345, 1218, 19, 123, "Output",
  CellTags->"diploid juvenile eqn"]
}, Open  ]],
Cell[16295, 367, 439, 9, 36, "Text"],
Cell[16737, 378, 98, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[16860, 385, 1206, 19, 107, "Input"],
Cell[18069, 406, 125, 2, 32, "Output"]
}, Open  ]],
Cell[18209, 411, 146, 3, 22, "Text"],
Cell[18358, 416, 116, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[18499, 423, 199, 4, 39, "Input"],
Cell[18701, 429, 498, 9, 40, "Output"]
}, Open  ]],
Cell[19214, 441, 102, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[19341, 448, 540, 10, 76, "Input"],
Cell[19884, 460, 353, 5, 38, "Output"]
}, Open  ]],
Cell[20252, 468, 153, 3, 22, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[20442, 476, 93, 1, 20, "SubsubsectionIcon",
  CellTags->"Cytonuclear associations"],
Cell[20538, 479, 858, 17, 82, "DefinitionBox",
  CellTags->"Cytonuclear rules"],
Cell[21399, 498, 388, 10, 24, "Text"],
Cell[21790, 510, 580, 10, 70, "Input"],
Cell[22373, 522, 65, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[22463, 526, 371, 7, 45, "Input"],
Cell[22837, 535, 1292, 20, 70, "Output"]
}, Closed]],
Cell[24144, 558, 59, 0, 18, "Text"],
Cell[24206, 560, 264, 5, 42, "MathCaption"],
Cell[24473, 567, 670, 11, 85, "Input"],
Cell[25146, 580, 56, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[25227, 584, 128, 2, 70, "Input"],
Cell[25358, 588, 486, 8, 70, "Output"]
}, Open  ]],
Cell[25859, 599, 284, 6, 70, "Text"],
Cell[26146, 607, 167, 5, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[26350, 617, 57, 0, 20, "SubsubsectionIcon"],
Cell[26410, 619, 822, 17, 70, "DefinitionBox",
  CellTags->"Cytonuclear rules"],
Cell[27235, 638, 140, 3, 70, "MathCaption"],
Cell[27378, 643, 580, 10, 70, "Input"],
Cell[27961, 655, 69, 0, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[28055, 659, 513, 9, 70, "Input"],
Cell[28571, 670, 1298, 21, 70, "Output"]
}, Open  ]],
Cell[29884, 694, 286, 8, 70, "MathCaption"],
Cell[30173, 704, 218, 4, 70, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[30428, 713, 247, 7, 20, "SubsubsectionIcon",
  CellTags->"Asmussen and Orive 2000"],
Cell[30678, 722, 460, 11, 37, "Text"],
Cell[31141, 735, 286, 5, 22, "Text"],
Cell[31430, 742, 97, 3, 28, "MathCaption"],
Cell[31530, 747, 242, 5, 54, "Input"],
Cell[31775, 754, 199, 4, 28, "MathCaption"],
Cell[31977, 760, 670, 11, 87, "Input"],
Cell[32650, 773, 70, 0, 28, "MathCaption"],
Cell[32723, 775, 816, 14, 70, "Input"],
Cell[33542, 791, 132, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[33699, 798, 264, 4, 45, "Input"],
Cell[33966, 804, 227, 4, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34230, 813, 280, 4, 42, "Input"],
Cell[34513, 819, 247, 5, 46, "Output"]
}, Open  ]],
Cell[34775, 827, 517, 9, 55, "Text"],
Cell[35295, 838, 82, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[35402, 843, 317, 5, 45, "Input"],
Cell[35722, 850, 902, 14, 104, "Output"]
}, Open  ]],
Cell[36639, 867, 65, 0, 22, "Text"],
Cell[36707, 869, 416, 7, 36, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37160, 881, 90, 1, 24, "SubsubsectionIcon",
  CellTags->"Multilocus MS"],
Cell[37253, 884, 261, 6, 23, "Text"],
Cell[37517, 892, 1607, 36, 45, "NumberedEquation",
  CellTags->"DAPrimeCentered"],
Cell[39127, 930, 77, 1, 22, "Text"],
Cell[39207, 933, 704, 15, 44, "NumberedEquation",
  CellTags->"dAProductDefn"],
Cell[39914, 950, 177, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[40116, 958, 153, 3, 38, "Input"],
Cell[40272, 963, 124, 2, 32, "Output"]
}, Open  ]],
Cell[40411, 968, 103, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[40539, 975, 598, 11, 50, "Input"],
Cell[41140, 988, 221, 4, 23, "Output"]
}, Open  ]],
Cell[41376, 995, 155, 5, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[41556, 1004, 899, 16, 55, "Input"],
Cell[42458, 1022, 237, 5, 23, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

