(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7775,        217]*)
(*NotebookOutlinePosition[      8970,        255]*)
(*  CellTagsIndexPosition[      8861,        248]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Mutation", "SubsectionIcon"],

Cell[TextData[{
  "Mutation is not implemented yet, since it raises some delicate issues \
relating to the description of ",
  ButtonBox["allelic state",
    ButtonData:>{"Allelic state", None},
    ButtonStyle->"AddOnsLink"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\[DoubleStruckI]\)]],
  ".  For more details, see Kirkpatrick et al. (",
  ButtonBox["in prep.",
    ButtonData:>{"Multilocus MS", "Mutation"},
    ButtonStyle->"AddOnsLink"],
  ")."
}], "Text"],

Cell["\<\
Almost all the rules defined in these packages can be applied \
independent of allelic state. however, mutation changes the allelic state, \
and so cannot be implemented without making restrictive assumptions about how \
allelic state is  described.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Two loci", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(BiallelicMutation[
              Mutation \[Rule] {\[Mu]\_i, \[Nu]\_i}]\), \(allows\ for\ \
mutation\ at\ \ a\ rate\ {\[Mu][i], \[Nu][
                  i]}\ from\ 0\ to\ 1\ and\ from\ 1\ to\ 0, \ \
\(\(respectively\)\(.\)\)\)},
          {\(BiallelicMutation[
              Mutation \[Rule] \[Mu]\_i]\), \(assumes\ rates\ are\ the\ same\ \
in\ either\ direction\)},
          {\(BiallelicMutation[{\[GothicCapitalG], \[GothicCapitalZ]}, 
              Mutation \[Rule] {\[Mu]\_i, \[Nu]\_i}]\), \(specifies\ the\ \
stages\ explicitly\)},
          {\(BiallelicMutation[{\[GothicCapitalG], \[GothicCapitalZ]}, {Sex}, 
              Mutation \[Rule] {\[Mu]\_i, \[Nu]\_i}]\), \(specifies\ that\ \
mutation\ rates\ depend\ on\ the\ specified\ context\ component\ \(\((here, \ 
                  Sex)\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->"NewGametes"]], "DefinitionBox",
  CellTags->{"Mutation", "BiallelicMutation"}],

Cell[TextData[{
  "In most of the examples, two alleles are assumed, so that ",
  Cell[BoxData[
      \(TraditionalForm\`X = 0\)]],
  " or 1.  With this convention, mutation ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Mu], \[Nu]}\)]],
  " in either direction has the simple effect of deflating associations among \
genes by a factor ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((1 - \[Mu]\_i - \[Nu]\_i)\)\(\ \)\)\)]],
  "for each locus ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " involved - provided that the reference point is set to the local allele \
frequencies, and so is shifted as mutation changes allele frequencies.  \
BiallelicMutation[Mutation\[Rule]{\[Mu],\[Nu]}] applies this rule to \
transform means and linkage disequilibria.  The default is for mutation \
between gametes (\[GothicCapitalG]) and zygotes (\[GothicCapitalZ]}. "
}], "Text"],

Cell["\<\
BiallelicMutation and genotype-dependent mutation rates are not yet \
implemented.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Multiple alleles", "SubsubsectionIcon"],

Cell[TextData[{
  "Multiple alleles can be handled by allowing repreated indices (e.g. ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckI], \[DoubleStruckJ]}\)]],
  ").  However, the effects of mutation are then hard to describe in a \
general way: one must specifiy how mutation alters the moments of the \
distribution of allelic effects.  A more natural representation is to denote \
allelic state by a vector, carrying a single '1' for the allele.  For \
example, ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\[DoubleStruckI] = {1, 0, 0, 0}\)]],
  " specifies that the first of four possible alleles is present.   Linkage \
disequilibria and selection coefficients are then tensors, of rank equal to \
the number of loci.  The reduction rule for repeated indices is essentially \
the same as in the biallelic case: ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[GothicCapitalD]\_\({\[DoubleStruckI], \[DoubleStruckI]}\
\[Vee]U\)\), "=", 
          RowBox[{
            RowBox[{\(\[GothicCapitalD]\_U\), 
              RowBox[{\(\[GothicM]\_\[DoubleStruckI]\), "(", 
                RowBox[{
                  StyleBox["1",
                    FontWeight->"Bold"], 
                  "-", \(\[GothicM]\_\[DoubleStruckI]\)}], ")"}]}], "+", 
            
            RowBox[{\(\[GothicCapitalD]\_\({\[DoubleStruckI]}\[Vee]U\)\), "(",
               
              RowBox[{
                StyleBox["1",
                  FontWeight->"Bold"], 
                "-", \(2  \[GothicM]\_\[DoubleStruckI]\)}], ")"}]}]}], 
        TraditionalForm]]],
  " where ",
  StyleBox["1",
    FontWeight->"Bold"],
  " is a vector of 1's, and the elements for each locus are multiplied \
together."
}], "Text"],

Cell["\<\
With this representation, mutation is described as a product of \
operators, one for each locus, and each being a matrix that multiplies the \
corresponding vector. Explicitly:\
\>", "Text"],

Cell[BoxData[
    \(TextForm\`\[GothicCapitalD]\_\[DoubleStruckCapitalU] \[Rule] \[Product]\
\+\(i \[Element] \[Gamma][\[DoubleStruckCapitalU]]\)\(\[Sum]\+\(\[Beta]\_i = \
1\)\%n\_i\( 
                M\_\(i, \[Alpha]\_i, \[Beta]\_i\)\) \((\[GothicCapitalD]\_\
\[DoubleStruckCapitalU])\)\_\(\[Beta]\_1, \[Ellipsis], \[Beta]\_i, \
\[Ellipsis]\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "where there are ",
  Cell[BoxData[
      \(TraditionalForm\`n\_i\)]],
  " alleles at locus ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`M\_i\)]],
  " is the mutation matrix for locus ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Baake (",
  ButtonBox["2001",
    ButtonData:>{"Multilocus references", "Baake 2001"},
    ButtonStyle->"AddOnsLink"],
  ") sets out this approach in detail.  In continuous time, she shows that by \
rotating the vector space such that the mutation matrix at each locus is \
diagionalized, the effects of both mutation and recombination can be written \
out explicitly, as a simple exponential decay."
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{912, 546},
WindowMargins->{{Automatic, 74}, {Automatic, 81}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Mutation"->{
    Cell[2590, 80, 995, 19, 92, "DefinitionBox",
      CellTags->{"Mutation", "BiallelicMutation"}]},
  "BiallelicMutation"->{
    Cell[2590, 80, 995, 19, 92, "DefinitionBox",
      CellTags->{"Mutation", "BiallelicMutation"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Mutation", 8607, 238},
  {"BiallelicMutation", 8734, 241}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 34, 0, 36, "SubsectionIcon"],
Cell[1776, 53, 473, 14, 23, "Text"],
Cell[2252, 69, 273, 5, 36, "Text"],

Cell[CellGroupData[{
Cell[2550, 78, 37, 0, 24, "SubsubsectionIcon"],
Cell[2590, 80, 995, 19, 92, "DefinitionBox",
  CellTags->{"Mutation", "BiallelicMutation"}],
Cell[3588, 101, 873, 19, 50, "Text"],
Cell[4464, 122, 106, 3, 22, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4607, 130, 45, 0, 24, "SubsubsectionIcon"],
Cell[4655, 132, 1751, 40, 80, "Text"],
Cell[6409, 174, 200, 4, 22, "Text"],
Cell[6612, 180, 369, 6, 56, "NumberedEquation"],
Cell[6984, 188, 329, 14, 22, "Text"],
Cell[7316, 204, 431, 9, 37, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

