(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     21429,        540]*)
(*NotebookOutlinePosition[     22857,        582]*)
(*  CellTagsIndexPosition[     22688,        574]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Expectations", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(\(\[LeftDoubleBracketingBar]f\[RightDoubleBracketingBar]\ or\)\(\
\ \)\(\n\)\(PopulationExpectation[
              f]\)\), \(gives\ the\ expectation\ of\ f\ over\ the\ \
distribution\ of\ \(\(populations\)\(.\)\(\ \ \)\)\)},
          {\(\(\(\[GothicCapitalC]\_\({{\[DoubleStruckCapitalU]}, {\
\[DoubleStruckCapitalV]} \[Ellipsis]}, {{\[DoubleStruckI]}, \
{\[DoubleStruckJ]} \[Ellipsis]}\)\) or\)\n
            PopulationDisequilibrium[{{\[DoubleStruckCapitalU]}, {\
\[DoubleStruckCapitalV]} \[Ellipsis]}, {{\[DoubleStruckI]}, \
{\[DoubleStruckJ]} \[Ellipsis]}]\), \(\(is\ the\ expectation\ over\ the\ \
distribution\ of\ populations\)\(,\)\(\ \)\(\[LeftDoubleBracketingBar]\(\
\[GothicCapitalD]\_\[DoubleStruckCapitalU]\) \(\[GothicCapitalD]\_\
\[DoubleStruckCapitalV]\) \[Ellipsis]\[VeryThinSpace]\(\[WeierstrassP]\_\
\[DoubleStruckI]\) \(\[WeierstrassP]\_\[DoubleStruckJ]\) \[Ellipsis]\
\[RightDoubleBracketingBar]\)\(\ \)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"PopulationExpectation", "PopulationDisequilibrium"}],

Cell[TextData[{
  "A ",
  StyleBox["distribution",
    FontSlant->"Italic"],
  " of populations can be described in terms of the means, mean square, and \
higher moments of the means, \[GothicM], and linkage disequilibria, \
\[GothicCapitalD].  The expected value of any polynomial expression in ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_\[DoubleStruckCapitalU]\)]],
  "\[Ellipsis], ",
  Cell[BoxData[
      \(TraditionalForm\`\[WeierstrassP]\_\[DoubleStruckI]\)]],
  "\[Ellipsis] can be reduced to a polynomial in these moments.  "
}], "Text"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(<< Multilocus`Multilocus`\)], "Input",
  CellLabel->"In[1]:=  (16:28:54 on 4/5/00)"],

Cell["This is a sum of three-way expectations:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[LeftDoubleBracketingBar]3 \( \[GothicCapitalD]\_\
\[DoubleStruckCapitalU]\) \(\[GothicCapitalD]\_\[DoubleStruckCapitalV]\) \
\[WeierstrassP]\_\[DoubleStruckI] + \[Alpha]\ \(\[GothicCapitalD]\_\
\[DoubleStruckCapitalU]\) \[GothicCapitalD]\_\[DoubleStruckCapitalA]\
\[RightDoubleBracketingBar]\)], "Input",
  CellLabel->"In[25]:=  (16:21:05 on 4/5/00)"],

Cell[BoxData[
    \(\[Alpha]\ \[GothicCapitalC]\_\({{\[DoubleStruckCapitalA]}, {\
\[DoubleStruckCapitalU]}}, {}\) + 
      3\ \[GothicCapitalC]\_\({{\[DoubleStruckCapitalU]}, {\
\[DoubleStruckCapitalV]}}, {{\[DoubleStruckI]}}\)\)], "Output",
  CellLabel->"Out[25]=  (16:21:05 on 4/5/00)"]
}, Open  ]],

Cell["Only polynomial expressions can be reduced:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[LeftDoubleBracketingBar]Log[
        3 \( \[GothicCapitalD]\_\[DoubleStruckCapitalU]\) \(\[GothicCapitalD]\
\_\[DoubleStruckCapitalV]\) \[WeierstrassP]\_\[DoubleStruckI]]\
\[RightDoubleBracketingBar]\)], "Input",
  CellLabel->"In[26]:=  (16:21:11 on 4/5/00)"],

Cell[BoxData[
    \(\[LeftDoubleBracketingBar]Log[3\ \[GothicCapitalD]\_\
\[DoubleStruckCapitalU]\ \[GothicCapitalD]\_\[DoubleStruckCapitalV]\ \
\[WeierstrassP]\_\[DoubleStruckI]]\[RightDoubleBracketingBar]\_\(\
Disequilibrium, MeanContribution\)\)], "Output",
  CellLabel->"Out[26]=  (16:21:11 on 4/5/00)"]
}, Open  ]],

Cell[TextData[{
  "Because, by definition, ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_{\[DoubleStruckI]} = \[GothicM]\_\
\[DoubleStruckI] - \[WeierstrassP]\_\[DoubleStruckI]\)]],
  ", the mean contribution can be replaced by ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicM]\_\[DoubleStruckI] = \[WeierstrassP]\_\
\[DoubleStruckI] + \[GothicCapitalD]\_{\[DoubleStruckI]}\)]],
  " throughout:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[LeftDoubleBracketingBar]\(\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}, 
                k\_{\[GothicCapitalG], \[GothicCapitalM]}}\) \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\) /. \[GothicM]\_\
\[DoubleStruckI]_ \[Rule] \[WeierstrassP]\_\[DoubleStruckI]_ + \
\[GothicCapitalD]\_{\[DoubleStruckI]_}\[RightDoubleBracketingBar]\)], "Input",\

  CellLabel->"In[27]:=  (16:22:19 on 4/5/00)"],

Cell[BoxData[
    \(\[GothicCapitalC]\_\({{{j\_{\[GothicCapitalG], \[GothicCapitalM]}, k\_{\
\[GothicCapitalG], \[GothicCapitalM]}}}}, {{i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}}\) + \[GothicCapitalC]\_\({{{i\_{\[GothicCapitalG], \
\[GothicCapitalM]}}}, {{j\_{\[GothicCapitalG], \[GothicCapitalM]}, k\_{\
\[GothicCapitalG], \[GothicCapitalM]}}}}, {}\)\)], "Output",
  CellLabel->"Out[27]=  (16:22:19 on 4/5/00)"]
}, Open  ]],

Cell[TextData[{
  "The rather cumbersome nested structure of the subscripts of \
\[GothicCapitalC] is required, because in general, expectations might be \
taken over functions with multiple arguments (",
  ButtonBox["see below",
    ButtonData:>"multiple arguments",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                SubscriptBox[
                  RowBox[{"\[LeftDoubleBracketingBar]", 
                    StyleBox["expr",
                      FontSlant->"Italic"], 
                    "\[RightDoubleBracketingBar]"}], \(f, g\[Ellipsis]\)], 
                " ", "or"}], " ", "\n", 
              RowBox[{"PopulationExpectation", "[", 
                RowBox[{
                  StyleBox["expr",
                    FontSlant->"Italic"], ",", "f", ",", "g\[Ellipsis]"}], 
                "]"}]}], 
            RowBox[{
              RowBox[{
              "gives", " ", "the", " ", "expectation", " ", "of", " ", 
                StyleBox["expr",
                  FontSlant->"Italic"], " ", "over", " ", "the", " ", 
                "random", " ", "variables", " ", "f"}], ",", 
              " ", \(g\[VeryThinSpace]\[Ellipsis]\)}]},
          {\(\(\(\(\[GothicCapitalC]\_\({{\[DoubleStruckCapitalA]\_1, \ \(\
\[DoubleStruckCapitalA]\_2\) \[Ellipsis]} \[Ellipsis]}, {{\
\[DoubleStruckCapitalB]\_1, \ \(\[DoubleStruckCapitalB]\_2\) \[Ellipsis]} \
\[Ellipsis]}, \[Ellipsis]\)\) 
                  or\ \(\(PopulationDisequilibrium\)\([\)\({{\
\[DoubleStruckCapitalA]\_1, \ \(\[DoubleStruckCapitalA]\_2\) \[Ellipsis]}, \
\[Ellipsis]}, {{\[DoubleStruckCapitalB]\_1, \ \(\[DoubleStruckCapitalB]\_2\) \
\[Ellipsis]} \[Ellipsis]}, \[Ellipsis]\)\)\)\(}\)\)\(]\)\), \(\(is\ the\ \
expectation\ over\ f\)\(,\)\(\ \)\(g\[VeryThinSpace]\[Ellipsis]\)\(,\)\(\ \
\)\(\[LeftDoubleBracketingBar]\[VeryThinSpace]f[\[DoubleStruckCapitalA]\_1, \ \
\(\[DoubleStruckCapitalA]\_2\) \[Ellipsis]] \[Ellipsis]\[VeryThinSpace]g[\
\[DoubleStruckCapitalB]\_1, \ \(\[DoubleStruckCapitalB]\_2\) \[Ellipsis]] \
\[Ellipsis]\[RightDoubleBracketingBar]\)\(\ \)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["\<\
There may be other sources of random fluctuation; for example, \
randomly varying selection coefficients, migration rates, ....  \
\>", "Text"],

Cell["\<\
Any set of random variables can be defined, and any polynomial in \
these variables can be reduced to a polynomial in the corresponding \
\[GothicCapitalC]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[LeftDoubleBracketingBar]f[\[DoubleStruckCapitalA]] \
\(\[GothicCapitalD]\_\[DoubleStruckCapitalU]\) \[WeierstrassP]\_\
\[DoubleStruckI] + 3  g[\[DoubleStruckCapitalB]] \[GothicCapitalD]\_\
\[DoubleStruckCapitalU]\[RightDoubleBracketingBar]\_\(\[GothicCapitalD], \
\[GothicM], f, g\)\)], "Input",
  CellLabel->"In[2]:=  (16:29:07 on 4/5/00)"],

Cell[BoxData[
    \(3\ \[GothicCapitalC]\_\({{\[DoubleStruckCapitalU]}}, {}, {}, {{\
\[DoubleStruckCapitalB]}}\) + \
\[GothicCapitalC]\_\({{\[DoubleStruckCapitalU]}}, {{\[DoubleStruckI]}}, {{\
\[DoubleStruckCapitalA]}}, {}\)\)], "Output",
  CellLabel->"Out[2]=  (16:29:07 on 4/5/00)"]
}, Open  ]],

Cell[TextData[{
  "By default, the expectation is taken over \[GothicCapitalD] and \
\[WeierstrassP], and the first two subscripts of  \[GothicCapitalC] \
correspond to these variables.  However, any set of subscripted arguments of \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\[LeftDoubleBracketingBar]\
\[RightDoubleBracketingBar]\_\(f, g\)\) can\ be\ given\)]],
  ", and correspond to additional variables.  These variables are denoted by \
additional subscripts to \[GothicCapitalC].  The \[GothicCapitalC] must \
therefore be interpreted with the aid of extra information about which \
variables they correspond to."
}], "Text"],

Cell[TextData[{
  "The special notation ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          RowBox[{"\[LeftDoubleBracketingBar]", 
            StyleBox["expr",
              FontSlant->"Italic"], "\[RightDoubleBracketingBar]"}], \(f, 
          g, \[Ellipsis]\)], TraditionalForm]]],
  " is represented internally as ",
  Cell[BoxData[
      FormBox[
        RowBox[{"PopulationExpectation", "[", 
          RowBox[{
            StyleBox["expr",
              FontSlant->"Italic"], ",", "f", ",", "g", ",", "\[Ellipsis]"}], 
          "]"}], TraditionalForm]]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[LeftDoubleBracketingBar]Log[f[x]]\[RightDoubleBracketingBar]\_\(f, g, \
h\) // FullForm\)], "Input",
  CellLabel->"In[31]:=  (16:28:08 on 4/5/00)"],

Cell[BoxData[
    TagBox[
      StyleBox[\(PopulationExpectation[Log[f[x]], f, g, h]\),
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[31]//FullForm=  (16:28:08 on 4/5/00)"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                SubscriptBox[
                  RowBox[{"\[LeftDoubleBracketingBar]", 
                    StyleBox["expr",
                      FontSlant->"Italic"], 
                    "\[RightDoubleBracketingBar]"}], \(\[GothicCapitalD], \
\[GothicM], \[GothicA], \[Ellipsis]\)], " ", "or"}], " ", "\n", 
              RowBox[{"PopulationExpectation", "[", 
                RowBox[{
                  StyleBox["expr",
                    FontSlant->"Italic"], ",", "Disequiilibrium", ",", " ", 
                  "MeanContribution", ",", " ", "SelectionCoefficient", ",", 
                  "\[Ellipsis]"}], "]"}]}], 
            RowBox[{
              RowBox[{
              "gives", " ", "the", " ", "expectation", " ", "of", " ", 
                StyleBox["expr",
                  FontSlant->"Italic"], " ", "over", " ", "the", " ", 
                "distribution", " ", "of", " ", "\[GothicCapitalD]"}], ",", 
              " ", "\[GothicM]", ",", " ", "\[GothicA]\[Ellipsis]", " "}]}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell[TextData[{
  "When associated with ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          RowBox[{"\[LeftDoubleBracketingBar]", 
            StyleBox["expr",
              FontSlant->"Italic"], 
            "\[RightDoubleBracketingBar]"}], \(\[GothicA], \[Ellipsis]\)], 
        TraditionalForm]]],
  ", the symbols \[GothicA], \[CapitalMu], \[GothicR] are interpreted in a \
special way, as indicating the functions SelectionCoefficient[], \
MigrationRate[], and RecombinationRate[]: "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[LeftDoubleBracketingBar]\(\[GothicA]\_\[DoubleStruckCapitalA]\) \
\[GothicCapitalD]\_\[DoubleStruckCapitalU]\[RightDoubleBracketingBar]\_\(\
\[GothicCapitalD], \[GothicM], \[GothicA]\)\)], "Input",
  CellLabel->"In[4]:=  (16:29:25 on 4/5/00)"],

Cell[BoxData[
    \(\[GothicCapitalC]\_\({{\[DoubleStruckCapitalU]}}, {}, {{\
\[DoubleStruckCapitalA]}}\)\)], "Output",
  CellLabel->"Out[4]=  (16:29:25 on 4/5/00)"]
}, Open  ]],

Cell["\<\
This gives the expectation of the product of selection coefficient \
and linkage disequilibrium.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            
            FormBox[\(\(\(\[GothicCapitalC]\_\({{\[DoubleStruckCapitalU]}, {\
\[DoubleStruckCapitalV]} \[Ellipsis]}, {{\[DoubleStruckI]}, \
{\[DoubleStruckJ]} \[Ellipsis]}, {{\(c\_1\) \[Ellipsis], \
\[DoubleStruckCapitalA]}, \[Ellipsis]}, {{c\_1, \[Ellipsis]\
\[DoubleStruckCapitalB]}, \[Ellipsis]}, \[Ellipsis]\)\) or\)\n
                PopulationDisequilibrium[{{\[DoubleStruckCapitalU]}, {\
\[DoubleStruckCapitalV]} \[Ellipsis]}, {{\[DoubleStruckI]}, \
{\[DoubleStruckJ]} \[Ellipsis]}, {{\(c\_1\) \[Ellipsis], \
\[DoubleStruckCapitalA]}, \[Ellipsis]}, {{c\_1, \[Ellipsis]\
\[DoubleStruckCapitalB]} \[Ellipsis]}, \[Ellipsis]]\),
              
              "TraditionalForm"], \(\(is\ the\ expectation\ over\ the\ \
distribution\ of\ populations\ and\ of\ f\)\(,\)\(\ \)\(g\[Ellipsis]\)\(,\)\(\
\ \)\(\[LeftDoubleBracketingBar]\(\[GothicCapitalD]\_\[DoubleStruckCapitalU]\)\
 \(\[GothicCapitalD]\_\[DoubleStruckCapitalV]\) \
\(\[Ellipsis]\[WeierstrassP]\_\[DoubleStruckI]\) \(\[WeierstrassP]\_\
\[DoubleStruckJ]\) \[Ellipsis]\[VeryThinSpace]f[\(c\_1\) \[Ellipsis]\
\[VeryThinSpace]\[DoubleStruckCapitalA]] \
\[Ellipsis]\[VeryThinSpace]g[\(c\_1\) \[Ellipsis]\[DoubleStruckCapitalB]]\
\[RightDoubleBracketingBar]\)\(\ \)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["\<\
Selection coefficients, recombination rates, and so on,  can depend \
on certain components of the context:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[LeftDoubleBracketingBar]\(\[GothicA]\_\(\[GothicCapitalM], \
\[DoubleStruckCapitalA]\)\) \[GothicCapitalD]\_\[DoubleStruckCapitalU]\
\[RightDoubleBracketingBar]\_\[GothicA]\)], "Input",
  CellLabel->"In[111]:=  (7:35:15 on 4/5/00)"],

Cell[BoxData[
    \(\[GothicCapitalC]\_\({{\[DoubleStruckCapitalU]}}, {}, {{\
\[GothicCapitalM], \[DoubleStruckCapitalA]}}\)\)], "Output",
  CellLabel->"Out[111]=  (7:35:15 on 4/5/00)"]
}, Open  ]],

Cell[TextData[{
  "Here, ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicA]\_\(\[GothicCapitalM], \
\[DoubleStruckCapitalU]\)\)]],
  " indicates selection coefficients peculiar to males.  This is handled by \
allowing the subscripts of \[GothicCapitalC] to have the form ",
  Cell[BoxData[
      \(TraditionalForm\`{\(c\_1\) \[Ellipsis], \[DoubleStruckCapitalA]}\)]],
  ".  The functions ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " must take the set of genes-in-context, \[DoubleStruckCapitalU], as their \
last argument.  It is the possibility of functions with mutliple arguments \
that requires the cumbersome nested structure of the \[GothicCapitalC].  "
}], "Text",
  CellTags->"multiple arguments"],

Cell[BoxData[GridBox[{
        {
          RowBox[{
            StyleBox["\[LeftDoubleBracketingBar]",
              FontFamily->"Times"], 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  UnderscriptBox[
                    RowBox[{
                      StyleBox["\[Sum]",
                        FontFamily->"Times"], 
                      SubscriptBox[
                        StyleBox["\[Alpha]",
                          FontFamily->"Times"], "i"]}], \(i \[Element] 
                      S\)], \((\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}\))\)}], ")"}], "2"], 
            "\[RightDoubleBracketingBar]"}], 
          
          StyleBox[\(simplifies\ expressions\ involving\ \(\[Sum]\+\(i \
\[Element] S\)\ or\ AddUp[expr, i, S]\)\),
            "Text",
            FontFamily->"Times"]}
        }]], "DefinitionBox"],

Cell[TextData[{
  "PopulationExpectation[] treats expressions involving sums over sets (",
  Cell[BoxData[
      StyleBox[\(\[Sum]\+\(i \[Element] S\)\ or\ AddUp[expr, i, S]\),
        "Text",
        FontFamily->"Times"]]],
  ") in a special way.  "
}], "Text"],

Cell["For example:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["\[LeftDoubleBracketingBar]",
        FontFamily->
          "Times"], \(\[Sum]\+\(i \[Element] Z\)\(\[Sum]\+\(j \[Element] \
Z\)\(\[Beta]\_\(i, 
                j\)\) \((\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}\))\) \((\
\[WeierstrassP]\_\(j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\)\), 
      "\[RightDoubleBracketingBar]"}]], "Input",
  CellLabel->"In[109]:=  (7:33:56 on 4/5/00)"],

Cell[BoxData[
    \(\[Sum]\+\({{i}\[Vee]{j}} \[Element] \
{{Z}\[Vee]{Z}}\)\((\[GothicCapitalC]\_\({}, {{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}, {j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}}\)\ \[Beta]\_\(i, j\) + \
\[GothicCapitalC]\_\({}, {{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}, {j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}}\)\ \[Beta]\_\(i, j\) + \[GothicCapitalC]\_\({}, {{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}, {j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}}\)\ \[Beta]\_\(i, j\
\) + \[GothicCapitalC]\_\({}, {{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}, {j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}}\)\ \[Beta]\_\(i, j\))\)\)], "Output",
  CellLabel->"Out[109]=  (7:33:56 on 4/5/00)"]
}, Open  ]],

Cell["Powers are handled correctly:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["\[LeftDoubleBracketingBar]",
        FontFamily->
          "Times"], \(\((\[Sum]\+\(i \[Element] Z\)\(\[Gamma]\_i\) \((\
\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\))\))\)\^2\), 
      "\[RightDoubleBracketingBar]"}]], "Input",
  CellLabel->"In[110]:=  (7:34:08 on 4/5/00)"],

Cell[BoxData[
    \(\[Sum]\+\({i$641, i$642} \[Element] {Z, Z}\)\((\[GothicCapitalC]\_\({}, \
{{i$641\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}, \
{i$642\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}}\)\ \
\[Gamma]\_i$641\ \[Gamma]\_i$642 + \[GothicCapitalC]\_\({}, {{i$641\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}, {i$642\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}}\)\ \[Gamma]\_i$641\
\ \[Gamma]\_i$642 + \[GothicCapitalC]\_\({}, {{i$641\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}, {i$642\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}}\)\ \[Gamma]\_i$641\ \[Gamma]\_i$642 + \
\[GothicCapitalC]\_\({}, {{i$641\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}, {i$642\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}}\)\ \[Gamma]\_i$641\ \[Gamma]\_i$642)\)\)], "Output",
  CellLabel->"Out[110]=  (7:34:08 on 4/5/00)"]
}, Open  ]],

Cell["The dummy variables i$641, i$642 have been introduced.", "Text"],

Cell[TextData[{
  "When the expression contains AddUp[],PopulationExpectation[] calls \
SimplifyAddUp[] to reduce it to a sum of terms like ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\({\[Alpha], \[Ellipsis]} \[Element] {S, \
\[Ellipsis]}\)\)]],
  ".  The expectation is then taken inside the sum."
}], "Text"],

Cell[TextData[{
  "Note that the analogous algorithm for TimesUp[] or ",
  Cell[BoxData[
      \(TraditionalForm\`\[Product]\+\(i \[Element] S\)\)]],
  " is ",
  StyleBox["not",
    FontWeight->"Bold"],
  " implemented: it is harder to expand expressions involving products over \
unknown sets."
}], "Text"]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{245, Automatic}, {Automatic, 46}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "PopulationExpectation"->{
    Cell[1758, 51, 1110, 18, 104, "DefinitionBox",
      CellTags->{"PopulationExpectation", "PopulationDisequilibrium"}]},
  "PopulationDisequilibrium"->{
    Cell[1758, 51, 1110, 18, 104, "DefinitionBox",
      CellTags->{"PopulationExpectation", "PopulationDisequilibrium"}]},
  "multiple arguments"->{
    Cell[15578, 396, 775, 19, 70, "Text",
      CellTags->"multiple arguments"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"PopulationExpectation", 22275, 561},
  {"PopulationDisequilibrium", 22431, 564},
  {"multiple arguments", 22581, 567}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 38, 0, 36, "SubsectionIcon"],
Cell[1758, 51, 1110, 18, 104, "DefinitionBox",
  CellTags->{"PopulationExpectation", "PopulationDisequilibrium"}],
Cell[2871, 71, 565, 13, 52, "Text"],
Cell[3439, 86, 46, 0, 28, "MathCaption"],
Cell[3488, 88, 104, 2, 38, "Input"],
Cell[3595, 92, 63, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3683, 96, 373, 6, 38, "Input"],
Cell[4059, 104, 288, 5, 34, "Output"]
}, Open  ]],
Cell[4362, 112, 66, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4453, 116, 281, 5, 38, "Input"],
Cell[4737, 123, 307, 5, 36, "Output"]
}, Open  ]],
Cell[5059, 131, 436, 10, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[5520, 145, 444, 8, 42, "Input"],
Cell[5967, 155, 416, 6, 39, "Output"]
}, Open  ]],
Cell[6398, 164, 317, 8, 36, "Text"],
Cell[6718, 174, 1890, 36, 57, "DefinitionBox"],
Cell[8611, 212, 153, 3, 70, "Text"],
Cell[8767, 217, 187, 4, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[8979, 225, 363, 6, 70, "Input"],
Cell[9345, 233, 284, 5, 70, "Output"]
}, Open  ]],
Cell[9644, 241, 636, 12, 70, "Text"],
Cell[10283, 255, 600, 18, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[10908, 277, 169, 3, 70, "Input"],
Cell[11080, 282, 236, 6, 70, "Output"]
}, Open  ]],
Cell[11331, 291, 1152, 24, 70, "DefinitionBox"],
Cell[12486, 317, 521, 13, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[13032, 334, 265, 4, 70, "Input"],
Cell[13300, 340, 165, 3, 70, "Output"]
}, Open  ]],
Cell[13480, 346, 120, 3, 70, "Text"],
Cell[13603, 351, 1352, 24, 70, "DefinitionBox"],
Cell[14958, 377, 138, 3, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[15121, 384, 254, 4, 70, "Input"],
Cell[15378, 390, 185, 3, 70, "Output"]
}, Open  ]],
Cell[15578, 396, 775, 19, 70, "Text",
  CellTags->"multiple arguments"],
Cell[16356, 417, 1002, 24, 70, "DefinitionBox"],
Cell[17361, 443, 262, 7, 70, "Text"],
Cell[17626, 452, 35, 0, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[17686, 456, 665, 13, 70, "Input"],
Cell[18354, 471, 866, 13, 70, "Output"]
}, Open  ]],
Cell[19235, 487, 52, 0, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[19312, 491, 443, 9, 70, "Input"],
Cell[19758, 502, 950, 13, 70, "Output"]
}, Open  ]],
Cell[20723, 518, 70, 0, 70, "Text"],
Cell[20796, 520, 319, 7, 70, "Text"],
Cell[21118, 529, 307, 9, 70, "Text"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

