(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8242,        231]*)
(*NotebookOutlinePosition[      9427,        269]*)
(*  CellTagsIndexPosition[      9309,        262]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Random union", "SubsectionIcon"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(RandomUnion[\[GothicCapitalG]]\), \(is\ a\ rule\ which\ \
represents\ random\ union\ of\ gametes, \ \[GothicCapitalG] . \ \ \ \
\[GothicCapitalD]\_\[DoubleStruckCapitalU]\ in\ a\ pair\ of\ male\ and\ \
female\ gametes\ is\ replaced\ by\ the\ product\ of\ the\ associations\ \
within\ each\ \(\(gamete\)\(.\)\)\)}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->"RandomUnion"],

Cell["\<\
RandomUnion[\[GothicCapitalG]] simplifies expressions by assuming \
that there are no associations among genes in the male and in the female \
gametes that united to form the zygote.\
\>", "Text"],

Cell["\<\
This gives the association among a set of three genes in a male \
zygote, in terms of associations in the gamete pool:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} /. UnionOfGametes[]\) /. 
      ReferencePointSame[\[GothicCapitalG], \[GothicCapitalZ]]\)], "Input",
  CellLabel->"In[50]:=  (19:06:42 on 3/3/01)"],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, k\_{\
\[GothicCapitalG], \[GothicCapitalM]}, k\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\)], "Output",
  CellLabel->"Out[50]=  (19:06:42 on 3/3/01)"]
}, Open  ]],

Cell["\<\
The reference points are kept the same for simplicity.  Note that \
this association is between genes in a male and in a female gemete.\
\>", \
"Text"],

Cell["\<\
Under random union, these associations are just products of the \
gametic \[GothicCapitalD] in the male & female gamete pools:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} /. UnionOfGametes[]\) /. 
        ReferencePointSame[\[GothicCapitalG], \[GothicCapitalZ]]\) /. 
      RandomUnion[\[GothicCapitalG]]\)], "Input",
  CellLabel->"In[51]:=  (19:08:29 on 3/3/01)"],

Cell[BoxData[
    \(\[GothicCapitalD]\_{k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, k\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\)], "Output",
  CellLabel->"Out[51]=  (19:08:29 on 3/3/01)"]
}, Open  ]],

Cell[TextData[{
  "RandomUnion[\[GothicCapitalG]] just uses the rule ",
  Cell[BoxData[
      \({\[GothicCapitalD]\_\(\[DoubleStruckCapitalU] : \
{_\_{\[GothicCapitalG], __} ... }\) \[RuleDelayed] \(\[GothicCapitalD]\_\(\
\[DoubleStruckCapitalU]\(\[CircleDot]\_Sex\){\[GothicCapitalM]}\)\) \
\[GothicCapitalD]\_\(\[DoubleStruckCapitalU]\(\[CircleDot]\_Sex\){\
\[GothicCapitalF]}\)}\)],
    InitializationCell->True],
  ".  "
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(RandomUnion[\[GothicCapitalG], {c\_1, \[Ellipsis]}]\), \
\(assumes\ that\ the\ genes\ are\ in\ different\ gametes\ if\ any\ of\ the\ \
components\ in\ the\ set\ {c\_1, \[Ellipsis]}\ differ\)}
            }], TraditionalForm]]]
}], "DefinitionBox"],

Cell[TextData[{
  "RandomUnion[\[GothicCapitalG]] assumes that all the genes in the male \
gamete are in the ",
  StyleBox["same",
    FontSlant->"Italic"],
  " gamete, and similarly for the genes in female gametes.  One might define \
an extra component representing individuals: for example, ",
  Cell[BoxData[
      \(TraditionalForm\`{i\_{\[GothicCapitalG], \[Alpha], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[Beta], \[GothicCapitalM]}}\)]],
  " might represent a pair of genes in different male gametes (labelled \
\[Alpha],\[Beta]). One might introduce a further component representing the \
deme, and assume that if either the sex, or the individual, or the deme label \
differ, then the genes are in different gametes.  "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`RandomUnion[\[GothicCapitalG], {c\_1, \
\[Ellipsis]}]\)]],
  " separates associations among genes into a product across different \
gametes:"
}], "MathCaption"],

Cell[BoxData[
    \(DefineContext[\[GothicCapitalZ], {Deme, Individual, Sex, 
        SexOfOrigin}]\)], "Input",
  CellLabel->"In[19]:="],

Cell["\<\
This assumes that there is no correlation among different \
individuals, distinguished according to the three components \
{Deme,Individual,Sex}:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], 1, \[Alpha], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], 2, \[Alpha], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], 1, \[Beta], \
\[GothicCapitalM], \[GothicCapitalF]}, l\_{\[GothicCapitalZ], 1, \[Beta], \
\[GothicCapitalM], \[GothicCapitalM]}} /. 
      RandomUnion[\[GothicCapitalZ], {Deme, Individual, Sex}]\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], 1, \[Alpha], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], 2, \[Alpha], \[GothicCapitalM], \[GothicCapitalM]}}\ \
\[GothicCapitalD]\_{k\_{\[GothicCapitalZ], 1, \[Beta], \[GothicCapitalM], \
\[GothicCapitalF]}, l\_{\[GothicCapitalZ], 1, \[Beta], \[GothicCapitalM], \
\[GothicCapitalM]}}\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell["\<\
RandomUnion[\[GothicCapitalG]] is just \
RandomUnion[\[GothicCapitalG],{Sex}] \
\>", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(RandomUnion[\[GothicCapitalZ]]\), \(is\ a\ rule\ which\ \
represents\ random\ union\ of\ zygotes, \ \[GothicCapitalZ] . \ \ \ \
\[GothicCapitalD]\_\[DoubleStruckCapitalU]\ in\ a\ pair\ of\ male\ and\ \
female\ zygotes\ is\ replaced\ by\ the\ product\ of\ the\ associations\ \
within\ each\ \(\(zygote\)\(.\)\)\)}
            }], TraditionalForm]]]
}], "DefinitionBox",
  CellTags->"Random union of zygotes"],

Cell[TextData[{
  "RandomUnion[\[GothicCapitalZ]] represents random union of zygotes; this is \
needed in models of ",
  ButtonBox["sexual selection",
    ButtonData:>{"Sexual selection", "Random union"},
    ButtonStyle->"AddOnsLink"],
  ", where male and female zygotes are taken to combine at random, and then \
be selected."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{774, 698},
WindowMargins->{{14, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "RandomUnion"->{
    Cell[1780, 53, 473, 11, 64, "DefinitionBox",
      CellTags->"RandomUnion"]},
  "Random union of zygotes"->{
    Cell[7398, 207, 485, 11, 64, "DefinitionBox",
      CellTags->"Random union of zygotes"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"RandomUnion", 9076, 252},
  {"Random union of zygotes", 9189, 255}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 38, 0, 36, "SubsectionIcon"],
Cell[1780, 53, 473, 11, 64, "DefinitionBox",
  CellTags->"RandomUnion"],
Cell[2256, 66, 206, 4, 36, "Text"],
Cell[2465, 72, 149, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2639, 79, 382, 6, 33, "Input"],
Cell[3024, 87, 233, 4, 26, "Output"]
}, Open  ]],
Cell[3272, 94, 161, 4, 22, "Text"],
Cell[3436, 100, 159, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3620, 108, 429, 7, 33, "Input"],
Cell[4052, 117, 254, 4, 26, "Output"]
}, Open  ]],
Cell[4321, 124, 436, 10, 30, "Text"],
Cell[4760, 136, 325, 8, 50, "DefinitionBox"],
Cell[5088, 146, 746, 14, 66, "Text"],
Cell[5837, 162, 217, 6, 28, "MathCaption"],
Cell[6057, 170, 137, 3, 27, "Input"],
Cell[6197, 175, 176, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6398, 183, 449, 7, 33, "Input"],
Cell[6850, 192, 428, 7, 26, "Output"]
}, Open  ]],
Cell[7293, 202, 102, 3, 22, "Text"],
Cell[7398, 207, 485, 11, 64, "DefinitionBox",
  CellTags->"Random union of zygotes"],
Cell[7886, 220, 340, 8, 37, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

