(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7444,        218]*)
(*NotebookOutlinePosition[      8472,        252]*)
(*  CellTagsIndexPosition[      8393,        246]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Selecting contexts", "SubsectionIcon"],

Cell[BoxData[
    StyleBox[GridBox[{
          {\(\[DoubleStruckCapitalU]\[CircleDot]c\ or\ SelectContext[\
\[DoubleStruckCapitalU], c]\), 
            RowBox[{
            "The", " ", "subset", " ", "of", " ", "genes", " ", "in", " ", 
              "\[DoubleStruckCapitalU]", " ", "that", " ", "matches", " ", 
              "context", 
              FormBox["c",
                "TraditionalForm"]}]},
          {\(\[DoubleStruckCapitalU]\(\[CircleDot]\_{\(x\_1\) \[Ellipsis]}\)c\
\ or\ SelectContext[\[DoubleStruckCapitalU], c, {\(x\_1\) \[Ellipsis]}]\), 
            RowBox[{
            "The", " ", "subset", " ", "of", " ", "genes", " ", "in", " ", 
              "\[DoubleStruckCapitalU]", " ", "that", " ", "matches", " ", 
              "context", 
              FormBox["c",
                "TraditionalForm"], "in", " ", "components", 
              " ", \({\(x\_1\) \[Ellipsis]}\)}]},
          {\(\[DoubleStruckCapitalU]\[CircleDot]{\[GothicCapitalZ], _, \
\[GothicCapitalF], _}\), \(an\ alternative\ notation\ that\ ignores\ \
components\ marked\ by\ _\)}
          },
        ColumnAlignments->{Left},
        GridFrame->False],
      FontFamily->"Times"]], "DefinitionBox",
  CellTags->"SelectContexts"],

Cell[TextData[{
  "Sets of genes in the appropriate contexts can be selected in various ways, \
using SelectContext[\[DoubleStruckCapitalU],c,x]; this is represented as ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalU]\(\[CircleDot]\_x\)c\)]],
  ".  (\[CircleDot] is entered as \[AliasIndicator]c.\[AliasIndicator])."
}], "Text"],

Cell["\<\
This defines a context for diploid zygotes, structured by time, sex \
and sex-of-origin; and a context for haploid gametes, structured by time and \
sex:\
\>", "MathCaption"],

Cell[BoxData[{
    \(\(DefineContext[\[GothicCapitalZ], {Time, Sex, 
          SexOfOrigin}];\)\), "\n", 
    \(\(DefineContext[\[GothicCapitalG], {Time, \ Sex}];\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
In its simplest form, \[DoubleStruckCapitalU]\[CircleDot]c picks \
out genes in the exact context c:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({i\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalF]}, 
        j\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalM]}}\
\[CircleDot]{\[GothicCapitalZ], 
        t, \[GothicCapitalM], \[GothicCapitalM]}\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    \({j\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalM]}}\)], \
"Output",
  CellLabel->"Out[52]="]
}, Open  ]],

Cell["This also works with the short form:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({{\[GothicCapitalZ], t, \[GothicCapitalM], #}, i\_{\[GothicCapitalF]}, 
        j\_{\[GothicCapitalM]}}\[CircleDot]{\[GothicCapitalZ], 
        t, \[GothicCapitalM], \[GothicCapitalM]}\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    \({j\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalM]}}\)], \
"Output",
  CellLabel->"Out[53]="]
}, Open  ]],

Cell["Some contexts can be ignored by representing them as _:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({i\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalF]}, 
        j\_{\[GothicCapitalZ], t, \[GothicCapitalF], \[GothicCapitalM]}, 
        k\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalM]}}\
\[CircleDot]{\[GothicCapitalZ], t, \[GothicCapitalM], _}\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    \({i\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalF]}, 
      k\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalM]}}\)], \
"Output",
  CellLabel->"Out[55]="]
}, Open  ]],

Cell["\<\
The same can be acheived by naming the relevant components in a \
subscript:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({i\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalF]}, 
        j\_{\[GothicCapitalZ], t, \[GothicCapitalF], \[GothicCapitalM]}}\(\
\[CircleDot]\_Sex\){\[GothicCapitalM]}\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \({i\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalF]}}\)], \
"Output",
  CellLabel->"Out[56]="]
}, Open  ]],

Cell["A list of components can be given:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({i\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalF]}, 
        j\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalM]}}\(\
\[CircleDot]\_{Sex, 
            SexOfOrigin}\){\[GothicCapitalM], \[GothicCapitalF]}\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \({i\_{\[GothicCapitalZ], t, \[GothicCapitalM], \[GothicCapitalF]}}\)], \
"Output",
  CellLabel->"Out[57]="]
}, Open  ]],

Cell["\<\
Note that for the relevant component to be specified by a \
subscript, all the stages must be the same.  (Otherwise, the component names \
are not uniquely defined).\
\>", "Text"],

Cell["For example:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({i\_{\[ScriptCapitalZ], t, \[GothicCapitalM], \[GothicCapitalF]}, 
        j\_{\[ScriptCapitalZ], t, \[GothicCapitalM], \[GothicCapitalM]}, 
        j\_{\[GothicCapitalG], t, \[GothicCapitalM]}}\(\[CircleDot]\_{Sex, 
            SexOfOrigin}\){\[GothicCapitalM], \[GothicCapitalF]}\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \({i\_{\[ScriptCapitalZ], t, \[GothicCapitalM], \[GothicCapitalF]}, 
        j\_{\[ScriptCapitalZ], t, \[GothicCapitalM], \[GothicCapitalM]}, 
        j\_{\[GothicCapitalG], t, \[GothicCapitalM]}}\ \(\[CircleDot]\_{Sex, 
            SexOfOrigin}\)\ {\[GothicCapitalM], \[GothicCapitalF]}\)], \
"Output",
  CellLabel->"Out[58]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{671, 689},
WindowMargins->{{Automatic, -5}, {Automatic, -2}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "SelectContexts"->{
    Cell[1786, 53, 1220, 26, 78, "DefinitionBox",
      CellTags->"SelectContexts"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"SelectContexts", 8282, 239}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 44, 0, 36, "SubsectionIcon"],
Cell[1786, 53, 1220, 26, 78, "DefinitionBox",
  CellTags->"SelectContexts"],
Cell[3009, 81, 347, 6, 36, "Text"],
Cell[3359, 89, 184, 4, 42, "MathCaption"],
Cell[3546, 95, 202, 4, 42, "Input"],
Cell[3751, 101, 131, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3907, 108, 280, 5, 28, "Input"],
Cell[4190, 115, 126, 3, 21, "Output"]
}, Open  ]],
Cell[4331, 121, 59, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4415, 125, 242, 4, 27, "Input"],
Cell[4660, 131, 126, 3, 21, "Output"]
}, Open  ]],
Cell[4801, 137, 78, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4904, 141, 329, 5, 28, "Input"],
Cell[5236, 148, 198, 4, 21, "Output"]
}, Open  ]],
Cell[5449, 155, 107, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5581, 162, 239, 4, 28, "Input"],
Cell[5823, 168, 126, 3, 21, "Output"]
}, Open  ]],
Cell[5964, 174, 57, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6046, 178, 286, 5, 28, "Input"],
Cell[6335, 185, 126, 3, 21, "Output"]
}, Open  ]],
Cell[6476, 191, 189, 4, 36, "Text"],
Cell[6668, 197, 35, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6728, 201, 339, 5, 28, "Input"],
Cell[7070, 208, 346, 6, 21, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

