(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     84810,       1590]*)
(*NotebookOutlinePosition[     88211,       1682]*)
(*  CellTagsIndexPosition[     88026,       1673]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Selection", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            "\[DoubleStruckCapitalW]", \(denotes\ the\ set\ of\ selected\ \
genes - in - \(\(context\)\(.\)\)\)},
          {\(\[GothicA]\_\[DoubleStruckCapitalU]\ or\ SelectionCoefficient[\
\[DoubleStruckCapitalU]]\), \(is\ the\ selection\ coefficient\)},
          {\(Selection[]\), \(is\ a\ rule\ which\ gives\ mean\ contributions\ \
and\ linkage\ disequilibria\ at\ the\ adult\ stage\ \[GothicCapitalA]\ in\ \
terms\ of\ those\ at\ the\ zygote\ stage, \ \[GothicCapitalZ] . \ 
                Selection\ between\ zygote\ and\ adult\ is\ described\ by\ \
the\ selection\ coefficients\ \[GothicA]\_\[DoubleStruckCapitalU], \ 
            and\ the\ set\ of\ selected\ genes\ \(\(\[DoubleStruckCapitalW]\)\
\(.\)\(\ \ \)\)\)},
          {\(Selection[{\[GothicCapitalZ], \[GothicCapitalA]}, 
              SelectionCoefficient, 
              FitnessSet]\), \(specifies\ the\ stages\ involved\ and\ the\ \
names\ of\ the\ coefficients\ \(\(explicitly\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"SelectionCoefficient", "Selection"}],

Cell[TextData[{
  "Suppose that survival between zygote and adult depends on locus ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ", present in two copies in a diploid.  For males, the set of selected loci \
could be written as:"
}], "MathCaption"],

Cell[BoxData[
    \(\[DoubleStruckCapitalW] = {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}; \)], \
"Input",
  CellLabel->"In[63]:="],

Cell["\<\
This is the cross-genome association after selection on \
males:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} /. Selection[]\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} + \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \
\((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \
\((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, \
i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell["This is the mean contribution after selection on males:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicM]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\) /. Selection[]\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[WeierstrassP]\_\(j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\) + \((\(-\[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\)\ \
\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \
\((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \
\((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, \
i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\)], "Output",
  CellLabel->"Out[67]="]
}, Open  ]],

Cell[TextData[{
  "By default, the selection coefficients are written as ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicA]\_\[DoubleStruckCapitalV]\)]],
  " (internally, SelectionCoefficient[\[DoubleStruckCapitalV]]), and the set \
of selected genes-in-context is taken to be \[DoubleStruckCapitalW].  \
Selection is taken to be between zygotes, \[GothicCapitalZ], and adults, \
\[GothicCapitalA].  This can be written out explicitly:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} /. 
      Selection[{\[GothicCapitalZ], \[GothicCapitalA]}, 
        SelectionCoefficient, \[DoubleStruckCapitalW]]\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} + \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \
\((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \
\((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, \
i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell[TextData[{
  "The function SelectionCoefficient[\[DoubleStruckCapitalV]] is \
automatically represented as ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicA]\_\[DoubleStruckCapitalV]\)]],
  ", for compactness.  Any function can be supplied:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} /. 
      Selection[{\[GothicCapitalZ], \[GothicCapitalA]}, 
        f, \[DoubleStruckCapitalW]]\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} + \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ f[{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}] + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ f[{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}] + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ f[{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
            i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}]\)], "Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell[TextData[{
  "There are two ways of generating non-standard subscripted notation ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[GothicB]\_\[DoubleStruckCapitalV], \ say\)\)]],
  "). One can use a function such as ",
  Cell[BoxData[
      \(TraditionalForm\`f\_# &\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} /. 
      Selection[{\[GothicCapitalZ], \[GothicCapitalA]}, 
        f\_# &, \[DoubleStruckCapitalW]]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} + \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ f\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ f\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ f\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\)], "Output",
  CellLabel->"Out[25]="]
}, Closed]],

Cell[TextData[{
  "However, this can lead to trouble: ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f\_\[DoubleStruckCapitalV]\)\(\ \)\)\)]],
  "is represented internally as ",
  Cell[BoxData[
      \(TraditionalForm\`Subscript[f, \[DoubleStruckCapitalV]]\)]],
  ", which may not be recognised properly."
}], "Text"],

Cell[TextData[{
  "A ",
  StyleBox["better",
    FontWeight->"Bold"],
  " method is to use:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(f\_x___\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(ff[x___]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], 
      ";"}], "\n", \(\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}} /. 
      Selection[{\[GothicCapitalZ], \[GothicCapitalA]}, 
        ff, \[DoubleStruckCapitalW]]\)}], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} + \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ f\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ f\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ f\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\)], "Output",
  CellLabel->"Out[29]="]
}, Closed]],

Cell[TextData[{
  "The subscripted ",
  Cell[BoxData[
      \(TraditionalForm\`f\_\[DoubleStruckCapitalV]\)]],
  " are represented internally as ff[\[DoubleStruckCapitalV]], a \
better-behaved construction.  It is ",
  StyleBox["essential",
    FontWeight->"Bold"],
  " to enter this notation using the",
  Cell[BoxData[
      FormBox[
        ButtonBox[\(\(\ \)\(Notation\ Palette\)\),
          ButtonData:>{
            FrontEnd`FileName[ {
              ParentDirectory[ 
                ParentDirectory[ ]], "AddOns", "ExtraPackages", "Utilities"}, 
              "NotationPalette.nb", CharacterEncoding -> "MacintoshRoman"], 
            None},
          ButtonStyle->"Hyperlink"], TraditionalForm]]],
  ", rather than just typing it in."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(\[DoubleStruckCapitalW]\_\(c\_1, \[Ellipsis]\)\ or\ FitnessSet[
                c\_1, \[Ellipsis]]\), \(denotes\ the\ set\ of\ selected\ \
genes - in - context\ relevant\ for\ components\ c\_1, \[Ellipsis]\)},
          {\(\[GothicA]\_\(c\_1, \[Ellipsis], \[DoubleStruckCapitalU]\)\ or\ \
SelectionCoefficient[
                c\_1, \[Ellipsis], \[DoubleStruckCapitalU]]\), \(is\ the\ \
selection\ coefficient\ relevant\ for\ components\ c\_1, \[Ellipsis]\)},
          {\(Selection[{c\_1, \[Ellipsis]}]\), 
            
            RowBox[{\(a\_\(c\_1, \[Ellipsis], \[DoubleStruckCapitalU]\)\), 
              " ", "and", " ", \(\[DoubleStruckCapitalW]\_\(c\_1,  ... \)\), 
              " ", "are", " ", 
              StyleBox["functions",
                FontSlant->"Italic"], " ", "of", " ", "the", " ", 
              "components", " ", "of", 
              " ", \(\[GothicCapitalZ] . \ \ Linkage\), " ", "disequilibria", 
              " ", "must", " ", "only", " ", "involve", " ", "genes", " ", 
              "with", " ", "the", " ", "same", " ", "values", " ", "of", " ", 
              "the", " ", "specified", " ", \(\(components\)\(.\)\)}]},
          {\(Selection[{\[GothicCapitalZ], \[GothicCapitalA]}, 
              SelectionCoefficient, 
              FitnessSet, {c\_1, \[Ellipsis]}]\), \(specifies\ the\ stages\ \
involved\ and\ the\ names\ of\ the\ coefficients\ \(\(explicitly\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"FitnessSet"],

Cell["\<\
In general, the set of selected loci and the selection coefficients \
depend on the context.  For example, both might differ between the sexes, or \
between demes.\
\>", "Text"],

Cell[TextData[{
  "Suppose that survival between zygote and adult depends on two loci ",
  Cell[BoxData[
      \(TraditionalForm\`{i, j}\)]],
  ", each with two copies.  The sets of relevant loci will depend on which \
sex is being selected.  "
}], "Text"],

Cell["The set of selected loci is defined using FitnessSet:", "MathCaption"],

Cell[BoxData[
    \(\(FitnessSet[sex_] := {i\_{\[GothicCapitalZ], sex, \[GothicCapitalM]}, 
          i\_{\[GothicCapitalZ], sex, \[GothicCapitalF]}, 
          j\_{\[GothicCapitalZ], sex, \[GothicCapitalM]}, 
          j\_{\[GothicCapitalZ], sex, \[GothicCapitalF]}};\)\)], "Input",
  CellLabel->"In[30]:="],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(FitnessSet\)\([\)\(c\_1, \[Ellipsis]\)\)\)]],
  "] is represented as ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalW]\_\(c\_1, \[Ellipsis]\)\)]],
  ", in the same way that ",
  Cell[BoxData[
      \(TraditionalForm\`SelectionCoefficient[
        c\_1, \[Ellipsis], \[DoubleStruckCapitalV]]\)]],
  " is represented as ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicA]\_\(c\_1, \[Ellipsis], \
\[DoubleStruckCapitalV]\)\)]],
  " (see above)."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[DoubleStruckCapitalW]\_\[GothicCapitalM]\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \({i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
      i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
      j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
      j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}\)], \
"Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell["\<\
This is the cross-genome association after selection on \
males:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} /. Selection[{Sex}]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} + \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\) + \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\) + \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\) + \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\) + \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\) + \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\)], "Output",
  CellLabel->"Out[31]="]
}, Closed]],

Cell[TextData[{
  "By default, selection coefficients are represented by ",
  Cell[BoxData[
      \(TraditionalForm\`SelectionCoefficient[
          c\_1, \[Ellipsis], \[DoubleStruckCapitalV]]\ \ or\ \
\[GothicA]\_\(c\_1, \[Ellipsis], \[DoubleStruckCapitalV]\)\)]],
  ", and the fitness set by ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalW]\_\(c\_1, \[Ellipsis]\)\)]],
  ".  This can be written out explicitly:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} /. 
      Selection[{\[GothicCapitalZ], \[GothicCapitalA]}, SelectionCoefficient, 
        FitnessSet, {Sex}]\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} + \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\) + \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\) + \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\) + \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\) + \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\) + \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\) + \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[GothicA]\_\(\
\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\)], "Output",
  CellLabel->"Out[33]="]
}, Closed]],

Cell["Any stage or function can be supplied:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[CapitalOmega][
        sex_] := {i\_{\[GothicCapitalZ], sex, \[GothicCapitalM]}, 
        i\_{\[GothicCapitalZ], sex, \[GothicCapitalF]}, 
        j\_{\[GothicCapitalZ], sex, \[GothicCapitalM]}, 
        j\_{\[GothicCapitalZ], sex, \[GothicCapitalF]}}; \), "\n", 
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} /. 
      Selection[{\[GothicCapitalZ], \[GothicCapitalA]}, 
        b, \[CapitalOmega], {Sex}]\)}], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}} + 
      b[\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}]\ \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\) + 
      b[\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}]\ \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\) + 
      b[\[GothicCapitalM], {j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}]\ \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\) + 
      b[\[GothicCapitalM], {j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}]\ \((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\) + 
      b[\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, 
            i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}]\ \
\((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\) + 
      b[\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, 
            j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}]\ \
\((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\) + 
      b[\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, 
            j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}]\ \
\((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\) + 
      b[\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, 
            j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}]\ \
\((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\) + 
      b[\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, 
            j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}]\ \
\((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\) + 
      b[\[GothicCapitalM], {j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, 
            j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}]\ \
\((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, k\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\) + 
      b[\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, 
            i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
            j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}]\ \
\((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\) + 
      b[\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, 
            i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
            j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}]\ \
\((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\) + 
      b[\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, 
            j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
            j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}]\ \
\((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\) + 
      b[\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, 
            j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
            
            j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}]\ \
\((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\) + 
      b[\[GothicCapitalM], {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, 
            i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
            j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
            j\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}]\ \
\((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, k\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, k\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\)], "Output",
  CellLabel->"Out[35]="]
}, Closed]],

Cell["Non-standard subscripted notation can be generated as above.", "Text"],

Cell[TextData[{
  "There are two kinds of component (in this example, Sex, and SexOfOrigin).  \
Here, selection acts separately on individuals of different sex, and ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(\[GothicCapitalM], \
\[DoubleStruckCapitalV]\)\)]],
  "specifies the selection on the set of loci \[DoubleStruckCapitalV] in \
males.  It only makes sense to apply selection to associations among sets \
which are all in one male individual, or all in  one female individual.  "
}], "Text"],

Cell["A warning is generated if this requirement is violated:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} /. Selection[{Sex}]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(Selection::"mix" \(\(:\)\(\ \)\) 
      "Mixed contexts in \!\(\[GothicCapitalD]\_\!\({j\_\({\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}\), k\_\({\[GothicCapitalA], \
\[GothicCapitalM], \
\[GothicCapitalF]}\)}\)\)/.Selection[\!\({\[GothicCapitalZ], \
\[GothicCapitalA]}\),\!\(SelectionCoefficient\),\!\(FitnessSet\),\!\({Sex}\)]:\
 the relevant components \!\({Sex}\) must be the same for all genes."\)], \
"Message",
  CellLabel->"From In[36]:="],

Cell[BoxData[
    \(\[GothicCapitalD]\_{j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}, k\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}}\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Selection on multiple alleles", "SubsubsectionIcon",
  CellTags->"Multiple alleles"],

Cell[TextData[{
  "In the examples above, there can be any number of alleles at each locus: \
the extra degrees of freedom are represented by higher-order associations \
such as ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalD]\_{\[DoubleStruckI], \
\[DoubleStruckI]}\)]],
  ".  Only when Biallelic[] is applied are these reduced on the assumption \
that just two alleles segregate. "
}], "Text"],

Cell["\<\
In order to apply selection with multiple alleles, repeated \
genes-in-context must be included in the set \[DoubleStruckCapitalW].  \
\>", \
"Text"],

Cell["\<\
For example, suppose that three alleles segregate at locus i, and \
influence fitness:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(\[DoubleStruckCapitalW] = {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, 
          i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
          i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
          i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}};\)\)], "Input",
  CellLabel->"In[16]:=  (8:11:12 on 3/18/01)"],

Cell["\<\
Selection coefficients are now defined for every subset of \
\[DoubleStruckCapitalW]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Subsets[\[DoubleStruckCapitalW]]\)], "Input",
  CellLabel->"In[17]:=  (8:11:14 on 3/18/01)"],

Cell[BoxData[
    \({{}, {i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}, {i\
\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}, {i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}, {i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}, {i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}, {i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}, {i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}, {i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}, {i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}, {i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}, {i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}, {i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}, {i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}, {i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}, {i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}}\)], \
"Output",
  CellLabel->"Out[17]=  (8:11:14 on 3/18/01)"]
}, Open  ]],

Cell["\<\
For example, this is the within genome association with a neutral \
locus j after selection on males:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}} /. Selection[]\)], "Input",
  CellLabel->"In[12]:=  (7:49:10 on 3/18/01)"],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} + 
      2\ \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + 
      2\ \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \
\((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, \
i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + 
      3\ \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, \
i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, \
i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, \
i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, \
i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, \
i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, \
i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, \
i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, \
i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\)], "Output",
  CellLabel->"Out[12]=  (7:49:10 on 3/18/01)"]
}, Closed]],

Cell[TextData[{
  "This involves selection coeffiicents such as ",
  Cell[BoxData[
      \(\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)]],
  ", which represents selection on the variance of effects of the paternal \
copy of locus i. If one assumes that cis-trans effects are equivalent, then \
most of these coefficients reduce: that is most easily done by writing \
fitness as a function of genotype, as above, and then using \
MakeSelectionCoefficient[]."
}], "Text"],

Cell[TextData[{
  "Suppose that there is quadratic stabilising selection of strength ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  "  on an additive trait, ",
  Cell[BoxData[
      \(TraditionalForm\`Z, \ with\ optimum\ Z\_opt\)]],
  ".  The effect of locus ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  "  on the trait is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\_i\)]],
  ":"
}], "MathCaption"],

Cell[BoxData[{
    \(\(Z\_sex_ := \[Sum]\+\(i \[Element] Union[\[Gamma][\
\[DoubleStruckCapitalW]\_sex]]\)\(\[Alpha]\_i\) \
\((X\_\(i\_{\[GothicCapitalZ], sex, \[GothicCapitalM]}\) + 
                X\_\(i\_{\[GothicCapitalZ], sex, \[GothicCapitalF]}\) - 
                1)\);\)\), "\[IndentingNewLine]", 
    \(W\_sex_ := 1 - \(s\/2\) \((Z\_sex - Zopt)\)\^2\)}], "Input",
  CellLabel->"In[18]:=  (8:11:46 on 3/18/01)"],

Cell[TextData[{
  "The trait value, ",
  Cell[BoxData[
      \(TraditionalForm\`Z\)]],
  ", is written as a sum over the set of selected genes, \[Gamma][",
  Cell[BoxData[
      \(\[DoubleStruckCapitalW]\_\[GothicCapitalM]\)]],
  "].  (\[Gamma][",
  Cell[BoxData[
      \(\[DoubleStruckCapitalW]\_\[GothicCapitalM]\)]],
  "] denotes the set of ",
  StyleBox["genes",
    FontSlant->"Italic"],
  "; ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalW]\_\[GothicCapitalM]\)]],
  "is the set of selected ",
  StyleBox["genes-in-context",
    FontSlant->"Italic"],
  ")"
}], "Text"],

Cell[TextData[{
  "Now, ",
  Cell[BoxData[
      \(TraditionalForm\`MakeSelectionCoefficient[\[DoubleStruckCapitalU], \
\[DoubleStruckCapitalW]\_sex]\ \ generates\ the\ appropriate\ selection\ \
coefficient . \ \ For\ example, \ 
      directional\ selection\ on\ locus\ i\ \(\(is\)\(:\)\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeSelectionCoefficient[{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}, W\_\[GothicCapitalM]]\)], "Input",
  CellLabel->"In[21]:=  (8:12:12 on 3/18/01)"],

Cell[BoxData[
    \(s\ Zopt\ \[Alpha]\_i + s\ \[Alpha]\_i\%2 - 
      s\ \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\)\ \[Alpha]\_i\%2 - 
      s\ \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\)\ \[Alpha]\_i\%2\)], "Output",
  CellLabel->"Out[21]=  (8:12:12 on 3/18/01)"]
}, Open  ]],

Cell["\<\
The six pairwise coefficients all have the same value, barring a \
factor of two:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ss = Subsets[\[DoubleStruckCapitalW], 2]\)], "Input",
  CellLabel->"In[24]:=  (8:12:44 on 3/18/01)"],

Cell[BoxData[
    \({{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}, {i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}, {i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}, {i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}}, {i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}, {i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
        i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}}\)], \
"Output",
  CellLabel->"Out[24]=  (8:12:45 on 3/18/01)"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MakeSelectionCoefficient[#, W\_\[GothicCapitalM]] &\) /@ 
      ss\)], "Input",
  CellLabel->"In[25]:=  (8:12:46 on 3/18/01)"],

Cell[BoxData[
    \({\(-s\)\ \[Alpha]\_i\%2, \(-\(1\/2\)\)\ s\ \[Alpha]\_i\%2, \(-s\)\ \
\[Alpha]\_i\%2, \(-s\)\ \[Alpha]\_i\%2, \(-\(1\/2\)\)\ s\ \[Alpha]\_i\%2, \
\(-s\)\ \[Alpha]\_i\%2}\)], "Output",
  CellLabel->"Out[25]=  (8:12:46 on 3/18/01)"]
}, Open  ]],

Cell["\<\
The expression for linkage disequilibrium now simplifies \
considerably:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}} /. Selection[]\) /. \[GothicA]\_\[DoubleStruckCapitalU]_ :> 
          MakeSelectionCoefficient[\[DoubleStruckCapitalU], 
            W\_\[GothicCapitalM]] // Simplify\)], "Input",
  CellLabel->"In[30]:=  (8:15:12 on 3/18/01)"],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} + 
      1\/2\ s\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ \[Alpha]\_i\%2 \
+ 3\ s\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[Alpha]\_i\%2 \
+ s\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ \[Alpha]\_i\%2 \
+ 1\/2\ s\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[Alpha]\_i\%2 \
+ 2\ s\ \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ \[Alpha]\_i\ \
\((Zopt - \((\(-1\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}\))\)\ \[Alpha]\_i)\) \
+ 2\ s\ \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \[Alpha]\_i\ \
\((Zopt - \((\(-1\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}\))\)\ \[Alpha]\_i)\)\
\)], "Output",
  CellLabel->"Out[30]=  (8:15:12 on 3/18/01)"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "SelectionCoefficient"->{
    Cell[1777, 53, 1126, 19, 140, "DefinitionBox",
      CellTags->{"SelectionCoefficient", "Selection"}]},
  "Selection"->{
    Cell[1777, 53, 1126, 19, 140, "DefinitionBox",
      CellTags->{"SelectionCoefficient", "Selection"}]},
  "FitnessSet"->{
    Cell[19666, 422, 1552, 26, 118, "DefinitionBox",
      CellTags->"FitnessSet"]},
  "Multiple alleles"->{
    Cell[62437, 1147, 90, 1, 24, "SubsubsectionIcon",
      CellTags->"Multiple alleles"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"SelectionCoefficient", 87549, 1657},
  {"Selection", 87674, 1660},
  {"FitnessSet", 87800, 1663},
  {"Multiple alleles", 87909, 1666}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 35, 0, 36, "SubsectionIcon"],
Cell[1777, 53, 1126, 19, 140, "DefinitionBox",
  CellTags->{"SelectionCoefficient", "Selection"}],
Cell[2906, 74, 254, 6, 28, "MathCaption"],
Cell[3163, 82, 223, 5, 27, "Input"],
Cell[3389, 89, 95, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3509, 96, 220, 4, 30, "Input"],
Cell[3732, 102, 2016, 30, 76, "Output"]
}, Open  ]],
Cell[5763, 135, 78, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5866, 139, 151, 3, 30, "Input"],
Cell[6020, 144, 1656, 25, 52, "Output"]
}, Open  ]],
Cell[7691, 172, 459, 8, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[8175, 184, 321, 6, 30, "Input"],
Cell[8499, 192, 2016, 30, 76, "Output"]
}, Open  ]],
Cell[10530, 225, 269, 6, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[10824, 235, 302, 6, 30, "Input"],
Cell[11129, 243, 2002, 31, 76, "Output"]
}, Open  ]],
Cell[13146, 277, 300, 8, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[13471, 289, 307, 6, 30, "Input"],
Cell[13781, 297, 1989, 30, 70, "Output"]
}, Closed]],
Cell[15785, 330, 318, 8, 18, "Text"],
Cell[16106, 340, 111, 5, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[16242, 349, 658, 16, 48, "Input"],
Cell[16903, 367, 1989, 30, 70, "Output"]
}, Closed]],
Cell[18907, 400, 756, 20, 20, "Text"],
Cell[19666, 422, 1552, 26, 118, "DefinitionBox",
  CellTags->"FitnessSet"],
Cell[21221, 450, 187, 4, 22, "Text"],
Cell[21411, 456, 256, 6, 22, "Text"],
Cell[21670, 464, 76, 0, 28, "MathCaption"],
Cell[21749, 466, 308, 5, 27, "Input"],
Cell[22060, 473, 562, 16, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[22647, 493, 100, 2, 26, "Input"],
Cell[22750, 497, 330, 6, 22, "Output"]
}, Open  ]],
Cell[23095, 506, 95, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[23215, 513, 225, 4, 30, "Input"],
Cell[23443, 519, 11915, 175, 70, "Output"]
}, Closed]],
Cell[35373, 697, 451, 10, 19, "MathCaption"],

Cell[CellGroupData[{
Cell[35849, 711, 315, 6, 30, "Input"],
Cell[36167, 719, 11915, 175, 70, "Output"]
}, Closed]],
Cell[48097, 897, 61, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[48183, 901, 575, 11, 48, "Input"],
Cell[48761, 914, 12017, 187, 338, "Output"]
}, Closed]],
Cell[60793, 1104, 76, 0, 18, "Text"],
Cell[60872, 1106, 503, 9, 36, "Text"],
Cell[61378, 1117, 78, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[61481, 1121, 225, 4, 30, "Input"],
Cell[61709, 1127, 482, 9, 42, "Message"],
Cell[62194, 1138, 206, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62437, 1147, 90, 1, 24, "SubsubsectionIcon",
  CellTags->"Multiple alleles"],
Cell[62530, 1150, 408, 9, 36, "Text"],
Cell[62941, 1161, 159, 4, 22, "Text"],
Cell[63103, 1167, 117, 3, 28, "MathCaption"],
Cell[63223, 1172, 396, 7, 39, "Input"],
Cell[63622, 1181, 116, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[63763, 1188, 112, 2, 38, "Input"],
Cell[63878, 1192, 2282, 34, 70, "Output"]
}, Open  ]],
Cell[66175, 1229, 132, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[66332, 1236, 242, 4, 42, "Input"],
Cell[66577, 1242, 9072, 137, 250, "Output"]
}, Closed]],
Cell[75664, 1382, 567, 11, 37, "Text"],
Cell[76234, 1395, 422, 14, 28, "MathCaption"],
Cell[76659, 1411, 421, 7, 87, "Input"],
Cell[77083, 1420, 593, 20, 24, "Text"],
Cell[77679, 1442, 312, 7, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[78016, 1453, 192, 3, 39, "Input"],
Cell[78211, 1458, 345, 6, 39, "Output"]
}, Open  ]],
Cell[78571, 1467, 112, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[78708, 1474, 120, 2, 38, "Input"],
Cell[78831, 1478, 903, 14, 34, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[79771, 1497, 148, 3, 38, "Input"],
Cell[79922, 1502, 249, 4, 48, "Output"]
}, Open  ]],
Cell[80186, 1509, 103, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[80314, 1516, 397, 6, 42, "Input"],
Cell[80714, 1524, 4056, 61, 179, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

