(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     36545,        864]*)
(*NotebookOutlinePosition[     38363,        918]*)
(*  CellTagsIndexPosition[     38103,        907]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Sex linkage", "SubsectionIcon"],

Cell[TextData[{
  "The rules defined for Mendelian inheritance extend almost unchanged to \
other kinds of inheritance. The only differences are that i) ",
  ButtonBox["reference points",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"reference points"],
  " may need to be set differently for loci that are inherited in different \
ways, and ii) recombination rates may be ",
  ButtonBox["asymmetric",
    ButtonData:>{"Non-Mendelian inheritance", "NonMendelian"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"asymmetric"],
  ".  For example, for an X-linked locus in a male, i, ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicR]\_\(\[GothicCapitalM], {i}, {}\)\)]],
  "=1 and ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicR]\_\(\[GothicCapitalM], {}, {i}\) = 0\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell["Setting up\[Ellipsis]", "SubsubsectionIcon",
  CellTags->"Setting up"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(<< Multilocus`Multilocus`; \)], "Input",
  CellLabel->"In[494]:=  (16:11:37 on 3/11/01)"],

Cell["The simplest life cycle is defined using:", "MathCaption"],

Cell[BoxData[{
    \(DefineContext[\[GothicCapitalG], {\ Sex}]; \), "\n", 
    \(DefineContext[\[GothicCapitalZ], {Sex, SexOfOrigin}]; \), "\n", 
    \(DefineContext[\[GothicCapitalA], {Sex, SexOfOrigin}]; \), "\n", 
    \(DefineContext[\(\[GothicCapitalG]\^*\), {\ Sex}]; \)}], "Input",
  CellLabel->"In[495]:=  (16:11:43 on 3/11/01)"],

Cell["\<\
Assume no selection by specifying that no genes affect \
fitness:\
\>", "MathCaption"],

Cell[BoxData[
    \(\[DoubleStruckCapitalW] = {}; \)], "Input",
  CellLabel->"In[499]:=  (16:11:44 on 3/11/01)"],

Cell[TextData[{
  "One could just drop the stage \[GothicCapitalA], and go directly from \
\[GothicCapitalZ] to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[GothicCapitalG]\^*\) . \ \ However, \ 
      the\ default\ rules\ assume\ that\ there\ is\ selection, \ \(\(and\)\(\ \
\)\(so\)\(\ \)\(it\)\(\ \)\(is\)\(\ \)\(easier\)\(\ \)\(just\)\(\ \)\(to\)\(\ \
\)\)\)]],
  "keep the extra stage."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simplifying recombination", "SubsubsectionIcon",
  CellTags->"Simplifying recombination"],

Cell[TextData[{
  "In general, the association between loci i and j in the new gamete pool, \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\[GothicCapitalG]\^*\), \ is\)]],
  " written as a sum over all possible recombination events:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, j\
\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} /. 
      Recombination[{Sex}]\)], "Input",
  CellLabel->"In[122]:=  (9:35:35 on 3/11/01)"],

Cell[BoxData[
    \(\[GothicR]\_\(\[GothicCapitalM], {i, j}, {}\)\ \((\[GothicCapitalD]\_{i\
\_{\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\(\[GothicCapitalM], {j}, {i}\)\ \((\
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\(\[GothicCapitalM], {i}, {j}\)\ \((\
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\) + \[GothicR]\_\(\[GothicCapitalM], {}, {i, j}\)\ \
\((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\)\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\)\)], "Output",
  CellLabel->"Out[122]=  (9:35:35 on 3/11/01)"]
}, Closed]],

Cell[TextData[{
  "Note: ",
  StyleBox["The sex must be specified, since recombination rates are \
necessarily sex-dependent for sex-linked loci.  Sex is given in the form ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[GothicR]\_\(\[Ellipsis], \[GothicCapitalM], A, B\)\
\)]]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "If locus i is X-linked and in a male, then it cannot be inherited from the \
father; ",
  Cell[BoxData[
      \(\[GothicR]\_\(\[GothicCapitalM], {j}, {i}\)\)]],
  "=",
  Cell[BoxData[
      \(\[GothicR]\_\(\[GothicCapitalM], {}, {i, j}\)\)]],
  "=0:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, \
j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} /. Recombination[{Sex}]\) /. 
      NonMendelian[XLinkedLoci -> {i}]\)], "Input",
  CellLabel->"In[124]:=  (9:36:18 on 3/11/01)"],

Cell[BoxData[
    \(\[GothicR]\_\(\[GothicCapitalM], {j}, {}\)\ \((\[GothicCapitalD]\_{i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{j\_{\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \
\((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) \
+ \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\(\[GothicCapitalM], {}, {j}\)\ \((\
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\)\)], "Output",
  CellLabel->"Out[124]=  (9:36:18 on 3/11/01)"]
}, Closed]],

Cell[TextData[{
  "This further simplifies if the autosomal locus j is inherited in a \
Mendelian way; ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicR]\_\({j}, {}\) = \(\[GothicR]\_\({}, {j}\) \
= \(\(1\/2\)\(:\)\)\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} /. 
            Recombination[{Sex}]\) /. NonMendelian[XLinkedLoci -> {i}]\) /. 
        SymmetricRecombination[] // Simplify\)], "Input",
  CellLabel->"In[125]:=  (9:36:33 on 3/11/01)"],

Cell[BoxData[
    \(1\/2\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\) - \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \((\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\) - \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\) + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) + \((\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\) - \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalM]}\) - \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalM], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\))\)\)], "Output",
  CellLabel->"Out[125]=  (9:36:33 on 3/11/01)"]
}, Closed]],

Cell[TextData[{
  "Note: ",
  StyleBox["SymmetricRecombination[] ",
    FontWeight->"Plain"],
  "must",
  StyleBox[" be applied ",
    FontWeight->"Plain"],
  "after",
  StyleBox[" NonMendelian[\[Ellipsis]]",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The complete life cycle", "SubsubsectionIcon",
  CellTags->"Complete life cycle"],

Cell[TextData[{
  "This expression still involves the (arbitrary) changes in reference points \
between stages.  As above, we can assume that the reference points in the \
gamete pools equal the local means (",
  Cell[BoxData[
      \(ReferencePointZero[{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalG]}]\)]],
  "); that the reference points in the diploid stages are inherited from the \
initial gamete pool (ReferencePointSame[\[GothicCapitalG],{\[GothicCapitalA],\
\[GothicCapitalZ]}]); and that gametes unite at random \
(UnionOfGametes[]\[Vee]RandomUnion[\[GothicCapitalG]])."
}], "Text"],

Cell["\<\
This is the set of rules that describes the complete life cycle; \
loci i and j are X-linked, and locus k is Y-linked:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(rules = \((Recombination[{Sex}]\[Vee]NonMendelian[
              XLinkedLoci -> {i, j}, 
              YLinkedLoci -> \
{k}]\[Vee]SymmetricRecombination[]\[Vee]Selection[]\[Vee]UnionOfGametes[]\
\[Vee]RandomUnion[\[GothicCapitalG]]\[Vee]ReferencePointSame[\[GothicCapitalG]\
, {\[GothicCapitalA], \[GothicCapitalZ]}]\[Vee]ReferencePointZero[{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalG]}])\);\)\)], "Input",
  CellLabel->"In[500]:=  (16:11:47 on 3/11/01)"],

Cell[TextData[{
  "Note: ",
  StyleBox["NonMendelian[] ",
    FontWeight->"Plain"],
  "must",
  StyleBox[" be applied before SymmetricRecombination[], and UnionOfGametes[] \
before RandomUnion[\[GothicCapitalG]]",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell["\<\
This shows the association between two X-linked loci after male and \
female meiosis:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}}, \
\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}, j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}}} //. 
          rules\) /. {\[GothicR]\_\(\[GothicCapitalF], {}, {i, j}\) -> \(1 - \
r\_\(\[GothicCapitalF], i, j\)\)\/2, \[GothicR]\_\(\[GothicCapitalF], {i}, \
{j}\) -> r\_\(\[GothicCapitalF], i, j\)\/2} // Simplify\)], "Input",
  CellLabel->"In[340]:=  (15:28:05 on 3/11/01)"],

Cell[BoxData[
    \({\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}, \((1 - 
              r\_\(\[GothicCapitalF], i, j\))\) \(\[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\)\/2\  + \
\(1\/4\) \((\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\) - \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \((\[GothicM]\_\
\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) - \[GothicM]\_\(j\_{\
\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \((1 - 
              2\ r\_\(\[GothicCapitalF], i, j\))\)}\)], "Output",
  CellLabel->"Out[340]=  (15:28:05 on 3/11/01)"]
}, Open  ]],

Cell[TextData[{
  "The association between two X-linked genes remainsd unaltered through male \
meiosis, but decreases by ",
  Cell[BoxData[
      \(TraditionalForm\`\((1 - 
            r\_\(\[GothicCapitalF], i, j\))\)\ \ in\ female\ \ meiosis; \ 
      there\ is\ also\ an\ extra\ term\ due\ to\ differences\ in\ mean\ \
between\ the\ sexes\ in\ the\ latter\ \(\(case\)\(.\)\(\ \)\)\)]],
  " "
}], "Text"],

Cell[TextData[{
  ButtonBox["Recall",
    ButtonData:>{"Recombination", "Factors of two"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Recall"],
  " that ",
  Cell[BoxData[
      \(\[GothicR]\_\(\[GothicCapitalF], {}, {i, j}\)\)]],
  "is the probability that both i and j come from the paternal genome, which \
has probability ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(1 - 
              r\_\(\[GothicCapitalF], i, j\)\)\/2\) \
\((r\_\(\[GothicCapitalF], i, j\)\ being\ the\ usual\ recombination\ rate\ in\
\ female\ mieosis)\) . \ \ Remember\ to\ include\ the\ factor\ of\ \(\(1\/2\)\
\(.\)\)\)]]
}], "Text"],

Cell[TextData[{
  "In contrast, the association between two autosomal loci l, m in female \
gametes is the average association across both sexes, deflated by ",
  Cell[BoxData[
      \(\((1 - r\_\(j, k\))\)\)]],
  ", plus a contribution from differences in mean between the sexes:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[GothicCapitalD]\_{l\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}, \
m\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}} //. 
          rules\) /. {\[GothicR]\_\(\[GothicCapitalF], {}, {l, m}\) -> \(1 - \
r\_\(\[GothicCapitalF], l, m\)\)\/2, \[GothicR]\_\(\[GothicCapitalF], {l}, \
{m}\) -> r\_\(\[GothicCapitalF], l, m\)\/2} // Simplify\)], "Input",
  CellLabel->"In[504]:=  (16:18:23 on 3/11/01)"],

Cell[BoxData[
    \(\((1 - 
            r\_\(\[GothicCapitalF], l, m\))\) \(\[GothicCapitalD]\_{l\_{\
\[GothicCapitalG], \[GothicCapitalF]}, m\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\  + \[GothicCapitalD]\_{l\_{\[GothicCapitalG], \
\[GothicCapitalM]}, m\_{\[GothicCapitalG], \[GothicCapitalM]}}\)\/2 + \
\(1\/4\) \((\[GothicM]\_\(l\_{\[GothicCapitalG], \[GothicCapitalF]}\) - \
\[GothicM]\_\(l\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \((\[GothicM]\_\
\(m\_{\[GothicCapitalG], \[GothicCapitalF]}\) - \[GothicM]\_\(m\_{\
\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \((1 - 
            2  r\_\(\[GothicCapitalF], l, m\))\)\)], "Output",
  CellLabel->"Out[342]=  (15:41:35 on 3/11/01)"]
}, Open  ]],

Cell["\<\
This shows the association between an X-linked locus, i, and an \
autosomal locus, l, after male and female meiosis:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, l\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}}, \
\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}, l\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}}} //. 
          rules\) /. {\[GothicR]\_\(sx_, {}, {i, l}\) -> \(1 - r\_\(sx, i, \
l\)\)\/2, \[GothicR]\_\(sx_, {i}, {l}\) -> r\_\(sx, i, l\)\/2} // 
      Simplify\)], "Input",
  CellLabel->"In[503]:=  (16:16:38 on 3/11/01)"],

Cell[BoxData[
    \({\ \ 1\/2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, l\_{\[GothicCapitalG], \[GothicCapitalF]}}, \ \((1 - 
              r\_\(\[GothicCapitalF], i, l\))\)\ \(\[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, l\_{\[GothicCapitalG], \
\[GothicCapitalF]}} + \ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, l\_{\[GothicCapitalG], \[GothicCapitalM]}}\)\/2\  + \
\(1\/4\) \((\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\) - \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \((\[GothicM]\_\
\(l\_{\[GothicCapitalG], \[GothicCapitalF]}\) - \[GothicM]\_\(l\_{\
\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \((1 - 
              2\ r\_\(\[GothicCapitalF], i, l\))\)}\)], "Output",
  CellLabel->"Out[423]=  (15:58:07 on 3/11/01)"]
}, Open  ]],

Cell[TextData[{
  "The association decreases by ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  "through male meiosis, and includes no contribution from changes in \
refrence point."
}], "Text"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  " SymmetricRecombination[] does not know that i is X-linked and l is \
autosomal, and so does not simplify ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicR]\_\(\[GothicCapitalF], {i}, {l}\)\ to\ \
\(\(1\/2\)\(.\)\)\)]]
}], "Text"],

Cell[TextData[{
  "The association between a Y-linked locus, k, and an autosomal locus, l, \
decreases by ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\ after\ male\ meiosis\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[GothicCapitalD]\_{k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, \
l\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} //. 
          rules\) /. {\[GothicR]\_\(sx_, {}, {k, l}\) -> \(1 - r\_\(sx, k, \
l\)\)\/2, \[GothicR]\_\(sx_, {k}, {l}\) -> r\_\(sx, k, l\)\/2} // 
      Simplify\)], "Input",
  CellLabel->"In[502]:=  (16:15:59 on 3/11/01)"],

Cell[BoxData[
    \(1\/2\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, \
l\_{\[GothicCapitalG], \[GothicCapitalM]}}\)], "Output",
  CellLabel->"Out[502]=  (16:15:59 on 3/11/01)"]
}, Open  ]],

Cell["\<\
This shows the means after male and female meiosis, for X-linked, \
Y-linked and autosomal loci (i, k, l):\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(\[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\), \(\[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\)},
                {\(\[GothicM]\_\(k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\), "\"\<n/a\>\""},
                {\(\[GothicM]\_\(l\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\), \(\[GothicM]\_\(l\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\)}
                }], ")"}], "//.", "rules"}], "//", "Simplify"}], "//", 
      "MatrixForm"}]], "Input",
  CellLabel->"In[501]:=  (16:12:01 on 3/11/01)"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\), \
\(1\/2\ \((\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\) + \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\)},
            {\(\[GothicM]\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\)\), "\
\<\"n/a\"\>"},
            {\(1\/2\ \((\[GothicM]\_\(l\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \[GothicM]\_\(l\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\), \(1\/2\ \((\[GothicM]\_\(l\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \[GothicM]\_\(l\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[501]//MatrixForm=  (16:12:02 on 3/11/01)"]
}, Open  ]],

Cell["\<\
For X-linked or autosomal loci in females, the mean in the new \
gamete pool is equal to the average of the initial male & female gamete \
pools.  In males, the mean for X-linked loci equals that in maternal gametes, \
whilst for Y-linked loci, the mean is that in paternal gametes. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reference points at the mean of the two sexes", "SubsubsectionIcon",
  CellTags->"ReferencePointMean"],

Cell[TextData[{
  "Associations among autosomal loci could be defined with respect to \
reference points at the mean of the two sexes of gamete, and at the mean of \
the two sexes-of-origin.  (Note that reference points could still differ \
between the two diploid sexes).  It is then natural to define the reference \
point for X-linked loci in male gametes equal to the mean in females, and \
conversely for Y-linked loci.  This can be done by specifying the set of \
XLinkedLoci and YLinkedLoci in ",
  ButtonBox["ReferencePointMean[]",
    ButtonData:>{"Reference points", "XLinkedLoci"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"reference points"],
  "."
}], "Text"],

Cell["\<\
This is the set of rules that describes the complete life \
cycle:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(rules = \((Recombination[{Sex}]\[Vee]NonMendelian[
              XLinkedLoci -> {i, j}, 
              YLinkedLoci -> \
{k}]\[Vee]SymmetricRecombination[]\[Vee]Selection[]\[Vee]UnionOfGametes[]\
\[Vee]RandomUnion[\[GothicCapitalG]]\[Vee]ReferencePointMean[{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalA], \[GothicCapitalZ], \
\[GothicCapitalG]}, XLinkedLoci -> {i, j}, 
              YLinkedLoci -> {k}])\);\)\)], "Input",
  CellLabel->"In[505]:=  (16:19:17 on 3/11/01)"],

Cell["\<\
This shows the association between an X-linked locus, i, and an \
autosomal locus, l, after male and female meiosis:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, l\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}}, \
\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}, l\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}}} //. 
          rules\) /. {\[GothicR]\_\(sx_, {}, {i, l}\) -> \(1 - r\_\(sx, i, \
l\)\)\/2, \[GothicR]\_\(sx_, {i}, {l}\) -> r\_\(sx, i, l\)\/2} // 
      Simplify\)], "Input",
  CellLabel->"In[508]:=  (16:20:23 on 3/11/01)"],

Cell[BoxData[
    \({1\/2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, l\
\_{\[GothicCapitalG], \[GothicCapitalF]}} - \(1\/12\) \((\[GothicM]\_\(i\_{\
\[GothicCapitalG], \[GothicCapitalF]}\) - \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \((\[GothicM]\_\
\(l\_{\[GothicCapitalG], \[GothicCapitalF]}\) - \[GothicM]\_\(l\_{\
\[GothicCapitalG], \[GothicCapitalM]}\))\), \ \((1 - 
              r\_\(\[GothicCapitalF], i, l\))\) \(\(\ \
\)\(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, l\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\  + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, l\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\)\)\/2 + \(1\/4\) \((\[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) - \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\ \((\[GothicM]\_\(l\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) - \[GothicM]\_\(l\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\ r\_\(\[GothicCapitalF], i, l\)}\)], "Output",
  CellLabel->"Out[508]=  (16:20:26 on 3/11/01)"]
}, Open  ]],

Cell[TextData[{
  "The association between two X-linked loci in",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(male\ gametes\ is\ half\ that\ in\ \
female\ gametes\ in\ the\ previous\ generation\)\(,\)\(\ \)\(but\)\(\ \
\)\)\)\)]],
  "has a more complicated form for female gametes:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}}, \
\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}, j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}}} //. 
          rules\) /. {\[GothicR]\_\(sx_, {}, {i, j}\) -> \(1 - r\_\(sx, i, \
j\)\)\/2, \[GothicR]\_\(sx_, {i}, {j}\) -> r\_\(sx, i, j\)\/2} // 
      Simplify\)], "Input",
  CellLabel->"In[510]:=  (16:28:13 on 3/11/01)"],

Cell[BoxData[
    \({\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}, \ \((1 - 
              r\_\(\[GothicCapitalF], i, j\))\) \(\(\[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\)\(\ \)\(+\)\(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\)\(\ \)\)\/2 - 
        2\/9\ \((\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\) - \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\ \((\[GothicM]\_\
\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) - \[GothicM]\_\(j\_{\
\[GothicCapitalG], \[GothicCapitalM]}\))\)\ r\_\(\[GothicCapitalF], i, \
j\)}\)], "Output",
  CellLabel->"Out[509]=  (16:26:20 on 3/11/01)"]
}, Open  ]],

Cell["\<\
The association between a Y-linked locus, k, and an autosomal \
locus, l, decreases by a factor of two:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, l\
\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} //. rules // 
      Simplify\)], "Input",
  CellLabel->"In[513]:=  (16:30:52 on 3/11/01)"],

Cell[BoxData[
    \(1\/2\ \[GothicCapitalD]\_{k\_{\[GothicCapitalG], \[GothicCapitalM]}, \
l\_{\[GothicCapitalG], \[GothicCapitalM]}}\)], "Output",
  CellLabel->"Out[513]=  (16:30:53 on 3/11/01)"]
}, Open  ]],

Cell["\<\
The means necessarily change in the same way, since they are not \
affected by reference points:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(\[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\), \(\[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\)},
                {\(\[GothicM]\_\(k\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\), "\"\<n/a\>\""},
                {\(\[GothicM]\_\(l\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\), \(\[GothicM]\_\(l\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\)}
                }], ")"}], "//.", "rules"}], "//", "Simplify"}], "//", 
      "MatrixForm"}]], "Input",
  CellLabel->"In[511]:=  (16:29:52 on 3/11/01)"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\), \
\(1\/2\ \((\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\) + \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\)},
            {\(\[GothicM]\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\)\), "\
\<\"n/a\"\>"},
            {\(1\/2\ \((\[GothicM]\_\(l\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \[GothicM]\_\(l\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\), \(1\/2\ \((\[GothicM]\_\(l\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \[GothicM]\_\(l\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[511]//MatrixForm=  (16:29:52 on 3/11/01)"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Z- and W-linkage", "SubsubsectionIcon",
  CellTags->{"ZLinkedLoci", "WLinkedLoci"}],

Cell["Z- and W-linkage are implemented in the same way.  ", "Text"],

Cell["\<\
Here are rules assuming the reference point is at the mean of each \
sex:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(rules = \((Recombination[{Sex}]\[Vee]NonMendelian[
              ZLinkedLoci -> {i, j}, 
              WLinkedLoci -> \
{k}]\[Vee]SymmetricRecombination[]\[Vee]Selection[]\[Vee]UnionOfGametes[]\
\[Vee]RandomUnion[\[GothicCapitalG]]\[Vee]ReferencePointSame[\[GothicCapitalG]\
, {\[GothicCapitalA], \[GothicCapitalZ]}]\[Vee]ReferencePointZero[{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalG]}])\);\)\)], "Input",
  CellLabel->"In[514]:=  (16:33:14 on 3/11/01)"],

Cell["\<\
This shows the association between a Z-linked locus, i, and an \
autosomal locus, l, after male and female meiosis:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}, l\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}}, \
\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}, l\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}}} //. 
          rules\) /. {\[GothicR]\_\(sx_, {}, {i, l}\) -> \(1 - r\_\(sx, i, \
l\)\)\/2, \[GothicR]\_\(sx_, {i}, {l}\) -> r\_\(sx, i, l\)\/2} // 
      Simplify\)], "Input",
  CellLabel->"In[515]:=  (16:33:23 on 3/11/01)"],

Cell[BoxData[
    \(\(\(\(\({\((1 - 
                  r\_\(\[GothicCapitalM], i, l\))\) \
\(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, l\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\  + \ \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, l\_{\[GothicCapitalG], \
\[GothicCapitalM]}}\)\/2 + \(1\/4\) \((\[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) - \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\ \((\[GothicM]\_\(l\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) - \[GothicM]\_\(l\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\ \((1 - 
                  2\ r\_\(\[GothicCapitalM], i, l\))\)\)\()\)\), 
      1\/2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, \
l\_{\[GothicCapitalG], \[GothicCapitalM]}}\)\(}\)\)\)], "Output",
  CellLabel->"Out[515]=  (16:33:24 on 3/11/01)"]
}, Open  ]],

Cell["\<\
The means necessarily change in the same way, since they are not \
affected by reference points:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(\[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\), \(\[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\)},
                {
                  "\"\<n/a\>\"", \
\(\[GothicM]\_\(k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\)},
                {\(\[GothicM]\_\(l\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\), \(\[GothicM]\_\(l\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\)\)}
                }], ")"}], "//.", "rules"}], "//", "Simplify"}], "//", 
      "MatrixForm"}]], "Input",
  CellLabel->"In[517]:=  (16:33:48 on 3/11/01)"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/2\ \((\[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\), \(\[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\)\)},
            {"\<\"n/a\"\>", \(\[GothicM]\_\(k\_{\[GothicCapitalG], \
\[GothicCapitalF]}\)\)},
            {\(1\/2\ \((\[GothicM]\_\(l\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \[GothicM]\_\(l\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\), \(1\/2\ \((\[GothicM]\_\(l\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \[GothicM]\_\(l\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[517]//MatrixForm=  (16:33:48 on 3/11/01)"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Setting up"->{
    Cell[2658, 77, 76, 1, 24, "SubsubsectionIcon",
      CellTags->"Setting up"]},
  "Simplifying recombination"->{
    Cell[3961, 118, 95, 1, 24, "SubsubsectionIcon",
      CellTags->"Simplifying recombination"]},
  "Complete life cycle"->{
    Cell[15059, 333, 87, 1, 24, "SubsubsectionIcon",
      CellTags->"Complete life cycle"]},
  "ReferencePointMean"->{
    Cell[25481, 594, 108, 1, 24, "SubsubsectionIcon",
      CellTags->"ReferencePointMean"]},
  "ZLinkedLoci"->{
    Cell[32561, 764, 89, 1, 24, "SubsubsectionIcon",
      CellTags->{"ZLinkedLoci", "WLinkedLoci"}]},
  "WLinkedLoci"->{
    Cell[32561, 764, 89, 1, 24, "SubsubsectionIcon",
      CellTags->{"ZLinkedLoci", "WLinkedLoci"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Setting up", 37378, 885},
  {"Simplifying recombination", 37494, 888},
  {"Complete life cycle", 37620, 891},
  {"ReferencePointMean", 37740, 894},
  {"ZLinkedLoci", 37853, 897},
  {"WLinkedLoci", 37975, 900}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 37, 0, 36, "SubsectionIcon"],
Cell[1779, 53, 854, 20, 38, "Text"],

Cell[CellGroupData[{
Cell[2658, 77, 76, 1, 24, "SubsubsectionIcon",
  CellTags->"Setting up"],
Cell[2737, 80, 46, 0, 28, "MathCaption"],
Cell[2786, 82, 109, 2, 38, "Input"],
Cell[2898, 86, 64, 0, 28, "MathCaption"],
Cell[2965, 88, 336, 5, 86, "Input"],
Cell[3304, 95, 96, 3, 28, "MathCaption"],
Cell[3403, 100, 112, 2, 38, "Input"],
Cell[3518, 104, 406, 9, 22, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3961, 118, 95, 1, 24, "SubsubsectionIcon",
  CellTags->"Simplifying recombination"],
Cell[4059, 121, 254, 6, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4338, 131, 233, 4, 45, "Input"],
Cell[4574, 137, 4323, 62, 96, "Output"]
}, Closed]],
Cell[8912, 202, 334, 9, 20, "Text"],
Cell[9249, 213, 288, 9, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[9562, 226, 273, 4, 45, "Input"],
Cell[9838, 232, 2197, 32, 52, "Output"]
}, Closed]],
Cell[12050, 267, 245, 6, 24, "MathCaption"],

Cell[CellGroupData[{
Cell[12320, 277, 332, 5, 45, "Input"],
Cell[12655, 284, 2085, 30, 81, "Output"]
}, Closed]],
Cell[14755, 317, 267, 11, 20, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15059, 333, 87, 1, 24, "SubsubsectionIcon",
  CellTags->"Complete life cycle"],
Cell[15149, 336, 591, 11, 50, "Text"],
Cell[15743, 349, 149, 3, 28, "MathCaption"],
Cell[15895, 354, 479, 8, 54, "Input"],
Cell[16377, 364, 272, 9, 24, "Text"],
Cell[16652, 375, 116, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[16793, 382, 549, 8, 54, "Input"],
Cell[17345, 392, 806, 12, 54, "Output"]
}, Open  ]],
Cell[18166, 407, 407, 9, 36, "Text"],
Cell[18576, 418, 619, 16, 54, "Text"],
Cell[19198, 436, 300, 6, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[19523, 446, 422, 6, 54, "Input"],
Cell[19948, 454, 691, 11, 54, "Output"]
}, Open  ]],
Cell[20654, 468, 147, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[20826, 475, 496, 8, 54, "Input"],
Cell[21325, 485, 821, 12, 54, "Output"]
}, Open  ]],
Cell[22161, 500, 202, 6, 28, "Text"],
Cell[22366, 508, 298, 8, 28, "Text"],
Cell[22667, 518, 206, 6, 34, "MathCaption"],

Cell[CellGroupData[{
Cell[22898, 528, 369, 6, 54, "Input"],
Cell[23270, 536, 196, 3, 48, "Output"]
}, Open  ]],
Cell[23481, 542, 137, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[23643, 549, 672, 15, 86, "Input"],
Cell[24318, 566, 804, 15, 85, "Output"]
}, Open  ]],
Cell[25137, 584, 307, 5, 36, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25481, 594, 108, 1, 24, "SubsubsectionIcon",
  CellTags->"ReferencePointMean"],
Cell[25592, 597, 678, 13, 51, "Text"],
Cell[26273, 612, 97, 3, 28, "MathCaption"],
Cell[26373, 617, 492, 9, 70, "Input"],
Cell[26868, 628, 147, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[27040, 635, 496, 8, 54, "Input"],
Cell[27539, 645, 1067, 16, 88, "Output"]
}, Open  ]],
Cell[28621, 664, 310, 7, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[28956, 675, 496, 8, 54, "Input"],
Cell[29455, 685, 806, 12, 54, "Output"]
}, Open  ]],
Cell[30276, 700, 134, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[30435, 707, 232, 4, 45, "Input"],
Cell[30670, 713, 196, 3, 48, "Output"]
}, Open  ]],
Cell[30881, 719, 127, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[31033, 726, 672, 15, 86, "Input"],
Cell[31708, 743, 804, 15, 85, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[32561, 764, 89, 1, 24, "SubsubsectionIcon",
  CellTags->{"ZLinkedLoci", "WLinkedLoci"}],
Cell[32653, 767, 67, 0, 22, "Text"],
Cell[32723, 769, 104, 3, 28, "MathCaption"],
Cell[32830, 774, 479, 8, 54, "Input"],
Cell[33312, 784, 146, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[33483, 791, 496, 8, 54, "Input"],
Cell[33982, 801, 856, 14, 58, "Output"]
}, Open  ]],
Cell[34853, 818, 127, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[35005, 825, 691, 16, 86, "Input"],
Cell[35699, 843, 806, 16, 85, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

