(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     56374,       1112]*)
(*NotebookOutlinePosition[     60038,       1212]*)
(*  CellTagsIndexPosition[     59779,       1201]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Sexual selection", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["Defining fitnesses", "SubsubsectionIcon",
  CellTags->"Defining fitnesses"],

Cell["\<\
Sexual selection on diploids can be described by assigning relative \
fitnesses to pairs of diploid individuals.  These relative fitnesses give the \
contribution of each diploid pair, relative to that expected from random \
union.  \
\>", "Text"],

Cell[TextData[{
  "The simplest scheme is a linear preference, with locus ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " in females leading to a preference for locus ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " in males:"
}], "MathCaption"],

Cell[BoxData[
    \(\(W = 
        1 + s \((X\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\) + 
                X\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\))\) \((X\_\(j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}\) + 
                X\_\(j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}\))\);\)\)], "Input"],

Cell[TextData[StyleBox["Four genes influence the finess of the diploid \
pair:", "MathCaption"]], "MathCaption"],

Cell[BoxData[
    \(\(\[DoubleStruckCapitalW] = {i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, 
          i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
          j\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}, 
          j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}};\)\)], "Input"],

Cell[TextData[StyleBox["The mean fitness is:", "MathCaption"]], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(wbar = \[LeftAngleBracket]W\[RightAngleBracket]\)], "Input"],

Cell[BoxData[
    \(1 + 
      s\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}} + 
      s\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}} + 
      s\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}} + 
      s\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}} + 
      s\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\) + 
      s\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}}\ \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\) + 
      s\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\) + 
      s\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}}\ \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\) + 
      s\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \[WeierstrassP]\_\(j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}\) + 
      s\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\ \[WeierstrassP]\_\(j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}\) + 
      s\ \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\)\ \[WeierstrassP]\_\(j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}\) + 
      s\ \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\)\ \[WeierstrassP]\_\(j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}\) + 
      s\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \[WeierstrassP]\_\(j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}\) + 
      s\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\ \[WeierstrassP]\_\(j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}\) + 
      s\ \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\)\ \[WeierstrassP]\_\(j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}\) + 
      s\ \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\)\ \[WeierstrassP]\_\(j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}\)\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["It is most efficient to store definitions of \
selection coefficients:", "MathCaption"]], "MathCaption"],

Cell[BoxData[
    \(\(aa[\[DoubleStruckCapitalU]_] := \(aa[\[DoubleStruckCapitalU]] = 
          MakeSelectionCoefficient[\[DoubleStruckCapitalU], W]/
            wb\);\)\)], "Input"],

Cell["For example:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({aa[{j\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}}], 
      aa[{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
          i\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}}], 
      aa[{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, 
          j\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}}]}\)], \
"Input"],

Cell[BoxData[
    \({\(s\ \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\) + s\ \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}\)\)\/wb, 0, s\/wb}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Random union of zygotes", "SubsubsectionIcon",
  CellTags->"Random union"],

Cell[TextData[{
  "In the zygote pool, we imagine that mating pairs combine at ",
  ButtonBox["random",
    ButtonData:>{"Random union", "Random union of zygotes"},
    ButtonStyle->"AddOnsLink"],
  " ",
  StyleBox["before",
    FontSlant->"Italic"],
  " sexual selection: associations among mating diploids are generated by \
sexual selection which occurs between the hypothetical pool of randomly \
combined zygote pairs, and of adults."
}], "Text"],

Cell["\<\
Zygote frequencies are now the product of frequencies among males & \
females separately:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}} /. RandomUnion[\[GothicCapitalZ]]\)], "Input"],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}}\)], "Output"]
}, Open  ]],

Cell["Assuming that reference points are unchanged:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}} //. \((UnionOfGametes[]\[Vee]ReferencePointSame[\
\[GothicCapitalG], \[GothicCapitalZ]])\)\)], "Input"],

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sexual selection", "SubsubsectionIcon",
  CellTags->"Sexual selection"],

Cell["\<\
Selection acts on the proportions of diploid pairs that contribute \
to the next generation.  \
\>", "Text"],

Cell[TextData[{
  "For example, the change in association between the maternal gene ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " in females and the maternal gene ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " in females is a sum over all relevant selection coefficients:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}} - \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}})\) //. Selection[]\)], "Input"],

Cell[BoxData[
    \(\((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}} + \
\((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \
\((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}})\)\ \
\[GothicA]\_{j\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}} + \
\((\(-\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{j\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}} + \
\((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, \
i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\%2\) + \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, \
j\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, \
j\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, \
j\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, \
j\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{j\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, \
j\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, \
i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, \
i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, \
j\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, \
j\_{\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}} + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}})\)\ \
\[GothicA]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, \
i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}}\)], "Output"]
}, Closed]],

Cell["\<\
Applying the assumption that the reference point equals the mean in \
each sex separately, measured in the gamete pool, and substituting for the \
actual selection coefficients:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(rr = \((ReferencePointSame[\[GothicCapitalG], {\[GothicCapitalA], \
\[GothicCapitalZ]}]\[Vee]ReferencePointZero[{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalG]}]\[Vee]Selection[])\);\)\), "\n", 
    \(\(\((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}} - \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}})\) //. 
          rr\) /. {\[GothicA]\_\[DoubleStruckCapitalU]_ \[RuleDelayed] \
\((MakeSelectionCoefficient[\[DoubleStruckCapitalU], W]/wb //. rr)\)} // 
      Simplify\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/wb\)\((s\ \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}}\%2\) - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}}\ \
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}} - \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}}\ \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}} - \[GothicCapitalD]\
\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}}\ \
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}, j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}} + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}} + \((\(-\
\[GothicCapitalD]\_{j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}})\)\ \((\[GothicM]\_\
\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\) + \[GothicM]\_\(i\_{\
\[GothicCapitalG], \[GothicCapitalM]}\))\) + \((\(-\[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}}\)\ \
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}})\)\ \((\[GothicM]\_\(i\_{\
\[GothicCapitalG], \[GothicCapitalF]}\) + \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + \((\(-\
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}}\)\ \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}, j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalF]}, i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}})\)\ \((\[GothicM]\_\
\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) + \[GothicM]\_\(j\_{\
\[GothicCapitalG], \[GothicCapitalM]}\))\) + \((\(-\[GothicCapitalD]\_{i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}}\)\ \
\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}, i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalM]}})\)\ \((\[GothicM]\_\(j\_{\
\[GothicCapitalG], \[GothicCapitalF]}\) + \
\[GothicM]\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\))\))\)\)\)], \
"Output"]
}, Open  ]],

Cell["\<\
Finally, if we (by definition) substitute for random combination of \
zygotes, derived by non-random union of gametes:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(rr = \((ReferencePointSame[\[GothicCapitalG], {\[GothicCapitalA], \
\[GothicCapitalZ]}]\[Vee]ReferencePointZero[{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalG]}]\[Vee]Selection[]\[Vee]UnionOfGametes[]\[Vee]RandomUnion[\
\[GothicCapitalZ]])\);\)\), "\n", 
    \(xx = \(\((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}} - \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalF]}})\) //. 
            rr\) /. {\[GothicA]\_\[DoubleStruckCapitalU]_ \[RuleDelayed] \
\((MakeSelectionCoefficient[\[DoubleStruckCapitalU], W]/wb //. rr)\)} // 
        Simplify\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/wb\)\((s\ \((\(-\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\%2\) - \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \((\[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}} + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}})\) + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\) + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\) + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\) + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}}\ \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\) + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\) + \[GothicCapitalD]\
\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}}\ \
\[GothicM]\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\))\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "There is a ",
  ButtonBox["subtle problem",
    ButtonData:>"subtle problem",
    ButtonStyle->"Hyperlink"],
  " here: UnionOfGametes[] must appear before RandomUnion[\[GothicCapitalZ]] \
in the list of rules, since otherwise, all \[GothicCapitalZ] stages will be \
represented in terms of \[GothicCapitalG] before \
RandomUnion[\[GothicCapitalZ]] is invoked."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Recombination", "SubsubsectionIcon",
  CellTags->"Recombination"],

Cell[TextData[{
  "Genes in the new gamete pool, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[GothicCapitalG]\^*\)\(,\)\(\ \)\)\)]],
  "derive from genes in the adults, via meiosis.  The association between \
gametes contributed by the two sexes depends on associations between male and \
female parents. "
}], "Text"],

Cell["\<\
For this two-locus example, proportions involve a product of the \
recombination rates in the two sexes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}, j\
\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} /. 
      Recombination[]\)], "Input"],

Cell[BoxData[
    \(\[GothicR]\_\({i}, {}\)\ \[GothicR]\_\({j}, {}\)\ \
\((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\({}, {i}\)\ \[GothicR]\_\({j}, {}\)\
\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}, j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalF]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\)\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\({}, {j}\)\ \[GothicR]\_\({i}, {}\)\
\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\)\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\) + \[GothicR]\_\({}, {i}\)\ \[GothicR]\_\({}, {j}\)\
\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}, j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalM]}\)\) + \[WeierstrassP]\_\(j\_{\[GothicCapitalA], \
\[GothicCapitalM], \[GothicCapitalM]}\))\) + \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\)\ \((\(-\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\)\) + \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalM], \
\[GothicCapitalM]}\))\))\)\)], "Output"]
}, Open  ]],

Cell["Associations within gametes are simpler:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}, j\
\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}} //. \
\((Recombination[]\[Vee]SymmetricRecombination[])\) // Simplify\)], "Input"],

Cell[BoxData[
    \(\[GothicR]\_\({}, {i, j}\)\ \
\((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) - \((\
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}} - \[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}\))\)\ \((\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\) - \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\))\) + \[GothicR]\
\_\({i}, {j}\)\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}, j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\) - \((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}} - \[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\)\ \((\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\) - \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}\))\))\) + \[GothicR]\_\({i}, {j}\)\ \
\((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}, j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalF]}\))\) - \((\
\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalF]}} - \[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalF]}\) + \[WeierstrassP]\_\(i\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalF]}\))\)\ \((\[WeierstrassP]\_\(j\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\) - \[WeierstrassP]\_\(j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\))\) + \[GothicR]\
\_\({}, {i, j}\)\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}, j\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}}\ \((\(-\
\[WeierstrassP]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\)\) + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\) - \((\[GothicCapitalD]\_{i\_{\[GothicCapitalA], \
\[GothicCapitalF], \[GothicCapitalM]}} - \[WeierstrassP]\_\(i\_{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalF]}\) + \[WeierstrassP]\_\(i\_{\
\[GothicCapitalA], \[GothicCapitalF], \[GothicCapitalM]}\))\)\ \((\
\[WeierstrassP]\_\(j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\) - \
\[WeierstrassP]\_\(j\_{\[GothicCapitalA], \[GothicCapitalF], \
\[GothicCapitalM]}\))\))\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The complete life cycle", "SubsubsectionIcon",
  CellTags->"Complete cycle"],

Cell["\<\
The same rules can be used as for natural selection on diploids, \
except that we impose RandomUnion[\[GothicCapitalZ]]:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(rules = \
\((Recombination[]\[Vee]SymmetricRecombination[]\[Vee]ReferencePointSame[\
\[GothicCapitalG], {\[GothicCapitalA], \
\[GothicCapitalZ]}]\[Vee]ReferencePointZero[{\(\[GothicCapitalG]\^*\), \
\[GothicCapitalG]}]\[Vee]Selection[]\[Vee]RandomUnion[\[GothicCapitalZ]]\[Vee]\
UnionOfGametes[]\[Vee]Symmetrise[Disequilibrium])\);\)\)], "Input"],

Cell["This is the new mean:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\) //. {\
\[GothicA]\_\[DoubleStruckCapitalU]_ \[RuleDelayed] 
              aa[\[DoubleStruckCapitalU]]}\[Vee]rules // Simplify\)], "Input"],

Cell[BoxData[
    \(\(\(\ \)\(\(\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\) + \
\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\)\)\/2 + \
\(\(s\/wb\)\(\ \)\(\((\[GothicM]\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\
\) + \[GothicM]\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\/2\) \((\
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\
\[GothicCapitalG], \[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}} + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\
\[GothicCapitalG], \[GothicCapitalM]}})\)\(\ \)\)\)\)\)], "Output",
  CellLabel->"Out[62]=  (8:50:19 on 3/4/01)"]
}, Open  ]],

Cell[TextData[{
  "It is crucial to apply UnionOfGametes[] after the other rules, to avoid \
the ",
  ButtonBox["subtle problem",
    ButtonData:>"subtle problem",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell["\<\
Sexual selection causes a difference in means between male and \
female gametes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((\[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}\) - \
\[GothicM]\_\(i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}\))\) //. {\
\[GothicA]\_\[DoubleStruckCapitalU]_ \[RuleDelayed] 
              aa[\[DoubleStruckCapitalU]]}\[Vee]rules // Simplify\)], "Input"],

Cell[BoxData[
    \(s\/\(\(\ \)\(wb\)\)\ \((\(\((\[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\/2\) \((\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}}\  + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\  + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}})\) - \(\((\
\[GothicM]\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) + \
\[GothicM]\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\/2\) \((\
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\  + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}} + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\
\[GothicCapitalG], \[GothicCapitalM]}})\))\)\)], "Output"]
}, Open  ]],

Cell["\<\
An associations between genes in gametes from the different parents \
is generated by :\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}, j\
\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} //. {\[GothicA]\_\
\[DoubleStruckCapitalU]_ \[RuleDelayed] 
              aa[\[DoubleStruckCapitalU]]}\[Vee]rules // Simplify\)], "Input"],

Cell[BoxData[
    \(s\/\(4  wb\)\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}} + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}})\)\^2\ \((1 - 
          s\/wb\ \((\[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\)\
\  + \[GothicM]\_\(i\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) \((\
\[GothicM]\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) + \
\[GothicM]\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\))\)\)], "Output",
  CellLabel->"Out[67]=  (8:58:04 on 3/4/01)"]
}, Open  ]],

Cell["\<\
This is the linkage disequilibrium within males (after some \
rearrangement by hand):\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, \
j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} //. {\[GothicA]\_\
\[DoubleStruckCapitalU]_ \[RuleDelayed] 
                aa[\[DoubleStruckCapitalU]]}\[Vee]rules\) /. \
{\[GothicR]\_\({i}, {j}\) \[Rule] 
            r\/2, \[GothicR]\_\({}, {i, j}\) \[Rule] \(1 - r\)\/2} // 
      Simplify\)], "Input"],

Cell[BoxData[
    \(\(\(\((1 - 
                r)\)\(\ \)\)\/2\) \
\((\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}} + \ \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}})\) + 
      r\/2\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, \
j\_{\[GothicCapitalG], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}})\) + \(\((1 - 
                2  r)\)\/4\) \((\[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) - \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\ \((\[GothicM]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) - \[GothicM]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\  + \ 
      s\/\(2  wb\)\ \((\[GothicM]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) + \[GothicM]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\)\ \((\ \((1 - 
                  r)\)\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}})\) + \ 
            r\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}})\) + \ \((\
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}} + \ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}})\) + \(\(\((1 - 
                      
                      2\ r)\)\(\ \)\)\/2\) \((\((\[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalF]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}} - \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}} + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}} - \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalM]}})\)\ \((\[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) - \[GothicM]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalM]}\))\) + \((\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, i\_{\[GothicCapitalG], \[GothicCapitalF]}} - \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalM]}, i\_{\
\[GothicCapitalG], \[GothicCapitalM]}})\)\ \((\[GothicM]\_\(j\_{\
\[GothicCapitalG], \[GothicCapitalF]}\) - \
\[GothicM]\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\))\))\) - \ \(\((s\
\/wb)\)\^2\) \((\[GothicM]\_\(j\_{\[GothicCapitalG], \[GothicCapitalF]}\) + \
\[GothicM]\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\)\^2\/4\ \((\
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, i\_{\
\[GothicCapitalG], \[GothicCapitalF]}} + 
            2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, \
i\_{\[GothicCapitalG], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, i\_{\[GothicCapitalG], \
\[GothicCapitalM]}})\)\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalF]}, j\_{\[GothicCapitalG], \[GothicCapitalF]}} + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}} + \[GothicCapitalD]\_{i\_{\
\[GothicCapitalG], \[GothicCapitalM]}, j\_{\[GothicCapitalG], \
\[GothicCapitalF]}} + \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \
\[GothicCapitalM]}, j\_{\[GothicCapitalG], \[GothicCapitalM]}})\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The first term is the average \[GothicCapitalD] in the parental gamete \
pool, reduced by recombination.  The second term is the generation by \
recombination of disequilibrium within gametes from associations across \
gametes.  The third term is generated by differences in mean between the \
sexes.  The fourth term is the first-order effect of selection; the last \
component is due to differences in mean and in linkage disequilibria between \
the sexes, and the first component is mediated by three way associations.  \
The last term, of order ",
  Cell[BoxData[
      \(TraditionalForm\`s\^2, \ 
      arises\ from\ the\ change\ in\ reference\ point\ between\ generations\ \
\[GothicCapitalG]\ and\ \(\[GothicCapitalG]\^*\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Note:  ",
  StyleBox["The results are expressed in terms of associations between \
gametes in males, and gametes in females, after recombination and within a \
(hypothetical) randomly mated pair.  It would perhaps be more natural to \
describe the population in terms of associations within and between genomes \
of an individual diploid male or female: that just requires counting the \
population from the zygote stage rather than the gamete stage.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "Note: ",
  StyleBox["If a list of rules of this sort is not applied as expected, see ",
    
    FontWeight->"Plain"],
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Applying rules"},
    ButtonStyle->"AddOnsLink"],
  StyleBox[".",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A subtle problem", "SubsubsectionIcon",
  CellTags->"subtle problem"],

Cell["\<\
If UnionOfGametes[] is implemented before RandomUnion[\
\[GothicCapitalZ]], it erases information about Sex, and about associations \
between zygotes, and leads to errors.  \
\>", "Text"],

Cell["These different associations give the same result:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}, \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}}} /. UnionOfGametes[]\)], "Input"],

Cell[BoxData[
    \({\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ \((\[WeierstrassP]\_\(i\_{\
\[GothicCapitalG], \[GothicCapitalF]}\) - \[WeierstrassP]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \((\
\[WeierstrassP]\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\) - \
\[WeierstrassP]\_\(j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + \((\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) - \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\[WeierstrassP]\_\(j\_{\
\[GothicCapitalG], \[GothicCapitalM]}\) - \[WeierstrassP]\_\(j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}\))\), \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ \((\[WeierstrassP]\_\(i\_{\
\[GothicCapitalG], \[GothicCapitalF]}\) - \[WeierstrassP]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \((\
\[WeierstrassP]\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\) - \
\[WeierstrassP]\_\(j\_{\[GothicCapitalZ], \[GothicCapitalF], \
\[GothicCapitalM]}\))\) + \((\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) - \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\[WeierstrassP]\_\(j\_{\
\[GothicCapitalG], \[GothicCapitalM]}\) - \[WeierstrassP]\_\(j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}\))\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "It is ",
  StyleBox["essential",
    FontWeight->"Bold"],
  " to apply RandomUnion[\[GothicCapitalZ]] first:"
}], "Text"],

Cell["\<\
Independence of male and female zygotes is implemented by \
RandomUnion[\[GothicCapitalZ]]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}, \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}, j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}}} /. 
      RandomUnion[\[GothicCapitalZ]]\)], "Input"],

Cell[BoxData[
    \({\[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}, j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}}, \[GothicCapitalD]\_{i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}}\ \[GothicCapitalD]\_{j\_{\
\[GothicCapitalZ], \[GothicCapitalF], \[GothicCapitalM]}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. UnionOfGametes[]\)], "Input"],

Cell[BoxData[
    \({\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalM]}} + \[GothicCapitalD]\_{j\_{\
\[GothicCapitalG], \[GothicCapitalM]}}\ \((\[WeierstrassP]\_\(i\_{\
\[GothicCapitalG], \[GothicCapitalF]}\) - \[WeierstrassP]\_\(i\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalF]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \((\
\[WeierstrassP]\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\) - \
\[WeierstrassP]\_\(j\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalM]}\))\) + \((\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \
\[GothicCapitalF]}\) - \[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \
\[GothicCapitalM], \[GothicCapitalF]}\))\)\ \((\[WeierstrassP]\_\(j\_{\
\[GothicCapitalG], \[GothicCapitalM]}\) - \[WeierstrassP]\_\(j\_{\
\[GothicCapitalZ], \[GothicCapitalM], \[GothicCapitalM]}\))\), \((\
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}} + \
\[WeierstrassP]\_\(i\_{\[GothicCapitalG], \[GothicCapitalF]}\) - \
\[WeierstrassP]\_\(i\_{\[GothicCapitalZ], \[GothicCapitalM], \
\[GothicCapitalF]}\))\)\ \((\[GothicCapitalD]\_{j\_{\[GothicCapitalG], \
\[GothicCapitalM]}} + \[WeierstrassP]\_\(j\_{\[GothicCapitalG], \
\[GothicCapitalM]}\) - \[WeierstrassP]\_\(j\_{\[GothicCapitalZ], \
\[GothicCapitalF], \[GothicCapitalM]}\))\)}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{956, 721},
WindowMargins->{{Automatic, 20}, {Automatic, 1}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Defining fitnesses"->{
    Cell[1806, 55, 81, 1, 24, "SubsubsectionIcon",
      CellTags->"Defining fitnesses"]},
  "Random union"->{
    Cell[7372, 184, 80, 1, 24, "SubsubsectionIcon",
      CellTags->"Random union"]},
  "Sexual selection"->{
    Cell[9045, 236, 77, 1, 24, "SubsubsectionIcon",
      CellTags->"Sexual selection"]},
  "Recombination"->{
    Cell[31299, 612, 71, 1, 24, "SubsubsectionIcon",
      CellTags->"Recombination"]},
  "Complete cycle"->{
    Cell[40187, 766, 82, 1, 24, "SubsubsectionIcon",
      CellTags->"Complete cycle"]},
  "subtle problem"->{
    Cell[51321, 1003, 75, 1, 24, "SubsubsectionIcon",
      CellTags->"subtle problem"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Defining fitnesses", 59111, 1179},
  {"Random union", 59222, 1182},
  {"Sexual selection", 59332, 1185},
  {"Recombination", 59443, 1188},
  {"Complete cycle", 59553, 1191},
  {"subtle problem", 59664, 1194}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 42, 0, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[1806, 55, 81, 1, 24, "SubsubsectionIcon",
  CellTags->"Defining fitnesses"],
Cell[1890, 58, 257, 5, 36, "Text"],
Cell[2150, 65, 258, 8, 28, "MathCaption"],
Cell[2411, 75, 386, 8, 30, "Input"],
Cell[2800, 85, 112, 1, 28, "MathCaption"],
Cell[2915, 88, 349, 6, 27, "Input"],
Cell[3267, 96, 78, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3370, 100, 80, 1, 26, "Input"],
Cell[3453, 103, 2847, 49, 73, "Output"]
}, Open  ]],
Cell[6315, 155, 128, 1, 28, "MathCaption"],
Cell[6446, 158, 183, 3, 26, "Input"],
Cell[6632, 163, 35, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6692, 167, 399, 6, 27, "Input"],
Cell[7094, 175, 229, 3, 38, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7372, 184, 80, 1, 24, "SubsubsectionIcon",
  CellTags->"Random union"],
Cell[7455, 187, 451, 11, 38, "Text"],
Cell[7909, 200, 120, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[8054, 207, 214, 3, 30, "Input"],
Cell[8271, 212, 202, 3, 27, "Output"]
}, Open  ]],
Cell[8488, 218, 68, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[8581, 222, 271, 4, 30, "Input"],
Cell[8855, 228, 141, 2, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9045, 236, 77, 1, 24, "SubsubsectionIcon",
  CellTags->"Sexual selection"],
Cell[9125, 239, 118, 3, 30, "Text"],
Cell[9246, 244, 308, 8, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[9579, 256, 352, 5, 31, "Input"],
Cell[9934, 263, 11247, 169, 396, "Output"]
}, Closed]],
Cell[21196, 435, 208, 4, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[21429, 443, 709, 11, 65, "Input"],
Cell[22141, 456, 4596, 70, 187, "Output"]
}, Open  ]],
Cell[26752, 529, 142, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[26919, 536, 778, 12, 64, "Input"],
Cell[27700, 550, 3156, 45, 115, "Output"]
}, Open  ]],
Cell[30871, 598, 391, 9, 46, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31299, 612, 71, 1, 24, "SubsubsectionIcon",
  CellTags->"Recombination"],
Cell[31373, 615, 323, 7, 46, "Text"],
Cell[31699, 624, 135, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[31859, 631, 180, 3, 34, "Input"],
Cell[32042, 636, 4291, 61, 154, "Output"]
}, Open  ]],
Cell[36348, 700, 63, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[36436, 704, 224, 3, 34, "Input"],
Cell[36663, 709, 3475, 51, 106, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[40187, 766, 82, 1, 24, "SubsubsectionIcon",
  CellTags->"Complete cycle"],
Cell[40272, 769, 151, 3, 28, "MathCaption"],
Cell[40426, 774, 368, 6, 43, "Input"],
Cell[40797, 782, 44, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[40866, 786, 223, 3, 32, "Input"],
Cell[41092, 791, 832, 12, 49, "Output"]
}, Open  ]],
Cell[41939, 806, 213, 7, 30, "Text"],
Cell[42155, 815, 111, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[42291, 822, 298, 4, 32, "Input"],
Cell[42592, 828, 1236, 18, 106, "Output"]
}, Open  ]],
Cell[43843, 849, 118, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[43986, 856, 280, 4, 34, "Input"],
Cell[44269, 862, 829, 12, 40, "Output"]
}, Open  ]],
Cell[45113, 877, 116, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[45254, 884, 400, 7, 42, "Input"],
Cell[45657, 893, 3997, 63, 202, "Output"]
}, Open  ]],
Cell[49669, 959, 771, 14, 78, "Text"],
Cell[50443, 975, 530, 10, 64, "Text"],
Cell[50976, 987, 308, 11, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51321, 1003, 75, 1, 24, "SubsubsectionIcon",
  CellTags->"subtle problem"],
Cell[51399, 1006, 197, 4, 30, "Text"],
Cell[51599, 1012, 73, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[51697, 1016, 351, 5, 31, "Input"],
Cell[52051, 1023, 1792, 26, 58, "Output"]
}, Open  ]],
Cell[53858, 1052, 140, 5, 32, "Text"],
Cell[54001, 1059, 122, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[54148, 1066, 372, 6, 31, "Input"],
Cell[54523, 1074, 353, 5, 34, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54913, 1084, 54, 1, 27, "Input"],
Cell[54970, 1087, 1364, 20, 58, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

