(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     95234,       3182]*)
(*NotebookOutlinePosition[    168170,       5798]*)
(*  CellTagsIndexPosition[    167852,       5784]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Iterating one deme", "SubsectionIcon"],

Cell["This loads this package, as well as the Graphics package:", \
"MathCaption"],

Cell[BoxData[
    \(<< NumericalModels`ExactModel`; << Graphics`;\)], "Input",
  CellLabel->"In[12]:=  (6:42:33 on 5/3/01)"],

Cell[CellGroupData[{

Cell["A single deme", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, 
              0]\), \(gives\ allele\ frequencies\ after\ one\ generation\ of\ \
selection, \ specified\ by\ W[p] = {W\&_, {s\_1, \[Ellipsis]} W\&_}\)},
          {
            RowBox[{"StoreExact", "[", 
              RowBox[{"\[Psi]", ",", \(\[Psi]\_0\), ",", "W", ",", "0", ",", 
                RowBox[{"{", 
                  RowBox[{"t", ",", 
                    StyleBox["dt",
                      FontSlant->"Italic"]}], 
                  StyleBox["}",
                    FontSlant->"Italic"]}]}], 
              "]"}], \(stores\ results\ at\ intervals\ dt\ in\ \[Psi][t], \ 
            starting\ with\ \[Psi][
                  0] = \[Psi]\_0 . \ \ Options\ are\ passed\ directly\ to\ \(\
\(IterateExact[]\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->{"IterateExact", "StoreExact"}],

Cell["\<\
This is the fitness function for selection against heterozygotes:\
\
\>", "MathCaption"],

Cell[BoxData[
    \(\(\(w[\[Sigma]_List, het]\)[
          p_List] := {1 - 
            2  \[Sigma] . \((p \((1 - p)\))\), \[Sigma] \((2  p - 
                1)\)};\)\)], "Input",
  CellLabel->"In[52]:=  (20:08:08 on 4/30/01)"],

Cell[TextData[{
  "The fitness of heterozygotes at locus i is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"1", "-", 
          RowBox[{
            FormBox[\(\[Sigma]\_i; \ \(\(mean\ fitness\ is\ W\&_\)\(=\)\)\),
              "TraditionalForm"], "1"}], 
          "-", \(2 \(\[Sum]\+i\( \[Sigma]\_i\) \(p\_i\) \((1 - p\_i)\)\)\)}], 
        TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              FormBox[\(\(s\_i\) W\&_ = \(\[Sigma]\_i\) \((p\)\),
                "TraditionalForm"], "i"], "-", \(q\_i\)}], ")"}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell["\<\
This shows the allele frequency at three loci, with selection \
s={0.1,0.2,0.05}against heterozygotes at the three loci:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pop = 
        AlleleFrequencies[{0.4, 0.49, 0.51}, 
          100];\)\), "\[IndentingNewLine]", 
    \(\(pop2 = 
        NestList[IterateExact[#, w[{0.1, 0.2, 0.05}, het], 0] &, pop, 
          100];\)\), "\n", 
    \(\(DisplayTogether @@ \((ListPlot /@ 
            Transpose[AlleleFrequencyTable[pop2]])\);\)\)}], "Input",
  CellLabel->"In[53]:=  (20:08:09 on 4/30/01)"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00942951 0.0147151 0.92039 [
[.2124 .00222 -6 -9 ]
[.2124 .00222 6 0 ]
[.40099 .00222 -6 -9 ]
[.40099 .00222 6 0 ]
[.58958 .00222 -6 -9 ]
[.58958 .00222 6 0 ]
[.77817 .00222 -6 -9 ]
[.77817 .00222 6 0 ]
[.96676 .00222 -9 -9 ]
[.96676 .00222 9 0 ]
[.01131 .10675 -18 -4.5 ]
[.01131 .10675 0 4.5 ]
[.01131 .19879 -18 -4.5 ]
[.01131 .19879 0 4.5 ]
[.01131 .29083 -18 -4.5 ]
[.01131 .29083 0 4.5 ]
[.01131 .38287 -18 -4.5 ]
[.01131 .38287 0 4.5 ]
[.01131 .47491 -18 -4.5 ]
[.01131 .47491 0 4.5 ]
[.01131 .56695 -18 -4.5 ]
[.01131 .56695 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2124 .01472 m
.2124 .02097 L
s
[(20)] .2124 .00222 0 1 Mshowa
.40099 .01472 m
.40099 .02097 L
s
[(40)] .40099 .00222 0 1 Mshowa
.58958 .01472 m
.58958 .02097 L
s
[(60)] .58958 .00222 0 1 Mshowa
.77817 .01472 m
.77817 .02097 L
s
[(80)] .77817 .00222 0 1 Mshowa
.96676 .01472 m
.96676 .02097 L
s
[(100)] .96676 .00222 0 1 Mshowa
.125 Mabswid
.07096 .01472 m
.07096 .01847 L
s
.1181 .01472 m
.1181 .01847 L
s
.16525 .01472 m
.16525 .01847 L
s
.25955 .01472 m
.25955 .01847 L
s
.30669 .01472 m
.30669 .01847 L
s
.35384 .01472 m
.35384 .01847 L
s
.44814 .01472 m
.44814 .01847 L
s
.49529 .01472 m
.49529 .01847 L
s
.54243 .01472 m
.54243 .01847 L
s
.63673 .01472 m
.63673 .01847 L
s
.68388 .01472 m
.68388 .01847 L
s
.73102 .01472 m
.73102 .01847 L
s
.82532 .01472 m
.82532 .01847 L
s
.87247 .01472 m
.87247 .01847 L
s
.91961 .01472 m
.91961 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10675 m
.03006 .10675 L
s
[(0.1)] .01131 .10675 1 0 Mshowa
.02381 .19879 m
.03006 .19879 L
s
[(0.2)] .01131 .19879 1 0 Mshowa
.02381 .29083 m
.03006 .29083 L
s
[(0.3)] .01131 .29083 1 0 Mshowa
.02381 .38287 m
.03006 .38287 L
s
[(0.4)] .01131 .38287 1 0 Mshowa
.02381 .47491 m
.03006 .47491 L
s
[(0.5)] .01131 .47491 1 0 Mshowa
.02381 .56695 m
.03006 .56695 L
s
[(0.6)] .01131 .56695 1 0 Mshowa
.125 Mabswid
.02381 .03312 m
.02756 .03312 L
s
.02381 .05153 m
.02756 .05153 L
s
.02381 .06994 m
.02756 .06994 L
s
.02381 .08835 m
.02756 .08835 L
s
.02381 .12516 m
.02756 .12516 L
s
.02381 .14357 m
.02756 .14357 L
s
.02381 .16198 m
.02756 .16198 L
s
.02381 .18039 m
.02756 .18039 L
s
.02381 .2172 m
.02756 .2172 L
s
.02381 .23561 m
.02756 .23561 L
s
.02381 .25402 m
.02756 .25402 L
s
.02381 .27242 m
.02756 .27242 L
s
.02381 .30924 m
.02756 .30924 L
s
.02381 .32765 m
.02756 .32765 L
s
.02381 .34606 m
.02756 .34606 L
s
.02381 .36446 m
.02756 .36446 L
s
.02381 .40128 m
.02756 .40128 L
s
.02381 .41969 m
.02756 .41969 L
s
.02381 .43809 m
.02756 .43809 L
s
.02381 .4565 m
.02756 .4565 L
s
.02381 .49332 m
.02756 .49332 L
s
.02381 .51173 m
.02756 .51173 L
s
.02381 .53013 m
.02756 .53013 L
s
.02381 .54854 m
.02756 .54854 L
s
.02381 .58536 m
.02756 .58536 L
s
.02381 .60376 m
.02756 .60376 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.03324 .38287 Mdot
.04267 .37753 Mdot
.0521 .37191 Mdot
.06153 .366 Mdot
.07096 .35979 Mdot
.08039 .35327 Mdot
.08982 .34644 Mdot
.09925 .3393 Mdot
.10868 .33184 Mdot
.1181 .32405 Mdot
.12753 .31595 Mdot
.13696 .30753 Mdot
.14639 .2988 Mdot
.15582 .28978 Mdot
.16525 .28047 Mdot
.17468 .27091 Mdot
.18411 .26111 Mdot
.19354 .25109 Mdot
.20297 .24091 Mdot
.2124 .23058 Mdot
.22183 .22017 Mdot
.23126 .2097 Mdot
.24069 .19923 Mdot
.25012 .18882 Mdot
.25955 .17851 Mdot
.26898 .16836 Mdot
.27841 .15841 Mdot
.28784 .14873 Mdot
.29727 .13936 Mdot
.30669 .13033 Mdot
.31612 .12168 Mdot
.32555 .11344 Mdot
.33498 .10563 Mdot
.34441 .09827 Mdot
.35384 .09136 Mdot
.36327 .0849 Mdot
.3727 .07889 Mdot
.38213 .0733 Mdot
.39156 .06814 Mdot
.40099 .06337 Mdot
.41042 .05898 Mdot
.41985 .05494 Mdot
.42928 .05124 Mdot
.43871 .04784 Mdot
.44814 .04474 Mdot
.45757 .04191 Mdot
.467 .03933 Mdot
.47643 .03697 Mdot
.48586 .03483 Mdot
.49529 .03288 Mdot
.50471 .03111 Mdot
.51414 .02951 Mdot
.52357 .02806 Mdot
.533 .02674 Mdot
.54243 .02555 Mdot
.55186 .02448 Mdot
.56129 .0235 Mdot
.57072 .02263 Mdot
.58015 .02183 Mdot
.58958 .02112 Mdot
.59901 .02048 Mdot
.60844 .01989 Mdot
.61787 .01937 Mdot
.6273 .0189 Mdot
.63673 .01848 Mdot
.64616 .0181 Mdot
.65559 .01775 Mdot
.66502 .01744 Mdot
.67445 .01717 Mdot
.68388 .01692 Mdot
.69331 .01669 Mdot
.70273 .01649 Mdot
.71216 .01631 Mdot
.72159 .01615 Mdot
.73102 .016 Mdot
.74045 .01587 Mdot
.74988 .01575 Mdot
.75931 .01565 Mdot
.76874 .01555 Mdot
.77817 .01547 Mdot
.7876 .01539 Mdot
.79703 .01532 Mdot
.80646 .01526 Mdot
.81589 .0152 Mdot
.82532 .01515 Mdot
.83475 .01511 Mdot
.84418 .01507 Mdot
.85361 .01503 Mdot
.86304 .015 Mdot
.87247 .01497 Mdot
.8819 .01494 Mdot
.89132 .01492 Mdot
.90075 .0149 Mdot
.91018 .01488 Mdot
.91961 .01486 Mdot
.92904 .01485 Mdot
.93847 .01483 Mdot
.9479 .01482 Mdot
.95733 .01481 Mdot
.96676 .0148 Mdot
.97619 .01479 Mdot
.03324 .46571 Mdot
.04267 .46459 Mdot
.0521 .46335 Mdot
.06153 .46195 Mdot
.07096 .46039 Mdot
.08039 .45864 Mdot
.08982 .45667 Mdot
.09925 .45448 Mdot
.10868 .45202 Mdot
.1181 .44927 Mdot
.12753 .44619 Mdot
.13696 .44275 Mdot
.14639 .4389 Mdot
.15582 .43461 Mdot
.16525 .42981 Mdot
.17468 .42446 Mdot
.18411 .4185 Mdot
.19354 .41187 Mdot
.20297 .40449 Mdot
.2124 .39631 Mdot
.22183 .38724 Mdot
.23126 .37723 Mdot
.24069 .36621 Mdot
.25012 .35411 Mdot
.25955 .3409 Mdot
.26898 .32655 Mdot
.27841 .31104 Mdot
.28784 .29443 Mdot
.29727 .27679 Mdot
.30669 .25824 Mdot
.31612 .23897 Mdot
.32555 .21923 Mdot
.33498 .19929 Mdot
.34441 .1795 Mdot
.35384 .1602 Mdot
.36327 .14172 Mdot
.3727 .12436 Mdot
.38213 .10837 Mdot
.39156 .09391 Mdot
.40099 .08106 Mdot
.41042 .06983 Mdot
.41985 .06016 Mdot
.42928 .05195 Mdot
.43871 .04505 Mdot
.44814 .03931 Mdot
.45757 .03458 Mdot
.467 .03071 Mdot
.47643 .02756 Mdot
.48586 .02501 Mdot
.49529 .02295 Mdot
.50471 .02129 Mdot
.51414 .01996 Mdot
.52357 .0189 Mdot
.533 .01805 Mdot
.54243 .01737 Mdot
.55186 .01683 Mdot
.56129 .0164 Mdot
.57072 .01605 Mdot
.58015 .01578 Mdot
.58958 .01556 Mdot
.59901 .01539 Mdot
.60844 .01525 Mdot
.61787 .01514 Mdot
.6273 .01505 Mdot
.63673 .01498 Mdot
.64616 .01493 Mdot
.65559 .01488 Mdot
.66502 .01485 Mdot
.67445 .01482 Mdot
.68388 .0148 Mdot
.69331 .01478 Mdot
.70273 .01477 Mdot
.71216 .01476 Mdot
.72159 .01475 Mdot
.73102 .01474 Mdot
.74045 .01474 Mdot
.74988 .01473 Mdot
.75931 .01473 Mdot
.76874 .01473 Mdot
.77817 .01472 Mdot
.7876 .01472 Mdot
.79703 .01472 Mdot
.80646 .01472 Mdot
.81589 .01472 Mdot
.82532 .01472 Mdot
.83475 .01472 Mdot
.84418 .01472 Mdot
.85361 .01472 Mdot
.86304 .01472 Mdot
.87247 .01472 Mdot
.8819 .01472 Mdot
.89132 .01472 Mdot
.90075 .01472 Mdot
.91018 .01472 Mdot
.91961 .01472 Mdot
.92904 .01472 Mdot
.93847 .01472 Mdot
.9479 .01472 Mdot
.95733 .01472 Mdot
.96676 .01472 Mdot
.97619 .01472 Mdot
.03324 .48411 Mdot
.04267 .48439 Mdot
.0521 .48468 Mdot
.06153 .48497 Mdot
.07096 .48528 Mdot
.08039 .48559 Mdot
.08982 .48591 Mdot
.09925 .48624 Mdot
.10868 .48658 Mdot
.1181 .48694 Mdot
.12753 .4873 Mdot
.13696 .48767 Mdot
.14639 .48805 Mdot
.15582 .48845 Mdot
.16525 .48885 Mdot
.17468 .48927 Mdot
.18411 .4897 Mdot
.19354 .49014 Mdot
.20297 .49059 Mdot
.2124 .49106 Mdot
.22183 .49154 Mdot
.23126 .49203 Mdot
.24069 .49254 Mdot
.25012 .49305 Mdot
.25955 .49359 Mdot
.26898 .49413 Mdot
.27841 .49469 Mdot
.28784 .49526 Mdot
.29727 .49585 Mdot
.30669 .49645 Mdot
.31612 .49707 Mdot
.32555 .49769 Mdot
.33498 .49833 Mdot
.34441 .49899 Mdot
.35384 .49965 Mdot
.36327 .50033 Mdot
.3727 .50103 Mdot
.38213 .50174 Mdot
.39156 .50246 Mdot
.40099 .50319 Mdot
.41042 .50394 Mdot
.41985 .50471 Mdot
.42928 .50549 Mdot
.43871 .50629 Mdot
.44814 .50711 Mdot
.45757 .50795 Mdot
.467 .5088 Mdot
.47643 .50968 Mdot
.48586 .51057 Mdot
.49529 .51149 Mdot
.50471 .51243 Mdot
.51414 .51339 Mdot
.52357 .51437 Mdot
.533 .51538 Mdot
.54243 .51642 Mdot
.55186 .51748 Mdot
.56129 .51856 Mdot
.57072 .51967 Mdot
.58015 .52081 Mdot
.58958 .52198 Mdot
.59901 .52318 Mdot
.60844 .5244 Mdot
.61787 .52566 Mdot
.6273 .52694 Mdot
.63673 .52826 Mdot
.64616 .52961 Mdot
.65559 .531 Mdot
.66502 .53241 Mdot
.67445 .53386 Mdot
.68388 .53535 Mdot
.69331 .53687 Mdot
.70273 .53843 Mdot
.71216 .54003 Mdot
.72159 .54167 Mdot
.73102 .54334 Mdot
.74045 .54506 Mdot
.74988 .54682 Mdot
.75931 .54861 Mdot
.76874 .55045 Mdot
.77817 .55234 Mdot
.7876 .55427 Mdot
.79703 .55624 Mdot
.80646 .55826 Mdot
.81589 .56032 Mdot
.82532 .56244 Mdot
.83475 .5646 Mdot
.84418 .56681 Mdot
.85361 .56907 Mdot
.86304 .57138 Mdot
.87247 .57374 Mdot
.8819 .57616 Mdot
.89132 .57862 Mdot
.90075 .58114 Mdot
.91018 .58372 Mdot
.91961 .58635 Mdot
.92904 .58904 Mdot
.93847 .59178 Mdot
.9479 .59458 Mdot
.95733 .59743 Mdot
.96676 .60035 Mdot
.97619 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[53]:=  (20:08:11 on 4/30/01)",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0012Ool5
0003Ool2000/Ool30003Ool2000ZOol30004Ool2000ZOol30004Ool2000WOol30004Ool20004Ool2
0004Ool004=oo`04001oogoo0002Ool01000Oomoo`00;7oo00D007ooOomoo`00009oo`03001oogoo
02Ioo`05001oogooOol00002Ool01000Oomoo`00:7oo00D007ooOomoo`00009oo`04001oogoo000W
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=oo`00A7oo00<007ooOol00Woo00@0
07ooOol002Uoo`D0009oo`04001oogoo000XOol01@00Oomoogoo00000Woo00@007ooOol002Qoo`05
001oogooOol00002Ool01000Oomoo`009goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0003Ool004Eoo`05001oogooOol00002Ool00`00Oomoo`0WOol01000Oomoo`000goo00@007ooOol0
02Qoo`@000=oo`04001oogoo000YOol30003Ool01000Oomoo`009goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0003Ool0049oo`05001oogooOol00002Ool01000Oomoo`00:Woo00<007oo
00000goo00@007ooOol002Qoo`03001oogoo00Aoo`04001oogoo000XOol01@00Oomoogoo00000Woo
00@007ooOol002Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000goo0012Ool01@00
Oomoogoo00000Woo00@007ooOol002]oo`8000=oo`04001oogoo000YOol00`00Oomoo`03Ool01000
Oomoo`00:7oo00D007ooOomoo`00009oo`04001oogoo000VOol20004Ool01000Oomoo`000Woo00@0
07ooOol000=oo`00@goo0`0017oo0P00;Goo00<007ooOol00Woo0P00:goo0P0017oo0P00:Woo0`00
17oo0P00:7oo00<007ooOol00goo0P0017oo0P0017oo000EOol00`00Oomoo`3oOol9Ool001Eoo`03
001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool000ioool0
01<000005Goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<0
07ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol02Woo00<007ooOol00Woo100000=oo`0000000P0000Aoo`00001oo`@00003Ool000000080
0003Ool0000000800004Ool00000Ool400000goo0000000200000goo0000000200000goo00000002
000017oo000007oo100000=oo`0000000P0000=oo`0000000P0000Aoo`00001oo`@00003Ool00000
00800003Ool0000000800004Ool00000Ool400000goo0000000200000goo00000002000017oo0000
07oo100000=oo`0000000P0000=oo`0000000P0000=oo`0000000P001goo000EOol00`00Oomoo`0`
Ool00`00Oomoo`0aOol00`00Oomoo`0FOol400000goo0000000200000goo00000003Ool200000goo
0000000200000goo0000000200000goo00000002000017oo000007oo100000=oo`0000000P0087oo
00<007ooOol0<7oo00<007ooOol027oo000EOol00`00Oomoo`1gOol2000017oo000007oo10000goo
0P0000=oo`0000000P0000Aoo`00001oo`@00003Ool00000079oo`005Goo00<007ooOol0MGoo1000
00=oo`0000000goo0P0000=oo`0000000P0000=oo`0000000P00OGoo000EOol2001cOol200000goo
00000003Ool200000goo0000000200000goo00000024Ool001Eoo`03001oogoo071oo`@00003Ool0
000000800004Ool00000Ool20029Ool001Eoo`03001oogoo071oo`@00003Ool00000008008moo`00
5Goo00<007ooOol0KGoo0P0000=oo`0000000P00U7oo000EOol00`00Oomoo`1]Ool200000goo0000
002FOol001Eoo`8006aoo`@009Uoo`005Goo00<007ooOol0J7oo0P0000=oo`000000Vgoo000EOol0
0`00Oomoo`1VOol4002NOol001Eoo`03001oogoo06=oo`800003Ool00000008009ioo`005Goo00<0
07ooOol0H7oo0P0000=oo`000000Xgoo000EOol2001QOol20004Ool2002POol001Eoo`03001oogoo
05ioo`8000Ioo`800:1oo`005Goo00<007ooOol0Fgoo0P0000=oo`000000Z7oo000EOol00`00Oomo
o`1KOol20006Ool2002SOol001Eoo`03001oogoo05Uoo`8000Qoo`800:=oo`005Goo0P00FWoo0P00
[Goo000EOol00`00Oomoo`1FOol20008Ool2002VOol001Eoo`03001oogoo05Aoo`@000Qoo`800:Io
o`000Woo0P0017oo00<007ooOol00Woo0`001Goo00<007ooOol0E7oo0P00/Woo00001Goo001oogoo
00002Goo00<007ooOol017oo00<007ooOol0DGoo0P00]Goo00001Goo001oogoo00002Goo00<007oo
Ool017oo0`00DGoo0P002goo0P00Z7oo00001Goo001oogoo00002Goo00<007ooOol017oo00<007oo
Ool0GWoo0P00Z7oo00001Goo001oogoo00002Goo00<007ooOol017oo00<007ooOol0CWoo0P00^7oo
00001Goo001oogoo000027oo0P001Woo00<007ooOol0CWoo0P00^7oo0002Ool2000:Ool00`00Oomo
o`04Ool00`00Oomoo`1<Ool2002jOol001Eoo`8004eoo`8000eoo`800:]oo`005Goo00<007ooOol0
BGoo0P0047oo0P00Zgoo000EOol00`00Oomoo`19Ool2002mOol001Eoo`03001oogoo0?moo`Uoo`00
5Goo00<007ooOol0Agoo0P0047oo0P00[Goo000EOol20018Ool2000@Ool2002]Ool001Eoo`03001o
ogoo04Aoo`800<9oo`005Goo00<007ooOol0A7oo0P00`Woo000EOol00`00Oomoo`3oOol9Ool001Eo
o`03001oogoo049oo`80019oo`800;1oo`005Goo0P00@goo0P004Woo0P00/7oo000EOol00`00Oomo
o`3oOol9Ool001Eoo`03001oogoo03moo`800<Moo`005Goo00<007ooOol0?goo0P00agoo000EOol0
0`00Oomoo`0lOol2003:Ool001Eoo`8003eoo`8001Ioo`800;9oo`005Goo00<007ooOol0E7oo0P00
/Woo000EOol00`00Oomoo`0jOol2003<Ool0009oo`8000Aoo`04001oogooOol50004Ool00`00Oomo
o`0jOol2003<Ool00005Ool007ooOol00008Ool01000Oomoo`0017oo00<007ooOol0ogoo2Goo0000
1Goo001oogoo00002Goo00<007ooOol017oo0`00=goo0P0067oo0P00]Goo00001Goo001oogoo0000
2Woo00<007ooOol00goo00<007ooOol0=goo0P0067oo0P00]Goo00001Goo001oogoo00001goo00D0
07ooOomoo`0000Aoo`03001oogoo0?moo`Uoo`0000Eoo`00Oomoo`0000Moo`05001oogooOol00004
Ool00`00Oomoo`0eOol2003AOol0009oo`8000Uoo`<000Eoo`03001oogoo03Eoo`800=5oo`005Goo
0P00Cgoo0P00^7oo000EOol00`00Oomoo`0bOol2000JOol2002hOol001Eoo`03001oogoo039oo`80
0=Aoo`005Goo00<007ooOol0<7oo0P00eWoo000EOol00`00Oomoo`0`Ool2003FOol001Eoo`800?mo
o`Yoo`005Goo00<007ooOol0;Goo0P007Goo0P00^Woo000EOol00`00Oomoo`0]Ool2000MOol2002j
Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0:goo0P00fgoo000EOol2000/Ool2003K
Ool001Eoo`03001oogoo04Uoo`800;eoo`005Goo00<007ooOol0:7oo0P007goo0P00_Goo000EOol0
0`00Oomoo`0XOol2003NOol001Eoo`03001oogoo02Eoo`800>5oo`005Goo0P009Woo0P00hGoo000E
Ool00`00Oomoo`17Ool2002oOol001Eoo`03001oogoo02=oo`80029oo`800;moo`000Woo0P0017oo
00<007ooOol00Woo0`001Goo00<007ooOol08goo0P00hgoo00001Goo001oogoo00001goo00D007oo
Oomoo`0000Aoo`03001oogoo0?moo`Uoo`0000Eoo`00Oomoo`0000]oo`03001oogoo009oo`<0021o
o`800>Ioo`0000Eoo`00Oomoo`0000Uoo`8000Eoo`03001oogoo021oo`80029oo`800<9oo`0000Eo
o`00Oomoo`0000]oo`03001oogoo009oo`03001oogoo01ioo`8002Aoo`800<9oo`0000Eoo`00Oomo
o`0000Moo`05001oogooOol00004Ool00`00Oomoo`0NOol2003XOol0009oo`8000Uoo`<000Eoo`03
001oogoo01]oo`800>]oo`005Goo0P0077oo0P009Goo0P00a7oo000EOol00`00Oomoo`12Ool20034
Ool001Eoo`03001oogoo01Uoo`800>eoo`005Goo00<007ooOol06Goo0P00kGoo000EOol00`00Oomo
o`0FOol2003`Ool001Eoo`8001Moo`8002Moo`800<Moo`005Goo00<007ooOol04goo0P00:Woo0P00
agoo000EOol00`00Oomoo`0COol2003cOol001Eoo`03001oogoo015oo`8002Uoo`800<Yoo`005Goo
00<007ooOol04Goo0P00:Goo0P00bWoo000EOol2000?Ool2003hOol001Eoo`03001oogoo00ioo`80
0?Qoo`005Goo00<007ooOol037oo0P00;7oo0P00c7oo000EOol00`00Oomoo`0<Ool2000/Ool2003<
Ool001Eoo`03001oogoo00Uoo`800?eoo`005Goo0P0027oo1000;7oo0P00cgoo000EOol00`00Oomo
o`07Ool2000^Ool2003?Ool001Eoo`03001oogoo00Aoo`800?moo`=oo`000Woo0P0017oo00<007oo
Ool00goo0`0017oo00@007ooOomoo`800003Ool0000002moo`800=5oo`0000Eoo`00Oomoo`0000Yo
o`03001oogoo00=oo`04001oogooOol2000bOol2003AOol00005Ool007ooOol00007Ool50004Ool4
003oOol8Ool00005Ool007ooOol00007Ool01000Oomoo`001Goo00@007oo0000035oo`800=Aoo`00
00Eoo`00Oomoo`0000Qoo`03001oo`0000Eoo`03001oogoo039oo`800=Aoo`0000Eoo`00Oomoo`00
00Uoo`8000Eoo`03001oogoo0?moo`Uoo`000Woo0P002goo00<007ooOol00goo00<007ooOol0<7oo
0P00eWoo000EOol2000aOol2003FOol001Eoo`03001oogoo02eoo`800=Uoo`005Goo00<007ooOol0
;Goo0P00fGoo000EOol00`00Oomoo`0[Ool2003KOol001Eoo`03001oogoo02]oo`800=]oo`005Goo
0P00:Goo0P00gWoo000EOol00`00Oomoo`0UOol200000goo0000003NOol001Eoo`03001oogoo02Eo
o`800>5oo`005Goo00<007ooOol08goo0P00hgoo000EOol00`00Oomoo`0POol200000goo0000003S
Ool001Eoo`8001moo`@00>Ioo`005Goo00<007ooOol06goo0P0000=oo`000000j7oo000EOol00`00
Oomoo`0IOol4003[Ool001Eoo`03001oogoo01Ioo`800003Ool000000>eoo`005Goo00<007ooOol0
4Goo100000=oo`000000l7oo000EOol2000=Ool400000goo00000002003cOol001Eoo`03001oogoo
00Moo`@00003Ool0000000800?Qoo`005Goo00<007oo00000`0000Aoo`00001oo`@00?eoo`000Woo
0P0017oo00<007ooOol00Woo0`001Goo00<007oo00000`0000=oo`000000ogoo0goo00001Goo001o
ogoo00001goo00D007ooOomoo`0000Aoo`03001oogoo0?moo`Uoo`0000Eoo`00Oomoo`0000]oo`03
001oogoo009oo`<00?moo`Uoo`0000Eoo`00Oomoo`0000]oo`03001oogoo009oo`03001oogoo0?mo
o`Uoo`0000Eoo`00Oomoo`0000Moo`@000Eoo`04001oo`00003oOol8Ool00005Ool007ooOol00007
Ool00`00Oomoo`06Ool00`00Ool00003000017oo000007oo100000=oo`0000000P0000=oo`000000
0P0000Aoo`00001oo`@00>]oo`000Woo0P0027oo1@0017oo00@007ooOomoo`800004Ool00000Ool4
00000goo0000000200000goo00000002000017oo000007oo100000=oo`0000000P0000=oo`000000
0P0000Aoo`00001oo`@00003Ool0000000800=Aoo`005Goo0P007goo100000=oo`0000000P0000Ao
o`00001oo`@00003Ool0000000800003Ool0000000800003Ool0000000800004Ool00000Ool40032
Ool001Eoo`03001oogoo03Eoo`@00003Ool0000000800004Ool00000Ool400000goo000000020000
0goo00000002000017oo000007oo0P00/Woo000EOol00`00Oomoo`17Ool400000goo000000020000
17oo000007oo100000=oo`0000000P0000=oo`0000000P00YWoo000EOol00`00Oomoo`1FOol20000
0goo0000000200000goo00000002000017oo000007oo100000=oo`0000000P00VGoo000EOol00`00
Oomoo`1SOol200000goo0000000200000goo0000000200000goo0000000200000goo00000002002?
Ool001Eoo`80075oo`@00003Ool0000000800004Ool00000Ool400000goo00000024Ool001Eoo`03
001oogoo07Yoo`800003Ool0000000800003Ool0000000800003Ool00000008007eoo`005Goo00<0
07ooOol0Q7oo0P0000=oo`0000000P0000Aoo`00001oo`@00003Ool00000079oo`005Goo00<007oo
Ool0S7oo0P0000=oo`0000000P0000=oo`0000000P0000=oo`0000000P00Jgoo000EOol00`00Oomo
o`2FOol200000goo00000002000017oo000007oo1000Hgoo000EOol2002OOol200000goo00000002
00000goo00000002001NOol001Eoo`03001oogoo0:Ioo`@00003Ool0000000800003Ool0000005Io
o`005Goo00<007ooOol0Zgoo100000=oo`0000000P0000=oo`000000DGoo000EOol00`00Oomoo`2b
Ool2000017oo000007oo1000C7oo000EOol00`00Oomoo`2hOol400000goo0000000200000goo0000
0014Ool001Eoo`800;ioo`@00003Ool0000000800003Ool0000003moo`005Goo00<007ooOol0a7oo
0P0000Aoo`00001oo`8003aoo`005Goo00<007ooOol0bWoo100000=oo`000000=goo0002Ool20004
Ool00`00Oomoo`02Ool30005Ool00`00Oomoo`3<Ool200000goo0000000200000goo0000000bOol0
0005Ool007ooOol00007Ool01@00Oomoogoo000017oo00<007ooOol0dGoo0P0000=oo`0000000P00
00=oo`000000;Goo00001Goo001oogoo00001goo00D007ooOomoo`0000Aoo`<00=Ioo`800004Ool0
0000Ool2000ZOol00005Ool007ooOol00007Ool40005Ool00`00Oomoo`3LOol400000goo0000000U
Ool00005Ool007ooOol00007Ool00`00Oomoo`06Ool00`00Oomoo`3NOol200000goo000000020000
0goo0000000POol00005Ool007ooOol00008Ool00`00Oomoo`05Ool00`00Oomoo`3SOol200000goo
00000002000NOol0009oo`8000Yoo`8000Eoo`03001oogoo0>Qoo`800003Ool0000001]oo`005Goo
0P00k7oo0P0000=oo`0000000P005Woo000EOol00`00Oomoo`3^Ool400000goo0000000COol001Eo
o`03001oogoo0?=oo`@00003Ool0000000ioo`005Goo00<007ooOol0mGoo0P0000=oo`0000000P00
37oo000EOol00`00Oomoo`3jOol200000goo00000009Ool001Eoo`800?ioo`@000Moo`005Goo00<0
07ooOol0ogoo0P001goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo
00<007ooOol0ogoo2Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-8.34219, -0.0502976, \
0.389783, 0.00399338}}]
}, Closed]],

Cell["\<\
This stores genotype frequencies in popNew[{0.1,0.2,0.05},pop][t], \
every 10 generations:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(StoreExact[popNew[{0.1, 0.2, 0.05}, pop], pop, 
        w[{0.1, 0.2, 0.05}, het], 0, {100, 10}];\)\)], "Input",
  CellLabel->"In[56]:=  (20:10:02 on 4/30/01)"],

Cell[CellGroupData[{

Cell[BoxData[
    \(?? popNew\)], "Input",
  CellLabel->"In[57]:=  (20:10:15 on 4/30/01)"],

Cell[BoxData[
    \("Global`popNew"\)], "Print",
  CellLabel->"From In[57]:=  (20:10:15 on 4/30/01)"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(\(popNew[{0.1`, 0.2`, 0.05`}, 
                        AlleleFrequencies[{0.4`, 0.49`, 0.51`}, 100]]\)[0] = 
                    AlleleFrequencies[{0.4`, 0.49`, 0.51`}, 100]\)},
                {" "},
                {\(\(popNew[{0.1`, 0.2`, 0.05`}, 
                        AlleleFrequencies[{0.4`, 0.49`, 0.51`}, 100]]\)[10] = 
                    AlleleFrequencies[{0.3272882387196337`, 
                        0.46879731146973463`, 0.513459404498749`}, 100]\)},
                {" "},
                {\(\(popNew[{0.1`, 0.2`, 0.05`}, 
                        AlleleFrequencies[{0.4`, 0.49`, 0.51`}, 100]]\)[20] = 
                    AlleleFrequencies[{0.22322115262457207`, 
                        0.4047507663375704`, 0.5180667731622366`}, 100]\)},
                {" "},
                {\(\(popNew[{0.1`, 0.2`, 0.05`}, 
                        AlleleFrequencies[{0.4`, 0.49`, 0.51`}, 100]]\)[30] = 
                    AlleleFrequencies[{0.11621435107798272`, 
                        0.24365387699609084`, 0.524071533307078`}, 100]\)},
                {" "},
                {\(\(popNew[{0.1`, 0.2`, 0.05`}, 
                        AlleleFrequencies[{0.4`, 0.49`, 0.51`}, 100]]\)[40] = 
                    AlleleFrequencies[{0.048088810684695664`, 
                        0.05988227476573517`, 0.5315449253309524`}, 100]\)},
                {" "},
                {\(\(popNew[{0.1`, 0.2`, 0.05`}, 
                        AlleleFrequencies[{0.4`, 0.49`, 0.51`}, 100]]\)[50] = 
                    AlleleFrequencies[{0.01781837746390674`, 
                        0.007147472846785924`, 0.5407617595090011`}, 100]\)},
                {" "},
                {\(\(popNew[{0.1`, 0.2`, 0.05`}, 
                        AlleleFrequencies[{0.4`, 0.49`, 0.51`}, 100]]\)[60] = 
                    AlleleFrequencies[{0.006258261522545135`, 
                        0.0007309284338244116`, 0.552440068157628`}, 100]\)},
                {" "},
                {\(\(popNew[{0.1`, 0.2`, 0.05`}, 
                        AlleleFrequencies[{0.4`, 0.49`, 0.51`}, 100]]\)[70] = 
                    AlleleFrequencies[{0.0021488820770889073`, 
                        0.00007366269425145896`, 0.5673240360982361`}, 
                      100]\)},
                {" "},
                {\(\(popNew[{0.1`, 0.2`, 0.05`}, 
                        AlleleFrequencies[{0.4`, 0.49`, 0.51`}, 100]]\)[80] = 
                    AlleleFrequencies[{0.0007319044763851365`, 
                        7.424227137588317`*^-6, 0.5862198219459513`}, 
                      100]\)},
                {" "},
                {\(\(popNew[{0.1`, 0.2`, 0.05`}, 
                        AlleleFrequencies[{0.4`, 0.49`, 0.51`}, 100]]\)[90] = 
                    AlleleFrequencies[{0.00024866698722255504`, 
                        7.491993107352931`*^-7, 0.6100034948749833`}, 
                      100]\)},
                {" "},
                {\(\(popNew[{0.1`, 0.2`, 0.05`}, 
                        AlleleFrequencies[{0.4`, 0.49`, 0.51`}, 100]]\)[
                      100] = AlleleFrequencies[{0.00008445868725408022`, 
                        7.573041217982908`*^-8, 0.6395155793945129`}, 100]\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ popNew],
      Editable->False]], "Print",
  CellLabel->"From In[57]:=  (20:10:15 on 4/30/01)"]
}, Closed]],

Cell["\<\
Storing large numbers of genotypes in every generation would waste \
memory.  \
\>", "Text"],

Cell["\<\
It is useful to store results in the form popNew[pars] so that \
results for different parameter sets can be kept tidily.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Immigration into one deme", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, 
              m]\), \(allows\ for\ immigration\ from\ a\ source\ of\ the\ \
same\ size, \ \ fixed\ for\ \(\({1, 1  \[Ellipsis]}\)\(.\)\(\ \)\)\)},
          {\(IterateExact[\[Psi], W, m, 
              FixedEnds -> {\[Psi]\_s}]\), \(allows\ for\ immigration\ from\ \
a\ source\ \[Psi]\_s\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->"IterateExact"],

Cell[TextData[{
  "This represents additive selection ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Sigma]\_i\)\(\ \)\(for\ '\) \(1'\)\(\ \
\)\)\)]],
  "alleles: "
}], "MathCaption"],

Cell[BoxData[
    \(\(\(w[\[Sigma]_List, add]\)[
          p_List] := {1 + \[Sigma] . \((2  p - 1)\), \[Sigma]};\)\)], "Input",\

  CellLabel->"In[2]:=  (21:03:50 on 5/2/01)"],

Cell[TextData[{
  "Fitnesses at each locus are ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(1 - \(\(\[Sigma]\_i\) : \(1 : 
            1 + \[Sigma]\_i\)\)\)\(,\)\(\ \)\(and\)\(\ \)\)\)]],
  " mean fitness is ",
  Cell[BoxData[
      \(TraditionalForm\`W\&_ = 
        1 + \[Sum]\+i\( \[Sigma]\_i\) \((p\_i - q\_i)\)\)]]
}], "Text"],

Cell["\<\
This shows the allele frequency at three loci, with selection \
s={-0.05,-0.1,-0.2} against '1' alleles, and immigration at 10% from a source \
fixed for '1':\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pop = AlleleFrequencies[{0, 0, 0}, 100];\)\), "\n", 
    \(\(StoreExact[pop[{\(-0.05\), \(-0.1\), \(-0.2\)}, 0.1, pop], pop, 
        w[{\(-0.05\), \(-0.1\), \(-0.2\)}, add], 0.1, {100, 10}];\)\), "\n", 
    \(\(pt[i_] := 
        Table[{t, \(AlleleFrequencyTable[\(pop[{\(-0.05\), \(-0.1\), \
\(-0.2\)}, 0.1, pop]\)[t]]\)\[LeftDoubleBracket]i\[RightDoubleBracket]}, {t, 
            0, 100, 10}];\)\), "\n", 
    \(\(DisplayTogether @@ 
        Table[ListPlot[pt[i], PlotJoined -> True], {i, 3}];\)\)}], "Input",
  CellLabel->"In[99]:=  (7:14:11 on 5/1/01)"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0147151 0.590429 [
[.21429 .00222 -6 -9 ]
[.21429 .00222 6 0 ]
[.40476 .00222 -6 -9 ]
[.40476 .00222 6 0 ]
[.59524 .00222 -6 -9 ]
[.59524 .00222 6 0 ]
[.78571 .00222 -6 -9 ]
[.78571 .00222 6 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .1328 -18 -4.5 ]
[.01131 .1328 0 4.5 ]
[.01131 .25089 -18 -4.5 ]
[.01131 .25089 0 4.5 ]
[.01131 .36897 -18 -4.5 ]
[.01131 .36897 0 4.5 ]
[.01131 .48706 -18 -4.5 ]
[.01131 .48706 0 4.5 ]
[.01131 .60514 -6 -4.5 ]
[.01131 .60514 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(20)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(40)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(60)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(80)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(100)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .1328 m
.03006 .1328 L
s
[(0.2)] .01131 .1328 1 0 Mshowa
.02381 .25089 m
.03006 .25089 L
s
[(0.4)] .01131 .25089 1 0 Mshowa
.02381 .36897 m
.03006 .36897 L
s
[(0.6)] .01131 .36897 1 0 Mshowa
.02381 .48706 m
.03006 .48706 L
s
[(0.8)] .01131 .48706 1 0 Mshowa
.02381 .60514 m
.03006 .60514 L
s
[(1)] .01131 .60514 1 0 Mshowa
.125 Mabswid
.02381 .04424 m
.02756 .04424 L
s
.02381 .07376 m
.02756 .07376 L
s
.02381 .10328 m
.02756 .10328 L
s
.02381 .16232 m
.02756 .16232 L
s
.02381 .19184 m
.02756 .19184 L
s
.02381 .22137 m
.02756 .22137 L
s
.02381 .28041 m
.02756 .28041 L
s
.02381 .30993 m
.02756 .30993 L
s
.02381 .33945 m
.02756 .33945 L
s
.02381 .39849 m
.02756 .39849 L
s
.02381 .42802 m
.02756 .42802 L
s
.02381 .45754 m
.02756 .45754 L
s
.02381 .51658 m
.02756 .51658 L
s
.02381 .5461 m
.02756 .5461 L
s
.02381 .57562 m
.02756 .57562 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.11905 .35911 L
.21429 .48089 L
.30952 .53676 L
.40476 .56588 L
.5 .58207 L
.59524 .59141 L
.69048 .5969 L
.78571 .60017 L
.88095 .60213 L
.97619 .60332 L
s
.02381 .01472 m
.11905 .31899 L
.21429 .41447 L
.30952 .45977 L
.40476 .48631 L
.5 .50381 L
.59524 .51625 L
.69048 .52555 L
.78571 .53275 L
.88095 .5385 L
.97619 .54319 L
s
.02381 .01472 m
.11905 .24412 L
.21429 .27754 L
.30952 .28014 L
.40476 .27735 L
.5 .27447 L
.59524 .27232 L
.69048 .2708 L
.78571 .26973 L
.88095 .26894 L
.97619 .26834 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[99]:=  (7:14:12 on 5/1/01)",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0012Ool5
0003Ool2000/Ool30003Ool2000ZOol30004Ool2000ZOol30004Ool2000XOol30004Ool20004Ool2
0003Ool004=oo`04001oogoo0002Ool01000Oomoo`00;7oo00D007ooOomoo`00009oo`03001oogoo
02Ioo`05001oogooOol00002Ool01000Oomoo`00:7oo00D007ooOomoo`00009oo`04001oogoo000X
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0009oo`00A7oo00<007ooOol00Woo00@0
07ooOol002Uoo`D0009oo`04001oogoo000XOol01@00Oomoogoo00000Woo00@007ooOol002Qoo`05
001oogooOol00002Ool01000Oomoo`00:7oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool004Eoo`05001oogooOol00002Ool00`00Oomoo`0WOol01000Oomoo`000goo00@007ooOol0
02Qoo`@000=oo`04001oogoo000YOol30003Ool01000Oomoo`00:7oo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0002Ool0049oo`05001oogooOol00002Ool01000Oomoo`00:Woo00<007oo
00000goo00@007ooOol002Qoo`03001oogoo00Aoo`04001oogoo000XOol01@00Oomoogoo00000Woo
00@007ooOol002Qoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo0012Ool01@00
Oomoogoo00000Woo00@007ooOol002]oo`8000=oo`04001oogoo000YOol00`00Oomoo`03Ool01000
Oomoo`00:7oo00D007ooOomoo`00009oo`04001oogoo000WOol20004Ool01000Oomoo`000Woo00@0
07ooOol0009oo`00@goo0`0017oo0P00;Goo00<007ooOol00Woo0P00:goo0P0017oo0P00:Woo0`00
17oo0P00:Goo00<007ooOol00goo0P0017oo0P000goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03
001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool000ioool0
010000=oo`005Goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo
00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo
00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo
00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo
00<007ooOol02Woo00<007ooOol01goo000EOol2000aOol00`00Oomoo`0aOol00`00Oomoo`0`Ool0
0`00Oomoo`0`Ool00`00Oomoo`0aOol00`00Oomoo`07Ool001Eoo`800?moo`Yoo`005Goo0P00ogoo
2Woo000EOol3003oOol9Ool001Eoo`03001oo`000?moo`Uoo`005Goo00@007oo00000?moo`Qoo`00
5Goo1000ogoo27oo000EOol00`00Ool00002003oOol7Ool001Eoo`03001oogoo00800?moo`Moo`00
5Goo00<007ooOol00P00ogoo1goo000EOol00`00Oomoo`03003oOol6Ool001Eoo`03001oogoo00<0
0?moo`Ioo`005Goo00L007ooOomoo`00Ool0003oOol5Ool001Eoo`04001oogooOol3003oOol5Ool0
01Eoo`80009oo`800003Ool007oo0?moo`=oo`005Goo00<007ooOol00Woo00<007oo0000ogoo17oo
000EOol00`00Oomoo`02Ool3003oOol4Ool001Eoo`03001oogoo009oo`800003Ool007oo0?moo`9o
o`005Goo00<007ooOol00Woo0P0000=oo`00Ool0ogoo0Woo000EOol00`00Oomoo`03Ool200000goo
001oo`3oOol1Ool001Eoo`03001oogoo00=oo`800003Ool007oo0?moo`5oo`005Goo00<007ooOol0
0goo0P0000=oo`00Ool0ogoo0Goo000EOol20005Ool01000Oomoo`00ogoo0Goo000EOol00`00Oomo
o`04Ool200000goo001oo`3oOol001Eoo`03001oogoo00Aoo`80009oo`03001oogoo0?eoo`005Goo
00<007ooOol017oo0P000Woo00<007ooOol0oGoo000EOol00`00Oomoo`05Ool20002Ool00`00Oomo
o`3lOol001Eoo`03001oogoo00Eoo`80009oo`03001oogoo0?aoo`000Woo0P0017oo00@007ooOomo
o`D000Aoo`03001oogoo00Eoo`80009oo`03001oogoo0?aoo`0000Eoo`00Oomoo`0000Qoo`04001o
ogoo0004Ool00`00Oomoo`06Ool20002Ool00`00Oomoo`3kOol00005Ool007ooOol00009Ool00`00
Oomoo`04Ool30006Ool20002Ool00`00Oomoo`3kOol00005Ool007ooOol0000:Ool00`00Oomoo`03
Ool00`00Oomoo`06Ool20003Ool00`00Oomoo`3jOol00005Ool007ooOol00007Ool01@00Oomoogoo
000017oo00<007ooOol01Woo00<007oo00000Woo00<007ooOol0nWoo00001Goo001oogoo00001goo
00D007ooOomoo`0000Aoo`03001oogoo00Moo`80009oo`03001oogoo0?Yoo`000Woo0P002Goo0`00
1Goo00<007ooOol01goo0P000goo00<007ooOol0nGoo000EOol00`00Oomoo`07Ool00`00Ool00002
Ool00`00Oomoo`3iOol001Eoo`03001oogoo00Moo`03001oo`0000=oo`03001oogoo0?Qoo`005Goo
00<007ooOol027oo0P000goo00<007ooOol0n7oo000EOol20009Ool00`00Ool00003Ool00`00Oomo
o`3gOol001Eoo`03001oogoo00Qoo`03001oo`0000=oo`03001oogoo0?Moo`005Goo00<007ooOol0
2Goo0P000goo00<007ooOol0mgoo000EOol00`00Oomoo`09Ool20004Ool00`00Oomoo`3fOol001Eo
o`03001oogoo00Uoo`03001oo`0000=oo`03001oogoo0?Ioo`005Goo00<007ooOol02Goo00<007oo
000017oo00<007ooOol0mGoo000EOol00`00Oomoo`0:Ool20004Ool00`00Oomoo`3eOol001Eoo`03
001oogoo00Yoo`03001oo`0000Aoo`03001oogoo0?Aoo`005Goo0P002goo00<007oo000017oo00<0
07ooOol0m7oo000EOol00`00Oomoo`0;Ool20004Ool00`00Oomoo`3dOol001Eoo`03001oogoo00]o
o`03001oo`0000Aoo`03001oogoo0?=oo`005Goo00<007ooOol02goo00<007oo000017oo00<007oo
Ool0lgoo000EOol00`00Oomoo`0;Ool00`00Ool00005Ool00`00Oomoo`3bOol001Eoo`03001oogoo
00aoo`03001oo`0000Aoo`03001oogoo0?9oo`005Goo00<007ooOol037oo00<007oo000017oo00<0
07ooOol0lWoo000EOol00`00Oomoo`0<Ool00`00Ool00005Ool00`00Oomoo`3aOol001Eoo`8000io
o`03001oo`0000Aoo`03001oogoo0?5oo`005Goo00<007ooOol03Goo00<007oo00001Goo00<007oo
Ool0l7oo000EOol00`00Oomoo`0=Ool00`00Ool00005Ool00`00Oomoo`3`Ool001Eoo`03001oogoo
00eoo`04001oogoo0005Ool00`00Oomoo`3_Ool001Eoo`03001oogoo00ioo`03001oo`0000Eoo`03
001oogoo0>moo`005Goo00<007ooOol03Woo00<007oo00001Goo00<007ooOol0kgoo0002Ool20004
Ool00`00Oomoo`03Ool30004Ool00`00Oomoo`0>Ool01000Oomoo`001Goo0P00kgoo00001Goo001o
ogoo00002Woo00<007ooOol00goo00<007ooOol03Woo00@007ooOol000Moo`<00>aoo`0000Eoo`00
Oomoo`0000Moo`D000Aoo`<000moo`03001oo`0000Yoo`<00>Uoo`0000Eoo`00Oomoo`0000Moo`04
001oogoo0005Ool00`00Oomoo`0?Ool00`00Ool0000=Ool3003VOol00005Ool007ooOol00008Ool0
0`00Ool00005Ool00`00Oomoo`0?Ool01000Oomoo`003goo0`00hgoo00001Goo001oogoo00002Goo
0P001Goo00<007ooOol047oo00<007oo00004Woo0P00hGoo0002Ool2000;Ool00`00Oomoo`03Ool0
0`00Oomoo`0@Ool00`00Ool0000DOol3003NOol001Eoo`03001oogoo011oo`04001oogoo000FOol3
001gOomK0009Ool001Eoo`03001oogoo011oo`04001oogoo000IOol30011Oolc001TOol001Eoo`03
001oogoo015oo`03001oo`0001aoo`h001UooaX009Moo`005Goo0P004Woo00@007ooOol002UooaT0
0;5oo`005Goo00<007ooOol04Goo00@007ooOol00?=oo`005Goo00<007ooOol04Woo00<007oo0000
lgoo000EOol00`00Oomoo`0BOol01000Oomoo`00lWoo000EOol00`00Oomoo`0BOol01000Oomoo`00
lWoo000EOol00`00Oomoo`0BOol01000Oomoo`00lWoo000EOol00`00Oomoo`0COol01000Oomoo`00
lGoo000EOol00`00Oomoo`0COol01000Oomoo`00lGoo000EOol2000DOol01000Oomoo`00lGoo000E
Ool00`00Oomoo`0DOol01000Oomoo`00l7oo000EOol00`00Oomoo`0DOol01000Oomoo`00l7oo000E
Ool00`00Oomoo`0DOol01000Oomoo`00l7oo000EOol00`00Oomoo`0DOol01@00Oomoogoo0000kgoo
000EOol00`00Oomoo`0EOol01@00Oomoogoo0000kWoo000EOol00`00Oomoo`0EOol00`00Oomoo`02
Ool00`00Oomoo`3[Ool001Eoo`03001oogoo01Eoo`03001oogoo00=oo`03001oogoo0>Yoo`005Goo
0P005Woo00<007ooOol017oo00<007ooOol0jGoo000EOol00`00Oomoo`0FOol00`00Oomoo`04Ool0
0`00Oomoo`3XOol001Eoo`03001oogoo01Ioo`03001oogoo00Eoo`03001oogoo0>Moo`005Goo00<0
07ooOol05Woo00<007ooOol01Woo00<007ooOol0iWoo000EOol00`00Oomoo`0GOol00`00Oomoo`06
Ool00`00Oomoo`3UOol0009oo`8000Aoo`03001oogoo009oo`<000Eoo`03001oogoo01Moo`03001o
ogoo00Moo`03001oogoo0>Aoo`0000Eoo`00Oomoo`0000Moo`05001oogooOol00004Ool00`00Oomo
o`0GOol00`00Oomoo`08Ool00`00Oomoo`3SOol00005Ool007ooOol00007Ool01@00Oomoogoo0000
17oo00<007ooOol067oo00<007ooOol027oo00<007ooOol0hWoo00001Goo001oogoo00001goo1000
1Goo0`006Goo00<007ooOol027oo00<007ooOol0hGoo00001Goo001oogoo00001goo00<007ooOol0
1Woo00<007ooOol06Woo00<007ooOol027oo00<007ooOol0h7oo00001Goo001oogoo000027oo00<0
07ooOol01Goo00<007ooOol06Woo00<007ooOol02Goo00<007ooOol0ggoo0002Ool2000:Ool20005
Ool00`00Oomoo`0KOol00`00Oomoo`09Ool00`00Oomoo`3NOol001Eoo`03001oogoo01aoo`03001o
ogoo00Uoo`03001oogoo0=eoo`005Goo00<007ooOol07Goo00<007ooOol02Goo00<007ooOol0g7oo
000EOol00`00Oomoo`0MOol00`00Oomoo`0:Ool00`00Oomoo`3KOol001Eoo`03001oogoo01ioo`03
001oogoo00Yoo`03001oogoo0=Yoo`005Goo0P0087oo00<007ooOol02Woo00<007ooOol0fGoo000E
Ool00`00Oomoo`0POol00`00Oomoo`0:Ool00`00Oomoo`3HOol001Eoo`03001oogoo021oo`03001o
ogoo00]oo`03001oogoo0=Moo`005Goo00<007ooOol08Goo00<007ooOol02goo00<007ooOol0eWoo
000EOol00`00Oomoo`0ROol00`00Oomoo`0;Ool2003FOol001Eoo`03001oogoo02=oo`03001oogoo
00aoo`800=Aoo`005Goo00<007ooOol097oo00<007ooOol03Goo0P00dWoo000EOol00`00Oomoo`0T
Ool00`00Oomoo`0?Ool3003?Ool001Eoo`8002Ioo`03001oogoo015oo`800<eoo`005Goo00<007oo
Ool09Woo00<007ooOol04Woo0P00bgoo000EOol00`00Oomoo`0WOol00`00Oomoo`0COol20039Ool0
01Eoo`03001oogoo02Moo`03001oogoo01Eoo`800<Moo`005Goo00<007ooOol0:7oo00<007ooOol0
5Woo0P00aGoo000EOol00`00Oomoo`0YOol00`00Oomoo`0GOol30032Ool001Eoo`03001oogoo02Yo
o`03001oogoo01Uoo`800<1oo`005Goo00<007ooOol0:Woo00<007ooOol06goo0P00_Woo000EOol2
000/Ool00`00Oomoo`0LOol3002kOol001Eoo`03001oogoo02aoo`03001oogoo01ioo`@00;Moo`00
5Goo00<007ooOol0;Goo00<007ooOol08Goo0`00]7oo000EOol00`00Oomoo`0]Ool00`00Oomoo`0T
Ool4002`Ool001Eoo`03001oogoo02ioo`03001oogoo02Moo`@00:aoo`000Woo0P0017oo00<007oo
Ool00Woo0`001Goo00<007ooOol0;goo00<007ooOol0:Woo0`00ZGoo00001Goo001oogoo00001goo
00D007ooOomoo`0000Aoo`03001oogoo031oo`8002eoo`@00:Eoo`0000Eoo`00Oomoo`0000Moo`05
001oogooOol00004Ool00`00Oomoo`0bOol2000_Ool5002POol00005Ool007ooOol00008Ool30005
Ool3000dOol00`00Oomoo`0aOol5002KOol00005Ool007ooOol00007Ool01@00Oomoogoo000017oo
00<007ooOol0=Goo0P00=Woo1@00UWoo00001Goo001oogoo00001goo00D007ooOomoo`0000Aoo`03
001oogoo03Moo`8003Uoo`D0095oo`000Woo0P002Goo0`001Goo00<007ooOol0>Goo0P00?7oo1@00
S7oo000EOol00`00Oomoo`0kOol00`00Oomoo`0nOol50027Ool001Eoo`03001oogoo03aoo`8004=o
o`L0081oo`005Goo00<007ooOol0?Woo0P00B7oo1P00NWoo000EOol00`00Oomoo`10Ool00`00Oomo
o`1;Ool7001cOol001Eoo`80049oo`80059oo`X006Uoo`005Goo00<007ooOol0@goo0P00FWoo3@00
G7oo000EOol00`00Oomoo`15Ool2001UOol<001@Ool001Eoo`03001oogoo04Moo`03001oogoo06io
o`d004=oo`005Goo00<007ooOol0B7oo0P00Ngoo3@00=Woo000EOol00`00Oomoo`1:Ool30025Ool=
000YOol001Eoo`03001oogoo04eoo`<008mooa<001Ioo`005Goo00<007ooOol0D7oo0`00Wgoo3@00
2Goo000EOol2001DOol3002bOol001Eoo`03001oogoo05Ioo`@00:ioo`005Goo00<007ooOol0FWoo
0`00Zgoo000EOol00`00Oomoo`1MOol3002XOol001Eoo`03001oogoo061oo`<00:Eoo`005Goo00<0
07ooOol0Hgoo1@00X7oo000EOol00`00Oomoo`1XOol6002JOol001Eoo`03001oogoo06ioo`L009=o
o`005Goo0P00MWoo1P00SGoo000EOol00`00Oomoo`1kOol70026Ool001Eoo`03001oogoo089oo`T0
07eoo`005Goo00<007ooOol0Rgoo2@00M7oo000EOol00`00Oomoo`2DOolA001SOol000eoo`<000Eo
o`03001oogoo0:EooaX004Uoo`003Woo00<007ooOol017oo00<007ooOol0_goo6@00<7oo000>Ool0
0`00Oomoo`04Ool00`00Oomoo`3HOolW0009Ool000ioo`03001oogoo00Aoo`<00?moo`Uoo`003Woo
00<007ooOol017oo00<007ooOol0ogoo2Goo000=Ool20006Ool00`00Oomoo`3oOol9Ool000ioo`03
001oogoo00Aoo`03001oogoo0?moo`Uoo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-8.32696, -0.0807933, \
0.389667, 0.00628545}}]
}, Closed]],

Cell[TextData[{
  "A stable equilibrium is reached at p=0.43 for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Sigma]\_i = 0.2\)\(,\)\(\ \)\)\)]],
  "but migration swamps selection at the two more weakly selected loci."
}], "Text"],

Cell[TextData[{
  ButtonBox["Note",
    ButtonData:>{"Potential problems", "Redefining fitness"},
    ButtonStyle->"AddOnsLink"],
  ": ",
  StyleBox["Unlike the other representations, ",
    FontWeight->"Plain"],
  StyleBox["results are not stored by IterateExact when AlleleFrequencies are \
modelled.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell["IterateExact can be used to find algebraic solutions:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(newP = \(AlleleFrequencyTable[
            IterateExact[AlleleFrequencies[{p}, 100], w[{\[Sigma]}, add], 
              m]]\)\[LeftDoubleBracket]1\[RightDoubleBracket] // 
        Simplify\)], "Input",
  CellLabel->"In[86]:=  (7:10:38 on 5/1/01)"],

Cell[BoxData[
    \(\(-\(\(\((m\ \((\(-1\) + p)\) - p)\)\ \((\(-1\) + 
                m\ \((\(-1\) + p)\)\ \[Sigma] - 
                p\ \[Sigma])\)\)\/\(\(-1\) + \((1 + 2\ m\ \((\(-1\) + p)\) - 
                  2\ p)\)\ \[Sigma]\)\)\)\)], "Output",
  CellLabel->"Out[86]=  (7:10:38 on 5/1/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(soln = Solve[p == newP, p] // Simplify\)], "Input",
  CellLabel->"In[83]:=  (7:09:58 on 5/1/01)"],

Cell[BoxData[
    \({{p \[Rule] 
          1}, {p \[Rule] \(m\ \((1 + m\ \[Sigma])\)\)\/\(\((\(-1\) + m\^2)\)\ \
\[Sigma]\)}}\)], "Output",
  CellLabel->"Out[83]=  (7:09:58 on 5/1/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(p /. soln\) /. {m -> 0.1, \[Sigma] -> \(-0.2\)}\)], "Input",
  CellLabel->"In[94]:=  (7:13:36 on 5/1/01)"],

Cell[BoxData[
    \({1, 0.494949494949495`}\)], "Output",
  CellLabel->"Out[94]=  (7:13:36 on 5/1/01)"]
}, Closed]],

Cell[TextData[{
  "With one locus, and  m<s, there is one stable equilibrium at approximately \
",
  Cell[BoxData[
      \(TraditionalForm\`\(m\/s\) . \ \ In\ the\ example\ above, 
      with\ three\ loci, \ the\ equilibrium\ is\)]],
  " somewhat lower.   This is because mean fitness is reduced by selection at \
the other two loci, which makes selection coefficients ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          RowBox[{\((s\_i = \[Sigma]\_i\/W\&_)\), " ", \(stronger . \ \ If\), 
            
            ButtonBox[\(\(\ \)\(genotype\ frequencies\)\),
              
              ButtonData:>{"Recursions: iterating one deme", 
                "Immigration example"},
              ButtonStyle->"AddOnsLink"], " ", "were", " ", "followed"}], ",",
           " ", \(\(there\)\(\ \)\(would\)\(\ \)\(be\)\(\ \)\(an\)\(\ \
\)\(additional\)\(\ \)\(effect\)\(\ \)\(from\)\(\ \)\)}], TraditionalForm]]],
  "positive linkage disequilibria, which assist selection."
}], "Text"],

Cell[TextData[{
  "Note:  ",
  StyleBox["If the option ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(FixedEnds -> {\[Psi]\_s}\ \ is\ used\ to\ specify\ a\ \
source\ population, \ 
          this\ is\ passed\ directly\ to\ MigrateExact . \ \ Thus, \ 
          even\ if\ selection\ in\ the\ target\ deme\ acts\ before\ migration\
\ \((MigrationOrder \[Rule] USM)\), \ 
          the\ source\ population\ is\ assumed\ not\ to\ be\ affected\ by\ \(\
\(selection\)\(.\)\)\),
          FontWeight->"Plain"], TraditionalForm]]]
}], "Text",
  FontWeight->"Bold"]
}, Closed]],

Cell[CellGroupData[{

Cell["Compiling", "SubsubsectionIcon",
  CellTags->"Compiling"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, m, 
              Compiled -> 
                True]\), \(\(uses\)\(\ \)\(compiled\)\(\ \)\(code\)\(\ \)\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->"IterateExact"],

Cell[TextData[{
  "Functions can be greatly speeded by ",
  ButtonBox["compiling",
    ButtonData:>{"Compile"},
    ButtonStyle->"RefGuideLink"],
  ".  This requires that only numbers, or rectangular arrays of numbers, are \
used internally.  However, an arbitrary fitness function can still be \
supplied.  When a population is represented by allele frequencies, compiled \
code must be generated and stored for each fitness function.  (In contrast, \
with other representations, a table of individual fitnesses is passed to a \
standard piece of compiled code).  Thus, compiled code should ",
  StyleBox["not",
    FontWeight->"Bold"],
  " be used if the fitness function keeps changing - too much memory will \
then be used. Another ",
  ButtonBox["potential problem",
    ButtonData:>{"Potential problems", "AlleleFrequencies"},
    ButtonStyle->"AddOnsLink"],
  " is that if the same name is used for different fitness functions, code \
appropriate to the old name will be used. "
}], "Text"],

Cell["With 3 loci, compiled code saves little time:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(w[\[Sigma]_List, add]\)[
          p_List] := {1 + \[Sigma] . \((2  p - 
                  1)\), \[Sigma]};\)\), "\[IndentingNewLine]", 
    \({Timing[
        Nest[IterateExact[#, w[{\(-0.05\), \(-0.1\), \(-0.2\)}, add], 
              0.01] &, AlleleFrequencies[{0, 0, 0}, 1], 1000]], 
      Timing[Nest[
          IterateExact[#, w[{\(-0.05\), \(-0.1\), \(-0.2\)}, add], 0.01, 
              Compiled -> True] &, AlleleFrequencies[{0, 0, 0}, 1], 
          1000]]}\)}], "Input",
  CellLabel->"In[16]:=  (21:11:30 on 5/2/01)"],

Cell[BoxData[
    \({{4.78333333333336`\ Second, 
        AlleleFrequencies[{0.24963924963922976`, 0.11976911976912032`, 
            0.054834054834054964`}, 1.`]}, {4.283333333333303`\ Second, 
        AlleleFrequencies[{0.24963924963922976`, 0.11976911976912032`, 
            0.054834054834054964`}, 1.`]}}\)], "Output",
  CellLabel->"Out[17]=  (21:11:39 on 5/2/01)"]
}, Closed]],

Cell["More time is saved with large numbers of loci:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Timing[\(Nest[IterateExact[#, w[\[Sigma]list, add], 0.01] &, 
            AlleleFrequencies[plist, 1], 
            100];\)], \[IndentingNewLine]Timing[\(Nest[
            IterateExact[#, w[\[Sigma]list, add], 0.01, Compiled -> True] &, 
            AlleleFrequencies[plist, 1], 100];\)]}\)], "Input",
  CellLabel->"In[14]:=  (21:11:01 on 5/2/01)"],

Cell[BoxData[
    \({{4.449999999999989`\ Second, Null}, {0.8833333333333258`\ Second, 
        Null}}\)], "Output",
  CellLabel->"Out[15]=  (21:11:10 on 5/2/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Varying deme size", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, m, 
              DemeSize -> F]\), \(changes\ deme\ size\ to\ F[n, W\&_]\)},
          {\(IterateExact[\[Psi], W, m, 
              DemeSize -> {r, \[Beta], \[Gamma], \[Lambda]}]\), \(changes\ \
deme\ size\ to\ r\ \(n\^\(1 - \[Gamma]\)\) \(W\&_\^\(1 - \[Beta]\)\) 
              Exp[\(-\[Lambda]\)\[VeryThinSpace]n]; \ 
            can\ be\ used\ with\ Compiled \[Rule] True\)},
          {\(\(ExponentialF[r, \[Beta], \[Lambda]]\)[n, 
              W\&_]\), \(represents\ r\[VeryThinSpace]n\[VeryThinSpace]\(W\&_\
\^\[Beta]\) Exp[\(-\[Lambda]\)\[VeryThinSpace]n]\)},
          {\(\(PowerF[r, \[Beta], \[Lambda]]\)[n, 
              W\&_]\), \(represents\ r\[VeryThinSpace]n\^\(1 - \[Lambda]\)\
\[VeryThinSpace]W\&_\^\[Beta]\)},
          {\(StoreExact[\[Psi], \[Psi]\_0, W, m, {t, dt}, 
              DemeSize -> 
                F]\), \(stores\ results\ in\ \[Psi]\ for\ t\ generations\ at\ \
intervals\ dt\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->"DemeSize"],

Cell["\<\
This uses ExponentialF to set deme size to decrease with density \
and increase with mean fitness, and iterates for 100 generations:\
\>", \
"MathCaption"],

Cell[BoxData[{
    \(\(\(w[\[Sigma]_List, add]\)[
          p_List] := {1 + \[Sigma] . \((2  p - 
                  1)\), \[Sigma]};\)\), "\[IndentingNewLine]", 
    \(\(pop = AlleleFrequencies[{0.001, 0.01, 0.1}, 1];\)\), "\n", 
    \(\(StoreExact[\[Psi], pop, w[{0.1, 0.1, 0.1}, add], 0, {100, 1}, 
        DemeSize -> ExponentialF[2, 1, 1]];\)\)}], "Input",
  CellLabel->"In[31]:=  (16:28:08 on 5/1/01)"],

Cell["\<\
There is 10% selection for '1' allele s at each of 3 loci; initial \
frequencies are {0.001, 0.01, 0.1}.\
\>", "Text"],

Cell["This plots deme size and allele frequencies:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tn = Table[{t, DemeSize[\[Psi][t]]}, {t, 0, 100}];\)\), "\n", 
    \(\(tp = 
        Table[AlleleFrequencyTable[\[Psi][t]], {t, 100}] // 
          Transpose;\)\), "\n", 
    \(\(tw = 
        Table[MeanW[\[Psi][t], w[{0.1, 0.1, 0.1}, add]], {t, 
            100}];\)\), "\[IndentingNewLine]", 
    \(\(Show[
        GraphicsArray[{DisplayTogether[
              ListPlot[tn, PlotJoined -> True], \[IndentingNewLine]ListPlot[
                tw, PlotJoined -> True, 
                PlotStyle -> Red], \[IndentingNewLine]ListPlot[Log[2  tw], 
                PlotJoined -> True, PlotStyle -> Dashing[{0.05, 0.05}]], 
              PlotRange -> {{0, 100}, {0, 1.6}}], 
            DisplayTogether @@ 
              MapThread[
                ListPlot[#1, PlotJoined -> True, 
                    PlotStyle -> #2] &, {tp, {Red, Green, 
                    Blue}}]}]];\)\)}], "Input",
  CellLabel->"In[47]:=  (16:31:13 on 5/1/01)"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.01 0 0.386271 [
[.2 -0.0125 -6 -9 ]
[.2 -0.0125 6 0 ]
[.4 -0.0125 -6 -9 ]
[.4 -0.0125 6 0 ]
[.6 -0.0125 -6 -9 ]
[.6 -0.0125 6 0 ]
[.8 -0.0125 -6 -9 ]
[.8 -0.0125 6 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[-0.0125 .07725 -18 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -18 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -18 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38627 -6 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -18 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(20)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(40)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(60)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(80)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(100)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07725 m
.00625 .07725 L
s
[(0.2)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(0.4)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(0.6)] -0.0125 .23176 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.8)] -0.0125 .30902 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(1)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(1.2)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(1.4)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1.6)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01931 m
.00375 .01931 L
s
0 .03863 m
.00375 .03863 L
s
0 .05794 m
.00375 .05794 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .13519 m
.00375 .13519 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .32833 m
.00375 .32833 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .40558 m
.00375 .40558 L
s
0 .4249 m
.00375 .4249 L
s
0 .44421 m
.00375 .44421 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .52147 m
.00375 .52147 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .38627 m
.01 .20525 L
.02 .17494 L
.03 .16196 L
.04 .1558 L
.05 .15306 L
.06 .15229 L
.07 .15274 L
.08 .15401 L
.09 .15587 L
.1 .15816 L
.11 .16079 L
.12 .1637 L
.13 .16684 L
.14 .17019 L
.15 .17369 L
.16 .17734 L
.17 .1811 L
.18 .18495 L
.19 .18885 L
.2 .1928 L
.21 .19676 L
.22 .20071 L
.23 .20465 L
.24 .20855 L
.25 .21241 L
.26 .21623 L
.27 .21998 L
.28 .22369 L
.29 .22733 L
.3 .23093 L
.31 .23447 L
.32 .23796 L
.33 .24141 L
.34 .24481 L
.35 .24817 L
.36 .25149 L
.37 .25478 L
.38 .25802 L
.39 .26122 L
.4 .26438 L
.41 .2675 L
.42 .27057 L
.43 .2736 L
.44 .27657 L
.45 .2795 L
.46 .28237 L
.47 .2852 L
.48 .28797 L
.49 .29068 L
Mistroke
.5 .29334 L
.51 .29595 L
.52 .29851 L
.53 .30102 L
.54 .30348 L
.55 .3059 L
.56 .30826 L
.57 .31059 L
.58 .31287 L
.59 .31511 L
.6 .3173 L
.61 .31946 L
.62 .32157 L
.63 .32364 L
.64 .32567 L
.65 .32766 L
.66 .3296 L
.67 .33149 L
.68 .33334 L
.69 .33513 L
.7 .33688 L
.71 .33857 L
.72 .34021 L
.73 .34179 L
.74 .34332 L
.75 .34479 L
.76 .3462 L
.77 .34755 L
.78 .34884 L
.79 .35008 L
.8 .35126 L
.81 .35238 L
.82 .35344 L
.83 .35445 L
.84 .35541 L
.85 .35631 L
.86 .35717 L
.87 .35797 L
.88 .35873 L
.89 .35944 L
.9 .36011 L
.91 .36074 L
.92 .36132 L
.93 .36187 L
.94 .36238 L
.95 .36286 L
.96 .36331 L
.97 .36373 L
.98 .36412 L
.99 .36448 L
Mistroke
1 .36482 L
Mfstroke
1 0 0 r
.01 .28004 m
.02 .28124 L
.03 .28256 L
.04 .28401 L
.05 .2856 L
.06 .28733 L
.07 .2892 L
.08 .29122 L
.09 .29339 L
.1 .2957 L
.11 .29815 L
.12 .30073 L
.13 .30343 L
.14 .30625 L
.15 .30916 L
.16 .31215 L
.17 .31521 L
.18 .31833 L
.19 .32149 L
.2 .32468 L
.21 .32789 L
.22 .3311 L
.23 .33432 L
.24 .33753 L
.25 .34073 L
.26 .34392 L
.27 .34709 L
.28 .35025 L
.29 .3534 L
.3 .35654 L
.31 .35967 L
.32 .36279 L
.33 .3659 L
.34 .369 L
.35 .3721 L
.36 .37519 L
.37 .37827 L
.38 .38134 L
.39 .3844 L
.4 .38744 L
.41 .39046 L
.42 .39346 L
.43 .39644 L
.44 .39939 L
.45 .4023 L
.46 .40519 L
.47 .40805 L
.48 .41087 L
.49 .41366 L
.5 .41641 L
Mistroke
.51 .41913 L
.52 .42182 L
.53 .42447 L
.54 .42709 L
.55 .42967 L
.56 .43223 L
.57 .43475 L
.58 .43725 L
.59 .43971 L
.6 .44214 L
.61 .44453 L
.62 .44689 L
.63 .44922 L
.64 .45151 L
.65 .45375 L
.66 .45596 L
.67 .45812 L
.68 .46023 L
.69 .46229 L
.7 .4643 L
.71 .46625 L
.72 .46815 L
.73 .46998 L
.74 .47175 L
.75 .47346 L
.76 .47511 L
.77 .47669 L
.78 .4782 L
.79 .47965 L
.8 .48103 L
.81 .48235 L
.82 .4836 L
.83 .48479 L
.84 .48592 L
.85 .48698 L
.86 .48799 L
.87 .48894 L
.88 .48984 L
.89 .49068 L
.9 .49147 L
.91 .49221 L
.92 .49291 L
.93 .49356 L
.94 .49417 L
.95 .49474 L
.96 .49527 L
.97 .49577 L
.98 .49623 L
.99 .49666 L
1 .49706 L
Mistroke
Mfstroke
0 g
[ .05 .05 ] 0 setdash
.01 .14352 m
.02 .14517 L
.03 .14697 L
.04 .14895 L
.05 .1511 L
.06 .15344 L
.07 .15595 L
.08 .15864 L
.09 .1615 L
.1 .16453 L
.11 .16772 L
.12 .17105 L
.13 .1745 L
.14 .17807 L
.15 .18172 L
.16 .18545 L
.17 .18922 L
.18 .19302 L
.19 .19684 L
.2 .20065 L
.21 .20445 L
.22 .20822 L
.23 .21195 L
.24 .21564 L
.25 .21928 L
.26 .22288 L
.27 .22643 L
.28 .22993 L
.29 .23339 L
.3 .2368 L
.31 .24018 L
.32 .24351 L
.33 .24681 L
.34 .25008 L
.35 .25331 L
.36 .2565 L
.37 .25966 L
.38 .26278 L
.39 .26587 L
.4 .26891 L
.41 .27191 L
.42 .27487 L
.43 .27778 L
.44 .28064 L
.45 .28345 L
.46 .28622 L
.47 .28893 L
.48 .29159 L
.49 .2942 L
.5 .29676 L
Mistroke
.51 .29928 L
.52 .30175 L
.53 .30417 L
.54 .30654 L
.55 .30888 L
.56 .31117 L
.57 .31341 L
.58 .31562 L
.59 .31779 L
.6 .31992 L
.61 .32201 L
.62 .32405 L
.63 .32606 L
.64 .32802 L
.65 .32994 L
.66 .33181 L
.67 .33364 L
.68 .33541 L
.69 .33714 L
.7 .33881 L
.71 .34043 L
.72 .342 L
.73 .34351 L
.74 .34497 L
.75 .34636 L
.76 .3477 L
.77 .34899 L
.78 .35021 L
.79 .35138 L
.8 .35249 L
.81 .35355 L
.82 .35455 L
.83 .3555 L
.84 .35639 L
.85 .35724 L
.86 .35804 L
.87 .35879 L
.88 .35949 L
.89 .36016 L
.9 .36078 L
.91 .36136 L
.92 .36191 L
.93 .36242 L
.94 .3629 L
.95 .36334 L
.96 .36376 L
.97 .36414 L
.98 .3645 L
.99 .36484 L
1 .36515 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0147151 0.588814 [
[.21429 .00222 -6 -9 ]
[.21429 .00222 6 0 ]
[.40476 .00222 -6 -9 ]
[.40476 .00222 6 0 ]
[.59524 .00222 -6 -9 ]
[.59524 .00222 6 0 ]
[.78571 .00222 -6 -9 ]
[.78571 .00222 6 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .13248 -18 -4.5 ]
[.01131 .13248 0 4.5 ]
[.01131 .25024 -18 -4.5 ]
[.01131 .25024 0 4.5 ]
[.01131 .368 -18 -4.5 ]
[.01131 .368 0 4.5 ]
[.01131 .48577 -18 -4.5 ]
[.01131 .48577 0 4.5 ]
[.01131 .60353 -6 -4.5 ]
[.01131 .60353 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(20)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(40)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(60)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(80)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(100)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13248 m
.03006 .13248 L
s
[(0.2)] .01131 .13248 1 0 Mshowa
.02381 .25024 m
.03006 .25024 L
s
[(0.4)] .01131 .25024 1 0 Mshowa
.02381 .368 m
.03006 .368 L
s
[(0.6)] .01131 .368 1 0 Mshowa
.02381 .48577 m
.03006 .48577 L
s
[(0.8)] .01131 .48577 1 0 Mshowa
.02381 .60353 m
.03006 .60353 L
s
[(1)] .01131 .60353 1 0 Mshowa
.125 Mabswid
.02381 .04416 m
.02756 .04416 L
s
.02381 .0736 m
.02756 .0736 L
s
.02381 .10304 m
.02756 .10304 L
s
.02381 .16192 m
.02756 .16192 L
s
.02381 .19136 m
.02756 .19136 L
s
.02381 .2208 m
.02756 .2208 L
s
.02381 .27968 m
.02756 .27968 L
s
.02381 .30912 m
.02756 .30912 L
s
.02381 .33856 m
.02756 .33856 L
s
.02381 .39744 m
.02756 .39744 L
s
.02381 .42688 m
.02756 .42688 L
s
.02381 .45633 m
.02756 .45633 L
s
.02381 .51521 m
.02756 .51521 L
s
.02381 .54465 m
.02756 .54465 L
s
.02381 .57409 m
.02756 .57409 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.03333 .01539 m
.04286 .01548 L
.05238 .01558 L
.0619 .0157 L
.07143 .01583 L
.08095 .01599 L
.09048 .01616 L
.1 .01635 L
.10952 .01656 L
.11905 .01681 L
.12857 .01708 L
.1381 .01738 L
.14762 .01773 L
.15714 .01811 L
.16667 .01853 L
.17619 .01901 L
.18571 .01953 L
.19524 .02012 L
.20476 .02077 L
.21429 .02149 L
.22381 .02228 L
.23333 .02316 L
.24286 .02414 L
.25238 .02521 L
.2619 .02639 L
.27143 .02768 L
.28095 .02911 L
.29048 .03067 L
.3 .03238 L
.30952 .03425 L
.31905 .0363 L
.32857 .03853 L
.3381 .04097 L
.34762 .04362 L
.35714 .04649 L
.36667 .04961 L
.37619 .05299 L
.38571 .05665 L
.39524 .06059 L
.40476 .06484 L
.41429 .06942 L
.42381 .07432 L
.43333 .07958 L
.44286 .08521 L
.45238 .09121 L
.4619 .0976 L
.47143 .10439 L
.48095 .11159 L
.49048 .1192 L
.5 .12722 L
Mistroke
.50952 .13566 L
.51905 .14452 L
.52857 .15379 L
.5381 .16345 L
.54762 .17351 L
.55714 .18393 L
.56667 .19471 L
.57619 .20581 L
.58571 .21721 L
.59524 .22889 L
.60476 .24079 L
.61429 .25289 L
.62381 .26515 L
.63333 .27753 L
.64286 .28998 L
.65238 .30245 L
.6619 .31492 L
.67143 .32733 L
.68095 .33963 L
.69048 .3518 L
.7 .36379 L
.70952 .37556 L
.71905 .38709 L
.72857 .39834 L
.7381 .40929 L
.74762 .41991 L
.75714 .43018 L
.76667 .44009 L
.77619 .44963 L
.78571 .45878 L
.79524 .46755 L
.80476 .47592 L
.81429 .48391 L
.82381 .4915 L
.83333 .49871 L
.84286 .50555 L
.85238 .51201 L
.8619 .51812 L
.87143 .52388 L
.88095 .5293 L
.89048 .5344 L
.9 .53919 L
.90952 .54368 L
.91905 .54789 L
.92857 .55182 L
.9381 .55551 L
.94762 .55895 L
.95714 .56216 L
.96667 .56515 L
.97619 .56794 L
Mistroke
Mfstroke
0 1 0 r
.03333 .02141 m
.04286 .02232 L
.05238 .02335 L
.0619 .02452 L
.07143 .02583 L
.08095 .0273 L
.09048 .02896 L
.1 .03082 L
.10952 .0329 L
.11905 .03521 L
.12857 .0378 L
.1381 .04067 L
.14762 .04386 L
.15714 .04739 L
.16667 .05128 L
.17619 .05556 L
.18571 .06027 L
.19524 .06542 L
.20476 .07104 L
.21429 .07716 L
.22381 .0838 L
.23333 .09099 L
.24286 .09873 L
.25238 .10705 L
.2619 .11596 L
.27143 .12547 L
.28095 .13557 L
.29048 .14626 L
.3 .15752 L
.30952 .16934 L
.31905 .1817 L
.32857 .19455 L
.3381 .20784 L
.34762 .22155 L
.35714 .23559 L
.36667 .24992 L
.37619 .26446 L
.38571 .27915 L
.39524 .2939 L
.40476 .30866 L
.41429 .32333 L
.42381 .33786 L
.43333 .35217 L
.44286 .36621 L
.45238 .37991 L
.4619 .39323 L
.47143 .40612 L
.48095 .41854 L
.49048 .43047 L
.5 .44188 L
Mistroke
.50952 .45275 L
.51905 .46309 L
.52857 .47288 L
.5381 .48214 L
.54762 .49085 L
.55714 .49904 L
.56667 .50672 L
.57619 .51391 L
.58571 .52062 L
.59524 .52688 L
.60476 .5327 L
.61429 .53812 L
.62381 .54314 L
.63333 .5478 L
.64286 .55212 L
.65238 .55611 L
.6619 .55981 L
.67143 .56322 L
.68095 .56637 L
.69048 .56928 L
.7 .57196 L
.70952 .57444 L
.71905 .57672 L
.72857 .57882 L
.7381 .58076 L
.74762 .58255 L
.75714 .58419 L
.76667 .58571 L
.77619 .5871 L
.78571 .58839 L
.79524 .58957 L
.80476 .59067 L
.81429 .59167 L
.82381 .5926 L
.83333 .59345 L
.84286 .59423 L
.85238 .59496 L
.8619 .59563 L
.87143 .59624 L
.88095 .59681 L
.89048 .59733 L
.9 .59781 L
.90952 .59825 L
.91905 .59866 L
.92857 .59904 L
.9381 .59939 L
.94762 .59971 L
.95714 .60001 L
.96667 .60028 L
.97619 .60053 L
Mistroke
Mfstroke
0 0 1 r
.03333 .08093 m
.04286 .08904 L
.05238 .09796 L
.0619 .10773 L
.07143 .11838 L
.08095 .12994 L
.09048 .1424 L
.1 .15575 L
.10952 .16998 L
.11905 .18503 L
.12857 .20084 L
.1381 .21733 L
.14762 .2344 L
.15714 .25193 L
.16667 .2698 L
.17619 .28786 L
.18571 .30599 L
.19524 .32402 L
.20476 .34184 L
.21429 .35931 L
.22381 .37631 L
.23333 .39275 L
.24286 .40854 L
.25238 .4236 L
.2619 .4379 L
.27143 .4514 L
.28095 .46407 L
.29048 .47591 L
.3 .48694 L
.30952 .49716 L
.31905 .5066 L
.32857 .5153 L
.3381 .52328 L
.34762 .5306 L
.35714 .53729 L
.36667 .54339 L
.37619 .54895 L
.38571 .55401 L
.39524 .5586 L
.40476 .56277 L
.41429 .56655 L
.42381 .56998 L
.43333 .57309 L
.44286 .5759 L
.45238 .57845 L
.4619 .58075 L
.47143 .58284 L
.48095 .58473 L
.49048 .58644 L
.5 .58799 L
Mistroke
.50952 .58939 L
.51905 .59066 L
.52857 .59182 L
.5381 .59286 L
.54762 .59381 L
.55714 .59467 L
.56667 .59545 L
.57619 .59616 L
.58571 .5968 L
.59524 .59738 L
.60476 .59792 L
.61429 .5984 L
.62381 .59884 L
.63333 .59924 L
.64286 .5996 L
.65238 .59993 L
.6619 .60024 L
.67143 .60051 L
.68095 .60076 L
.69048 .60099 L
.7 .6012 L
.70952 .6014 L
.71905 .60157 L
.72857 .60173 L
.7381 .60188 L
.74762 .60201 L
.75714 .60214 L
.76667 .60225 L
.77619 .60235 L
.78571 .60245 L
.79524 .60253 L
.80476 .60261 L
.81429 .60269 L
.82381 .60275 L
.83333 .60281 L
.84286 .60287 L
.85238 .60292 L
.8619 .60297 L
.87143 .60301 L
.88095 .60306 L
.89048 .60309 L
.9 .60313 L
.90952 .60316 L
.91905 .60319 L
.92857 .60321 L
.9381 .60324 L
.94762 .60326 L
.95714 .60328 L
.96667 .6033 L
.97619 .60332 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[47]:=  (16:31:16 on 5/1/01)",
  ImageSize->{532.188, 156.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008D0000W1000`40O003h00Oogooogoo5Woo003o
OoooOolFOol00?mooomooaIoo`00ogooogoo5Woo003oOoooOolFOol00?mooomooaIoo`00AWoo1@00
0goo0P008Woo0`000goo0P008Goo0`0017oo0P008Goo0`0017oo0P007Woo0`0017oo0P0017oo0P00
Dgoo1@000goo0P008Woo0`000goo0P008Goo0`0017oo0P008Goo0`0017oo0P007Woo0`0017oo0P00
17oo0P004Goo0017Ool01000Oomoo`000Woo00@007ooOol0029oo`05001oogooOol00002Ool00`00
Oomoo`0MOol01@00Oomoogoo00000Woo00@007ooOol001moo`05001oogooOol00002Ool01000Oomo
o`007Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo001COol01000Oomoo`000Woo00@0
07ooOol0029oo`05001oogooOol00002Ool00`00Oomoo`0MOol01@00Oomoogoo00000Woo00@007oo
Ool001moo`05001oogooOol00002Ool01000Oomoo`007Woo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo000@Ool004Qoo`03001oogoo009oo`04001oogoo000OOol50002Ool01000Oomoo`00
7goo00D007ooOomoo`00009oo`04001oogoo000OOol01@00Oomoogoo00000Woo00@007ooOol001io
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00E7oo00<007ooOol00Woo00@007ooOol0
01moo`D0009oo`04001oogoo000OOol01@00Oomoogoo00000Woo00@007ooOol001moo`05001oogoo
Ool00002Ool01000Oomoo`007Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo000@Ool0
04Uoo`05001oogooOol00002Ool00`00Oomoo`0MOol01000Oomoo`000goo00@007ooOol001moo`@0
00=oo`04001oogoo000POol30003Ool01000Oomoo`007Woo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo001EOol01@00Oomoogoo00000Woo00<007ooOol07Goo00@007ooOol000=oo`04001o
ogoo000OOol40003Ool01000Oomoo`0087oo0`000goo00@007ooOol001ioo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`0047oo0016Ool01@00Oomoogoo00000Woo00@007ooOol0021oo`03
001oo`0000=oo`04001oogoo000OOol00`00Oomoo`04Ool01000Oomoo`007goo00D007ooOomoo`00
009oo`04001oogoo000NOol00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0059oo`05001o
ogooOol00002Ool01000Oomoo`0087oo00<007oo00000goo00@007ooOol001moo`03001oogoo00Ao
o`04001oogoo000OOol01@00Oomoogoo00000Woo00@007ooOol001ioo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`0047oo0016Ool01@00Oomoogoo00000Woo00@007ooOol0025oo`8000=o
o`04001oogoo000POol00`00Oomoo`03Ool01000Oomoo`007goo00D007ooOomoo`00009oo`04001o
ogoo000MOol20004Ool01000Oomoo`000Woo00@007ooOol0059oo`05001oogooOol00002Ool01000
Oomoo`008Goo0P000goo00@007ooOol0021oo`03001oogoo00=oo`04001oogoo000OOol01@00Oomo
ogoo00000Woo00@007ooOol001eoo`8000Aoo`04001oogoo0002Ool01000Oomoo`0047oo0017Ool3
0004Ool2000SOol00`00Oomoo`02Ool2000ROol20004Ool2000QOol30004Ool2000OOol00`00Oomo
o`03Ool20004Ool2001DOol30004Ool2000SOol00`00Oomoo`02Ool2000ROol20004Ool2000QOol3
0004Ool2000OOol00`00Oomoo`03Ool20004Ool2000AOol00?moob]oo`03001oogoo0>Moo`00ogoo
:goo00<007ooOol0igoo003oOol[Ool00`00Oomoo`3WOol0029oom<0031oomd0019oo`008Woo00<0
07ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<0
07ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<0
07ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<0
07ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<0
07ooOol0<goo00<007ooO0008G`01Woo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo
00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo
00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo
00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol05Goo000ROol00`00Oomo
o`0WOol00`00Oomoo`0WOol00`00Oomoo`0WOol00`00Oomoo`0WOol00`00Oomoo`0WOol00`00Oomo
o`0cOol00`00Ool3h0050n0LOol<O00TOol00`00Oomoo`0WOol00`00Oomoo`0WOol00`00Oomoo`0W
Ool00`00Oomoo`0EOol0029oo`03001oogoo0?moo`Ioo`03001oogoo00Eoo`L3h25oo`Ul0;5oo`00
8Woo0P00ogoo1goo00<007ooOol037oo1P?P97oo1W`0Zgoo000ROol00`00Oomoo`3oOol6Ool00`00
Oomoo`0BOol20n0XOol4O02WOol0029oo`03001oogoo0?moo`Ioo`03001oogoo01Aoo`@3h2Qoo`Al
0:=oo`008Woo00<007ooOol0ogoo1Woo0P006Goo0P?P:Woo17`0Wgoo000ROol00`00Oomoo`3oOol6
Ool00`00Oomoo`0JOol20n0/Ool2O02MOol0029oo`800?moo`Moo`03001oogoo01aoo`@3h2Yoo`=l
09Yoo`008Woo00<007ooOol0ogoo1Woo00<007ooOol087oo00<3h7ooOol0:Woo0W`0V7oo000ROol0
0`00Oomoo`3oOol6Ool00`00Oomoo`0QOol20n0/Ool2O02FOol0029oo`03001oogoo0?moo`Ioo`03
001oogoo02=oo`83h2aoo`9l09Aoo`008Woo0P00ogoo1goo0P009Woo0P?P;7oo0W`0TWoo000?Ool2
0004Ool01000Oomoogoo1@0017oo00<007ooOol0ogoo1Woo00<007ooOol09goo00<3h7ooOol0:goo
0W`0T7oo000>Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo0?moo`Ioo`03001oo`0O
02Qoo`030n1oogoo02aoo`9l08ioo`003Woo00@007ooOol000Uoo`03001oogoo00Aoo`03001oogoo
0?moo`Ioo`04001oogoo01lXOol20n0^Ool2O02<Ool000ioo`04001oogoo000:Ool00`00Oomoo`03
Ool2003oOol7Ool01@00Oomoogoo01l0:Goo00<3h7ooOol0;Goo00=l07ooOol0RGoo000>Ool01000
Oomoo`001goo00D007ooOomoo`0000Aoo`03001oogoo0?moo`Ioo`03001oogoo009oo`0301moogoo
02Moo`030n1oogoo02eoo`03O01oogoo08Qoo`003Woo00@007ooOol000Moo`05001oogooOol00004
Ool00`00Oomoo`3oOol6Ool00`00Oomoo`03Ool00`0OOomoo`0WOol00`?POomoo`0]Ool2O028Ool0
00moo`8000Uoo`<000Eoo`03001oogoo0?moo`Ioo`8000Eoo`0301moogoo02Moo`030n1oogoo02io
o`9l08Ioo`008Woo0P00ogoo1goo00<007ooOol01Goo00<07gooOol09goo00<3h7ooOol0;goo00=l
07ooOol0Pgoo000ROol00`00Oomoo`3oOol6Ool00`00Oomoo`06Ool00`0OOomoo`0WOol00`?POomo
o`0_Ool00g`0Oomoo`22Ool0029oo`03001oogoo0?moo`Ioo`03001oogoo00Moo`0301moogoo02Mo
o`030n1oogoo02moo`03O01oogoo085oo`008Woo00<007ooOol0lWoo0P0017oo00@007ooOomoo`D0
00Aoo`03001oogoo00Moo`0301moogoo02Qoo`030n1oogoo02moo`9l085oo`008Woo0P00lWoo00@0
07ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`08Ool00`0OOomoo`0XOol20n0aOol00g`0Oomo
o`1nOol0029oo`03001oogoo0?5oo`04001oogoo0009Ool00`00Oomoo`04Ool2000:Ool00`0OOomo
o`0YOol00`?POomoo`0_Ool00g`0Oomoo`1mOol0029oo`03001oogoo0?5oo`04001oogoo000:Ool0
0`00Oomoo`03Ool00`00Oomoo`0:Ool00`0OOomoo`0YOol00`?POomoo`0_Ool00g`0Oomoo`1lOol0
029oo`03001oogoo0?5oo`04001oogoo0007Ool01@00Oomoogoo000017oo00<007ooOol02goo00<0
7gooOol0:Goo00<3h7ooOol0;goo00=l07ooOol0Ngoo000ROol2003bOol01000Oomoo`001goo00D0
07ooOomoo`0000Aoo`03001oogoo00aoo`0301moogoo02Uoo`030n1oogoo02moo`03O01oogoo07Yo
o`003goo0P0017oo00<007ooOol00goo0`0017oo00<007ooOol0lWoo0P002Goo0`001Goo00<007oo
Ool037oo00<07gooOol0:Goo00<3h7ooOol0<7oo00=l07ooOol0NGoo000>Ool01000Oomoo`002Woo
00<007ooOol00goo00<007oo00001@00ogoo0Goo00<007ooOol03Goo00<07gooOol0:Goo00<3h7oo
Ool0<7oo00=l07ooOol0N7oo000>Ool01000Oomoo`001goo1@0017oo00<007ooOol01Goo0P000Woo
1@00mgoo00<007ooOol03Woo00<07gooOol0:Goo00<3h7ooOol0<7oo00=l07ooOol0Mgoo000>Ool0
1000Oomoo`001goo00@007ooOol000Eoo`8000Eoo`D000Eoo`@00?=oo`8000moo`0301moogoo02Uo
o`030n1oogoo035oo`03O01oogoo07Ioo`003Woo00@007ooOol000Qoo`03001oo`0000Eoo`03001o
ogoo00=oo`03001oogoo00aoo`@00>moo`03001oogoo00moo`0301moogoo02Uoo`030n1oogoo035o
o`03O01oogoo07Eoo`003Woo00@007ooOol000Uoo`8000Eoo`03001oogoo00=oo`03001oogoo00]o
o`<0009oo`@00>]oo`03001oogoo011oo`0301moogoo02Uoo`030n1oogoo035oo`03O01oogoo07Ao
o`003goo0P002goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol03goo10000Woo0`00j7oo
00<007ooOol047oo00<07gooOol0:Woo00<3h7ooOol0<7oo00=l07ooOol0M7oo000ROol20002Ool0
0`00Oomoo`0DOol20003Ool2003VOol00`00Oomoo`0AOol00`0OOomoo`0ZOol00`?POomoo`0`Ool0
0g`0Oomoo`1cOol0029oo`05001oogooOol0000HOol20003Ool4003ROol00`00Oomoo`0BOol00`0O
Oomoo`0YOol00`?POomoo`0aOol00g`0Oomoo`1bOol0029oo`05001oogooOol0000QOol2003POol2
000COol00`0OOomoo`0ZOol00`?POomoo`0aOol00g`0Oomoo`1aOol0029oo`04001oogoo000TOol2
003NOol00`00Oomoo`0COol00`0OOomoo`0ZOol00`?POomoo`0aOol00g`0Oomoo`1`Ool0029oo`80
0003Ool007oo02Eoo`800=aoo`03001oogoo01=oo`0301moogoo02Yoo`030n1oogoo039oo`03O01o
ogoo06moo`008Woo00@007ooOol002=oo`<0009oo`800=Yoo`03001oogoo01Aoo`0301moogoo02Yo
o`030n1oogoo039oo`03O01oogoo06ioo`008Woo00<007oo00009goo2000eWoo00<007ooOol057oo
00<07gooOol0:goo00<3h7ooOol0<Woo00=l07ooOol0KGoo000ROol00`00Ool0000[Ool20002Ool3
003COol00`00Oomoo`0EOol00`0OOomoo`0ZOol00`?POomoo`0cOol00g`0Oomoo`1/Ool0029oo`<0
02eoo`8000=oo`800=5oo`03001oogoo01Ioo`0301moogoo02Yoo`030n1oogoo03=oo`03O01oogoo
06]oo`008Woo00<007oo0000=7oo0P00cgoo0P005goo00<07gooOol0:goo00<3h7ooOol0<Woo00=l
07ooOol0Jgoo000?Ool20004Ool00`00Oomoo`02Ool30005Ool00`00Ool0000fOol4003;Ool00`00
Oomoo`0GOol00`0OOomoo`0ZOol00`?POomoo`0cOol00g`0Oomoo`1ZOol000ioo`04001oogoo0007
Ool01@00Oomoogoo000017oo00<007oo0000>Woo0P00bGoo00<007ooOol05goo00<07gooOol0:goo
00<3h7ooOol0<goo00=l07ooOol0JGoo000>Ool01000Oomoo`001goo00D007ooOomoo`0000Aoo`<0
03Qoo`H00<Moo`03001oogoo01Qoo`0301moogoo02]oo`030n1oogoo03=oo`03O01oogoo06Qoo`00
3Woo00@007ooOol000Moo`@000Eoo`03001oo`0003aoo`H00;1oo`8000Aoo`03001oogoo00=oo`<0
00Aoo`03001oogoo01Qoo`0301moogoo02]oo`030n1oogoo03Aoo`03O01oogoo06Moo`003Woo00@0
07ooOol000Moo`03001oogoo00Ioo`03001oo`0003ioo`80009oo`800:eoo`04001oogoo000:Ool0
0`00Oomoo`03Ool00`00Oomoo`0IOol00`0OOomoo`0[Ool00`?POomoo`0cOol00g`0Oomoo`1WOol0
00ioo`04001oogoo0008Ool00`00Oomoo`05Ool00`00Ool00010Ool3000017oo00000000ZWoo00@0
07ooOol000Moo`D000Aoo`8001Yoo`0301moogoo02aoo`030n1oogoo03=oo`03O01oogoo06Ioo`00
3goo0P002Woo0P001Goo0`00Agoo1000YWoo00@007ooOol000Moo`04001oogoo0005Ool00`00Oomo
o`0JOol00`0OOomoo`0[Ool00`?POomoo`0dOol00g`0Oomoo`1UOol0029oo`8004aoo`800:Aoo`04
001oogoo0008Ool00`00Ool00005Ool00`00Oomoo`0JOol00`0OOomoo`0/Ool00`?POomoo`0cOol0
0g`0Oomoo`1UOol0029oo`8004eoo`D00:1oo`04001oogoo0009Ool20005Ool00`00Oomoo`0KOol0
0`0OOomoo`0[Ool00`?POomoo`0dOol00g`0Oomoo`1TOol0029oo`8004ioo`H009moo`8000]oo`03
001oogoo00=oo`03001oogoo01]oo`0301moogoo02aoo`030n1oogoo03Aoo`03O01oogoo06=oo`00
8Woo0P00DWoo1P00[Woo00<007ooOol077oo00<07gooOol0;7oo00<3h7ooOol0=7oo00=l07ooOol0
HWoo000ROol2001DOol9002YOol00`00Oomoo`0LOol00`0OOomoo`0]Ool00`?POomoo`0dOol00g`0
Oomoo`1QOol0029oo`8000Al05Uoo`800:Moo`8001ioo`0301moogoo02eoo`030n1oogoo03=oo`03
O01oogoo065oo`008Woo0P0017oo1g`0E7oo1000Xgoo00<007ooOol07Goo00<07gooOol0;Goo00<3
h7ooOol0=7oo00=l07ooOol0H7oo000ROol2000;Ool4O01BOol6002OOol00`00Oomoo`0NOol00`0O
Oomoo`0]Ool00`?POomoo`0dOol00g`0Oomoo`1OOol0029oo`8000moo`Al051oo`H009eoo`03001o
ogoo01ioo`0301moogoo02ioo`030n1oogoo03=oo`03O01oogoo05moo`003goo0P0017oo00<007oo
Ool00Woo0`001Goo0P004goo17`0D7oo1P00VGoo00<007ooOol07goo00<07gooOol0;Goo00<3h7oo
Ool0=7oo00=l07ooOol0GWoo000>Ool01000Oomoo`001goo00D007ooOomoo`0000Aoo`8001Moo`Al
051oo`L009Aoo`03001oogoo021oo`0301moogoo02eoo`030n1oogoo03Aoo`03O01oogoo05eoo`00
3Woo00@007ooOol000Moo`05001oogooOol00004Ool2000KOol5O01BOol4002@Ool2000ROol00`0O
Oomoo`0]Ool00`?POomoo`0cOol00g`0Oomoo`1MOol000ioo`04001oogoo0008Ool30005Ool2000P
Ool2O01DOol4002<Ool00`00Oomoo`0QOol00`0OOomoo`0]Ool00`?POomoo`0dOol00g`0Oomoo`1L
Ool000ioo`04001oogoo0007Ool01@00Oomoogoo000017oo0P008Woo17`0DGoo1`00R7oo00<007oo
Ool08Woo00<07gooOol0;Goo00<3h7ooOol0=7oo0W`0G7oo000>Ool01000Oomoo`001goo00D007oo
Oomoo`0000Aoo`8002Ioo`9l05Aoo`P0089oo`03001oogoo029oo`0301moogoo02eoo`030n1oogoo
03Ioo`03O01oogoo05Uoo`003goo0P002Goo0`001Goo0P00:7oo17`0EWoo00<007oo00001000OGoo
00<007ooOol08goo00<07gooOol0;Goo00<3h7ooOol0=Woo00=l07ooOol0F7oo000ROol2000/Ool2
O01KOol6001gOol00`00Oomoo`0SOol00`0OOomoo`0]Ool00`?POomoo`0fOol00g`0Oomoo`1HOol0
029oo`8002ioo`El05Uoo`L007=oo`03001oogoo02Aoo`0301moogoo02eoo`030n1oogoo03Ioo`03
O01oogoo05Moo`008Woo0P00<goo0W`0G7oo2000KGoo0P009Goo00<07gooOol0;Woo00<3h7ooOol0
=Woo00=l07ooOol0EWoo000ROol2000eOol4O01POol9001TOol00`00Oomoo`0UOol00`0OOomoo`0]
Ool00`?POomoo`0fOol00g`0Oomoo`1FOol0029oo`03001oogoo03Qoo`9l06Ioo`T005aoo`03001o
ogoo02Eoo`0301moogoo02ioo`030n1oogoo03Ioo`03O01oogoo05Eoo`008Woo00<007ooOol0>Woo
17`0JGoo3@00DGoo00<007ooOol09Woo00<07gooOol0;Woo00<3h7ooOol0=Woo00=l07ooOol0E7oo
000ROol00`00Oomoo`0nOol2O01dOol>000`Ool20004Ool00`00Oomoo`02Ool30005Ool00`00Oomo
o`0WOol00`0OOomoo`0]Ool00`?POomoo`0gOol00g`0Oomoo`1COol0029oo`80045oo`Al07ioo`h0
025oo`04001oogoo0007Ool01@00Oomoogoo000017oo00<007ooOol09goo00<07gooOol0;Woo00<3
h7ooOol0=goo00=l07ooOol0DWoo000ROol00`00Oomoo`14Ool3O02ZOol01000Oomoo`001goo00D0
07ooOomoo`0000Aoo`8002Uoo`0301moogoo02ioo`030n1oogoo03Ioo`03O01oogoo059oo`006Woo
0`001Goo00<007ooOol0Agoo17`0YWoo00@007ooOol000Moo`@000Eoo`03001oogoo02Qoo`0301mo
ogoo02ioo`030n1oogoo03Moo`03O01oogoo055oo`006goo00<007ooOol017oo00<007ooOol0Bgoo
0W`0Y7oo00@007ooOol000Moo`03001oogoo00Ioo`03001oogoo02Uoo`0301moogoo02ioo`030n1o
ogoo03Moo`03O01oogoo051oo`006goo00<007ooOol017oo00<007ooOol0CGoo17`0X7oo00@007oo
Ool000Qoo`03001oogoo00Eoo`03001oogoo02Uoo`0301moogoo02moo`030n1oogoo03Ioo`03O01o
ogoo051oo`006goo00<007ooOol017oo0P00DWoo17`0WGoo0P002Woo0P001Goo00<007ooOol0:Woo
00<07gooOol0;Woo00<3h7ooOol0=goo00=l07ooOol0Cgoo000KOol00`00Oomoo`04Ool00`00Oomo
o`1EOol2O02^Ool00`00Oomoo`0ZOol00`0OOomoo`0_Ool00`?POomoo`0gOol00g`0Oomoo`1>Ool0
01Yoo`8000Ioo`03001oogoo05Moo`El0:Uoo`03001oogoo02]oo`0301moogoo02moo`030n1oogoo
03Moo`03O01oogoo04eoo`006goo00<007ooOol017oo00<007ooOol0G7oo0W`0Ygoo0P00;7oo00<0
7gooOol0;goo00<3h7ooOol0>7oo00=l07ooOol0C7oo000ROol2001OOol4O02SOol00`00Oomoo`0/
Ool00`0OOomoo`0_Ool00`?POomoo`0hOol00g`0Oomoo`1;Ool0029oo`03001oogoo069oo`Al09mo
o`03001oogoo02eoo`0301moogoo02moo`83h3Uoo`03O01oogoo04Yoo`008Woo00<007ooOol0IWoo
17`0Vgoo00<007ooOol0;Goo00<07gooOol0<Goo00<3h7ooOol0=Woo00=l07ooOol0BWoo000ROol0
0`00Oomoo`1ZOol2O02IOol00`00Oomoo`0^Ool00`0OOomoo`0aOol00`?POomoo`0fOol00g`0Oomo
o`19Ool0029oo`8006eoo`El09Aoo`03001oogoo02ioo`0301moogoo035oo`030n1oogoo03Moo`03
O01oogoo04Qoo`008Woo00<007ooOol0LGoo17`0T7oo0P00<7oo00<07gooOol0<Goo00<3h7ooOol0
=goo00=l07ooOol0Agoo000ROol00`00Oomoo`1eOol4O02<Ool00`00Oomoo`0_Ool00`0OOomoo`0b
Ool00`?POomoo`0gOol2O017Ool0029oo`03001oogoo07Uoo`Al08Qoo`03001oogoo031oo`0301mo
ogoo035oo`030n1oogoo03Uoo`03O01oogoo04Aoo`008Woo0P00OWoo17`0Q7oo00<007ooOol0<Goo
00<07gooOol0<Goo00<3h7ooOol0>Goo00=l07ooOol0@goo000>Ool30004Ool01000Oomoogoo1@00
17oo00<007ooOol0PGoo1G`0Ogoo00<007ooOol0<Goo00<07gooOol0<Woo00<3h7ooOol0>Goo00=l
07ooOol0@Woo000?Ool00`00Oomoo`08Ool01000Oomoo`0017oo00<007ooOol0QWoo17`0Ngoo00<0
07ooOol0<Woo00<07gooOol0<Woo00<3h7ooOol0>Goo00=l07ooOol0@Goo000?Ool00`00Oomoo`09
Ool00`00Oomoo`04Ool00`00Oomoo`2:Ool4O01gOol00`00Oomoo`0cOol00`0OOomoo`0bOol00`?P
Oomoo`0iOol00g`0Oomoo`10Ool000moo`03001oogoo00Yoo`03001oogoo00=oo`8008moo`Il075o
o`8003Eoo`0301moogoo039oo`030n1oogoo03Uoo`03O01oogoo03moo`003goo00<007ooOol01goo
00D007ooOomoo`0000Aoo`03001oogoo09Aoo`Ml06Yoo`03001oogoo03Eoo`0301moogoo039oo`03
0n1oogoo03Uoo`03O01oogoo03ioo`003Woo0P002Goo00D007ooOomoo`0000Aoo`03001oogoo09]o
o`Al06Ioo`03001oogoo03Ioo`0301moogoo039oo`030n1oogoo03Uoo`03O01oogoo03eoo`003goo
00<007ooOol027oo0`001Goo00<007ooOol0Wgoo27`0GWoo00<007ooOol0=goo00<07gooOol0<Woo
00<3h7ooOol0>Goo00=l07ooOol0?7oo000ROol2002XOol9O012Ool20004Ool00`00Oomoo`02Ool3
0005Ool00`00Oomoo`0hOol00`0OOomoo`0aOol00`?POomoo`0jOol00g`0Oomoo`0kOol0029oo`03
001oogoo0;1oo`Yl03Moo`04001oogoo0007Ool01@00Oomoogoo000017oo00<007ooOol0>7oo00<0
7gooOol0<Woo00<3h7ooOol0>Woo00=l07ooOol0>Woo000ROol00`00Oomoo`2jOol?O00XOol01000
Oomoo`001goo00D007ooOomoo`0000Aoo`8003Yoo`0301moogoo039oo`83h3]oo`03O01oogoo03Uo
o`008Woo00<007ooOol0bGoo1g`08Goo00@007ooOol000Qoo`<000Eoo`03001oogoo03Yoo`0301mo
ogoo03=oo`030n1oogoo03Uoo`03O01oogoo03Qoo`008Woo0P00lWoo00@007ooOol000Moo`05001o
ogooOol00004Ool00`00Oomoo`0kOol00`0OOomoo`0cOol00`?POomoo`0iOol2O00hOol0029oo`03
001oogoo0?5oo`04001oogoo0007Ool01@00Oomoogoo000017oo00<007ooOol0?7oo00<07gooOol0
<goo00<3h7ooOol0>Woo00=l07ooOol0=Goo000ROol00`00Oomoo`3bOol20009Ool30005Ool00`00
Oomoo`0mOol00`0OOomoo`0cOol00`?POomoo`0jOol00g`0Oomoo`0dOol0029oo`03001oogoo0?mo
o`Ioo`03001oogoo03ioo`0301moogoo03=oo`83h3]oo`9l03Aoo`008Woo0P00ogoo1goo00<007oo
Ool0?goo00<07gooOol0=7oo00<3h7ooOol0>Woo0g`0<Goo000>Ool30004Ool00`00Oomoo`03Ool3
0004Ool00`00Oomoo`3oOol6Ool20011Ool00`0OOomoo`0dOol20n0mOol00g`0Oomoo`0^Ool000mo
o`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo0?moo`Ioo`03001oogoo045oo`0301moogoo
03Eoo`83h3aoo`03O01oogoo02eoo`003goo00<007ooOol01goo1@0017oo00<007ooOol0ogoo1Woo
00<007ooOol0@Woo0P0O=goo00<3h7ooOol0>Woo0W`0;Goo000?Ool00`00Oomoo`07Ool01000Oomo
o`001Goo0P00ogoo1goo00<007ooOol0A7oo00<07gooOol0=Goo00<3h7ooOol0>goo0W`0:goo000?
Ool00`00Oomoo`08Ool00`00Ool00005Ool00`00Oomoo`3oOol6Ool00`00Oomoo`15Ool00`0OOomo
o`0eOol20n0mOol2O00YOol000ioo`8000]oo`8000Eoo`03001oogoo0?moo`Ioo`03001oogoo04Io
o`807cMoo`83h3eoo`9l02Moo`003goo00<007ooOol02Woo00<007ooOol00goo00<007ooOol0ogoo
1Woo0P00BGoo0P0O=goo0P?P?Goo0W`09Goo000ROol2003oOol7Ool00`00Oomoo`1:Ool301lfOol2
0n0mOol2O00SOol0029oo`03001oogoo0?moo`Ioo`03001oogoo04eoo`807cIoo`83h3eoo`9l025o
o`008Woo00<007ooOol0ogoo1Woo00<007ooOol0Cgoo0P0O=Woo0P?P?Goo1G`077oo000ROol00`00
Oomoo`3oOol6Ool00`00Oomoo`1AOol201lfOol50n0mOol2O00JOol0029oo`800?moo`Moo`03001o
ogoo05=oo`807cUoo`83h3eoo`=l01Moo`008Woo00<007ooOol0ogoo1Woo00<007ooOol0EGoo0P0O
>Goo10?PDgoo000ROol00`00Oomoo`3oOol6Ool2001HOol401liOol40n1?Ool0029oo`03001oogoo
0?moo`Ioo`03001oogoo05]oo`@07cUoo`@3h4]oo`008Woo0P00ogoo1goo00<007ooOol0Ggoo1@0O
>7oo1`?PA7oo000ROol00`00Oomoo`3oOol6Ool00`00Oomoo`1TOol801lgOol80n0lOol000ioo`<0
00Aoo`03001oogoo009oo`<000Eoo`03001oogoo0?eoo`<000Eoo`03001oogoo06aoo`/07cAoo`/3
h35oo`003goo00<007ooOol01goo00D007ooOomoo`0000Aoo`03001oogoo0?ioo`03001oogoo00Ao
o`03001oogoo07Mooa807beooaL3h1Yoo`003goo00<007ooOol01goo00D007ooOomoo`0000Aoo`80
0?moo`03001oogoo00Aoo`8008YoodL07aMoo`003goo00<007ooOol01goo1000ogoo1goo00<007oo
Ool017oo00<007ooOol0igoo000?Ool00`00Oomoo`07Ool00`00Oomoo`3oOol8Ool00`00Oomoo`04
Ool00`00Oomoo`3WOol000ioo`8000Yoo`03001oogoo0?moo`Ioo`8000Ioo`03001oogoo0>Moo`00
3goo00<007ooOol02Goo0P00ogoo1goo00<007ooOol0kWoo003oOoooOolFOol00?mooomooaIoo`00
ogooogoo5Woo003oOoooOolFOol00?mooomooaIoo`00\
\>"],
  ImageRangeCache->{{{0, 531.188}, {155.562, 0}} -> {-0.0551807, -0.0147182, \
0.00397292, 0.00397292}, {{13.875, 253.562}, {151.812, 3.6875}} -> {-16.4248, \
-0.202906, 0.476055, 0.0123244}, {{277.562, 517.25}, {151.812, 3.6875}} -> \
{-142.104, -0.12747, 0.476349, 0.00770473}}]
}, Closed]],

Cell[TextData[{
  "Initially, ",
  StyleBox["mean fitness",
    FontColor->RGBColor[1, 0, 0]],
  " is low, because deleterious alleles are present at the three loci.  \
Population size therefore decreases to a minimum of ~0.4.  As the deleterious \
alleles are eliminated, ",
  StyleBox["mean fitness",
    FontColor->RGBColor[1, 0, 0]],
  " increases, and population size increases to its equilibrium value of \
1.29."
}], "Text"],

Cell[TextData[{
  "In this example, the recursion for deme size is given by \
ExponentialF[2,1,1], which represents ",
  Cell[BoxData[
      \(TraditionalForm\`\(n\^*\) = 
        2  n\ Exp[\(-n\)]\ \(\(W\&_\)\(.\)\(\ \)\)\)]],
  "The equilibrium density is ",
  Cell[BoxData[
      \(TraditionalForm\`n = Log[2  W\&_]\ for\ W\&_ > 1\/2; \ 
      if\ W\&_ < 1\/2, \ the\ population\ goes\ \(\(extinct\)\(.\)\)\)]],
  "  In this example, the population density soon approaches a \
quasi-equilibrium of ",
  Cell[BoxData[
      \(TraditionalForm\`n = Log[2  W\&_]\)]],
  " (dashed line)."
}], "Text"],

Cell[TextData[{
  "The option DemeSize->F is passed to ",
  ButtonBox["NewGametes",
    ButtonData:>{"Allele frequencies: reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ", which changes deme size accordingly.  Note that deme size is assumed to \
remain constant through meiosis and random union, but changes as a result of \
",
  ButtonBox["migration",
    ButtonData:>{"Allele frequencies: migration", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "Text"],

Cell["\<\
When compiled code is used, only certain settings for F can be \
used.\
\>", "Text"],

Cell[TextData[{
  "The logistic model ",
  Cell[BoxData[
      \(TraditionalForm\`f[n, W\&_] = 
        n + r\[VeryThinSpace]n \((1 - n\/K)\)\)]],
  " should be avoided,because in discrete time, it can lead to negative \
population sizes."
}], "Text"],

Cell[TextData[{
  StyleBox["Note: ",
    FontWeight->"Bold"],
  " In ",
  ButtonBox["MigrateExact",
    ButtonData:>{"Allele frequencies: migration", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ", m denotes the fraction of the population that migrates: it is the \
forward migration rate.  The deme size after migration is ",
  Cell[BoxData[
      \(TraditionalForm\`\(n\^*\) m + n \((1 - m)\), \ 
      and\ the\ proportion\ of\ immigrants\ is\ \(\(n\^*\) m\)\/\(\(n\^*\) m \
+ n \((1 - m)\)\)\)]],
  "; this increases as deme size, n, decreases.  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The life cycle", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(\(\ \)\(IterateExact[\[Psi], W, m, 
              MigrationOrder \[Rule] 
                UMS]\)\), \(represents\ the\ default\ order\ of\ events\ \
random\ union \[Rule] \(migration \[Rule] \(selection \[Rule] 
                  meiosis . \ \ \n
                      Regulation\ of\ population\ size\ always\ occurs\ \
immediately\ after\ \(\(selection\)\(.\)\)\)\)\)},
          {\(\(\ \)\(IterateExact[\[Psi], W, m, 
              MigrationOrder \[Rule] 
                MUS]\)\), \(represents\ migration \[Rule] \(random\ union \
\[Rule] \(selection \[Rule] meiosis\)\); \ 
            equivalent\ to\ UMS\ for\ allele\ frequency\ \
\(\(recursions\)\(.\)\)\)},
          {\(\(\ \)\(IterateExact[\[Psi], W, m, 
              MigrationOrder \[Rule] 
                USM]\)\), \(represents\ random\ union \[Rule] \(selection \
\[Rule] \(migration \[Rule] \(\(meiosis\)\(.\)\)\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}],

Cell["\<\
The default order of events in the life cycle is MigrationOrder\
\[Rule]UMS, representing random union of gametes\[Rule]diploid migration\
\[Rule]selection\[Rule]meiosis.  For a single deme with immigration from a \
population \[Psi]s, this is implemented by:\
\>", "Text"],

Cell[BoxData[
    \(NewGametes[
      MigrateExact[MakeDiploid[AlleleFrequencies[p, nd]], 
        MakeDiploid[\[Psi]s], m], W, opts]\)], "Input"],

Cell["\<\
In this example, there are 3 loci with 10% selection against '1' \
alleles, balanced by immigration of m=0.05:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(w[\[Sigma]_List, add]\)[
          p_List] := {1 + \[Sigma] . \((2  p - 
                  1)\), \[Sigma]};\)\), "\[IndentingNewLine]", 
    \(\(ppUMS = 
        Nest[IterateExact[#, w[{\(-0.1\), \(-0.1\), \(-0.1\)}, add], 0.05] &, 
          AlleleFrequencies[{0, 0, 0}, 1], 100];\)\), "\[IndentingNewLine]", 
    \(AlleleFrequencyMean[ppUMS]\)}], "Input",
  CellLabel->"In[56]:=  (16:33:27 on 5/1/01)"],

Cell[BoxData[
    \(0.4941733915437551`\)], "Output",
  CellLabel->"Out[58]=  (16:33:28 on 5/1/01)"]
}, Closed]],

Cell["\<\
MigrationOrder\[Rule]MUS represents haploid migration\[Rule]random \
union of gametes\[Rule]selection\[Rule]meiosis.  For a single deme with \
immigration from a population fixed for '1' alleles, this is implemented \
by:\
\>", "Text"],

Cell[BoxData[
    \(\(\(\ \ \)\(NewGametes[
      MakeDiploid[MigrateExact[HaploidFrequencies[\[Psi], nd], \[Psi]s, m]], 
      W, opts]\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ppMUS = 
        Nest[IterateExact[#, w[{\(-0.1\), \(-0.1\), \(-0.1\)}, add], 0.05, 
              MigrationOrder \[Rule] MUS] &, AlleleFrequencies[{0, 0, 0}, 1], 
          100];\)\), "\[IndentingNewLine]", 
    \(AlleleFrequencyMean[ppMUS]\)}], "Input",
  CellLabel->"In[59]:=  (16:34:20 on 5/1/01)"],

Cell[BoxData[
    \(0.4941733915437551`\)], "Output",
  CellLabel->"Out[60]=  (16:34:21 on 5/1/01)"]
}, Closed]],

Cell["\<\
When only allele frequencies are followed, this makes no difference \
to the outcome: migration before or after random union affects allele \
frequencies in the same way.\
\>", "Text"],

Cell["\<\
MigrationOrder\[Rule]USM represents random union of \
gametes\[Rule]selection\[Rule]diploid migration\[Rule]meiosis.  For a single \
deme with immigration from a population fixed for '1' alleles, this is \
implemented by:\
\>", "Text"],

Cell[BoxData[
    \(MigrateExact[
      NewGametes[MakeDiploid[HaploidFrequencies[\[Psi], nd]], W, 
        opts], \[Psi]s, m]\)], "Input",
  CellLabel->"In[61]:=  (16:35:41 on 5/1/01)"],

Cell["\<\
Note that this really implements random union of \
gametes\[Rule]selection\[Rule]meiosis\[Rule]haploid migration.  However, the \
two are equivalent, since migration is a linear process.  With strong \
selection (s=10% on each of 3 loci), this leads to a slightly higher \
equilibrium frequency than MigrationOrder\[Rule]MUS or USM.  This is because \
the final step was migration, rather than selection:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ppUSM = 
        Nest[IterateExact[#, w[{\(-0.1\), \(-0.1\), \(-0.1\)}, add], 0.05, 
              MigrationOrder \[Rule] USM] &, AlleleFrequencies[{0, 0, 0}, 1], 
          100];\)\), "\[IndentingNewLine]", 
    \(AlleleFrequencyMean[ppUSM]\)}], "Input",
  CellLabel->"In[62]:=  (16:36:10 on 5/1/01)"],

Cell[BoxData[
    \(0.5194300824862176`\)], "Output",
  CellLabel->"Out[63]=  (16:36:12 on 5/1/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Random drift", "SubsubsectionIcon",
  CellTags->"Random drift"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, m, 
              RandomDrift -> True]\), \(allows\ for\ random\ drift\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->"IterateExact"],

Cell["\<\
This simulates 100 replicates of a population of 100 individuals, \
evolving over one generation, with no selection or immigration:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(p0 = {0.1, 0.2, 0.3}; \(w[neutral]\)[
        p_List] := {1, {0, 0, 0}};\), "\n", 
    \(\(tt = 
        Table[IterateExact[AlleleFrequencies[p0, 100], w[neutral], 0, 
            RandomDrift -> True], {100}];\)\), "\n", 
    \(\(pt = AlleleFrequencyTable /@ tt;\)\), "\n", 
    \({p0, Mean[pt], \(p0 \((1 - p0)\)\)\/100, Variance[pt]} // 
      MatrixForm\)}], "Input",
  CellLabel->"In[3]:=  (16:39:23 on 5/1/01)"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.1`", "0.2`", "0.3`"},
            {"0.09759999999999999`", "0.1998`", "0.29350000000000004`"},
            {"0.0009000000000000002`", "0.0016`", "0.0021`"},
            {"0.0007982222222222225`", "0.0017979393939393938`", 
              "0.0020613636363636355`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[6]//MatrixForm=  (16:39:24 on 5/1/01)"]
}, Closed]],

Cell[TextData[{
  "The option RandomDrift->True is passed to ",
  Cell[BoxData[
      FormBox[
        ButtonBox["NewGametes",
          ButtonData:>{"Allele frequencies: reproduction", "RandomDrift"},
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  ", and ensures that haploid gametes are sampled from a multinomial \
distribution, immediately after selection and population regulation.  Other \
options, such as Compiled->True, and MigrationOrder->MUS, can be used with \
RandomDrift->True."
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{917, 633},
WindowMargins->{{Automatic, 14}, {Automatic, 39}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "IterateExact"->{
    Cell[2065, 64, 958, 20, 60, "DefinitionBox",
      CellTags->{"IterateExact", "StoreExact"}],
    Cell[28520, 922, 502, 10, 56, "DefinitionBox",
      CellTags->"IterateExact"],
    Cell[47673, 1458, 318, 7, 37, "DefinitionBox",
      CellTags->"IterateExact"],
    Cell[93279, 3127, 284, 6, 37, "DefinitionBox",
      CellTags->"IterateExact"]},
  "StoreExact"->{
    Cell[2065, 64, 958, 20, 60, "DefinitionBox",
      CellTags->{"IterateExact", "StoreExact"}]},
  "Compiling"->{
    Cell[47607, 1455, 63, 1, 20, "SubsubsectionIcon",
      CellTags->"Compiling"]},
  "DemeSize"->{
    Cell[50755, 1538, 1119, 21, 134, "DefinitionBox",
      CellTags->"DemeSize"]},
  "MigrationOrder"->{
    Cell[88571, 2995, 1052, 20, 104, "DefinitionBox",
      CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}]},
  "UMS"->{
    Cell[88571, 2995, 1052, 20, 104, "DefinitionBox",
      CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}]},
  "MUS"->{
    Cell[88571, 2995, 1052, 20, 104, "DefinitionBox",
      CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}]},
  "USM"->{
    Cell[88571, 2995, 1052, 20, 104, "DefinitionBox",
      CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}]},
  "Random drift"->{
    Cell[93207, 3124, 69, 1, 20, "SubsubsectionIcon",
      CellTags->"Random drift"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"IterateExact", 166542, 5747},
  {"StoreExact", 166911, 5756},
  {"Compiling", 167027, 5759},
  {"DemeSize", 167128, 5762},
  {"MigrationOrder", 167234, 5765},
  {"UMS", 167358, 5768},
  {"MUS", 167482, 5771},
  {"USM", 167606, 5774},
  {"Random drift", 167739, 5777}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 44, 0, 36, "SubsectionIcon"],
Cell[1786, 53, 82, 1, 28, "MathCaption"],
Cell[1871, 56, 124, 2, 39, "Input"],

Cell[CellGroupData[{
Cell[2020, 62, 42, 0, 24, "SubsubsectionIcon"],
Cell[2065, 64, 958, 20, 60, "DefinitionBox",
  CellTags->{"IterateExact", "StoreExact"}],
Cell[3026, 86, 98, 3, 28, "MathCaption"],
Cell[3127, 91, 228, 5, 39, "Input"],
Cell[3358, 98, 651, 20, 36, "Text"],
Cell[4012, 120, 151, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4188, 127, 396, 9, 69, "Input"],
Cell[4587, 138, 19422, 675, 184, 9058, 542, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[24024, 816, 121, 3, 28, "MathCaption"],
Cell[24148, 821, 181, 3, 39, "Input"],

Cell[CellGroupData[{
Cell[24354, 828, 90, 2, 39, "Input"],
Cell[24447, 832, 101, 2, 20, "Print"],
Cell[24551, 836, 3610, 68, 348, "Print"]
}, Closed]],
Cell[28176, 907, 102, 3, 22, "Text"],
Cell[28281, 912, 145, 3, 22, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[28463, 920, 54, 0, 20, "SubsubsectionIcon"],
Cell[28520, 922, 502, 10, 56, "DefinitionBox",
  CellTags->"IterateExact"],
Cell[29025, 934, 186, 6, 28, "MathCaption"],
Cell[29214, 942, 175, 4, 39, "Input"],
Cell[29392, 948, 334, 9, 36, "Text"],
Cell[29729, 959, 189, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[29943, 967, 582, 10, 84, "Input"],
Cell[30528, 979, 13535, 366, 184, 3392, 236, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[44078, 1348, 235, 5, 22, "Text"],
Cell[44316, 1355, 363, 11, 24, "Text"],
Cell[44682, 1368, 76, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[44783, 1372, 267, 5, 39, "Input"],
Cell[45053, 1379, 299, 5, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[45389, 1389, 117, 2, 39, "Input"],
Cell[45509, 1393, 185, 4, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[45731, 1402, 128, 2, 39, "Input"],
Cell[45862, 1406, 103, 2, 32, "Output"]
}, Closed]],
Cell[45980, 1411, 999, 22, 92, "Text"],
Cell[46982, 1435, 588, 15, 36, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[47607, 1455, 63, 1, 20, "SubsubsectionIcon",
  CellTags->"Compiling"],
Cell[47673, 1458, 318, 7, 37, "DefinitionBox",
  CellTags->"IterateExact"],
Cell[47994, 1467, 997, 20, 68, "Text"],
Cell[48994, 1489, 68, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[49087, 1493, 553, 11, 69, "Input"],
Cell[49643, 1506, 370, 6, 32, "Output"]
}, Closed]],
Cell[50028, 1515, 69, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[50122, 1519, 369, 6, 54, "Input"],
Cell[50494, 1527, 163, 3, 32, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[50706, 1536, 46, 0, 20, "SubsubsectionIcon"],
Cell[50755, 1538, 1119, 21, 134, "DefinitionBox",
  CellTags->"DemeSize"],
Cell[51877, 1561, 165, 4, 28, "MathCaption"],
Cell[52045, 1567, 407, 7, 69, "Input"],
Cell[52455, 1576, 128, 3, 22, "Text"],
Cell[52586, 1581, 67, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[52678, 1585, 951, 20, 129, "Input"],
Cell[53632, 1607, 32407, 1306, 163, 14951, 1086, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[86054, 2916, 431, 11, 36, "Text"],
Cell[86488, 2929, 598, 15, 64, "Text"],
Cell[87089, 2946, 480, 12, 38, "Text"],
Cell[87572, 2960, 94, 3, 22, "Text"],
Cell[87669, 2965, 251, 7, 34, "Text"],
Cell[87923, 2974, 565, 14, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[88525, 2993, 43, 0, 20, "SubsubsectionIcon"],
Cell[88571, 2995, 1052, 20, 104, "DefinitionBox",
  CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}],
Cell[89626, 3017, 283, 5, 36, "Text"],
Cell[89912, 3024, 146, 3, 27, "Input"],
Cell[90061, 3029, 141, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[90227, 3036, 429, 8, 69, "Input"],
Cell[90659, 3046, 100, 2, 32, "Output"]
}, Closed]],
Cell[90774, 3051, 245, 5, 36, "Text"],
Cell[91022, 3058, 153, 3, 27, "Input"],

Cell[CellGroupData[{
Cell[91200, 3065, 325, 6, 54, "Input"],
Cell[91528, 3073, 100, 2, 32, "Output"]
}, Closed]],
Cell[91643, 3078, 194, 4, 22, "Text"],
Cell[91840, 3084, 245, 5, 36, "Text"],
Cell[92088, 3091, 186, 4, 39, "Input"],
Cell[92277, 3097, 428, 7, 50, "Text"],

Cell[CellGroupData[{
Cell[92730, 3108, 325, 6, 54, "Input"],
Cell[93058, 3116, 100, 2, 32, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[93207, 3124, 69, 1, 20, "SubsubsectionIcon",
  CellTags->"Random drift"],
Cell[93279, 3127, 284, 6, 37, "DefinitionBox",
  CellTags->"IterateExact"],
Cell[93566, 3135, 164, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[93755, 3143, 437, 9, 98, "Input"],
Cell[94195, 3154, 479, 10, 79, "Output"]
}, Closed]],
Cell[94689, 3167, 517, 11, 36, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

