(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     51106,       1357]*)
(*NotebookOutlinePosition[    123484,       3959]*)
(*  CellTagsIndexPosition[    123244,       3948]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Iterating a cline", "SubsectionIcon"],

Cell["This loads this package, as well as the Graphics package:", \
"MathCaption"],

Cell[BoxData[
    \(<< NumericalModels`ExactModel`; << Graphics`;\)], "Input",
  CellLabel->"In[1]:="],

Cell[CellGroupData[{

Cell["A simple example", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, 
              m]\), \(iterates\ a\ cline; \ \ \[Psi]\ represents\ a\ list\ of\
\ populations . \ \ Fitness\ is\ specified\ as\ \(W[
                    deme]\)[{p\_1, \[Ellipsis]}] = {W\&_, {\(s\_1\) \
\[Ellipsis]} W\&_}\)},
          {
            RowBox[{"StoreExact", "[", 
              RowBox[{"\[Psi]", ",", \(\[Psi]\_0\), ",", "W", ",", "m", ",", 
                RowBox[{"{", 
                  RowBox[{"t", ",", 
                    StyleBox["dt",
                      FontSlant->"Italic"]}], 
                  StyleBox["}",
                    FontSlant->"Italic"]}]}], 
              "]"}], \(stores\ results\ at\ intervals\ dt\ in\ \[Psi][t], \ 
            starting\ with\ \[Psi][
                  0] = \[Psi]\_0 . \ \ Options\ are\ passed\ directly\ to\ \(\
\(IterateExact[]\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->{"IterateExact", "StoreExact"}],

Cell["\<\
This fitness function represents selection \[Sigma] against \
heterozygotes:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(\(\(w[\[Sigma]_List, het]\)[d_]\)[
          p_List] := {1 - 
            2  \[Sigma] . \((p \((1 - p)\))\), \[Sigma] \((2  p - 
                1)\)};\)\)], "Input",
  CellLabel->"In[2]:=  (21:51:33 on 5/2/01)"],

Cell["Selection is independent of deme, d.", "Text"],

Cell[TextData[{
  "This shows a cline at three loci, across 10 demes and with deme size 100; \
",
  Cell[BoxData[
      \(TraditionalForm\`m = 0.5\)]],
  ".  Selection on the three loci is {0.05, 0.1, 0.2}.  This shows the mean \
clines, at t=0, 10, 20, 30 generations:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pop[ng_] := 
        MakeCline[10, ng, 100, 
          NumericalModel -> AlleleFrequencies];\)\), "\n", 
    \(\(StoreExact[cline[3, {0.05, 0.1, 0.2}], pop[3], 
        w[{0.05, 0.1, 0.2}, het], 0.5, {30, 10}];\)\), "\n", 
    \(\(DisplayTogether @@ 
        Table[ListPlot[
            AlleleFrequencyMean[\(cline[3, {0.05, 0.1, 0.2}]\)[t]], 
            PlotJoined -> True], {t, 0, 30, 10}];\)\)}], "Input",
  CellLabel->"In[23]:=  (21:15:44 on 5/2/01)"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.588604 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.11905 .01472 m
.21429 .01472 L
.30952 .01472 L
.40476 .01472 L
.5 .01472 L
.59524 .60332 L
.69048 .60332 L
.78571 .60332 L
.88095 .60332 L
.97619 .60332 L
s
.11905 .02239 m
.21429 .03418 L
.30952 .06577 L
.40476 .13163 L
.5 .24193 L
.59524 .3761 L
.69048 .4864 L
.78571 .55226 L
.88095 .58386 L
.97619 .59564 L
s
.11905 .04078 m
.21429 .0556 L
.30952 .09026 L
.40476 .1538 L
.5 .25145 L
.59524 .36659 L
.69048 .46424 L
.78571 .52777 L
.88095 .56244 L
.97619 .57725 L
s
.11905 .05307 m
.21429 .06783 L
.30952 .10171 L
.40476 .16257 L
.5 .25486 L
.59524 .36317 L
.69048 .45547 L
.78571 .51632 L
.88095 .5502 L
.97619 .56496 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[23]:=  (21:15:46 on 5/2/01)",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool5
000aOol3000_Ool3000aOol3000^Ool30004Ool20004Ool004Moo`04001oogoo000bOol00`00Oomo
o`0]Ool01@00Oomoogoo0000;goo00D007ooOomoo`0002ioo`03001oogoo009oo`04001oogoo0003
Ool004Qoo`03001oogoo02moo`D002ioo`05001oogooOol0000_Ool01@00Oomoogoo0000;Woo00<0
07ooOol00Woo00@007ooOol000=oo`00BGoo00<007ooOol0;Woo00@007ooOol002moo`@0035oo`<0
02moo`03001oogoo009oo`04001oogoo0003Ool004Ioo`05001oogooOol0000`Ool00`00Ool0000_
Ool00`00Oomoo`0aOol01@00Oomoogoo0000;Woo00<007ooOol00Woo00@007ooOol000=oo`00AWoo
00D007ooOomoo`00035oo`80031oo`03001oogoo031oo`05001oogooOol0000]Ool20004Ool01000
Oomoo`000goo0017Ool3000cOol00`00Oomoo`0_Ool2000aOol3000_Ool00`00Oomoo`03Ool20004
Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9
Ool001Eoo`03001oogoo0?moo`Uoo`003gooo`004@000Goo000EOol00`00Oomoo`0:Ool00`00Oomo
o`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomo
o`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomo
o`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomo
o`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool001Eoo`03
001oogoo01Moo`D001Eoo`03001oogoo035oo`03001oogoo01Ioo`03001oogoo01Moo`03001oogoo
035oo`03001oogoo035oo`03001oogoo00Eoo`005Goo00<007ooOol077oo2@00FGoo00<007ooOol0
Qgoo000EOol00`00Oomoo`0UOol9001AOol00`00Oomoo`26Ool001Eoo`03001oogoo02ioo`D004ao
o`03001oogoo08Ioo`005Goo00<007ooOol0<goo0`00BGoo00<007ooOol0QWoo000EOol00`00Oomo
o`0GOol4000KOol30016Ool00`00Oomoo`26Ool001Eoo`8001aoo`L001Moo`<004=oo`03001oogoo
08Ioo`005Goo00<007ooOol08Woo1P0057oo0`00@7oo00<007ooOol0QWoo000EOol00`00Oomoo`0G
Ool4000=Ool7000@Ool3000nOol00`00Oomoo`25Ool001Eoo`03001oogoo01]oo`L000eoo`@000mo
o`<003]oo`03001oogoo08Eoo`005Goo00<007ooOol08Woo1P002goo0`003goo0`00>7oo00<007oo
Ool0QGoo000EOol00`00Oomoo`0XOol70007Ool3000?Ool3000eOol00`00Oomoo`25Ool001Eoo`03
001oogoo02moo`@000Ioo`<000moo`8003=oo`03001oogoo08Eoo`005Goo00<007ooOol0<goo0`00
1Woo0`003Woo00<007ooOol0<7oo00<007ooOol0QGoo000EOol2000gOol30006Ool3000<Ool2000a
Ool00`00Oomoo`24Ool001Eoo`03001oogoo03Uoo`8000Moo`<000]oo`03001oogoo02ioo`03001o
ogoo08Aoo`005Goo00<007ooOol0>goo0`001goo0`002Goo0P00;Woo00<007ooOol0Q7oo000EOol0
0`00Oomoo`0nOol20008Ool30008Ool00`00Oomoo`0[Ool00`00Oomoo`24Ool001Eoo`03001oogoo
041oo`<000Qoo`8000Moo`03001oogoo02Yoo`03001oogoo08Aoo`005Goo00<007ooOol0@goo0`00
1goo00<007ooOol01Goo0P00:Woo00<007ooOol0Q7oo000EOol00`00Oomoo`16Ool20006Ool20007
Ool00`00Oomoo`0WOol00`00Oomoo`24Ool001Eoo`03001oogoo04Qoo`<000Eoo`03001oogoo00Eo
o`8002Qoo`03001oogoo08=oo`005Goo0P00C7oo0P0017oo0P001goo00<007ooOol09Goo00<007oo
Ool0Pgoo000EOol00`00Oomoo`1=Ool00`00Oomoo`03Ool00`00Oomoo`05Ool2000UOol00`00Oomo
o`23Ool001Eoo`03001oogoo04ioo`8000Aoo`03001oogoo00Ioo`03001oogoo029oo`03001oogoo
08=oo`005Goo00<007ooOol0D7oo0P000goo0P001goo0P008Woo00<007ooOol0Pgoo000EOol00`00
Oomoo`1BOol00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0OOol00`00Oomoo`23Ool0009o
o`8000Aoo`04001oogooOol50004Ool00`00Oomoo`1COol20003Ool20007Ool00`00Oomoo`0OOol0
0`00Oomoo`22Ool00005Ool007ooOol00008Ool01000Oomoo`0017oo00<007ooOol0EGoo0P000goo
00<007ooOol01Goo0P007goo00<007ooOol0PWoo00001Goo001oogoo00002Goo00<007ooOol017oo
00<007ooOol0Egoo00@007ooOomoo`8000Moo`03001oogoo01aoo`03001oogoo089oo`0000Eoo`00
Oomoo`0000Yoo`03001oogoo00=oo`<005Qoo`8000=oo`03001oogoo00Eoo`03001oogoo01]oo`03
001oogoo089oo`0000Eoo`00Oomoo`0000Moo`05001oogooOol00004Ool00`00Oomoo`1JOol01000
Oomoogoo0P001Goo00<007ooOol06goo00<007ooOol0PWoo00001Goo001oogoo00001goo00D007oo
Oomoo`0000Aoo`03001oogoo05]oo`8000=oo`03001oogoo00=oo`03001oogoo01Yoo`03001oogoo
089oo`000Woo0P002Goo0`001Goo00<007ooOol0GGoo0P000Woo00<007ooOol00goo00<007ooOol0
6Woo00<007ooOol0PGoo000EOol00`00Oomoo`1OOol00`00Oomoo`020004Ool00`00Oomoo`0IOol0
0`00Oomoo`21Ool001Eoo`03001oogoo061oo`80009oo`03001oogoo009oo`03001oogoo01Qoo`03
001oogoo085oo`005Goo00<007ooOol0HWoo0P0000=oo`00Ool00goo00<007ooOol05goo00<007oo
Ool0PGoo000EOol00`00Oomoo`1TOol20004Ool00`00Oomoo`0GOol00`00Oomoo`21Ool001Eoo`80
06Ioo`8000Aoo`03001oogoo01Ioo`03001oogoo085oo`005Goo00<007ooOol0IWoo0P0017oo00<0
07ooOol05Woo00<007ooOol0P7oo000EOol00`00Oomoo`1WOol20004Ool00`00Oomoo`0EOol00`00
Oomoo`20Ool001Eoo`03001oogoo06Qoo`8000Aoo`03001oogoo01Aoo`03001oogoo081oo`005Goo
00<007ooOol0JGoo0P0017oo00<007ooOol04goo00<007ooOol0P7oo000EOol00`00Oomoo`1ZOol2
0003Ool00`00Oomoo`0COol00`00Oomoo`20Ool001Eoo`03001oogoo06]oo`8000=oo`03001oogoo
019oo`03001oogoo081oo`005Goo00<007ooOol0K7oo0P000goo00<007ooOol04Woo00<007ooOol0
Ogoo000EOol2001^Ool20003Ool00`00Oomoo`0AOol00`00Oomoo`1oOol001Eoo`03001oogoo06io
o`8000=oo`03001oogoo011oo`03001oogoo07moo`005Goo00<007ooOol0Kgoo0P000goo00<007oo
Ool03goo00<007ooOol0Ogoo000EOol00`00Oomoo`1`Ool20002Ool00`00Oomoo`0?Ool00`00Oomo
o`1oOol001Eoo`03001oogoo075oo`80009oo`03001oogoo00ioo`03001oogoo07moo`005Goo00<0
07ooOol0LWoo0P000Woo00<007ooOol03Woo00<007ooOol0OWoo000EOol00`00Oomoo`1cOol20002
Ool00`00Oomoo`0=Ool00`00Oomoo`1nOol001Eoo`03001oogoo07Aoo`80009oo`03001oogoo00ao
o`03001oogoo07ioo`005Goo0P00MWoo0P000Woo00<007ooOol02goo00<007ooOol0OWoo000EOol0
0`00Oomoo`1fOol200000goo001oo`0<Ool00`00Oomoo`1nOol001Eoo`03001oogoo07Moo`800003
Ool007oo00]oo`03001oogoo07ioo`005Goo00<007ooOol0N7oo0P0000=oo`00Ool02goo00<007oo
Ool0OGoo000EOol00`00Oomoo`1iOol200000goo001oo`0:Ool00`00Oomoo`1mOol0009oo`8000Ao
o`03001oogoo00=oo`<000Aoo`03001oogoo07Yoo`800003Ool007oo00Uoo`03001oogoo07eoo`00
00Eoo`00Oomoo`0000Yoo`03001oogoo00=oo`03001oogoo07]oo`800003Ool007oo00Qoo`03001o
ogoo07eoo`0000Eoo`00Oomoo`0000Moo`D000Aoo`03001oogoo07aoo`<000Uoo`03001oogoo07eo
o`0000Eoo`00Oomoo`0000Moo`04001oogoo0005Ool3001mOol30008Ool00`00Oomoo`1mOol00005
Ool007ooOol00008Ool00`00Ool00005Ool00`00Oomoo`1nOol00`00Ool00007Ool00`00Oomoo`1m
Ool00005Ool007ooOol00009Ool20005Ool00`00Oomoo`1nOol200000goo001oo`06Ool00`00Oomo
o`1lOol0009oo`8000]oo`03001oogoo00=oo`03001oogoo07moo`<000Moo`03001oogoo07aoo`00
5Goo00<007ooOol0P7oo0`001Woo00<007ooOol0O7oo000EOol00`00Oomoo`21Ool30005Ool00`00
Oomoo`1lOol001Eoo`03001oogoo089oo`8000Eoo`03001oogoo07aoo`005Goo00<007ooOol0Pgoo
0P0017oo00<007ooOol0O7oo000EOol20025Ool20004Ool00`00Oomoo`1kOol001Eoo`03001oogoo
08Eoo`8000=oo`03001oogoo07]oo`005Goo00<007ooOol0QGoo0P000goo00<007ooOol0Ngoo000E
Ool00`00Oomoo`26Ool20002Ool00`00Oomoo`1kOol001Eoo`03001oogoo08Moo`800003Ool007oo
07aoo`005Goo00<007ooOol0R7oo00<007oo0000OGoo000EOol00`00Oomoo`29Ool00`00Ool0001l
Ool001Eoo`03001oogoo08Yoo`8007aoo`005Goo0P00S7oo00<007ooOol0NWoo000EOol00`00Oomo
o`2;Ool00`00Oomoo`1jOol001Eoo`03001oogoo08]oo`8007]oo`005Goo00<007ooOol0Rgoo00<0
07oo0000NWoo000EOol00`00Oomoo`2<Ool00`00Ool0001iOol001Eoo`03001oogoo08aoo`04001o
o`00001hOol001Eoo`03001oogoo08aoo`03001oogoo008007Moo`005Goo00<007ooOol0S7oo00@0
07ooOomoo`8007Ioo`005Goo0P00SGoo00@007ooOomoo`<007Eoo`005Goo00<007ooOol0S7oo00<0
07ooOol00Woo0P00MGoo000EOol00`00Oomoo`2=Ool00`00Oomoo`02Ool2001dOol001Eoo`03001o
ogoo08eoo`03001oogoo00=oo`8007=oo`005Goo00<007ooOol0SGoo00<007ooOol00goo0`00LWoo
0002Ool20004Ool00`00Oomoo`02Ool30005Ool00`00Oomoo`2=Ool00`00Oomoo`04Ool3001aOol0
0005Ool007ooOol00007Ool01@00Oomoogoo000017oo00<007ooOol0SGoo00<007ooOol01Goo0`00
L7oo00001Goo001oogoo00001goo00D007ooOomoo`0000Aoo`03001oogoo08eoo`03001oogoo00Eo
o`03001oo`00008006ioo`0000Eoo`00Oomoo`0000Moo`@000Eoo`<008ioo`03001oogoo00Eoo`05
001oo`00Ool0001]Ool00005Ool007ooOol00007Ool00`00Oomoo`06Ool00`00Oomoo`2>Ool00`00
Oomoo`06Ool01@00Ool007oo0000K7oo00001Goo001oogoo000027oo00<007ooOol01Goo00<007oo
Ool0SWoo00<007ooOol01goo00D007oo001oo`0006]oo`000Woo0P002Woo0P001Goo00<007ooOol0
SWoo00<007ooOol01goo00H007ooOol007oo001ZOol001Eoo`03001oogoo08ioo`03001oogoo00Qo
o`06001oogoo001oo`00JGoo000EOol00`00Oomoo`2>Ool00`00Oomoo`09Ool01P00Oomoo`00Ool0
06Qoo`005Goo00<007ooOol0SWoo00<007ooOol02Woo00H007ooOol007oo001WOol001Eoo`03001o
ogoo08moo`03001oogoo00Yoo`06001oogoo001oo`00IWoo000EOol2002@Ool00`00Oomoo`0;Ool0
1P00Oomoo`00Ool006Eoo`005Goo00<007ooOol0Sgoo00<007ooOol037oo00H007ooOol007oo001T
Ool001Eoo`03001oogoo08moo`03001oogoo00eoo`06001oogoo001oo`00Hgoo000EOol00`00Oomo
o`2?Ool00`00Oomoo`0=Ool01`00Oomoogoo001oo`00069oo`005Goo00<007ooOol0Sgoo00<007oo
Ool03Woo00L007ooOomoo`00Ool0001QOol001Eoo`03001oogoo091oo`03001oogoo00ioo`07001o
ogooOol007oo0000H7oo000EOol00`00Oomoo`2@Ool00`00Oomoo`0?Ool01`00Oomoogoo001oo`00
05moo`005Goo00<007ooOol0T7oo00<007ooOol047oo00L007ooOomoo`00Ool0001NOol001Eoo`80
095oo`03001oogoo015oo`07001oogooOol007oo0000GGoo000EOol00`00Oomoo`2@Ool00`00Oomo
o`0BOol01`00Oomoogoo001oo`0005aoo`005Goo00<007ooOol0T7oo00<007ooOol04Woo00<007oo
Ool00Woo00<007oo0000Fgoo000EOol00`00Oomoo`2AOol00`00Oomoo`0BOol00`00Oomoo`02Ool0
0`00Ool0001JOol001Eoo`03001oogoo095oo`03001oogoo01=oo`03001oogoo009oo`03001oo`00
05Uoo`005Goo00<007ooOol0TGoo00<007ooOol057oo00<007ooOol00Woo00<007oo0000F7oo000E
Ool00`00Oomoo`2AOol00`00Oomoo`0EOol00`00Oomoo`02Ool00`00Ool0001GOol001Eoo`03001o
ogoo095oo`03001oogoo01Ioo`03001oogoo009oo`03001oo`0005Ioo`005Goo0P00TWoo00<007oo
Ool05goo00<007ooOol00Woo00@007oo000005Aoo`005Goo00<007ooOol0TWoo00<007ooOol05goo
00<007ooOol00Woo00@007ooOol005=oo`005Goo00<007ooOol0TWoo00<007ooOol05goo00<007oo
Ool00goo0P0000=oo`000000DGoo000EOol00`00Oomoo`2BOol00`00Oomoo`0HOol00`00Oomoo`04
Ool00`00Oomoo`02001?Ool001Eoo`03001oogoo099oo`03001oogoo01Uoo`03001oogoo00Aoo`80
009oo`03001oogoo04aoo`000Woo0P0017oo00<007ooOol00Woo0`001Goo00<007ooOol0TWoo00<0
07ooOol06Woo00<007ooOol01Goo00<007ooOol00P00C7oo00001Goo001oogoo00001goo00D007oo
Oomoo`0000Aoo`03001oogoo099oo`03001oogoo01]oo`03001oogoo00Eoo`80009oo`8004Yoo`00
00Eoo`00Oomoo`0000Moo`05001oogooOol00004Ool00`00Oomoo`2COol00`00Oomoo`0KOol00`00
Oomoo`06Ool01@00Oomoogoo0000BGoo00001Goo001oogoo000027oo0`001Goo0`00Tgoo00<007oo
Ool077oo0P001goo0P000Woo0P00Agoo00001Goo001oogoo00001goo00D007ooOomoo`0000Aoo`03
001oogoo09=oo`03001oogoo01ioo`03001oogoo00Ioo`05001oogooOol00016Ool00005Ool007oo
Ool00007Ool01@00Oomoogoo000017oo00<007ooOol0Tgoo00<007ooOol07goo0P001goo0P000Woo
0P00A7oo0002Ool20009Ool30005Ool00`00Oomoo`2COol00`00Oomoo`0QOol00`00Oomoo`06Ool2
0002Ool20012Ool001Eoo`03001oogoo09=oo`03001oogoo029oo`8000Qoo`05001oogooOol00011
Ool001Eoo`03001oogoo09Aoo`03001oogoo02=oo`03001oogoo00Ioo`80009oo`8003moo`005Goo
00<007ooOol0U7oo00<007ooOol097oo00<007ooOol01goo00@007ooOomoo`8003eoo`005Goo00<0
07ooOol0U7oo00<007ooOol09Goo0P0027oo0P000goo00<007ooOol0>Woo000EOol2002EOol00`00
Oomoo`0WOol00`00Oomoo`07Ool01000Oomoogoo0P00>Woo000EOol00`00Oomoo`2DOol00`00Oomo
o`0XOol20008Ool20003Ool3000gOol001Eoo`03001oogoo09Aoo`03001oogoo02Yoo`03001oogoo
00Moo`03001oogoo00=oo`<003Aoo`005Goo00<007ooOol0UGoo00<007ooOol0:Woo0P0027oo0P00
1Woo0P00<Woo000EOol00`00Oomoo`2EOol00`00Oomoo`0/Ool00`00Oomoo`07Ool30005Ool3000_
Ool001Eoo`03001oogoo09Eoo`03001oogoo02eoo`8000Yoo`<000Eoo`8002eoo`005Goo00<007oo
Ool0UGoo00<007ooOol0;goo00<007ooOol02Woo0P001Goo0`00:Woo000EOol00`00Oomoo`2EOol0
0`00Oomoo`0`Ool00`00Oomoo`0;Ool30005Ool3000WOol001Eoo`8009Ioo`03001oogoo035oo`80
00ioo`8000Ioo`8002Eoo`005Goo00<007ooOol0UGoo00<007ooOol0<goo00<007ooOol03Goo0`00
1Goo0`008Woo000EOol00`00Oomoo`2FOol00`00Oomoo`0cOol2000@Ool30005Ool4000NOol001Eo
o`03001oogoo09Ioo`03001oogoo03Eoo`<0011oo`8000Moo`L001Moo`005Goo00<007ooOol0UWoo
00<007ooOol0>7oo0`003goo0`002goo1P004Goo000EOol00`00Oomoo`2FOol00`00Oomoo`0kOol3
000?Ool4000=Ool7000:Ool001Eoo`03001oogoo09Ioo`03001oogoo03ioo`<0011oo`L000eoo`<0
00Moo`005Goo00<007ooOol0UWoo00<007ooOol0@Goo0`0057oo1P004Goo000EOol2002HOol00`00
Oomoo`13Ool3000GOol7000:Ool001Eoo`03001oogoo09Moo`03001oogoo04Ioo`<001]oo`<000Mo
o`005Goo00<007ooOol0Ugoo00<007ooOol0BGoo0`008Woo000EOol00`00Oomoo`2GOol00`00Oomo
o`1<Ool5000MOol001Eoo`03001oogoo09Moo`03001oogoo055oo`T001Aoo`003Goo0`001Goo00<0
07ooOol0Ugoo00<007ooOol0FWoo2@002goo000>Ool00`00Oomoo`04Ool00`00Oomoo`2HOol00`00
Oomoo`1ROol40007Ool000ioo`03001oogoo00Aoo`03001oogoo09Qoo`03001oogoo06eoo`003Woo
00<007ooOol017oo0`00V7ooJ@001goo000>Ool00`00Oomoo`04Ool00`00Oomoo`3oOol9Ool000eo
o`8000Ioo`03001oogoo0?moo`Uoo`003Woo00<007ooOol017oo00<007ooOol0ogoo2Goo000EOol0
0`00Oomoo`3oOol9Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.829852, -0.07747, \
0.0386179, 0.00624851}}]
}, Closed]],

Cell["\<\
This shows the clines at the three loci after 30 generations:\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DisplayTogether @@ \((\(ListPlot[#, PlotJoined -> True] &\) /@ 
          Transpose[
            AlleleFrequencyTable[\(cline[3, {0.05, 0.1, 0.2}]\)[
                30]]])\)\)], "Input",
  CellLabel->"In[36]:=  (18:28:24 on 5/1/01)"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.598367 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .13439 -18 -4.5 ]
[.01131 .13439 0 4.5 ]
[.01131 .25406 -18 -4.5 ]
[.01131 .25406 0 4.5 ]
[.01131 .37374 -18 -4.5 ]
[.01131 .37374 0 4.5 ]
[.01131 .49341 -18 -4.5 ]
[.01131 .49341 0 4.5 ]
[.01131 .61308 -6 -4.5 ]
[.01131 .61308 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13439 m
.03006 .13439 L
s
[(0.2)] .01131 .13439 1 0 Mshowa
.02381 .25406 m
.03006 .25406 L
s
[(0.4)] .01131 .25406 1 0 Mshowa
.02381 .37374 m
.03006 .37374 L
s
[(0.6)] .01131 .37374 1 0 Mshowa
.02381 .49341 m
.03006 .49341 L
s
[(0.8)] .01131 .49341 1 0 Mshowa
.02381 .61308 m
.03006 .61308 L
s
[(1)] .01131 .61308 1 0 Mshowa
.125 Mabswid
.02381 .04463 m
.02756 .04463 L
s
.02381 .07455 m
.02756 .07455 L
s
.02381 .10447 m
.02756 .10447 L
s
.02381 .16431 m
.02756 .16431 L
s
.02381 .19423 m
.02756 .19423 L
s
.02381 .22414 m
.02756 .22414 L
s
.02381 .28398 m
.02756 .28398 L
s
.02381 .3139 m
.02756 .3139 L
s
.02381 .34382 m
.02756 .34382 L
s
.02381 .40365 m
.02756 .40365 L
s
.02381 .43357 m
.02756 .43357 L
s
.02381 .46349 m
.02756 .46349 L
s
.02381 .52333 m
.02756 .52333 L
s
.02381 .55325 m
.02756 .55325 L
s
.02381 .58316 m
.02756 .58316 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.11905 .08477 m
.21429 .10354 L
.30952 .14192 L
.40476 .1999 L
.5 .27377 L
.59524 .35403 L
.69048 .4279 L
.78571 .48587 L
.88095 .52425 L
.97619 .54303 L
s
.11905 .05189 m
.21429 .06854 L
.30952 .10612 L
.40476 .17052 L
.5 .26199 L
.59524 .3658 L
.69048 .45727 L
.78571 .52168 L
.88095 .55926 L
.97619 .57591 L
s
.11905 .02448 m
.21429 .03405 L
.30952 .06142 L
.40476 .12464 L
.5 .24077 L
.59524 .38703 L
.69048 .50316 L
.78571 .56638 L
.88095 .59374 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[36]:=  (18:28:25 on 5/1/01)",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0017Ool5
000`Ool3000_Ool3000`Ool3000]Ool30004Ool20006Ool004Qoo`04001oogoo000aOol00`00Oomo
o`0]Ool01@00Oomoogoo0000;Woo00D007ooOomoo`0002eoo`03001oogoo009oo`04001oogoo0005
Ool004Uoo`03001oogoo02ioo`D002ioo`05001oogooOol0000^Ool01@00Oomoogoo0000;Goo00<0
07ooOol00Woo00@007ooOol000Eoo`00BWoo00<007ooOol0;Goo00@007ooOol002moo`@0031oo`<0
02ioo`03001oogoo009oo`04001oogoo0005Ool004Moo`05001oogooOol0000_Ool00`00Ool0000_
Ool00`00Oomoo`0`Ool01@00Oomoogoo0000;Goo00<007ooOol00Woo00@007ooOol000Eoo`00Agoo
00D007ooOomoo`00031oo`80031oo`03001oogoo02moo`05001oogooOol0000/Ool20004Ool01000
Oomoo`001Goo0018Ool3000bOol00`00Oomoo`0_Ool2000`Ool3000^Ool00`00Oomoo`03Ool20006
Ool001Moo`03001oogoo0?moo`Moo`005goo00<007ooOol0ogoo1goo000GOol00`00Oomoo`3oOol7
Ool001Moo`03001oogoo0?moo`Moo`004Gooo`003@000goo000GOol00`00Oomoo`0:Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomo
o`0:Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool001Moo`03
001oogoo031oo`03001oogoo031oo`03001oogoo031oo`03001oogoo031oo`03001oogoo031oo`03
001oogoo00Moo`005goo00<007ooOol05goo1`00j7oo000GOol00`00Oomoo`0NOol=003KOol001Mo
o`03001oogoo02]oo`P00==oo`005goo00<007ooOol0<goo1000cgoo000GOol00`00Oomoo`0gOol3
003<Ool001Moo`8003]oo`@00<Qoo`005goo00<007ooOol0?Woo1000a7oo000GOol00`00Oomoo`0G
Ool4000WOol30031Ool001Moo`03001oogoo01]oo`H002Aoo`@00;eoo`005goo00<007ooOol08Goo
1`008Goo0`00^Woo000GOol00`00Oomoo`0XOol6000NOol00`00Oomoo`2gOol001Moo`03001oogoo
02ioo`@001]oo`800;Moo`005goo00<007ooOol0<Woo0`006Woo00<007ooOol0]7oo000GOol2000f
Ool3000HOol2002dOol001Moo`03001oogoo03Qoo`8001Qoo`03001oogoo0;5oo`005goo00<007oo
Ool0>Woo0`005Woo0P00/Goo000GOol00`00Oomoo`0GOol4000ROol2000FOol00`00Oomoo`2^Ool0
01Moo`03001oogoo01]oo`D001moo`<001Aoo`800:ioo`005goo00<007ooOol087oo1@007Goo0`00
4goo00<007ooOol0Zgoo000GOol00`00Oomoo`0UOol5000KOol2000BOol00`00Oomoo`2ZOol001Mo
o`03001oogoo02Yoo`D001Qoo`<0011oo`800:Yoo`005goo0P00<7oo0`0067oo0P0047oo00<007oo
Ool0Ygoo000GOol00`00Oomoo`0bOol3000GOol00`00Oomoo`0>Ool2002WOol001Moo`03001oogoo
03Eoo`<001Eoo`03001oogoo00moo`03001oogoo0:Aoo`005goo00<007ooOol0>7oo0P0057oo0P00
47oo0P00Y7oo000GOol00`00Oomoo`0jOol3000COol00`00Oomoo`0?Ool00`00Oomoo`2QOol000Ao
o`8000Aoo`04001oogooOol50004Ool00`00Oomoo`0mOol2000BOol2000@Ool00`00Oomoo`2POol0
00=oo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol0?goo0`004Goo00<007ooOol03Goo
00<007ooOol0X7oo0003Ool01000Oomoo`002Goo00<007ooOol017oo00<007ooOol0@Woo0`003goo
00<007ooOol03Goo00<007ooOol0Wgoo0003Ool01000Oomoo`002Woo00<007ooOol00goo0`00AGoo
0P003Woo0P003Woo00<007ooOol0WWoo0003Ool01000Oomoo`001goo00D007ooOomoo`0000Aoo`03
001oogoo04Moo`<000eoo`03001oogoo00aoo`03001oogoo09eoo`000goo00@007ooOol000Moo`05
001oogooOol00004Ool00`00Oomoo`1:Ool2000<Ool2000=Ool00`00Oomoo`2LOol000Aoo`8000Uo
o`<000Eoo`03001oogoo04aoo`8000aoo`03001oogoo00Yoo`03001oogoo09aoo`005goo00<007oo
Ool0CWoo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol0Vgoo000GOol00`00Oomoo`1?Ool2
000;Ool2000;Ool00`00Oomoo`2JOol001Moo`03001oogoo055oo`8000]oo`03001oogoo00Uoo`03
001oogoo09Uoo`005goo00<007ooOol0Dgoo00<007ooOol02Goo0P002Woo00<007ooOol0V7oo000G
Ool2001EOol2000;Ool00`00Oomoo`07Ool00`00Oomoo`2HOol001Moo`03001oogoo05Ioo`8000Yo
o`03001oogoo00Moo`03001oogoo09Moo`005goo00<007ooOol0F7oo00<007ooOol027oo0P0027oo
00<007ooOol0UWoo000GOol00`00Oomoo`1IOol2000:Ool00`00Oomoo`06Ool00`00Oomoo`2EOol0
01Moo`03001oogoo05]oo`8000Uoo`03001oogoo00Ioo`03001oogoo09Aoo`005goo00<007ooOol0
GGoo00<007ooOol01goo00<007ooOol01Woo00<007ooOol0Tgoo000GOol00`00Oomoo`1NOol20008
Ool00`00Oomoo`05Ool00`00Oomoo`2COol001Moo`03001oogoo061oo`8000Moo`03001oogoo00Eo
o`03001oogoo099oo`005goo0P00Hgoo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0TGoo
000GOol00`00Oomoo`1SOol20006Ool00`00Oomoo`05Ool00`00Oomoo`2@Ool001Moo`03001oogoo
06Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo08moo`005goo00<007ooOol0IWoo00<0
07ooOol017oo00<007ooOol017oo00<007ooOol0Sgoo000GOol00`00Oomoo`1WOol00`00Oomoo`04
Ool00`00Oomoo`04Ool00`00Oomoo`2>Ool001Moo`03001oogoo06Qoo`8000Eoo`03001oogoo00Ao
o`03001oogoo08eoo`005goo00<007ooOol0JWoo00<007ooOol00goo00<007ooOol017oo00<007oo
Ool0S7oo000GOol00`00Oomoo`1[Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`2;Ool0
01Moo`8006eoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo08]oo`005goo00<007ooOol0
KGoo0P0017oo00<007ooOol00goo00<007ooOol0RWoo000GOol00`00Oomoo`1_Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`29Ool001Moo`03001oogoo071oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo08Qoo`005goo00<007ooOol0LGoo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol0Qgoo0004Ool20004Ool00`00Oomoo`03Ool30004Ool00`00Oomoo`1bOol20003Ool0
0`00Oomoo`02Ool00`00Oomoo`27Ool000=oo`04001oogoo000:Ool00`00Oomoo`03Ool00`00Oomo
o`1dOol01@00Oomoogoo000017oo00<007ooOol0QWoo0003Ool01000Oomoo`001goo1@0017oo00<0
07ooOol0MGoo00D007ooOomoo`0000Aoo`03001oogoo08Eoo`000goo00@007ooOol000Moo`04001o
ogoo0005Ool3001fOol01@00Oomoogoo00000goo00<007ooOol0QGoo0003Ool01000Oomoo`0027oo
00<007oo00001Goo00<007ooOol0Mgoo0P000Woo00D007ooOomoo`0008Ioo`000goo00@007ooOol0
00Uoo`8000Eoo`03001oogoo07Uoo`04001oogoo0003Ool00`00Oomoo`23Ool000Aoo`8000]oo`03
001oogoo00=oo`03001oogoo07Yoo`03001oo`0000=oo`03001oogoo08=oo`005goo00<007ooOol0
Ngoo00<007oo00000goo00<007ooOol0PWoo000GOol00`00Oomoo`1lOol30003Ool00`00Oomoo`21
Ool001Moo`03001oogoo07ioo`80009oo`03001oogoo085oo`005goo00<007ooOol0Ogoo0P000Woo
00<007ooOol0P7oo000GOol20021Ool200000goo001oo`21Ool001Moo`03001oogoo085oo`800003
Ool007oo081oo`005goo00<007ooOol0PWoo0P0000=oo`00Ool0Ogoo000GOol00`00Oomoo`24Ool2
0020Ool001Moo`03001oogoo08Eoo`8007moo`005goo00<007ooOol0QWoo0P00OWoo000GOol00`00
Oomoo`27Ool00`00Oomoo`1lOol001Moo`03001oogoo08Qoo`03001oogoo07]oo`005goo0P00RWoo
0P00Ngoo000GOol00`00Oomoo`29Ool00`00Ool0001jOol001Moo`03001oogoo08Yoo`03001oo`00
07Uoo`005goo00<007ooOol0Rgoo00<007oo0000N7oo000GOol00`00Oomoo`2;Ool200000goo001o
o`1fOol001Moo`03001oogoo08aoo`800003Ool0000007Eoo`005goo00<007ooOol0SGoo0P000Woo
00<007ooOol0LWoo000GOol00`00Oomoo`2=Ool00`00Ool00002Ool00`00Oomoo`1aOol001Moo`80
08moo`03001oo`00009oo`03001oogoo071oo`005goo00<007ooOol0Sgoo00<007oo00000Woo00<0
07ooOol0Kgoo000GOol00`00Oomoo`2?Ool01000Oomoo`000Woo00<007ooOol0KWoo000GOol00`00
Oomoo`2@Ool01000Oomoo`000Woo0P00KWoo000GOol00`00Oomoo`2@Ool01@00Oomoogoo00000goo
00<007ooOol0Jgoo0004Ool20004Ool00`00Oomoo`02Ool30005Ool00`00Oomoo`2AOol01@00Oomo
ogoo00000goo00<007ooOol0JWoo0003Ool01000Oomoo`001goo00D007ooOomoo`0000Aoo`03001o
ogoo099oo`04001oogooOol20002Ool2001ZOol000=oo`04001oogoo0007Ool01@00Oomoogoo0000
17oo00<007ooOol0TWoo00<007ooOol00goo00D007ooOomoo`0006Uoo`000goo00@007ooOol000Mo
o`@000Eoo`<009=oo`03001oogoo00=oo`05001oogooOol0001XOol000=oo`04001oogoo0007Ool0
0`00Oomoo`06Ool00`00Oomoo`2DOol00`00Oomoo`03Ool01000Oomoogoo0P00IWoo0003Ool01000
Oomoo`0027oo00<007ooOol01Goo00<007ooOol0U7oo00<007ooOol017oo00<007ooOol00Woo00<0
07ooOol0Hgoo0004Ool2000:Ool20005Ool00`00Oomoo`2EOol00`00Oomoo`04Ool00`00Oomoo`02
Ool00`00Oomoo`1ROol001Moo`03001oogoo09Ioo`03001oogoo00Aoo`03001oogoo009oo`80069o
o`005goo00<007ooOol0UWoo00<007ooOol01Goo00<007ooOol00goo00<007ooOol0Ggoo000GOol0
0`00Oomoo`2GOol00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`1NOol001Moo`03001oogoo
09Qoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo05eoo`005goo0P00VWoo00<007ooOol0
1Goo00<007ooOol00goo0P00GGoo000GOol00`00Oomoo`2JOol00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`1JOol001Moo`03001oogoo09Yoo`03001oogoo00Ioo`03001oogoo00Aoo`03001o
ogoo05Uoo`005goo00<007ooOol0Vgoo00<007ooOol01Woo00<007ooOol017oo0P00FGoo000GOol0
0`00Oomoo`2LOol00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`1FOol001Moo`03001oogoo
09eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo05Eoo`005goo00<007ooOol0WWoo00<0
07ooOol01Woo00<007ooOol01Goo0P00EGoo000GOol00`00Oomoo`2NOol00`00Oomoo`07Ool00`00
Oomoo`06Ool00`00Oomoo`1BOol001Moo`800:1oo`03001oogoo00Moo`03001oogoo00Ioo`80059o
o`005goo00<007ooOol0X7oo00<007ooOol01goo00<007ooOol01goo0P00D7oo000GOol00`00Oomo
o`2QOol00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`1=Ool001Moo`03001oogoo0:9oo`03
001oogoo00Moo`03001oogoo00Qoo`8004eoo`005goo00<007ooOol0Xgoo00<007ooOol01goo00<0
07ooOol02Goo0P00Bgoo000GOol00`00Oomoo`2SOol00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00
Oomoo`18Ool001Moo`03001oogoo0:Aoo`03001oogoo00Qoo`8000]oo`8004Qoo`005goo00<007oo
Ool0YGoo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0AGoo000GOol2002WOol00`00Oomo
o`09Ool2000;Ool20015Ool001Moo`03001oogoo0:Moo`03001oogoo00Yoo`03001oogoo00Yoo`80
04=oo`005goo00<007ooOol0Ygoo00<007ooOol02goo0P0037oo00<007ooOol0@7oo000GOol00`00
Oomoo`2XOol00`00Oomoo`0<Ool00`00Oomoo`0:Ool20010Ool001Moo`03001oogoo0:Uoo`03001o
ogoo00aoo`03001oogoo00]oo`8003ioo`0017oo0P0017oo00<007ooOol00Woo0`001Goo00<007oo
Ool0ZWoo00<007ooOol037oo0P003Goo00<007ooOol0>goo0003Ool01000Oomoo`001goo00D007oo
Oomoo`0000Aoo`03001oogoo0:]oo`03001oogoo00eoo`03001oogoo00]oo`8003]oo`000goo00@0
07ooOol000Moo`05001oogooOol00004Ool00`00Oomoo`2[Ool00`00Oomoo`0>Ool2000=Ool3000h
Ool000=oo`04001oogoo0008Ool30005Ool3002/Ool00`00Oomoo`0?Ool00`00Oomoo`0=Ool2000f
Ool000=oo`04001oogoo0007Ool01@00Oomoogoo000017oo00<007ooOol0[Goo00<007ooOol03goo
0P003goo0`00<goo0003Ool01000Oomoo`001goo00D007ooOomoo`0000Aoo`03001oogoo0:ioo`03
001oogoo011oo`03001oogoo00moo`80035oo`0017oo0P002Goo0`001Goo00<007ooOol0[goo0P00
4Goo0P004Goo0`00;Woo000GOol00`00Oomoo`2aOol00`00Oomoo`0@Ool00`00Oomoo`0AOol2000/
Ool001Moo`03001oogoo0;9oo`80015oo`03001oogoo019oo`<002Uoo`005goo00<007ooOol0]7oo
00<007ooOol03goo0P005Goo0P009goo000GOol00`00Oomoo`2eOol2000AOol00`00Oomoo`0DOol3
000TOol001Moo`800;Qoo`03001oogoo00moo`8001Moo`@0021oo`005goo00<007ooOol0^7oo0P00
4Goo0`0067oo1@006goo000GOol00`00Oomoo`2jOol00`00Oomoo`0AOol2000KOol5000FOol001Mo
o`03001oogoo0;]oo`8001=oo`<001eoo`D0015oo`005goo00<007ooOol0_Goo0P0057oo0P0087oo
1@0037oo000GOol00`00Oomoo`2oOol00`00Oomoo`0COol3000ROol30009Ool001Moo`03001oogoo
0<1oo`8001Ioo`8002aoo`005goo00<007ooOol0`Woo00<007ooOol05Goo0`00:Goo000GOol20034
Ool2000HOol2000WOol001Moo`03001oogoo0<Eoo`03001oogoo01Moo`<002Aoo`005goo00<007oo
Ool0aWoo0P006Woo100087oo000GOol00`00Oomoo`38Ool00`00Oomoo`0KOol7000IOol001Moo`03
001oogoo0<Uoo`<0025oo`H001=oo`005goo00<007ooOol0c7oo0`0097oo1`0037oo000GOol00`00
Oomoo`3?Ool4000WOol30009Ool001Moo`03001oogoo0==oo`@002moo`005goo0P00f7oo0`00;7oo
000GOol00`00Oomoo`3JOol4000XOol001Moo`03001oogoo0=ioo`<002Eoo`005goo00<007ooOol0
hGoo2@0077oo000GOol00`00Oomoo`3ZOol=000?Ool000moo`<000Eoo`03001oogoo0?Moo`H000Uo
o`0047oo00<007ooOol017oo00<007ooOol0ogoo1goo000@Ool00`00Oomoo`04Ool00`00Oomoo`3o
Ool7Ool0011oo`03001oogoo00Aoo`<00?moo`Moo`0047oo00<007ooOol017oo00<007ooOol0ogoo
1goo000?Ool2003oOol@Ool0011oo`03001oogoo0?moo`ioo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.925475, -0.0771043, \
0.0392449, 0.00624636}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Compiling", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, m, 
              Compiled -> 
                True]\), \(compiles\ the\ \(\(recursions\)\(.\)\(\ \)\)\)},
          {
            RowBox[{"StoreExact", "[", 
              RowBox[{"\[Psi]", ",", \(\[Psi]\_0\), ",", "W", ",", "m", ",", 
                RowBox[{"{", 
                  RowBox[{"t", ",", 
                    StyleBox["dt",
                      FontSlant->"Italic"]}], 
                  StyleBox["}",
                    FontSlant->"Italic"]}], 
                StyleBox[",",
                  FontSlant->"Italic"], \(Compiled -> True\)}], 
              "]"}], \(stores\ calculations\ made\ using\ compiled\ \
\(\(code\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->"Compiled"],

Cell[TextData[{
  "Functions can be greatly speeded by ",
  ButtonBox["compiling",
    ButtonData:>{"Compile"},
    ButtonStyle->"RefGuideLink"],
  ".  This requires that only numbers, or rectangular arrays of numbers, are \
used internally.  However, an arbitrary fitness function can still be \
supplied.  This isused to calculate and store a table of fitnesses, which is \
then used by the compiled code. "
}], "Text"],

Cell["Other options can be set as for uncompiled code.", "Text"],

Cell["Little time is saved with three loci:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(\(w[\[Sigma]_List, het]\)[d_]\)[
          p_List] := {1 - 
            2  \[Sigma] . \((p \((1 - p)\))\), \[Sigma] \((2  p - 
                1)\)};\)\), "\n", 
    \(\(pop[ng_] := 
        MakeCline[10, ng, 100, 
          NumericalModel -> AlleleFrequencies];\)\), "\n", 
    \({Timing[\(StoreExact[cline[3, {0.05, 0.1, 0.2}], pop[3], 
            w[{0.05, 0.1, 0.2}, het], 0.5, {30, 10}];\)], \n
      Timing[\(StoreExact[cline[3, {0.05, 0.1, 0.2}], pop[3], 
            w[{0.05, 0.1, 0.2}, het], 0.5, {30, 10}, 
            Compiled -> True];\)]}\)}], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \({{0.6333333333333258`\ Second, Null}, {0.6166666666666742`\ Second, 
        Null}}\)], "Output",
  CellLabel->"Out[21]="]
}, Closed]],

Cell["There is a larger saving in time with 30 loci:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ng = 30; \[Sigma]list = 
      Array[0.1\ Random[] &, ng];\), "\[IndentingNewLine]", 
    \({Timing[\(StoreExact[cline[ng, \[Sigma]list], pop[ng], 
            w[\[Sigma]list, het], 0.5, {100, 10}];\)], \n
      Timing[\(StoreExact[cline[ng, \[Sigma]list], pop[ng], 
            w[\[Sigma]list, het], 0.5, {100, 10}, 
            Compiled -> True];\)]}\)}], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \({{7.066666666666606`\ Second, Null}, {2.900000000000091`\ Second, 
        Null}}\)], "Output",
  CellLabel->"Out[49]="]
}, Closed]],

Cell[TextData[{
  "Note: ",
  StyleBox[" ",
    FontWeight->"Plain"],
  StyleBox[ButtonBox["Numerical errors",
    ButtonData:>{"Bugs", "Numerical bug"},
    ButtonStyle->"AddOnsLink"],
    FontWeight->"Plain"],
  StyleBox[" arise when compiled code is used with more loci.  This may be \
some kind of underflow error.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold",
  CellTags->"Numerical bug"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  "  Compilation cannot be used if fitnesses change in every generation.  \
With allele frequencies, ",
  ButtonBox["StoreResults",
    ButtonData:>{"Recursions: reproduction", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  "->False does not prevent compiled code being stored for every new fitness \
function.."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Varying deme size", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              FormBox[\(\(DemeSize\)\(->\)\),
                "TraditionalForm"], 
              "F"}], \(fixes\ deme\ size\ at\ \(F[deme]\)[n, W\&_]\)},
          {
            RowBox[{
              FormBox[\(DemeSize -> \(n\^*\)\),
                "TraditionalForm"], 
              "&"}], \(fixes\ deme\ size\ at\ \(n\^*\), \ 
            a\ fixed\ \(\(number\)\(.\)\)\)},
          {\(DemeSize -> ExponentialF[r, \[Beta], \[Lambda]]\), 
            RowBox[{
              RowBox[{
              "sets", " ", "deme", " ", "size", " ", "to", " ", "r", " ", "n",
                 
                
                FormBox[\(\(\(\(W\&_\)\(\ \)\)\^\[Beta]\) \(\(Exp\)\([\)\(-\
\[Lambda]\)\)\),
                  "TraditionalForm"], "n"}], "]"}]},
          {\(DemeSize -> PowerF[r, \[Beta], \[Lambda]]\), 
            RowBox[{
            "sets", " ", "deme", " ", "size", " ", "to", " ", "r", 
              " ", \(n\^\(1 - \[Lambda]\)\), 
              FormBox[\(\(\(W\&_\)\(\ \)\)\^\[Beta]\),
                "TraditionalForm"]}]},
          {\(DemeSize -> {{r\_1, \[Beta]\_1, \[Gamma]\_1, \[Lambda]\_1}, \
\[Ellipsis]}\), 
            RowBox[{
              RowBox[{
              "sets", " ", "the", " ", "new", " ", "size", " ", "of", " ", 
                "deme", " ", "i", " ", "to", " ", \(r\_i\), 
                " ", \(n\_i\%\(1 - \[Lambda]\_i\)\), 
                FormBox[\(\(\(W\&_\_i\)\(\ \)\)\^\[Beta]\_i\),
                  "TraditionalForm"], \(Exp[\(-\[Lambda]\_i\) n\_i]\)}], ";", 
              " ", \(can\ be\ used\ with\ Compiled -> True\)}]}
          }], TraditionalForm]],
  CellTags->{"DemeSize", "ExponentialF", "PowerF"}]], "DefinitionBox",
  CellTags->"DemeSize"],

Cell["\<\
The general form DemeSize->F allows deme size to be set as an \
arbitrary function of location, current deme size immediately before \
selection, and mean fitness.\
\>", "Text",
  CellTags->"DemeSize"],

Cell[TextData[{
  "Compiled code can only be used with certain definite versions of DemeSize: \
arbitrary functions cannot be supplied.  The general form is  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"r", " ", \(n\^\(1 - \[Lambda]\)\), 
          FormBox[\(\(\(\(W\&_\)\(\ \)\)\^\[Beta]\) Exp[\(-\[Lambda]n\)]\),
            "TraditionalForm"]}], TraditionalForm]]],
  " or ",
  Cell[BoxData[
      FormBox[
        RowBox[{"r", " ", \(n\^\(1 - \[Lambda]\)\), 
          FormBox[\(\(\(W\&_\)\(\ \)\)\^\[Beta]\),
            "TraditionalForm"]}], TraditionalForm]]],
  ".   If these functions are the same in every deme, they can be supplied in \
forms such as DemeSize\[Rule]ExponentialF[r, \[Beta], \[Lambda]]. "
}], "Text"],

Cell[TextData[{
  "This sets deme size to be a decreasing function of density, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"2", " ", "n", 
            FormBox[\(W\&_\ \(\(Exp\)\([\)\(-0.01\)\)\),
              "TraditionalForm"], "n"}], "]"}], TraditionalForm]]],
  ", via the function ",
  "ExponentialF[2,1,0.01]",
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(\(w[\[Sigma]_List, het]\)[d_]\)[
          p_List] := {1 - 
            2  \[Sigma] . \((p \((1 - p)\))\), \[Sigma] \((2  p - 
                1)\)};\)\), "\n", 
    \(\(pop[ng_] := 
        MakeCline[10, ng, 100, 
          NumericalModel -> AlleleFrequencies];\)\), "\n", 
    \(IterateExact[pop[3], w[{0.05, 0.1, 0.2}, het], 0.5, 
      DemeSize -> ExponentialF[2, 1, 0.01]]\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \({AlleleFrequencies[{0, 0, 0}, 73.57588823428847`], 
      AlleleFrequencies[{0, 0, 0}, 73.57588823428847`], 
      AlleleFrequencies[{0, 0, 0}, 73.57588823428847`], 
      AlleleFrequencies[{0, 0, 0}, 73.57588823428847`], 
      AlleleFrequencies[{0.2446043165467626`, 0.2392086330935252`, 
          0.22841726618705036`}, 63.91905290353811`], 
      AlleleFrequencies[{0.7553956834532374`, 0.7607913669064748`, 
          0.7715827338129497`}, 63.91905290353811`], 
      AlleleFrequencies[{1.`, 1.`, 1.`}, 73.57588823428847`], 
      AlleleFrequencies[{1.`, 1.`, 1.`}, 73.57588823428847`], 
      AlleleFrequencies[{1.`, 1.`, 1.`}, 73.57588823428847`], 
      AlleleFrequencies[{1.`, 1.`, 1.`}, 73.57588823428847`]}\)], "Output",
  CellLabel->"Out[4]="]
}, Closed]],

Cell["\<\
In these examples, deme size is lower in the centre, where mean \
fitness is reduced.\
\>", "Text"],

Cell["\<\
With this particular form of density-dependence, compiled code can \
be used:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IterateExact[pop[3], w[{0.05, 0.1, 0.2}, het], 0.5, 
      DemeSize -> ExponentialF[2, 1, 0.01], Compiled \[Rule] True]\)], "Input",\

  CellLabel->"In[83]:="],

Cell[BoxData[
    \({AlleleFrequencies[{0.`, 0.`, 0.`}, 73.57588823428847`], 
      AlleleFrequencies[{0.`, 0.`, 0.`}, 73.57588823428847`], 
      AlleleFrequencies[{0.`, 0.`, 0.`}, 73.57588823428847`], 
      AlleleFrequencies[{0.`, 0.`, 0.`}, 73.57588823428847`], 
      AlleleFrequencies[{0.2446043165467626`, 0.2392086330935252`, 
          0.22841726618705036`}, 63.91905290353811`], 
      AlleleFrequencies[{0.7553956834532374`, 0.7607913669064748`, 
          0.7715827338129497`}, 63.91905290353811`], 
      AlleleFrequencies[{1.`, 1.`, 1.`}, 73.57588823428847`], 
      AlleleFrequencies[{1.`, 1.`, 1.`}, 73.57588823428847`], 
      AlleleFrequencies[{1.`, 1.`, 1.`}, 73.57588823428847`], 
      AlleleFrequencies[{1.`, 1.`, 1.`}, 73.57588823428847`]}\)], "Output",
  CellLabel->"Out[83]="]
}, Closed]],

Cell[TextData[{
  "This general form, ",
  Cell[BoxData[
      \(TraditionalForm\`\(F[deme]\)[n, W\&_]\)]],
  ", can only be used with uncompiled code:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IterateExact[pop[3], w[{0.05, 0.1, 0.2}, het], 0.5, 
      DemeSize \[Rule] F]\)], "Input",
  CellLabel->"In[87]:="],

Cell[BoxData[
    \({AlleleFrequencies[{0, 0, 0}, \(F[1]\)[100.`, 1.`]], 
      AlleleFrequencies[{0, 0, 0}, \(F[2]\)[100.`, 1.`]], 
      AlleleFrequencies[{0, 0, 0}, \(F[3]\)[100.`, 1.`]], 
      AlleleFrequencies[{0, 0, 0}, \(F[4]\)[100.`, 1.`]], 
      AlleleFrequencies[{0.2446043165467626`, 0.2392086330935252`, 
          0.22841726618705036`}, \(F[5]\)[100.`, 0.86875`]], 
      AlleleFrequencies[{0.7553956834532374`, 0.7607913669064748`, 
          0.7715827338129497`}, \(F[6]\)[100.`, 0.86875`]], 
      AlleleFrequencies[{1.`, 1.`, 1.`}, \(F[7]\)[100.`, 1.`]], 
      AlleleFrequencies[{1.`, 1.`, 1.`}, \(F[8]\)[100.`, 1.`]], 
      AlleleFrequencies[{1.`, 1.`, 1.`}, \(F[9]\)[100.`, 1.`]], 
      AlleleFrequencies[{1.`, 1.`, 1.`}, \(F[10]\)[100.`, 1.`]]}\)], "Output",\

  CellLabel->"Out[87]="]
}, Closed]],

Cell[TextData[{
  "Variation in density regulation across demes can be accommodated using \
compiled code by supplying a table of parameters, ",
  Cell[BoxData[
      \(TraditionalForm\`{{r\_1, \[Beta]\_1, \[Gamma]\_1, \[Lambda]\_1}, \
\[Ellipsis]}\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tbl = Array[{2, 1, 0, 0.01} &, 10];\)\), "\n", 
    \(IterateExact[pop[3], w[{0.05, 0.1, 0.2}, het], 0.5, 
      DemeSize -> tbl]\)}], "Input",
  CellLabel->"In[88]:="],

Cell[BoxData[
    \({AlleleFrequencies[{0, 0, 0}, 73.57588823428847`], 
      AlleleFrequencies[{0, 0, 0}, 73.57588823428847`], 
      AlleleFrequencies[{0, 0, 0}, 73.57588823428847`], 
      AlleleFrequencies[{0, 0, 0}, 73.57588823428847`], 
      AlleleFrequencies[{0.2446043165467626`, 0.2392086330935252`, 
          0.22841726618705036`}, 63.91905290353811`], 
      AlleleFrequencies[{0.7553956834532374`, 0.7607913669064748`, 
          0.7715827338129497`}, 63.91905290353811`], 
      AlleleFrequencies[{1.`, 1.`, 1.`}, 73.57588823428847`], 
      AlleleFrequencies[{1.`, 1.`, 1.`}, 73.57588823428847`], 
      AlleleFrequencies[{1.`, 1.`, 1.`}, 73.57588823428847`], 
      AlleleFrequencies[{1.`, 1.`, 1.`}, 73.57588823428847`]}\)], "Output",
  CellLabel->"Out[89]="]
}, Closed]],

Cell[TextData[{
  "Density-dependence must still be of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(r\_i\), " ", \(n\_i\%\(1 - \[Lambda]\_i\)\), 
          FormBox[\(\(\(W\&_\_i\)\(\ \)\)\^\[Beta]\_i\),
            "TraditionalForm"], \(Exp[\(-\[Lambda]\_i\) n\_i]\)}], 
        TraditionalForm]]]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Random drift", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, m, 
              RandomDrift -> True]\), \(allows\ for\ random\ drift\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->{"IterateExact", "RandomDrift"}],

Cell["\<\
This defines selection against heterozygotes, and the initial \
cline:\
\>", "MathCaption"],

Cell[BoxData[{
    \(\(\(\(w[\[Sigma]_List, het]\)[d_]\)[
          p_List] := {1 - 
            2  \[Sigma] . \((p \((1 - p)\))\), \[Sigma] \((2  p - 
                1)\)};\)\), "\n", 
    \(\(pop[ng_] := 
        MakeCline[10, ng, 100, 
          NumericalModel -> AlleleFrequencies];\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
This iterates 10 replicate clines of 10 demes, each over 20 \
generations; population size is 2N=100 per deme:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tt = 
        Table[Nest[
            IterateExact[#, w[{0.05, 0.1, 0.2}, het], 0.5, 
                RandomDrift -> True, MigrationOrder -> USM] &, pop[3], 
            20], {10}];\)\), "\n", 
    \(\(pt = AlleleFrequencyTable /@ tt;\)\), "\n", 
    \({Table[
          Mean[pt\[LeftDoubleBracket]Range[10], d, 
              l\[RightDoubleBracket]], {l, 3}, {d, 10}] // MatrixForm, 
      Table[StandardDeviation[
            pt\[LeftDoubleBracket]Range[10], d, l\[RightDoubleBracket]], {l, 
            3}, {d, 10}] // MatrixForm}\)}], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0.09249999999999999`", "0.12025000000000001`", 
                  "0.17475000000000002`", "0.255`", "0.38575000000000004`", 
                  "0.55125`", "0.7`", "0.8155000000000001`", "0.885`", 
                  "0.909`"},
                {"0.05425000000000001`", "0.07625000000000001`", "0.14375`", 
                  "0.25075`", "0.39275`", "0.5645`", "0.7260000000000001`", 
                  "0.84375`", "0.915`", "0.9490000000000001`"},
                {"0.0175`", "0.039999999999999994`", "0.09725`", "0.2225`", 
                  "0.4175000000000001`", "0.627`", "0.7935000000000001`", 
                  "0.9047499999999999`", "0.9675`", "0.9915`"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0.06088468152535944`", "0.06330536663225673`", 
                  "0.0746794073951373`", "0.08478731561317936`", 
                  "0.09105897051422837`", "0.09066306671774713`", 
                  "0.070059498523279`", "0.046767747671041665`", 
                  "0.04065436972550156`", "0.0457681354462056`"},
                {"0.034177843700268745`", "0.0386265956160893`", 
                  "0.051211028543121886`", "0.059512487018365416`", 
                  "0.07725723626661488`", "0.08672914414684631`", 
                  "0.08311805526545428`", "0.07062469272302871`", 
                  "0.04092676385936226`", "0.016338434577536608`"},
                {"0.00927960727138337`", "0.011547005383792516`", 
                  "0.03228454222482745`", "0.06347571714180682`", 
                  "0.09374907406950155`", "0.09671550490427525`", 
                  "0.08907082076140933`", "0.06632673752802193`", 
                  "0.030912061651652334`", "0.011914044000441012`"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output",
  CellLabel->"Out[6]="]
}, Closed]],

Cell[TextData[{
  "The option RandomDrift->True is passed to ",
  Cell[BoxData[
      FormBox[
        ButtonBox["NewGametes",
          ButtonData:>{"Allele frequencies: reproduction", "RandomDrift"},
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  ", and ensures that haploid gametes are sampled from a multinomial \
distribution, immediately after selection and population regulation.  Other \
options, such as Compiled->True, and MigrationOrder->MUS, can be used with \
RandomDrift->True."
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{974, 660},
WindowMargins->{{4, Automatic}, {Automatic, 2}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "IterateExact"->{
    Cell[2045, 64, 1031, 22, 60, "DefinitionBox",
      CellTags->{"IterateExact", "StoreExact"}],
    Cell[46999, 1258, 301, 6, 37, "DefinitionBox",
      CellTags->{"IterateExact", "RandomDrift"}]},
  "StoreExact"->{
    Cell[2045, 64, 1031, 22, 60, "DefinitionBox",
      CellTags->{"IterateExact", "StoreExact"}]},
  "Compiled"->{
    Cell[34786, 923, 855, 20, 56, "DefinitionBox",
      CellTags->"Compiled"]},
  "Numerical bug"->{
    Cell[37659, 1003, 408, 13, 24, "Text",
      CellTags->"Numerical bug"]},
  "DemeSize"->{
    Cell[38545, 1035, 1778, 40, 136, "DefinitionBox",
      CellTags->"DemeSize"],
    Cell[40326, 1077, 211, 5, 22, "Text",
      CellTags->"DemeSize"]},
  "RandomDrift"->{
    Cell[46999, 1258, 301, 6, 37, "DefinitionBox",
      CellTags->{"IterateExact", "RandomDrift"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"IterateExact", 122412, 3922},
  {"StoreExact", 122631, 3927},
  {"Compiled", 122747, 3930},
  {"Numerical bug", 122849, 3933},
  {"DemeSize", 122943, 3936},
  {"RandomDrift", 123117, 3941}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 43, 0, 36, "SubsectionIcon"],
Cell[1785, 53, 82, 1, 28, "MathCaption"],
Cell[1870, 56, 102, 2, 26, "Input"],

Cell[CellGroupData[{
Cell[1997, 62, 45, 0, 24, "SubsubsectionIcon"],
Cell[2045, 64, 1031, 22, 60, "DefinitionBox",
  CellTags->{"IterateExact", "StoreExact"}],
Cell[3079, 88, 107, 3, 28, "MathCaption"],
Cell[3189, 93, 234, 5, 39, "Input"],
Cell[3426, 100, 52, 0, 22, "Text"],
Cell[3481, 102, 289, 7, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[3795, 113, 479, 10, 69, "Input"],
Cell[4277, 125, 15720, 400, 184, 3494, 244, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[20012, 528, 87, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[20124, 535, 254, 5, 39, "Input"],
Cell[20381, 542, 14315, 373, 184, 3343, 233, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[34745, 921, 38, 0, 20, "SubsubsectionIcon"],
Cell[34786, 923, 855, 20, 56, "DefinitionBox",
  CellTags->"Compiled"],
Cell[35644, 945, 421, 9, 37, "Text"],
Cell[36068, 956, 64, 0, 22, "Text"],
Cell[36135, 958, 60, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[36220, 962, 615, 13, 72, "Input"],
Cell[36838, 977, 142, 3, 20, "Output"]
}, Closed]],
Cell[36995, 983, 69, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[37089, 987, 412, 8, 57, "Input"],
Cell[37504, 997, 140, 3, 20, "Output"]
}, Closed]],
Cell[37659, 1003, 408, 13, 24, "Text",
  CellTags->"Numerical bug"],
Cell[38070, 1018, 389, 10, 38, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[38496, 1033, 46, 0, 20, "SubsubsectionIcon"],
Cell[38545, 1035, 1778, 40, 136, "DefinitionBox",
  CellTags->"DemeSize"],
Cell[40326, 1077, 211, 5, 22, "Text",
  CellTags->"DemeSize"],
Cell[40540, 1084, 733, 16, 39, "Text"],
Cell[41276, 1102, 366, 11, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[41667, 1117, 440, 10, 58, "Input"],
Cell[42110, 1129, 776, 13, 46, "Output"]
}, Closed]],
Cell[42901, 1145, 109, 3, 18, "Text"],
Cell[43013, 1150, 108, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[43146, 1157, 179, 4, 26, "Input"],
Cell[43328, 1163, 801, 13, 65, "Output"]
}, Closed]],
Cell[44144, 1179, 171, 5, 20, "MathCaption"],

Cell[CellGroupData[{
Cell[44340, 1188, 136, 3, 26, "Input"],
Cell[44479, 1193, 810, 14, 95, "Output"]
}, Closed]],
Cell[45304, 1210, 278, 7, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[45607, 1221, 191, 4, 42, "Input"],
Cell[45801, 1227, 777, 13, 65, "Output"]
}, Closed]],
Cell[46593, 1243, 325, 8, 22, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[46955, 1256, 41, 0, 20, "SubsubsectionIcon"],
Cell[46999, 1258, 301, 6, 37, "DefinitionBox",
  CellTags->{"IterateExact", "RandomDrift"}],
Cell[47303, 1266, 101, 3, 28, "MathCaption"],
Cell[47407, 1271, 327, 8, 42, "Input"],
Cell[47737, 1281, 141, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[47903, 1288, 594, 13, 90, "Input"],
Cell[48500, 1303, 2046, 36, 94, "Output"]
}, Closed]],
Cell[50561, 1342, 517, 11, 32, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

