(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11768,        392]*)
(*NotebookOutlinePosition[     13526,        447]*)
(*  CellTagsIndexPosition[     13277,        436]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Immigration from a source  population", "SubsectionIcon",
  CellTags->"Immigration"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MigrateExact[\[Phi], \[Phi]\_s, 
              m]\), \(gives\ allele\ frequencies\ and\ deme\ sizes\ after\ \
migration\ from\ a\ source\ population\ \[Phi]\_s\)},
          {\(FixedEnds \[Rule] {\[Psi]\_s}\), \(specifies\ the\ source\ \
population\ \(\(explicitly\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"MigrateExact"],

Cell["\<\
This gives the allele frequencies after a proportion m of \
individuals migrate:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(pop = AlleleFrequencies[{0.1, 0.2, 0.3}, 10]; 
    popS = AlleleFrequencies[{1, 1, 1}, 10];\), "\n", 
    \(popM = MigrateExact[pop, popS, m]; 
    AlleleFrequencyTable[popM] // Simplify\)}], "Input",
  CellLabel->"In[4]:=  (18:25:18 on 4/30/01)"],

Cell[BoxData[
    \({\(\(0.1`\)\(\[InvisibleSpace]\)\) + 
        0.9`\ m, \(\(0.2`\)\(\[InvisibleSpace]\)\) + 
        0.8`\ m, \(\(0.3`\)\(\[InvisibleSpace]\)\) + 0.7`\ m}\)], "Output",
  CellLabel->"Out[5]=  (18:25:18 on 4/30/01)"]
}, Open  ]],

Cell["\<\
The deme size is the same in both demes, and so remains constant:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DemeSize[popM] // Simplify\)], "Input",
  CellLabel->"In[6]:=  (18:25:30 on 4/30/01)"],

Cell[BoxData[
    \(10\)], "Output",
  CellLabel->"Out[6]=  (18:25:30 on 4/30/01)"]
}, Open  ]],

Cell["\<\
Immigration from a larger population has a greater effect on allele \
frequency:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(popBig = AlleleFrequencies[{1, 1, 1}, 100];\)\), "\n", 
    \(popM2 = MigrateExact[pop, popBig, m]; 
    AlleleFrequencyTable[popM2] // Simplify\)}], "Input",
  CellLabel->"In[7]:=  (18:26:49 on 4/30/01)"],

Cell[BoxData[
    \({\(\(\(1.`\)\(\[InvisibleSpace]\)\) + 99.`\ m\)\/\(10 + 90\ m\), \
\(\(\(2.`\)\(\[InvisibleSpace]\)\) + 98.`\ m\)\/\(10 + 90\ m\), \(\(\(3.`\)\(\
\[InvisibleSpace]\)\) + 97.`\ m\)\/\(10 + 90\ m\)}\)], "Output",
  CellLabel->"Out[8]=  (18:26:49 on 4/30/01)"]
}, Open  ]],

Cell["The deme size also increases:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DemeSize[popM2]\)], "Input",
  CellLabel->"In[9]:=  (18:26:58 on 4/30/01)"],

Cell[BoxData[
    \(10\ \((1 - m)\) + 100\ m\)], "Output",
  CellLabel->"Out[9]=  (18:26:58 on 4/30/01)"]
}, Open  ]],

Cell[TextData[{
  "In general, the new deme size is ",
  Cell[BoxData[
      \(TraditionalForm\`n \((1 - m)\) + \(n\_s\) 
          m, \ \(\(and\)\(\ \)\(the\)\(\ \)\(new\)\(\ \)\(allele\)\(\ \
\)\(frequency\)\(\ \)\(is\)\(\ \)\)\)]],
  Cell[BoxData[
      FormBox[
        FractionBox[
          FormBox[\(n\ p \((1 - m)\) + \(n\_s\) \(p\_s\) m\),
            "TraditionalForm"], \(n \((1 - m)\) + \(n\_s\) m\)], 
        TraditionalForm]]],
  "; thus, m is the ",
  StyleBox["forward",
    FontSlant->"Italic"],
  " migration rate. "
}], "Text"],

Cell[TextData[{
  "The ",
  StyleBox["backwards",
    FontSlant->"Italic"],
  " migration rate (the proportion of the new population that are \
immigrants), is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(m\_b\)\(=\)\)\)]],
  " ",
  Cell[BoxData[
      FormBox[
        FractionBox[
          FormBox[\(\(n\_s\) m\),
            "TraditionalForm"], \(n \((1 - m)\) + \(n\_s\) m\)], 
        TraditionalForm]]]
}], "Text"],

Cell[CellGroupData[{

Cell["Simulating constant numbers of immigrants", "SubsubsectionIcon",
  CellTags->"Constant numbers"],

Cell["\<\
MigrateExact[\[Psi],m] is not at present set up to model other \
kinds of migration in a natural way.  However, one can work around the \
problem, as follows.\
\>", "Text"],

Cell[TextData[{
  "Suppose that a constant number of immigrants, M, comes in from a source \
population withactual allele frequencies ",
  Cell[BoxData[
      \(TraditionalForm\`P\_s\)]],
  ".  No individuals emigrate.  We need to set the dummy variables ",
  Cell[BoxData[
      \(TraditionalForm\`n\_s, \ p\_s, \ m\ appropriately\)]],
  ":"
}], "Text"],

Cell[BoxData[{
    \(M + n = \(n\_s\) m + n \((1 - m)\)\ \), "\[IndentingNewLine]", 
    \(M\[VeryThinSpace]P\_s + n\[VeryThinSpace]p = \(n\_s\) p\_s\ m + 
        n\ p\ \((1 - m)\)\)}], "DisplayMath"],

Cell["The solution is:", "Text"],

Cell[BoxData[{
    \(m = M\/\(\((n\_s - n)\)\(\ \)\)\), "\[IndentingNewLine]", 
    \(p\_s = \[VeryThinSpace]\(P\_s\) \((1 - 
              n\/n\_s)\) + \(\(n\/n\_s\)\(\ \)\(p\)\(\ \ \)\)\)}], \
"DisplayMath"],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`P\_s = 
        1, \ \(\(this\ simplifies\ to\ q\_s\)\(=\)\)\)]],
  Cell[BoxData[
      \(\(\(n\/n\_s\)\(\ \)\(q\)\(\ \)\)\)]]
}], "Text"],

Cell[TextData[{
  "The source deme size, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n\_s\)\(,\)\)\)]],
  " can be set to any arbitrary value, provided that it is always greater \
than the actual deme size, n."
}], "Text"],

Cell["\<\
If migration occurs after selection, then the problem is more \
complicated.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Nearest-neighbour migration", "SubsectionIcon",
  CellTags->"Nearest-neighbour migration"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MigrateExact[{\[Phi]\_1, \[Ellipsis], \[Phi]\_n}, 
              m]\), \(gives\ the\ array\ of\ genotype\ frequencies\ after\ \
nearest - neighbour\ migration\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["\<\
This sets up a stepped cline across 6 demes, with 3 loci and deme \
size 10:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cl = 
      MakeCline[6, 3, 10, 
        NumericalModel \[Rule] AlleleFrequencies]\)], "Input",
  CellLabel->"In[10]:=  (18:27:47 on 4/30/01)"],

Cell[BoxData[
    \({AlleleFrequencies[{0, 0, 0}, 10], AlleleFrequencies[{0, 0, 0}, 10], 
      AlleleFrequencies[{0, 0, 0}, 10], AlleleFrequencies[{1, 1, 1}, 10], 
      AlleleFrequencies[{1, 1, 1}, 10], 
      AlleleFrequencies[{1, 1, 1}, 10]}\)], "Output",
  CellLabel->"Out[10]=  (18:27:47 on 4/30/01)"]
}, Open  ]],

Cell["\<\
Nearest-neighbour migration only affects the central demes in this \
example:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cl2 = MigrateExact[cl, m] // Simplify\)], "Input",
  CellLabel->"In[11]:=  (18:27:59 on 4/30/01)"],

Cell[BoxData[
    \({AlleleFrequencies[{0, 0, 0}, 10], AlleleFrequencies[{0, 0, 0}, 10], 
      AlleleFrequencies[{m\/2, m\/2, m\/2}, 10], 
      AlleleFrequencies[{1 - m\/2, 1 - m\/2, 1 - m\/2}, 10], 
      AlleleFrequencies[{1, 1, 1}, 10], 
      AlleleFrequencies[{1, 1, 1}, 10]}\)], "Output",
  CellLabel->"Out[11]=  (18:27:59 on 4/30/01)"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MigrateExact[{\[Phi]\_1, \[Ellipsis], \[Phi]\_n}, m, 
              FixedEnds \[Rule] {\[Phi]\_0, \[Phi]\_\(n + 1\)}]\), 
            
            RowBox[{\(sets\ fixed\ endpoints\), ",", " ", \(\[Phi]\_0\), ",", 
              
              RowBox[{\(\[Phi]\_\(n + 1\)\), " ", 
                StyleBox["outside",
                  FontSlant->"Italic"], " ", "the", " ", "iterated", " ", 
                "demes"}]}]}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"FixedEnds"],

Cell["\<\
Using FixedEnds sets up hypothetical demes with fixed genotype \
frequencies (here, 0.1 and 0.9) outside the ends of the iterated cline:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Psi]0 = 
        MakePopulation[3, 0.1, 10, 
          NumericalModel \[Rule] 
            AlleleFrequencies];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]1 = 
        MakePopulation[3, 0.9, 10, 
          NumericalModel \[Rule] 
            AlleleFrequencies];\)\), "\[IndentingNewLine]", 
    \({\[Psi]0, \[Psi]1}\)}], "Input",
  CellLabel->"In[21]:=  (18:31:03 on 4/30/01)"],

Cell[BoxData[
    \({AlleleFrequencies[{0.1`, 0.1`, 0.1`}, 10], 
      AlleleFrequencies[{0.9`, 0.9`, 0.9`}, 10]}\)], "Output",
  CellLabel->"Out[23]=  (18:31:04 on 4/30/01)"]
}, Open  ]],

Cell["\<\
Immigration from these source populations introduces \
polymorphism:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cl3 = MigrateExact[cl, 0.5, FixedEnds \[Rule] {\[Psi]0, \[Psi]1}]; 
    AlleleFrequencyMean[cl3]\)], "Input",
  CellLabel->"In[15]:=  (18:29:04 on 4/30/01)"],

Cell[BoxData[
    \({0.025000000000000005`, 0, 0.25`, 0.75`, 1.`, 
      0.9750000000000001`}\)], "Output",
  CellLabel->"Out[15]=  (18:29:04 on 4/30/01)"]
}, Open  ]],

Cell["\<\
FixedEnds can also be used to set different kinds of boundary \
condition at either end: \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cl4 = MigrateExact[cl, 0.5, FixedEnds \[Rule] {{}, \[Psi]1}]; 
    AlleleFrequencyMean[cl4]\)], "Input",
  CellLabel->"In[16]:=  (18:29:18 on 4/30/01)"],

Cell[BoxData[
    \({0, 0, 0.25`, 0.75`, 1.`, 0.9750000000000001`}\)], "Output",
  CellLabel->"Out[16]=  (18:29:18 on 4/30/01)"]
}, Open  ]],

Cell["\<\
The default {} or {{}} indicates that there should be no flow \
across the boundary.\
\>", "Text"],

Cell["Deme sizes may change as a result of migration:", "MathCaption",
  CellTags->"DemeSize"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Psi]1 = 
        MakePopulation[3, 0.9, 100, 
          NumericalModel \[Rule] 
            AlleleFrequencies];\)\), "\[IndentingNewLine]", 
    \(cl5 = 
      MigrateExact[cl, 0.5, 
        FixedEnds \[Rule] {{}, \[Psi]1}]; {AlleleFrequencyMean[cl5], 
      DemeSize[cl5]}\)}], "Input",
  CellLabel->"In[24]:=  (18:31:23 on 4/30/01)"],

Cell[BoxData[
    \({{0, 0, 0.25`, 0.75`, 1.`, 0.923076923076923`}, {10.`, 10.`, 10.`, 
        10.`, 10.`, 32.5`}}\)], "Output",
  CellLabel->"Out[25]=  (18:31:23 on 4/30/01)"]
}, Open  ]],

Cell[TextData[{
  "m is the ",
  StyleBox["forward",
    FontSlant->"Italic"],
  " migration rate (see above); immigration from the larger source population \
increases deme size."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{929, 672},
WindowMargins->{{Automatic, 40}, {Automatic, 3}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Immigration"->{
    Cell[1739, 51, 90, 1, 36, "SubsectionIcon",
      CellTags->"Immigration"]},
  "MigrateExact"->{
    Cell[1832, 54, 419, 8, 56, "DefinitionBox",
      CellTags->"MigrateExact"]},
  "Constant numbers"->{
    Cell[5193, 171, 102, 1, 24, "SubsubsectionIcon",
      CellTags->"Constant numbers"]},
  "Nearest-neighbour migration"->{
    Cell[6877, 230, 96, 1, 36, "SubsectionIcon",
      CellTags->"Nearest-neighbour migration"]},
  "FixedEnds"->{
    Cell[8488, 281, 559, 12, 37, "DefinitionBox",
      CellTags->"FixedEnds"]},
  "DemeSize"->{
    Cell[10886, 361, 94, 1, 28, "MathCaption",
      CellTags->"DemeSize"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Immigration", 12630, 414},
  {"MigrateExact", 12731, 417},
  {"Constant numbers", 12837, 420},
  {"Nearest-neighbour migration", 12963, 423},
  {"FixedEnds", 13078, 426},
  {"DemeSize", 13175, 429}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 90, 1, 36, "SubsectionIcon",
  CellTags->"Immigration"],
Cell[1832, 54, 419, 8, 56, "DefinitionBox",
  CellTags->"MigrateExact"],
Cell[2254, 64, 111, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2390, 71, 268, 5, 54, "Input"],
Cell[2661, 78, 234, 4, 32, "Output"]
}, Open  ]],
Cell[2910, 85, 98, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3033, 92, 106, 2, 39, "Input"],
Cell[3142, 96, 83, 2, 32, "Output"]
}, Open  ]],
Cell[3240, 101, 111, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3376, 108, 228, 4, 54, "Input"],
Cell[3607, 114, 277, 4, 48, "Output"]
}, Open  ]],
Cell[3899, 121, 52, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3976, 125, 95, 2, 39, "Input"],
Cell[4074, 129, 105, 2, 32, "Output"]
}, Open  ]],
Cell[4194, 134, 547, 16, 38, "Text"],
Cell[4744, 152, 424, 15, 36, "Text"],

Cell[CellGroupData[{
Cell[5193, 171, 102, 1, 24, "SubsubsectionIcon",
  CellTags->"Constant numbers"],
Cell[5298, 174, 182, 4, 22, "Text"],
Cell[5483, 180, 354, 9, 36, "Text"],
Cell[5840, 191, 201, 3, 41, "DisplayMath"],
Cell[6044, 196, 32, 0, 22, "Text"],
Cell[6079, 198, 209, 4, 76, "DisplayMath"],
Cell[6291, 204, 205, 7, 36, "Text"],
Cell[6499, 213, 226, 6, 22, "Text"],
Cell[6728, 221, 100, 3, 22, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6877, 230, 96, 1, 36, "SubsectionIcon",
  CellTags->"Nearest-neighbour migration"],
Cell[6976, 233, 276, 5, 37, "DefinitionBox"],
Cell[7255, 240, 107, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7387, 247, 163, 4, 39, "Input"],
Cell[7553, 253, 307, 5, 45, "Output"]
}, Open  ]],
Cell[7875, 261, 108, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[8008, 268, 118, 2, 39, "Input"],
Cell[8129, 272, 344, 6, 72, "Output"]
}, Open  ]],
Cell[8488, 281, 559, 12, 37, "DefinitionBox",
  CellTags->"FixedEnds"],
Cell[9050, 295, 169, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[9244, 303, 401, 10, 69, "Input"],
Cell[9648, 315, 175, 3, 32, "Output"]
}, Open  ]],
Cell[9838, 321, 99, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[9962, 328, 177, 3, 39, "Input"],
Cell[10142, 333, 155, 3, 32, "Output"]
}, Open  ]],
Cell[10312, 339, 120, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[10457, 346, 172, 3, 39, "Input"],
Cell[10632, 351, 128, 2, 32, "Output"]
}, Open  ]],
Cell[10775, 356, 108, 3, 22, "Text"],
Cell[10886, 361, 94, 1, 28, "MathCaption",
  CellTags->"DemeSize"],

Cell[CellGroupData[{
Cell[11005, 366, 360, 9, 54, "Input"],
Cell[11368, 377, 177, 3, 32, "Output"]
}, Open  ]],
Cell[11560, 383, 192, 6, 24, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

