(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    101240,       2295]*)
(*NotebookOutlinePosition[    173021,       4871]*)
(*  CellTagsIndexPosition[    172884,       4863]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Stability", "SubsectionIcon"],

Cell["\<\
The stability of an equilibrium is given by the eigenvalues of the \
stability matrix.  This is the matrix of derivatives of the new values with \
respect to the old values.  \
\>", "Text"],

Cell["\<\
The stability matrix can also be calculated for populations which \
are not at equilibrium.  For example, it might be used to calculate the \
distribution of fluctuations caused by random drift, or the sensitivity of \
the outcome to initial conditions.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(StabilityDirect[AlleleFrequencies[p\+_, n], W, 
              m]\), \(gives\ the\ derivative\ of\ {\(p\+_\^*\), \(n\^*\)}\ \
wrt\ p\+_, n, \ 
            by\ direct\ differentiation\ of\ \(\(IterateExact[]\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->"StabilityDirect"]], "DefinitionBox",
  CellTags->"StabilityDirect"],

Cell[TextData[{
  "StabilityDirect[] can take all the options of IterateExact[].  However, \
RandomDrift->True and Compiled\[Rule]True cannot be used, since algebraic \
derivatives are taken.   For a single deme, generates one number, whilst for \
a stepping-stone model, generates an array ",
  Cell[BoxData[
      \(n\_d\[Times]n\_d\)]],
  "."
}], "Text"],

Cell["This loads the package. ", "MathCaption",
  CellTags->{"S5.24.1", "1.4"}],

Cell[BoxData[
    \(\(<< NumericalModels`ExactModel`;\)\)], "Input",
  CellLabel->"In[1]:="],

Cell[TextData[{
  "This defines a fitness with heterozygote advantage ",
  Cell[BoxData[
      \(TraditionalForm\`s\_1, \ s\_2\)]],
  "at two loci, and with epistasis \[Epsilon] favouring genotypes {0,0} and \
{1,1}:"
}], "MathCaption"],

Cell[BoxData[
    \(\(\(w[{s1_, s2_, \[Epsilon]_}, epi]\)[{p1_, p2_}] := {1 + 
            2 \((s1\ p1 \((1 - p1)\) + 
                  s2\ p2 \((1 - p2)\))\) + \[Epsilon] \((2  p1 - 
                  1)\) \((2  p2 - 
                  1)\), {\(-s1\) \((2  p1 - 1)\) + \[Epsilon] \((2  p2 - 
                    1)\), \(-s2\) \((2  p2 - 1)\) + \[Epsilon] \((2  p1 - 
                    1)\)}};\)\)], "Input",
  CellLabel->"In[119]:="],

Cell["The individual fitnesses are:", "MathCaption"],

Cell[BoxData[GridBox[{
        {" ", \(\(Q\_2\) Q\_2\), \(\(Q\_2\) P\_2\), \(\(P\_2\) P\_2\)},
        {\(\(Q\_1\) Q\_1\), \(1 + \[Epsilon]\), \(1 + 
            s\_2\), \(1 - \[Epsilon]\)},
        {\(\(Q\_1\) P\_1\), \(1 + s\_1\), \(1 + s\_1 + s\_2\), \(1 + s\_1\)},
        {\(\(P\_1\) P\_1\), \(1 - \[Epsilon]\), \(1 + 
            s\_2\), \(1 + \[Epsilon]\)}
        },
      GridFrame->True,
      RowLines->True,
      ColumnLines->True]], "DisplayMath"],

Cell[TextData[{
  "This shows the mean fitness as a function of allele frequencies (i.e. the \
",
  StyleBox["adaptive landscape",
    FontSlant->"Italic"],
  "):"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ContourPlot[\(\(w[{0.1, 0.2, 0.3}, epi]\)[{p1, 
              p2}]\)\[LeftDoubleBracket]1\[RightDoubleBracket], {p1, 0, 
          1}, {p2, 0, 1}];\)\)], "Input",
  CellLabel->"In[146]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.21154 -0.0125 -9 -9 ]
[.21154 -0.0125 9 0 ]
[.40385 -0.0125 -9 -9 ]
[.40385 -0.0125 9 0 ]
[.59615 -0.0125 -9 -9 ]
[.59615 -0.0125 9 0 ]
[.78846 -0.0125 -9 -9 ]
[.78846 -0.0125 9 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -18 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -18 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -18 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -18 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(0.2)] .21154 -0.0125 0 1 Mshowa
.40385 0 m
.40385 .00625 L
s
[(0.4)] .40385 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(0.6)] .59615 -0.0125 0 1 Mshowa
.78846 0 m
.78846 .00625 L
s
[(0.8)] .78846 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.5 0 m
.5 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0.2)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(0.4)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(0.6)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(0.8)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(1)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .25962 m
.00375 .25962 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .45192 m
.00375 .45192 L
s
0 .5 m
.00375 .5 L
s
0 .54808 m
.00375 .54808 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .74038 m
.00375 .74038 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.21154 .99375 m
.21154 1 L
s
.40385 .99375 m
.40385 1 L
s
.59615 .99375 m
.59615 1 L
s
.78846 .99375 m
.78846 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.25962 .99625 m
.25962 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.45192 .99625 m
.45192 1 L
s
.5 .99625 m
.5 1 L
s
.54808 .99625 m
.54808 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.74038 .99625 m
.74038 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .5 m
1 .5 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.8 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.7 g
.01923 .42712 m
.04415 .43132 L
.08791 .4413 L
.15659 .45627 L
.22527 .47256 L
.29396 .49121 L
.32061 .5 L
.36264 .5152 L
.43132 .55516 L
.45147 .56868 L
.5 .62554 L
.50756 .63736 L
.54477 .70604 L
.56868 .76121 L
.57595 .77473 L
.60446 .84341 L
.63162 .91209 L
.63736 .9251 L
.65798 .98077 L
.01923 .98077 L
F
0 g
.01923 .42712 m
.04415 .43132 L
.08791 .4413 L
.15659 .45627 L
.22527 .47256 L
.29396 .49121 L
.32061 .5 L
.36264 .5152 L
.43132 .55516 L
.45147 .56868 L
.5 .62554 L
.50756 .63736 L
.54477 .70604 L
.56868 .76121 L
.57595 .77473 L
.60446 .84341 L
.63162 .91209 L
.63736 .9251 L
.65798 .98077 L
s
.6 g
.01923 .52225 m
.08791 .54921 L
.13216 .56868 L
.15659 .58032 L
.22527 .61732 L
.25757 .63736 L
.29396 .66263 L
.34776 .70604 L
.36264 .71964 L
.4161 .77473 L
.43132 .79253 L
.47107 .84341 L
.5 .88503 L
.51766 .91209 L
.55874 .98077 L
.01923 .98077 L
F
0 g
.01923 .52225 m
.08791 .54921 L
.13216 .56868 L
.15659 .58032 L
.22527 .61732 L
.25757 .63736 L
.29396 .66263 L
.34776 .70604 L
.36264 .71964 L
.4161 .77473 L
.43132 .79253 L
.47107 .84341 L
.5 .88503 L
.51766 .91209 L
.55874 .98077 L
s
.5 g
.01923 .60651 m
.07956 .63736 L
.08791 .64194 L
.15659 .68269 L
.19172 .70604 L
.22527 .73028 L
.28045 .77473 L
.29396 .78661 L
.35271 .84341 L
.36264 .85392 L
.41348 .91209 L
.43132 .93426 L
.46616 .98077 L
.01923 .98077 L
F
0 g
.01923 .60651 m
.07956 .63736 L
.08791 .64194 L
.15659 .68269 L
.19172 .70604 L
.22527 .73028 L
.28045 .77473 L
.29396 .78661 L
.35271 .84341 L
.36264 .85392 L
.41348 .91209 L
.43132 .93426 L
.46616 .98077 L
s
.4 g
.01923 .68295 m
.05844 .70604 L
.08791 .72454 L
.15659 .77183 L
.16051 .77473 L
.22527 .82615 L
.24519 .84341 L
.29396 .88895 L
.31693 .91209 L
.36264 .96165 L
.37905 .98077 L
.01923 .98077 L
F
0 g
.01923 .68295 m
.05844 .70604 L
.08791 .72454 L
.15659 .77183 L
.16051 .77473 L
.22527 .82615 L
.24519 .84341 L
.29396 .88895 L
.31693 .91209 L
.36264 .96165 L
.37905 .98077 L
s
.3 g
.01923 .75342 m
.05183 .77473 L
.08791 .79973 L
.146 .84341 L
.15659 .85187 L
.22527 .91093 L
.22654 .91209 L
.29396 .97805 L
.29655 .98077 L
.01923 .98077 L
F
0 g
.01923 .75342 m
.05183 .77473 L
.08791 .79973 L
.146 .84341 L
.15659 .85187 L
.22527 .91093 L
.22654 .91209 L
.29396 .97805 L
.29655 .98077 L
s
.9 g
.01923 .31542 m
.08791 .30684 L
.13528 .29396 L
.15659 .28467 L
.21905 .22527 L
.22527 .21225 L
.23937 .15659 L
.24123 .08791 L
.23444 .01923 L
.01923 .01923 L
F
0 g
.01923 .31542 m
.08791 .30684 L
.13528 .29396 L
.15659 .28467 L
.21905 .22527 L
.22527 .21225 L
.23937 .15659 L
.24123 .08791 L
.23444 .01923 L
s
.2 g
.01923 .81912 m
.05347 .84341 L
.08791 .86921 L
.14126 .91209 L
.15659 .92511 L
.21798 .98077 L
.01923 .98077 L
F
0 g
.01923 .81912 m
.05347 .84341 L
.08791 .86921 L
.14126 .91209 L
.15659 .92511 L
.21798 .98077 L
s
.1 g
.01923 .88091 m
.06032 .91209 L
.08791 .9341 L
.14285 .98077 L
.01923 .98077 L
F
0 g
.01923 .88091 m
.06032 .91209 L
.08791 .9341 L
.14285 .98077 L
s
1 g
.01923 .17325 m
.04201 .15659 L
.08791 .10172 L
.09483 .08791 L
.11599 .01923 L
.01923 .01923 L
F
0 g
.01923 .17325 m
.04201 .15659 L
.08791 .10172 L
.09483 .08791 L
.11599 .01923 L
s
.01923 .9394 m
.07073 .98077 L
.01923 .98077 L
F
.01923 .9394 m
.07073 .98077 L
s
.7 g
.98077 .57288 m
.95585 .56868 L
.91209 .5587 L
.84341 .54373 L
.77473 .52744 L
.70604 .50879 L
.67939 .5 L
.63736 .4848 L
.56868 .44484 L
.54853 .43132 L
.5 .37446 L
.49244 .36264 L
.45523 .29396 L
.43132 .23879 L
.42405 .22527 L
.39554 .15659 L
.36838 .08791 L
.36264 .0749 L
.34202 .01923 L
.98077 .01923 L
F
0 g
.98077 .57288 m
.95585 .56868 L
.91209 .5587 L
.84341 .54373 L
.77473 .52744 L
.70604 .50879 L
.67939 .5 L
.63736 .4848 L
.56868 .44484 L
.54853 .43132 L
.5 .37446 L
.49244 .36264 L
.45523 .29396 L
.43132 .23879 L
.42405 .22527 L
.39554 .15659 L
.36838 .08791 L
.36264 .0749 L
.34202 .01923 L
s
.6 g
.98077 .47775 m
.91209 .45079 L
.86784 .43132 L
.84341 .41968 L
.77473 .38268 L
.74243 .36264 L
.70604 .33737 L
.65224 .29396 L
.63736 .28036 L
.5839 .22527 L
.56868 .20747 L
.52893 .15659 L
.5 .11497 L
.48234 .08791 L
.44126 .01923 L
.98077 .01923 L
F
0 g
.98077 .47775 m
.91209 .45079 L
.86784 .43132 L
.84341 .41968 L
.77473 .38268 L
.74243 .36264 L
.70604 .33737 L
.65224 .29396 L
.63736 .28036 L
.5839 .22527 L
.56868 .20747 L
.52893 .15659 L
.5 .11497 L
.48234 .08791 L
.44126 .01923 L
s
.5 g
.98077 .39349 m
.92044 .36264 L
.91209 .35806 L
.84341 .31731 L
.80828 .29396 L
.77473 .26972 L
.71955 .22527 L
.70604 .21339 L
.64729 .15659 L
.63736 .14608 L
.58652 .08791 L
.56868 .06574 L
.53384 .01923 L
.98077 .01923 L
F
0 g
.98077 .39349 m
.92044 .36264 L
.91209 .35806 L
.84341 .31731 L
.80828 .29396 L
.77473 .26972 L
.71955 .22527 L
.70604 .21339 L
.64729 .15659 L
.63736 .14608 L
.58652 .08791 L
.56868 .06574 L
.53384 .01923 L
s
.4 g
.98077 .31705 m
.94156 .29396 L
.91209 .27546 L
.84341 .22817 L
.83949 .22527 L
.77473 .17385 L
.75481 .15659 L
.70604 .11105 L
.68307 .08791 L
.63736 .03835 L
.62095 .01923 L
.98077 .01923 L
F
0 g
.98077 .31705 m
.94156 .29396 L
.91209 .27546 L
.84341 .22817 L
.83949 .22527 L
.77473 .17385 L
.75481 .15659 L
.70604 .11105 L
.68307 .08791 L
.63736 .03835 L
.62095 .01923 L
s
.3 g
.98077 .24658 m
.94817 .22527 L
.91209 .20027 L
.854 .15659 L
.84341 .14813 L
.77473 .08907 L
.77346 .08791 L
.70604 .02195 L
.70345 .01923 L
.98077 .01923 L
F
0 g
.98077 .24658 m
.94817 .22527 L
.91209 .20027 L
.854 .15659 L
.84341 .14813 L
.77473 .08907 L
.77346 .08791 L
.70604 .02195 L
.70345 .01923 L
s
.9 g
.98077 .68458 m
.91209 .69316 L
.86472 .70604 L
.84341 .71533 L
.78095 .77473 L
.77473 .78775 L
.76063 .84341 L
.75877 .91209 L
.76556 .98077 L
.98077 .98077 L
F
0 g
.98077 .68458 m
.91209 .69316 L
.86472 .70604 L
.84341 .71533 L
.78095 .77473 L
.77473 .78775 L
.76063 .84341 L
.75877 .91209 L
.76556 .98077 L
s
.2 g
.98077 .18088 m
.94653 .15659 L
.91209 .13079 L
.85874 .08791 L
.84341 .07489 L
.78202 .01923 L
.98077 .01923 L
F
0 g
.98077 .18088 m
.94653 .15659 L
.91209 .13079 L
.85874 .08791 L
.84341 .07489 L
.78202 .01923 L
s
.1 g
.98077 .11909 m
.93968 .08791 L
.91209 .0659 L
.85715 .01923 L
.98077 .01923 L
F
0 g
.98077 .11909 m
.93968 .08791 L
.91209 .0659 L
.85715 .01923 L
s
1 g
.98077 .82675 m
.95799 .84341 L
.91209 .89828 L
.90517 .91209 L
.88401 .98077 L
.98077 .98077 L
F
0 g
.98077 .82675 m
.95799 .84341 L
.91209 .89828 L
.90517 .91209 L
.88401 .98077 L
s
.98077 .0606 m
.92927 .01923 L
.98077 .01923 L
F
.98077 .0606 m
.92927 .01923 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[146]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`006@3oool2000002/0oooo0P0000040?ooo`040000003oool0oooo0?ooo`D00000903oool2
000000@0oooo00<000000?ooo`3oool00`3oool3000002@0oooo0P0000040?ooo`030000003oool0
oooo0080oooo0`00000U0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<00000:P3oool3
000000H0oooo000H0?ooo`040000003oool0oooo000002T0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000S0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool08P3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000008`3oool0
10000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000:P3oool00`000000oooo
0?ooo`050?ooo`00603oool010000000oooo0?ooo`00000Y0?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool08`3oool010000000oooo0?ooo`0000070?ooo`D000008`3oool01000
0000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000008`3oool010000000oooo0?oo
o`0000070?ooo`050000003oool0oooo0?ooo`000000:P3oool00`000000oooo0?ooo`050?ooo`00
603oool010000000oooo0?ooo`00000Y0?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool08P3oool010000000oooo0?ooo`0000070?ooo`040000003oool0oooo000002@0oooo00@0
00000?ooo`3oool000001`3oool4000002@0oooo00@000000?ooo`3oool00000203oool3000002/0
oooo00<000000?ooo`3oool01@3oool001P0oooo00@000000?ooo`3oool00000:@3oool010000000
oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000008`3oool010000000oooo0?ooo`00
00080?ooo`030000003oool0000002@0oooo00@000000?ooo`3oool000001`3oool00`000000oooo
0?ooo`0U0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000Z0?oo
o`030000003oool0oooo00D0oooo000H0?ooo`040000003oool0oooo000002T0oooo00@000000?oo
o`3oool000001`3oool01@000000oooo0?ooo`3oool0000002<0oooo00@000000?ooo`3oool00000
2@3oool2000002@0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0T0?ooo`04
0000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo0000000Y0?ooo`8000001`3oool0
01T0oooo0P00000[0?ooo`8000002@3oool3000002D0oooo0P00000;0?ooo`030000003oool0oooo
02<0oooo0P00000:0?ooo`8000009@3oool2000000T0oooo0`00000[0?ooo`030000003oool0oooo
00D0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000E0?oo
ool000002`0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool00P3oool100000040oooo000>0?ooo`8000001@3oool00`000000oooo0?oo
o`3o0?ooo`L0oooo0@0000010?ooo`003@3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0?l0oooo1`3oool100000040oooo000=0?ooo`040000003oool0oooo000000@0oooo0P00
000M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo0140oooo0P00000B0?ooo`8000004P3oool2000000l0oooo0P00
00010?ooo`003@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01`0oooo00<0
00000>KViP3Vi^H0703Vi^H00`000000c<c<0<c<c00J0<c<c0030000002c/k<0/k>c01L0/k>c00<0
000009VIV@2IVIT05P2IVIT00`000000Ogmo07moO`0D07moO`030000001VIVH0IVIV01<0IVIV00<0
000004a<C01<C4`04`1<C4`00`000000<c<c03<c<`0A03<c<`030000000I6AT06ATI01406ATI2`00
00050?ooo`4000000@3oool000d0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0L0?ooo`030000003Vi^H0i^KV01`0i^KV00<000000<c<c03<c<`06`3<c<`00`000000/k>c0;>c
/`0G0;>c/`030000002IVIT0VIVI01H0VIVI00<0000007moO`1oOgl0501oOgl00`000000IVIV06IV
IP0C06IVIP030000001<C4`0C4a<01<0C4a<00<0000003<c<`0c<c<04@0c<c<00`0000006ATI01TI
6@0A01TI6@X000001@3oool100000040oooo000=0?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool06`3oool00`000000i^KV0>KViP0M0>KViP030000003<c<`0c<c<01/0c<c<00<0
00000;>c/`2c/k<05`2c/k<00`000000VIVI09VIV@0G09VIV@030000001oOgl0Ogmo01@0Ogmo00<0
000006IVIP1VIVH04`1VIVH00`000000C4a<04a<C00C04a<C0030000000c<c<0<c<c0140<c<c00<0
000001TI6@0I6AT04@0I6AT9000000D0oooo0@0000010?ooo`003P3oool2000000D0oooo00<00000
0?ooo`3oool06`3oool00`000000i^KV0>KViP0M0>KViP030000003<c<`0c<c<01/0c<c<00<00000
0;>c/`2c/k<0602c/k<00`000000VIVI09VIV@0F09VIV@030000001oOgl0Ogmo01@0Ogmo00<00000
06IVIP1VIVH0501VIVH00`000000C4a<04a<C00C04a<C0030000000c<c<0<c<c0140<c<c00<00000
01TI6@0I6AT04@0I6AT8000000D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0K0?oo
o`030000003Vi^H0i^KV01d0i^KV00<000000<c<c03<c<`0703<c<`00`000000/k>c0;>c/`0H0;>c
/`030000002IVIT0VIVI01H0VIVI00<0000007moO`1oOgl0501oOgl00`000000IVIV06IVIP0D06IV
IP030000001<C4`0C4a<01<0C4a<00<0000003<c<`0c<c<04@0c<c<00`0000006ATI01TI6@0A01TI
6@L000001@3oool100000040oooo000E0?ooo`030000003oool0oooo01X0oooo00<000000>KViP3V
i^H07`3Vi^H00`000000c<c<0<c<c00K0<c<c0030000002c/k<0/k>c01P0/k>c00<0000009VIV@2I
VIT05`2IVIT00`000000Ogmo07moO`0D07moO`030000001VIVH0IVIV01@0IVIV00<0000004a<C01<
C4`04`1<C4`00`000000<c<c03<c<`0A03<c<`8000004`0I6AT5000000D0oooo0@0000010?ooo`00
5@3oool00`000000oooo0?ooo`0J0?ooo`030000003Vi^H0i^KV01l0i^KV00<000000<c<c03<c<`0
6`3<c<`00`000000/k>c0;>c/`0I0;>c/`030000002IVIT0VIVI01L0VIVI00<0000007moO`1oOgl0
4`1oOgl00`000000IVIV06IVIP0E06IVIP030000001<C4`0C4a<01<0C4a<0P00000C03<c<`030000
000I6AT06ATI01406ATI100000050?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool06P3o
ool00`000000i^KV0>KViP0O0>KViP030000003<c<`0c<c<01`0c<c<00<000000;>c/`2c/k<0602c
/k<00`000000VIVI09VIV@0G09VIV@030000001oOgl0Ogmo01@0Ogmo00<0000006IVIP1VIVH05@1V
IVH00`000000C4a<04a<C00D04a<C0030000000c<c<0<c<c0140<c<c00<0000001TI6@0I6AT04@0I
6AT3000000D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0I0?ooo`030000003Vi^H0
i^KV0200i^KV00<000000<c<c03<c<`0703<c<`00`000000/k>c0;>c/`0I0;>c/`030000002IVIT0
VIVI01L0VIVI00<0000007moO`1oOgl0501oOgl00`000000IVIV06IVIP0E06IVIP030000001<C4`0
C4a<01@0C4a<00<0000003<c<`0c<c<04@0c<c<00`0000006ATI01TI6@0A01TI6@8000001@3oool1
00000040oooo000E0?ooo`030000003oool0oooo01T0oooo00<000000>KViP3Vi^H0803Vi^H00`00
0000c<c<0<c<c00L0<c<c0030000002c/k<0/k>c01X0/k>c00<0000009VIV@2IVIT05`2IVIT00`00
0000Ogmo07moO`0D07moO`030000001VIVH0IVIV01D0IVIV00<0000004a<C01<C4`0501<C4`00`00
0000<c<c03<c<`0A03<c<`030000000I6AT06ATI01406ATI00<000000?ooo`3oool00`3oool10000
0040oooo000E0?ooo`030000003oool0oooo01T0oooo00<000000>KViP3Vi^H0803Vi^H00`000000
c<c<0<c<c00M0<c<c0030000002c/k<0/k>c01T0/k>c00<0000009VIV@2IVIT05`2IVIT00`000000
Ogmo07moO`0E07moO`030000001VIVH0IVIV01D0IVIV00<0000004a<C01<C4`0501<C4`00`000000
<c<c03<c<`0A03<c<`030000000I6AT06ATI01406ATI00<000000?ooo`3oool00P3oool100000040
oooo000E0?ooo`030000003oool0oooo01P0oooo00<000000>KViP3Vi^H08@3Vi^H00`000000c<c<
0<c<c00M0<c<c0030000002c/k<0/k>c01X0/k>c00<0000009VIV@2IVIT05`2IVIT00`000000Ogmo
07moO`0E07moO`030000001VIVH0IVIV01D0IVIV00<0000004a<C01<C4`0501<C4`00`000000<c<c
03<c<`0A03<c<`030000000I6AT06ATI01006ATI1@3oool100000040oooo000E0?ooo`8000006@3o
ool00`000000i^KV0>KViP0Q0>KViP030000003<c<`0c<c<01d0c<c<00<000000;>c/`2c/k<06P2c
/k<00`000000VIVI09VIV@0H09VIV@030000001oOgl0Ogmo01D0Ogmo00<0000006IVIP1VIVH05@1V
IVH00`000000C4a<04a<C00D04a<C0030000000c<c<0<c<c0140<c<c0P00000@01TI6@@0oooo0P00
00010?ooo`005@3oool00`000000oooo0?ooo`0H0?ooo`030000003Vi^H0i^KV0240i^KV00<00000
0<c<c03<c<`07P3<c<`00`000000/k>c0;>c/`0J0;>c/`030000002IVIT0VIVI01L0VIVI00<00000
07moO`1oOgl05P1oOgl00`000000IVIV06IVIP0E06IVIP030000001<C4`0C4a<01@0C4a<00<00000
03<c<`0c<c<04P0c<c<00`0000006ATI01TI6@0=01TI6@D0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`0G0?ooo`030000003Vi^H0i^KV02<0i^KV00<000000<c<c03<c<`07@3<c<`00`00
0000/k>c0;>c/`0J0;>c/`030000002IVIT0VIVI01P0VIVI00<0000007moO`1oOgl05P1oOgl00`00
0000IVIV06IVIP0E06IVIP030000001<C4`0C4a<01@0C4a<00<0000003<c<`0c<c<04P0c<c<00`00
00006ATI01TI6@0<01TI6@D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003Vi^H0i^KV02<0i^KV00<000000<c<c03<c<`07@3<c<`00`000000/k>c0;>c/`0K0;>c/`03
0000002IVIT0VIVI01P0VIVI00<0000007moO`1oOgl05P1oOgl00`000000IVIV06IVIP0E06IVIP03
0000001<C4`0C4a<01@0C4a<00<0000003<c<`0c<c<04P0c<c<00`0000006ATI01TI6@0;01TI6@D0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0G0?ooo`030000003Vi^H0i^KV02<0i^KV
00<000000<c<c03<c<`07P3<c<`00`000000/k>c0;>c/`0K0;>c/`030000002IVIT0VIVI01P0VIVI
00<0000007moO`1oOgl05P1oOgl00`000000IVIV06IVIP0E06IVIP030000001<C4`0C4a<01@0C4a<
00<0000003<c<`0c<c<04P0c<c<00`0000006ATI01TI6@0:01TI6@D0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003Vi^H0i^KV02@0i^KV00<000000<c<c03<c<`07P3<
c<`00`000000/k>c0;>c/`0K0;>c/`030000002IVIT0VIVI01T0VIVI00<0000007moO`1oOgl05P1o
Ogl00`000000IVIV06IVIP0E06IVIP030000001<C4`0C4a<01@0C4a<00<0000003<c<`0c<c<04P0c
<c<00`0000006ATI01TI6@0901TI6@D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0F
0?ooo`030000003Vi^H0i^KV02@0i^KV00<000000<c<c03<c<`07`3<c<`00`000000/k>c0;>c/`0K
0;>c/`030000002IVIT0VIVI01T0VIVI00<0000007moO`1oOgl05P1oOgl00`000000IVIV06IVIP0E
06IVIP<00000501<C4`2000001<0<c<c0P00000901TI6@D0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003Vi^H0i^KV02@0i^KV00<000000<c<c03<c<`07`3<c<`00`00
0000/k>c0;>c/`0K0;>c/`030000002IVIT0VIVI01T0VIVI00<0000007moO`1oOgl05`1oOgl00`00
0000IVIV06IVIP0G06IVIP030000001<C4`0C4a<01<0C4a<00<0000003<c<`0c<c<04P0c<c<00`00
00006ATI01TI6@0601TI6@D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003Vi^H0i^KV02D0i^KV00<000000<c<c03<c<`0803<c<`00`000000/k>c0;>c/`0K0;>c/`03
0000002IVIT0VIVI01T0VIVI00<0000007moO`1oOgl05`1oOgl00`000000IVIV06IVIP0G06IVIP03
0000001<C4`0C4a<01<0C4a<00<0000003<c<`0c<c<04P0c<c<00`0000006ATI01TI6@0501TI6@D0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0D0?ooo`030000003Vi^H0i^KV02H0i^KV
00<000000<c<c03<c<`0803<c<`00`000000/k>c0;>c/`0L0;>c/`030000002IVIT0VIVI01T0VIVI
00<0000007moO`1oOgl05`1oOgl00`000000IVIV06IVIP0G06IVIP030000001<C4`0C4a<01<0C4a<
00<0000003<c<`0c<c<04P0c<c<2000000D06ATI1@3oool100000040oooo000E0?ooo`030000003o
ool0oooo01@0oooo00<000000>KViP3Vi^H09P3Vi^H00`000000c<c<0<c<c00P0<c<c0030000002c
/k<0/k>c01d0/k>c00<0000009VIV@2IVIT06@2IVIT00`000000Ogmo07moO`0G07moO`030000001V
IVH0IVIV01L0IVIV00<0000004a<C01<C4`04`1<C4`2000001@0<c<c00<0000001TI6@0I6AT00P0I
6AT50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool04`3oool00`000000i^KV0>KViP0W
0>KViP030000003<c<`0c<c<0240c<c<00<000000;>c/`2c/k<0702c/k<00`000000VIVI09VIV@0J
09VIV@030000001oOgl0Ogmo01L0Ogmo00<0000006IVIP1VIVH05`1VIVH00`000000C4a<04a<C00D
04a<C0030000000c<c<0<c<c0180<c<c0P00000201TI6@D0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003Vi^H0i^KV02P0i^KV00<000000<c<c03<c<`08@3<c<`00`00
0000/k>c0;>c/`0M0;>c/`030000002IVIT0VIVI01X0VIVI00<0000007moO`1oOgl05`1oOgl20000
01P0IVIV00<0000004a<C01<C4`0501<C4`00`000000<c<c03<c<`0C03<c<`030000000I6AT0oooo
00@0oooo0@0000010?ooo`005@3oool200000180oooo00<000000>KViP3Vi^H0:@3Vi^H00`000000
c<c<0<c<c00R0<c<c0030000002c/k<0/k>c01d0/k>c00<0000009VIV@2IVIT06P2IVIT00`000000
Ogmo07moO`0H07moO`030000001VIVH0IVIV01H0IVIV00<0000004a<C01<C4`0501<C4`2000001@0
<c<c00<000000?ooo`3oool00P3oool200000040oooo000E0?ooo`030000003oool0oooo0100oooo
00<000000>KViP3Vi^H0:P3Vi^H00`000000c<c<0<c<c00R0<c<c0030000002c/k<0/k>c01d0/k>c
00<0000009VIV@2IVIT06`2IVIT00`000000Ogmo07moO`0H07moO`030000001VIVH0IVIV01H0IVIV
0P00000F04a<C0030000000c<c<0<c<c0180<c<c00<000000?ooo`3oool00P3oool100000040oooo
000E0?ooo`030000003oool0oooo0100oooo00<000000>KViP3Vi^H0:P3Vi^H00`000000c<c<0<c<
c00R0<c<c0030000002c/k<0/k>c01h0/k>c00<0000009VIV@2IVIT06P2IVIT00`000000Ogmo07mo
O`0I07moO`030000001VIVH0IVIV01L0IVIV00<0000004a<C01<C4`0501<C4`00`000000<c<c03<c
<`0A03<c<`D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`0?0?ooo`030000003Vi^H0
i^KV02X0i^KV00<000000<c<c03<c<`0903<c<`00`000000/k>c0;>c/`0N0;>c/`030000002IVIT0
VIVI01X0VIVI00<0000007moO`1oOgl06@1oOgl00`000000IVIV06IVIP0G06IVIP030000001<C4`0
C4a<01@0C4a<00<0000003<c<`0c<c<0400c<c<50?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool03P3oool00`000000i^KV0>KViP0[0>KViP030000003<c<`0c<c<02@0c<c<00<000000;>c
/`2c/k<07P2c/k<00`000000VIVI09VIV@0K09VIV@030000001oOgl0Ogmo01T0Ogmo00<0000006IV
IP1VIVH05`1VIVH00`000000C4a<04a<C00D04a<C0800000400c<c<50?ooo`4000000@3oool001D0
oooo00<000000?ooo`3oool03@3oool00`000000i^KV0>KViP0/0>KViP030000003<c<`0c<c<02@0
c<c<00<000000;>c/`2c/k<07`2c/k<00`000000VIVI09VIV@0K09VIV@030000001oOgl0Ogmo01T0
Ogmo00<0000006IVIP1VIVH05`1VIVH00`000000C4a<04a<C00E04a<C0030000000c<c<0<c<c00d0
<c<c1@3oool100000040oooo000E0?ooo`030000003oool0oooo00`0oooo00<000000>KViP3Vi^H0
;@3Vi^H00`000000c<c<0<c<c00U0<c<c0030000002c/k<0/k>c01l0/k>c00<0000009VIV@2IVIT0
6`2IVIT00`000000Ogmo07moO`0I07moO`030000001VIVH0IVIV01L0IVIV00<0000004a<C01<C4`0
5@1<C4`00`000000<c<c03<c<`0<03<c<`D0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`0<0?ooo`030000003Vi^H0i^KV02d0i^KV00<000000<c<c03<c<`09@3<c<`00`000000/k>c0;>c
/`0O0;>c/`030000002IVIT0VIVI01`0VIVI00<0000007moO`1oOgl06@1oOgl00`000000IVIV06IV
IP0G06IVIP030000001<C4`0C4a<01D0C4a<0P00000<03<c<`D0oooo0@0000010?ooo`005@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003Vi^H0i^KV02h0i^KV00<000000<c<c03<c<`09P3<c<`0
0`000000/k>c0;>c/`0O0;>c/`030000002IVIT0VIVI01`0VIVI00<0000007moO`1oOgl06@1oOgl0
0`000000IVIV06IVIP0G06IVIP030000001<C4`0C4a<01H0C4a<00<0000003<c<`0c<c<02@0c<c<5
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool02P3oool00`000000i^KV0>KViP0_0>KV
iP030000003<c<`0c<c<02H0c<c<00<000000;>c/`2c/k<07`2c/k<00`000000VIVI09VIV@0M09VI
V@030000001oOgl0Ogmo01T0Ogmo00<0000006IVIP1VIVH05`1VIVH2000001L0C4a<00<0000003<c
<`0c<c<0200c<c<50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool02@3oool00`000000
i^KV0>KViP0`0>KViP030000003<c<`0c<c<02H0c<c<00<000000;>c/`2c/k<0802c/k<00`000000
VIVI09VIV@0M09VIV@030000001oOgl0Ogmo01T0Ogmo00<0000006IVIP1VIVH0601VIVH00`000000
C4a<04a<C00E04a<C0030000000c<c<0<c<c00L0<c<c1@3oool100000040oooo000E0?ooo`030000
003oool0oooo00L0oooo0P00000c0>KViP030000003<c<`0c<c<02L0c<c<00<000000;>c/`2c/k<0
802c/k<00`000000VIVI09VIV@0M09VIV@030000001oOgl0Ogmo01T0Ogmo0P00000I06IVIP800000
5P1<C4`2000000L0<c<c1@3oool100000040oooo000E0?ooo`030000003oool0oooo00H0oooo00<0
00000>KViP3Vi^H0<`3Vi^H00`000000c<c<0<c<c00W0<c<c0030000002c/k<0/k>c0200/k>c00<0
000009VIV@2IVIT07P2IVIT00`000000Ogmo07moO`0J07moO`030000001VIVH0IVIV01P0IVIV00<0
000004a<C01<C4`05@1<C4`00`000000<c<c03<c<`0403<c<`D0oooo0@0000010?ooo`005@3oool2
000000D0oooo0P00000f0>KViP030000003<c<`0c<c<02P0c<c<00<000000;>c/`2c/k<0802c/k<0
0`000000VIVI09VIV@0N09VIV@030000001oOgl0Ogmo01X0Ogmo00<0000006IVIP1VIVH0601VIVH0
0`000000C4a<04a<C00E04a<C0800000100c<c<40?ooo`8000000@3oool001D0oooo00<000000?oo
o`3oool00`3oool00`000000i^KV0>KViP0e0>KViP030000003<c<`0c<c<02T0c<c<00<000000;>c
/`2c/k<08@2c/k<00`000000VIVI09VIV@0N09VIV@030000001oOgl0Ogmo01X0Ogmo00<0000006IV
IP1VIVH0601VIVH00`000000C4a<04a<C00F04a<C0040000000c<c<0<c<c03<c<`D0oooo0@000001
0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003Vi^H0i^KV03H0i^KV00<000000<c<
c03<c<`0:@3<c<`00`000000/k>c0;>c/`0R0;>c/`030000002IVIT0VIVI01h0VIVI00<0000007mo
O`1oOgl06P1oOgl00`000000IVIV06IVIP0H06IVIP8000005`1<C4`20000000303<c<`3oool0oooo
00<0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooocT0i^KV00<000000<c<c03<
c<`0:P3<c<`00`000000/k>c0;>c/`0R0;>c/`030000002IVIT0VIVI01h0VIVI00<0000007moO`1o
Ogl06P1oOgl2000001X0IVIV00<0000004a<C01<C4`05P1<C4`00`000000oooo0?ooo`030?ooo`40
00000@3oool001D0oooo00<000000?ooo`3oool00P3oooli0>KViP030000003<c<`0c<c<02X0c<c<
00<000000;>c/`2c/k<08`2c/k<00`000000VIVI09VIV@0N09VIV@030000001oOgl0Ogmo01/0Ogmo
00<0000006IVIP1VIVH0601VIVH00`000000C4a<04a<C00F04a<C0030000003oool0oooo0080oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooocT0i^KV00<000000<c<c03<c<`0:`3<
c<`00`000000/k>c0;>c/`0S0;>c/`030000002IVIT0VIVI01h0VIVI00<0000007moO`1oOgl06`1o
Ogl00`000000IVIV06IVIP0H06IVIP030000001<C4`0C4a<01D0C4a<1@3oool100000040oooo000E
0?ooo`030000003oool0oooo0080oooo>03Vi^H00`000000c<c<0<c<c00/0<c<c0030000002c/k<0
/k>c02<0/k>c00<0000009VIV@2IVIT07`2IVIT00`000000Ogmo07moO`0K07moO`8000006@1VIVH2
000001D0C4a<1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo>03Vi^H00`00
0000c<c<0<c<c00/0<c<c0030000002c/k<0/k>c02@0/k>c00<0000009VIV@2IVIT07`2IVIT00`00
0000Ogmo07moO`0L07moO`030000001VIVH0IVIV01P0IVIV00<0000004a<C01<C4`04P1<C4`50?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool00P3ooolh0>KViP030000003<c<`0c<c<02d0
c<c<00<000000;>c/`2c/k<0902c/k<00`000000VIVI09VIV@0O09VIV@030000001oOgl0Ogmo01`0
Ogmo00<0000006IVIP1VIVH0601VIVH00`000000C4a<04a<C00A04a<C0D0oooo0@0000010?ooo`00
5@3oool00`000000oooo0?ooo`020?ooocP0i^KV00<000000<c<c03<c<`0;@3<c<`00`000000/k>c
0;>c/`0U0;>c/`030000002IVIT0VIVI01l0VIVI00<0000007moO`1oOgl0701oOgl2000001T0IVIV
00<0000004a<C01<C4`0401<C4`50?ooo`4000000@3oool00080oooo0P0000040?ooo`040000003o
ool0oooo0?ooo`D00000103oool00`000000oooo0?ooo`020?ooocP0i^KV00<000000<c<c03<c<`0
;@3<c<`00`000000/k>c0;>c/`0V0;>c/`030000002IVIT0VIVI01l0VIVI00<0000007moO`1oOgl0
7@1oOgl00`000000IVIV06IVIP0G06IVIP800000401<C4`50?ooo`4000000@3oool000050?ooo`00
0000oooo0?ooo`000000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080
oooo=`3Vi^H00`000000c<c<0<c<c00_0<c<c0030000002c/k<0/k>c02H0/k>c00<0000009VIV@2I
VIT07`2IVIT00`000000Ogmo07moO`0M07moO`030000001VIVH0IVIV01P0IVIV0P00000>04a<C0D0
oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000090?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3ooolg0>KViP030000003<c<`0c<c<02l0c<c<00<000000;>c/`2c
/k<09P2c/k<00`000000VIVI09VIV@0P09VIV@030000001oOgl0Ogmo01d0Ogmo00<0000006IVIP1V
IVH06@1VIVH00`000000C4a<04a<C00;04a<C0D0oooo0@0000010?ooo`0000D0oooo0000003oool0
oooo0000000:0?ooo`030000003oool0oooo00<0oooo0P0000030?ooocL0i^KV00<000000<c<c03<
c<`0<03<c<`00`000000/k>c0;>c/`0V0;>c/`030000002IVIT0VIVI0200VIVI0P00000N07moO`80
00006P1VIVH2000000/0C4a<103oool200000040oooo00001@3oool000000?ooo`3oool0000000L0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo=`3Vi^H00`00
0000c<c<0<c<c00`0<c<c0030000002c/k<0/k>c02L0/k>c00<0000009VIV@2IVIT08@2IVIT00`00
0000Ogmo07moO`0M07moO`030000001VIVH0IVIV01T0IVIV0P00000904a<C0D0oooo0@0000010?oo
o`0000D0oooo0000003oool0oooo000000070?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`020?ooocH0i^KV00<000000<c<c03<c<`0<@3<c<`00`000000/k>c0;>c/`0X
0;>c/`030000002IVIT0VIVI0240VIVI00<0000007moO`1oOgl07@1oOgl00`000000IVIV06IVIP0J
06IVIP030000001<C4`0C4a<00H0C4a<1@3oool100000040oooo00020?ooo`8000002@3oool30000
00D0oooo00<000000?ooo`3oool00P3ooold0>KViP800000=@3<c<`00`000000/k>c0;>c/`0X0;>c
/`030000002IVIT0VIVI0240VIVI0P00000N07moO`030000001VIVH0IVIV01X0IVIV0P00000604a<
C0D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?oooc<0i^KV00<000000<c<c03<
c<`0=@3<c<`00`000000/k>c0;>c/`0X0;>c/`030000002IVIT0VIVI02<0VIVI00<0000007moO`1o
Ogl0701oOgl2000001`0IVIV00<0000004a<C01<C4`00`1<C4`50?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool00P3ooolb0>KViP030000003<c<`0c<c<03L0c<c<00<000000;>c/`2c/k<0
:02c/k<00`000000VIVI09VIV@0S09VIV@030000001oOgl0Ogmo01d0Ogmo00<0000006IVIP1VIVH0
6P1VIVH00`000000C4a<04a<C00204a<C0D0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`020?oooc40i^KV00<000000<c<c03<c<`0>03<c<`00`000000/k>c0;>c/`0Y0;>c/`030000002I
VIT0VIVI02<0VIVI00<0000007moO`1oOgl07@1oOgl00`000000IVIV06IVIP0J06IVIP8000000P1<
C4`50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3oool`0>KViP030000003<c<`0
c<c<03X0c<c<00<000000;>c/`2c/k<0:@2c/k<00`000000VIVI09VIV@0S09VIV@8000007P1oOgl2
000001`0IVIV00<0000004a<C03oool0103oool100000040oooo000E0?ooo`030000003oool0oooo
0080oooo;`3Vi^H00`000000c<c<0<c<c00k0<c<c0030000002c/k<0/k>c02X0/k>c00<0000009VI
V@2IVIT0902IVIT00`000000Ogmo07moO`0M07moO`030000001VIVH0IVIV01X0IVIV00<000000?oo
o`3oool00`3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo;P3Vi^H00`000000
c<c<0<c<c00m0<c<c0030000002c/k<0/k>c02X0/k>c00<0000009VIV@2IVIT0902IVIT00`000000
Ogmo07moO`0M07moO`8000006`1VIVH00`000000oooo0?ooo`020?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool00P3oool]0>KViP030000003<c<`0c<c<03h0c<c<00<000000;>c/`2c/k<0
:`2c/k<00`000000VIVI09VIV@0T09VIV@030000001oOgl0Ogmo01h0Ogmo00<0000006IVIP1VIVH0
601VIVH50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3oool/0>KViP030000003<
c<`0c<c<0400c<c<00<000000;>c/`2c/k<0:`2c/k<00`000000VIVI09VIV@0T09VIV@8000007`1o
Ogl00`000000IVIV06IVIP0G06IVIPD0oooo0@0000010?ooo`005@3oool2000000<0oooo:`3Vi^H0
0`000000c<c<0<c<c0110<c<c0030000002c/k<0/k>c02`0/k>c00<0000009VIV@2IVIT09@2IVIT0
0`000000Ogmo07moO`0M07moO`8000005`1VIVH40?ooo`8000000@3oool001D0oooo00<000000?oo
o`3oool00P3ooolZ0>KViP030000003<c<`0c<c<04<0c<c<00<000000;>c/`2c/k<0;02c/k<00`00
0000VIVI09VIV@0U09VIV@030000001oOgl0Ogmo01h0Ogmo00<0000006IVIP1VIVH0501VIVH50?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool00P3ooolY0>KViP030000003<c<`0c<c<04@0
c<c<00<000000;>c/`2c/k<0;@2c/k<00`000000VIVI09VIV@0U09VIV@030000001oOgl0Ogmo01h0
Ogmo0P00000D06IVIPD0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooobP0i^KV
00<000000<c<c03<c<`0AP3<c<`00`000000/k>c0;>c/`0]0;>c/`030000002IVIT0VIVI02D0VIVI
0P00000P07moO`030000001VIVH0IVIV0140IVIV1@3oool100000040oooo000E0?ooo`030000003o
ool0oooo0080oooo9`3Vi^H00`000000c<c<0<c<c0170<c<c0030000002c/k<0/k>c02h0/k>c00<0
000009VIV@2IVIT09P2IVIT00`000000Ogmo07moO`0N07moO`030000001VIVH0IVIV0100IVIV1@3o
ool100000040oooo000E0?ooo`030000003oool0oooo0080oooo9P3Vi^H00`000000c<c<0<c<c019
0<c<c0030000002c/k<0/k>c02h0/k>c00<0000009VIV@2IVIT09P2IVIT00`000000Ogmo07moO`0N
07moO`800000401VIVH50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3ooolU0>KV
iP030000003<c<`0c<c<04X0c<c<00<000000;>c/`2c/k<0;`2c/k<2000002L0VIVI0P00000P07mo
O`8000003P1VIVH50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3ooolS0>KViP80
0000CP3<c<`00`000000/k>c0;>c/`0`0;>c/`030000002IVIT0VIVI02H0VIVI00<0000007moO`1o
Ogl07`1oOgl2000000`0IVIV1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo
803Vi^H300000500c<c<00<000000;>c/`2c/k<0<@2c/k<00`000000VIVI09VIV@0V09VIV@030000
001oOgl0Ogmo0200Ogmo0P00000:06IVIPD0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`020?oooad0i^KV0`00001D0<c<c0030000002c/k<0/k>c0340/k>c0P00000W09VIV@8000008P1o
Ogl2000000P0IVIV1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo6P3Vi^H3
000005L0c<c<00<000000;>c/`2c/k<0<`2c/k<00`000000VIVI09VIV@0V09VIV@030000001oOgl0
Ogmo0240Ogmo00<0000006IVIP1VIVH01@1VIVH50?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool00P3ooolG0>KViP<00000F`3<c<`00`000000/k>c0;>c/`0c0;>c/`030000002IVIT0VIVI
02H0VIVI0P00000R07moO`8000001@1VIVH50?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool00P3ooolD0>KViP<00000GP3<c<`00`000000/k>c0;>c/`0d0;>c/`030000002IVIT0VIVI02L0
VIVI00<0000007moO`1oOgl08@1oOgl00`000000IVIV06IVIP0206IVIPD0oooo0@0000010?ooo`00
5@3oool2000000<0oooo3P3Vi^H600000680c<c<00<000000;>c/`2c/k<0=02c/k<00`000000VIVI
09VIV@0W09VIV@030000001oOgl0Ogmo0240Ogmo00@0000006IVIP1VIVH0IVIV103oool200000040
oooo000E0?ooo`030000003oool0oooo0080oooo1@3Vi^H9000006P0c<c<00<000000;>c/`2c/k<0
=@2c/k<00`000000VIVI09VIV@0W09VIV@8000008P1oOgl20000000306IVIP3oool0oooo00<0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`D00000LP3<c<`00`000000/k>c0;>c
/`0e0;>c/`800000:@2IVIT00`000000Ogmo07moO`0Q07moO`030000003oool0oooo00<0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`020?ooogL0c<c<00<000000;>c/`2c/k<0=`2c/k<0
0`000000VIVI09VIV@0W09VIV@8000008P1oOgl00`000000oooo0?ooo`020?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool00P3ooomh0<c<c0030000002c/k<0/k>c03L0/k>c00<0000009VI
V@2IVIT0:02IVIT200000200Ogmo1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080
ooooN03<c<`00`000000/k>c0;>c/`0h0;>c/`030000002IVIT0VIVI02T0VIVI0P00000N07moO`D0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooogT0c<c<00<000000;>c/`2c/k<0
>02c/k<00`000000VIVI09VIV@0Z09VIV@030000001oOgl0Ogmo01/0Ogmo1@3oool100000040oooo
000E0?ooo`030000003oool0oooo0080ooooNP3<c<`00`000000/k>c0;>c/`0h0;>c/`030000002I
VIT0VIVI02X0VIVI0P00000K07moO`D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`02
0?ooogX0c<c<00<000000;>c/`2c/k<0>@2c/k<2000002`0VIVI0P00000I07moO`D0oooo0@000001
0?ooo`005@3oool00`000000oooo0?ooo`020?ooog/0c<c<00<000000;>c/`2c/k<0>P2c/k<00`00
0000VIVI09VIV@0[09VIV@8000005`1oOgl50?ooo`4000000@3oool001D0oooo00<000000?ooo`3o
ool00P3ooomk0<c<c0030000002c/k<0/k>c03/0/k>c0P00000]09VIV@8000005@1oOgl50?ooo`40
00000@3oool001D0oooo00<000000?ooo`3oool00P3oooml0<c<c0030000002c/k<0/k>c03`0/k>c
00<0000009VIV@2IVIT0;02IVIT00`000000Ogmo07moO`0B07moO`D0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`020?ooog`0c<c<00<000000;>c/`2c/k<0?@2c/k<00`000000VIVI09VI
V@0/09VIV@8000004P1oOgl50?ooo`4000000@3oool001D0oooo0P0000030?ooogd0c<c<00<00000
0;>c/`2c/k<0?@2c/k<2000002h0VIVI00<0000007moO`1oOgl03`1oOgl40?ooo`8000000@3oool0
01D0oooo00<000000?ooo`3oool00P3ooomm0<c<c0030000002c/k<0/k>c03l0/k>c00<0000009VI
V@2IVIT0;02IVIT00`000000Ogmo07moO`0>07moO`D0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`020?ooogh0c<c<00<000000;>c/`2c/k<0?`2c/k<2000002d0VIVI0P00000>07moO`D0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooogh0c<c<00<000000;>c/`2c/k<0
@@2c/k<2000002d0VIVI0P00000<07moO`D0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`020?ooogl0c<c<00<000000;>c/`2c/k<0@P2c/k<2000002d0VIVI0P00000:07moO`D0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`020?oooh00c<c<00<000000;>c/`2c/k<0@`2c/k<0
0`000000VIVI09VIV@0/09VIV@800000201oOgl50?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool00P3ooon00<c<c0030000002c/k<0/k>c04@0/k>c0P00000^09VIV@8000001P1oOgl50?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool00P3ooon10<c<c0030000002c/k<0/k>c04D0
/k>c0P00000^09VIV@800000101oOgl50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
0P3ooon20<c<c0030000002c/k<0/k>c04H0/k>c0P00000^09VIV@8000000P1oOgl50?ooo`400000
0@3oool001D0oooo00<000000?ooo`3oool00P3ooon30<c<c0030000002c/k<0/k>c04L0/k>c0P00
000^09VIV@8000001@3oool100000040oooo00020?ooo`800000103oool00`000000oooo0?ooo`03
0?ooo`<00000103oool00`000000oooo0?ooo`020?oooh@0c<c<00<000000;>c/`2c/k<0B02c/k<0
0`000000VIVI09VIV@0]09VIV@030000003oool0oooo0080oooo0@0000010?ooo`0000D0oooo0000
003oool0oooo0000000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3ooon4
0<c<c0030000002c/k<0/k>c04T0/k>c0P00000]09VIV@D0oooo0@0000010?ooo`0000D0oooo0000
003oool0oooo000000070?ooo`D00000103oool00`000000oooo0?ooo`020?ooohD0c<c<00<00000
0;>c/`2c/k<0BP2c/k<2000002/0VIVI1@3oool100000040oooo00001@3oool000000?ooo`3oool0
000000L0oooo00@000000?ooo`3oool000001@3oool2000000<0ooooQP3<c<`00`000000/k>c0;>c
/`1;0;>c/`800000:@2IVIT40?ooo`8000000@3oool000050?ooo`000000oooo0?ooo`000000203o
ool00`000000oooo000000050?ooo`030000003oool0oooo0080ooooQ`3<c<`00`000000/k>c0;>c
/`1<0;>c/`8000009`2IVIT50?ooo`4000000@3oool000050?ooo`000000oooo0?ooo`0000002@3o
ool2000000D0oooo00<000000?ooo`3oool00P3ooon80<c<c0030000002c/k<0/k>c04d0/k>c00<0
000009VIV@2IVIT0902IVIT50?ooo`4000000@3oool00080oooo0P00000;0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3ooon80<c<c0030000002c/k<0/k>c04h0/k>c0P00000T
09VIV@D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooohT0c<c<00<000000;>c
/`2c/k<0C`2c/k<200000280VIVI1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080
ooooRP3<c<`00`000000/k>c0;>c/`1@0;>c/`800000802IVIT50?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool00P3oool5000008H0c<c<00<000000;>c/`2c/k<0D@2c/k<2000001h0VIVI
1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo1@2c/k<500000880c<c<0P00
001C0;>c/`800000702IVIT50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3oool:
0;>c/`@00000P03<c<`00`000000/k>c0;>c/`1B0;>c/`<000006@2IVIT50?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool00P3oool>0;>c/`<00000OP3<c<`2000005D0/k>c0P00000G09VI
V@D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?oooa40/k>c1000001l0<c<c003
0000002c/k<0/k>c05@0/k>c0P00000E09VIV@D0oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`020?oooaD0/k>c1@00001h0<c<c0800000EP2c/k<300000180VIVI1@3oool100000040oooo
000E0?ooo`8000000`3ooolJ0;>c/`@00000MP3<c<`2000005L0/k>c0P00000@09VIV@@0oooo0P00
00010?ooo`005@3oool00`000000oooo0?ooo`020?oooah0/k>c1@00001c0<c<c0800000E`2c/k<3
000000d0VIVI1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo8`2c/k<40000
0740c<c<00<000000;>c/`2c/k<0E`2c/k<2000000/0VIVI1@3oool100000040oooo000E0?ooo`03
0000003oool0oooo0080oooo9`2c/k<5000006d0c<c<0P00001I0;>c/`<00000202IVIT50?ooo`40
00000@3oool001D0oooo00<000000?ooo`3oool00P3oool/0;>c/`D00000JP3<c<`2000005X0/k>c
0`00000509VIV@D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?oooc40/k>c1@00
001W0<c<c0800000F`2c/k<2000000<0VIVI1@3oool100000040oooo000E0?ooo`030000003oool0
oooo0080oooo=P2c/k<4000006D0c<c<0P00001K0;>c/`<000001@3oool100000040oooo000E0?oo
o`030000003oool0oooo0080oooo>P2c/k<3000006@0c<c<00<000000;>c/`2c/k<0F`2c/k<00`00
0000oooo0?ooo`020?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3ooolm0;>c/`@0
0000H@3<c<`2000005/0/k>c1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo
@@2c/k<4000005l0c<c<0P00001I0;>c/`D0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`020?ooodD0/k>c0`00001N0<c<c0<00000EP2c/k<50?ooo`4000000@3oool001D0oooo00<00000
0?ooo`3oool00P3ooom80;>c/`@00000G@3<c<`3000005<0/k>c1@3oool100000040oooo000E0?oo
o`030000003oool0oooo0080ooooC02c/k<3000005d0c<c<0`00001@0;>c/`D0oooo0@0000010?oo
o`005@3oool2000000<0ooooC`2c/k<3000005d0c<c<0`00001=0;>c/`@0oooo0P0000010?ooo`00
5@3oool00`000000oooo0?ooo`020?oooe80/k>c0`00001M0<c<c0<00000BP2c/k<50?ooo`400000
0@3oool001D0oooo00<000000?ooo`3oool00P3ooomE0;>c/`<00000G@3<c<`4000004H0/k>c1@3o
ool100000040oooo000E0?ooo`030000003oool0oooo0080ooooF02c/k<3000005h0c<c<10000012
0;>c/`D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?oooe/0/k>c0P00001P0<c<
c0@00000?P2c/k<50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3ooomM0;>c/`03
0000003<c<`0c<c<0640c<c<0`00000k0;>c/`D0oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`020?ooo`800000G02c/k<2000006@0c<c<1000000g0;>c/`D0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`020?ooo`80VIVI0`00001K0;>c/`800000IP3<c<`4000003<0/k>c1@3o
ool100000040oooo000E0?ooo`030000003oool0oooo0080oooo1@2IVIT2000005/0/k>c00<00000
0<c<c03<c<`0I`3<c<`300000300/k>c1@3oool100000040oooo000E0?ooo`030000003oool0oooo
0080oooo1`2IVIT3000005T0/k>c0P00001Z0<c<c0@00000;02c/k<50?ooo`4000000@3oool001D0
oooo00<000000?ooo`3oool00P3oool:09VIV@<00000F02c/k<2000006`0c<c<1000000X0;>c/`D0
oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`d0VIVI0P00001H0;>c/`030000
003<c<`0c<c<06d0c<c<0`00000U0;>c/`D0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`020?ooo`l0VIVI0`00001F0;>c/`800000L03<c<`400000240/k>c1@3oool100000040oooo000E
0?ooo`8000000`3ooolB09VIV@800000EP2c/k<200000780c<c<1@00000L0;>c/`@0oooo0P000001
0?ooo`005@3oool00`000000oooo0?ooo`020?oooa@0VIVI0`00001E0;>c/`030000003<c<`0c<c<
07@0c<c<1000000H0;>c/`D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?oooaL0
VIVI0P00001D0;>c/`800000N03<c<`5000001<0/k>c1@3oool100000040oooo000E0?ooo`030000
003oool0oooo0080oooo6@2IVIT2000005@0/k>c0P00001k0<c<c0D000003P2c/k<50?ooo`400000
0@3oool001D0oooo00<000000?ooo`3oool00P3ooolK09VIV@<00000D`2c/k<2000007h0c<c<1P00
00080;>c/`D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?oooah0VIVI0P00001C
0;>c/`030000003<c<`0c<c<0840c<c<1@0000030;>c/`D0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`020?ooob00VIVI0P00001A0;>c/`030000003<c<`0c<c<08H0c<c<0`0000050?oo
o`4000000@3oool001D0oooo00<000000?ooo`3oool00P3ooolR09VIV@800000D02c/k<00`000000
c<c<0<c<c0280<c<c0030000003oool0oooo0080oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`020?ooob@0VIVI0P00001?0;>c/`030000003<c<`0c<c<08L0c<c<1@3oool100000040oooo
000E0?ooo`030000003oool0oooo0080oooo9P2IVIT2000004h0/k>c00<000000<c<c03<c<`0QP3<
c<`50?ooo`4000000@3oool00080oooo0P0000040?ooo`030000003oool0oooo0080oooo0`000005
0?ooo`030000003oool0oooo0080oooo:02IVIT2000004d0/k>c00<000000<c<c03<c<`0Q@3<c<`5
0?ooo`4000000@3oool000050?ooo`000000oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool00P3ooolZ09VIV@800000C02c/k<00`000000c<c<0<c<
c0240<c<c0D0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooob`0VIVI0P00001;0;>c/`030000
003<c<`0c<c<08<0c<c<1@3oool100000040oooo00001@3oool000000?ooo`3oool0000000L0oooo
100000050?ooo`8000000`3oool^09VIV@030000002c/k<0/k>c04T0/k>c00<000000<c<c03<c<`0
PP3<c<`40?ooo`8000000@3oool000050?ooo`000000oooo0?ooo`0000001`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo;`2IVIT2000004T0/k>c00<000000<c<c03<c<`0
PP3<c<`50?ooo`4000000@3oool000050?ooo`000000oooo0?ooo`000000203oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo0P00000_09VIV@800000B02c/k<00`000000c<c<
0<c<c0210<c<c0D0oooo0@0000010?ooo`000P3oool2000000X0oooo0P0000050?ooo`030000003o
ool0oooo0080oooo0P1oOgl2000002l0VIVI0P0000170;>c/`030000003<c<`0c<c<0800c<c<1@3o
ool100000040oooo000E0?ooo`030000003oool0oooo0080oooo101oOgl00`000000VIVI09VIV@0^
09VIV@800000AP2c/k<00`000000c<c<0<c<c01o0<c<c0D0oooo0@0000010?ooo`005@3oool00`00
0000oooo0?ooo`020?ooo`D0Ogmo0P00000`09VIV@800000A@2c/k<00`000000c<c<0<c<c01n0<c<
c0D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`L0Ogmo0P00000`09VIV@03
0000002c/k<0/k>c04<0/k>c00<000000<c<c03<c<`0O@3<c<`50?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool00P3oool907moO`800000;`2IVIT00`000000/k>c0;>c/`130;>c/`030000
003<c<`0c<c<07`0c<c<1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo2`1o
Ogl2000002h0VIVI0P0000130;>c/`030000003<c<`0c<c<07`0c<c<1@3oool100000040oooo000E
0?ooo`030000003oool0oooo0080oooo3@1oOgl00`000000VIVI09VIV@0]09VIV@030000002c/k<0
/k>c0440/k>c00<000000<c<c03<c<`0N`3<c<`50?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool00P3oool>07moO`800000;P2IVIT00`000000/k>c0;>c/`100;>c/`030000003<c<`0c<c<
07/0c<c<1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo401oOgl2000002d0
VIVI0P0000110;>c/`030000003<c<`0c<c<07X0c<c<1@3oool100000040oooo000E0?ooo`800000
0`3ooolB07moO`800000;@2IVIT2000003l0/k>c00<000000<c<c03<c<`0NP3<c<`40?ooo`800000
0@3oool001D0oooo00<000000?ooo`3oool00P3ooolD07moO`030000002IVIT0VIVI02`0VIVI00<0
00000;>c/`2c/k<0?@2c/k<00`000000c<c<0<c<c01i0<c<c0D0oooo0@0000010?ooo`005@3oool0
0`000000oooo0?ooo`020?oooaD0Ogmo0P00000]09VIV@800000?@2c/k<00`000000c<c<0<c<c01i
0<c<c0D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?oooaL0Ogmo0P00000]09VI
V@800000?02c/k<00`000000c<c<0<c<c01h0<c<c0D0oooo0@0000010?ooo`005@3oool00`000000
oooo0?ooo`020?oooaT0Ogmo00<0000009VIV@2IVIT0;02IVIT00`000000/k>c0;>c/`0i0;>c/`03
0000003<c<`0c<c<07P0c<c<1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo
6P1oOgl2000002d0VIVI0P00000j0;>c/`030000003<c<`0c<c<07L0c<c<1@3oool100000040oooo
000E0?ooo`030000003oool0oooo0080oooo701oOgl2000002d0VIVI00<000000;>c/`2c/k<0=`2c
/k<00`000000c<c<0<c<c01g0<c<c0D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`02
0?oooah0Ogmo00<0000009VIV@2IVIT0:`2IVIT00`000000/k>c0;>c/`0g0;>c/`030000003<c<`0
c<c<07H0c<c<1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo7`1oOgl20000
02`0VIVI00<000000;>c/`2c/k<0=P2c/k<00`000000c<c<0<c<c01f0<c<c0D0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`020?ooob40Ogmo0P00000[09VIV@030000002c/k<0/k>c03H0
/k>c00<000000<c<c03<c<`0M@3<c<`50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
0P3ooolS07moO`030000002IVIT0VIVI02T0VIVI00<000000;>c/`2c/k<0=@2c/k<00`000000c<c<
0<c<c01e0<c<c0D0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`8000008P1o
Ogl2000002X0VIVI0P00000f0;>c/`030000003<c<`0c<c<0700c<c<1@0000040?ooo`4000000@3o
ool001D0oooo00<000000?ooo`3oool00P3oool206IVIP8000008P1oOgl2000002X0VIVI00<00000
0;>c/`2c/k<0<`2c/k<00`000000c<c<0<c<c01W0<c<c0T00000103Vi^H50?ooo`4000000@3oool0
01D0oooo0P0000030?ooo`@0IVIV00<0000007moO`1oOgl08@1oOgl00`000000VIVI09VIV@0X09VI
V@030000002c/k<0/k>c03<0/k>c00<000000<c<c03<c<`0G`3<c<`7000000d0i^KV103oool20000
0040oooo000E0?ooo`030000003oool0oooo0080oooo1@1VIVH200000280Ogmo0P00000Y09VIV@03
0000002c/k<0/k>c0380/k>c00<000000<c<c03<c<`0G03<c<`3000001@0i^KV1@3oool100000040
oooo000E0?ooo`030000003oool0oooo0080oooo1`1VIVH200000280Ogmo0P00000X09VIV@030000
002c/k<0/k>c0380/k>c00<000000<c<c03<c<`0F03<c<`3000001L0i^KV1@3oool100000040oooo
000E0?ooo`030000003oool0oooo0080oooo2@1VIVH00`000000Ogmo07moO`0Q07moO`030000002I
VIT0VIVI02H0VIVI00<000000;>c/`2c/k<0<@2c/k<00`000000c<c<0<c<c01E0<c<c0<000006P3V
i^H50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3oool:06IVIP8000008P1oOgl2
000002L0VIVI0P00000b0;>c/`030000003<c<`0c<c<0540c<c<0`00000M0>KViPD0oooo0@000001
0?ooo`005@3oool00`000000oooo0?ooo`020?ooo``0IVIV00<0000007moO`1oOgl08@1oOgl00`00
0000VIVI09VIV@0V09VIV@030000002c/k<0/k>c02l0/k>c00<000000<c<c03<c<`0CP3<c<`30000
0200i^KV1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo3@1VIVH200000280
Ogmo0P00000W09VIV@030000002c/k<0/k>c02l0/k>c00<000000<c<c03<c<`0B`3<c<`2000002<0
i^KV1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo3`1VIVH200000280Ogmo
00<0000009VIV@2IVIT09@2IVIT00`000000/k>c0;>c/`0^0;>c/`030000003<c<`0c<c<04X0c<c<
00<000000>KViP3Vi^H08`3Vi^H50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3o
oolA06IVIP030000001oOgl0Ogmo0200Ogmo0P00000U09VIV@030000002c/k<0/k>c02l0/k>c00<0
00000<c<c03<c<`0B03<c<`00`000000i^KV0>KViP0T0>KViPD0oooo0@0000010?ooo`005@3oool0
0`000000oooo0?ooo`020?oooa80IVIV0P00000R07moO`030000002IVIT0VIVI02<0VIVI00<00000
0;>c/`2c/k<0;P2c/k<00`000000c<c<0<c<c0170<c<c0030000003Vi^H0i^KV02D0i^KV1@3oool1
00000040oooo000E0?ooo`030000003oool0oooo0080oooo501VIVH00`000000Ogmo07moO`0P07mo
O`800000902IVIT00`000000/k>c0;>c/`0^0;>c/`030000003<c<`0c<c<04D0c<c<00<000000>KV
iP3Vi^H09P3Vi^H50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3ooolE06IVIP80
00008P1oOgl00`000000VIVI09VIV@0R09VIV@030000002c/k<0/k>c02d0/k>c00<000000<c<c03<
c<`0A03<c<`00`000000i^KV0>KViP0W0>KViPD0oooo0@0000010?ooo`005@3oool00`000000oooo
0?ooo`020?oooaL0IVIV00<0000007moO`1oOgl0801oOgl00`000000VIVI09VIV@0R09VIV@030000
002c/k<0/k>c02d0/k>c00<000000<c<c03<c<`0@P3<c<`00`000000i^KV0>KViP0X0>KViPD0oooo
0@0000010?ooo`005@3oool2000000<0oooo601VIVH200000240Ogmo00<0000009VIV@2IVIT08P2I
VIT00`000000/k>c0;>c/`0/0;>c/`030000003<c<`0c<c<0440c<c<00<000000>KViP3Vi^H0:@3V
i^H40?ooo`8000000@3oool001D0oooo00<000000?ooo`3oool00P3ooolJ06IVIP030000001oOgl0
Ogmo01l0Ogmo00<0000009VIV@2IVIT08P2IVIT00`000000/k>c0;>c/`0[0;>c/`030000003<c<`0
c<c<0400c<c<00<000000>KViP3Vi^H0:P3Vi^H50?ooo`4000000@3oool001D0oooo00<000000?oo
o`3oool00P3ooolK06IVIP800000801oOgl00`000000VIVI09VIV@0R09VIV@030000002c/k<0/k>c
02/0/k>c00<000000<c<c03<c<`0?P3<c<`00`000000i^KV0>KViP0[0>KViPD0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`020?ooo`8000006`1VIVH00`000000Ogmo07moO`0N07moO`80
00008`2IVIT00`000000/k>c0;>c/`0Z0;>c/`030000003<c<`0c<c<03d0c<c<00<000000>KViP3V
i^H0;03Vi^H50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3oool204a<C0030000
001VIVH0IVIV01T0IVIV0P00000P07moO`030000002IVIT0VIVI0240VIVI00<000000;>c/`2c/k<0
:P2c/k<00`000000c<c<0<c<c00k0<c<c0030000003Vi^H0i^KV02d0i^KV1@3oool100000040oooo
000E0?ooo`030000003oool0oooo0080oooo0`1<C4`2000001/0IVIV00<0000007moO`1oOgl07P1o
Ogl00`000000VIVI09VIV@0Q09VIV@030000002c/k<0/k>c02T0/k>c00<000000<c<c03<c<`0>P3<
c<`00`000000i^KV0>KViP0^0>KViPD0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`02
0?ooo`D0C4a<00<0000006IVIP1VIVH06@1VIVH2000001l0Ogmo00<0000009VIV@2IVIT08@2IVIT0
0`000000/k>c0;>c/`0Y0;>c/`030000003<c<`0c<c<03P0c<c<00<000000>KViP3Vi^H0;`3Vi^H5
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3oool604a<C08000006`1VIVH00`00
0000Ogmo07moO`0M07moO`030000002IVIT0VIVI0240VIVI00<000000;>c/`2c/k<0:02c/k<00`00
0000c<c<0<c<c00g0<c<c0030000003Vi^H0i^KV0300i^KV1@3oool100000040oooo000E0?ooo`03
0000003oool0oooo0080oooo201<C4`00`000000IVIV06IVIP0I06IVIP030000001oOgl0Ogmo01d0
Ogmo00<0000009VIV@2IVIT08@2IVIT00`000000/k>c0;>c/`0X0;>c/`030000003<c<`0c<c<03D0
c<c<00<000000>KViP3Vi^H0<@3Vi^H50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool0
0P3oool904a<C08000006P1VIVH2000001h0Ogmo0P00000R09VIV@030000002c/k<0/k>c02P0/k>c
00<000000<c<c03<c<`0<`3<c<`00`000000i^KV0>KViP0b0>KViPD0oooo0@0000010?ooo`000P3o
ool2000000@0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool00P3o
ool;04a<C0030000001VIVH0IVIV01T0IVIV00<0000007moO`1oOgl07@1oOgl00`000000VIVI09VI
V@0O09VIV@030000002c/k<0/k>c02P0/k>c00<000000<c<c03<c<`0<`3<c<`00`000000i^KV0>KV
iP0b0>KViPD0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?ooo``0C4a<00<0000006IVIP1VIVH0
6@1VIVH00`000000Ogmo07moO`0M07moO`030000002IVIT0VIVI01l0VIVI00<000000;>c/`2c/k<0
:02c/k<00`000000c<c<0<c<c00b0<c<c0030000003Vi^H0i^KV0380i^KV1@3oool100000040oooo
00001@3oool000000?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo0080oooo3@1<C4`2000001X0IVIV0P00000N07moO`030000002IVIT0VIVI01l0
VIVI00<000000;>c/`2c/k<09`2c/k<00`000000c<c<0<c<c00a0<c<c0030000003Vi^H0i^KV03<0
i^KV1@3oool100000040oooo00001@3oool000000?ooo`3oool0000000P0oooo0`0000050?ooo`80
00000`3oool?04a<C0030000001VIVH0IVIV01T0IVIV00<0000007moO`1oOgl0701oOgl00`000000
VIVI09VIV@0O09VIV@030000002c/k<0/k>c02H0/k>c00<000000<c<c03<c<`0<@3<c<`00`000000
i^KV0>KViP0c0>KViP@0oooo0P0000010?ooo`0000D0oooo0000003oool0oooo000000070?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?oooa00C4a<00<0000006IV
IP1VIVH06@1VIVH00`000000Ogmo07moO`0L07moO`030000002IVIT0VIVI01l0VIVI00<000000;>c
/`2c/k<09P2c/k<00`000000c<c<0<c<c00`0<c<c0030000003Vi^H0i^KV03<0i^KV1@3oool10000
0040oooo00001@3oool000000?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo0080oooo4@1<C4`00`000000IVIV06IVIP0I06IVIP030000001oOgl0
Ogmo01`0Ogmo00<0000009VIV@2IVIT07P2IVIT00`000000/k>c0;>c/`0V0;>c/`030000003<c<`0
c<c<0300c<c<00<000000>KViP3Vi^H0<`3Vi^H50?ooo`4000000@3oool00080oooo0P0000090?oo
o`<000001@3oool00`000000oooo0?ooo`020?oooa80C4a<0P00000J06IVIP8000007@1oOgl00`00
0000VIVI09VIV@0N09VIV@030000002c/k<0/k>c02H0/k>c00<000000<c<c03<c<`0;P3<c<`00`00
0000i^KV0>KViP0d0>KViPD0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?oooa@0
C4a<00<0000006IVIP1VIVH06@1VIVH00`000000Ogmo07moO`0K07moO`030000002IVIT0VIVI01h0
VIVI00<000000;>c/`2c/k<09@2c/k<00`000000c<c<0<c<c00^0<c<c0030000003Vi^H0i^KV03@0
i^KV1@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo5@1<C4`2000001X0IVIV
00<0000007moO`1oOgl06`1oOgl00`000000VIVI09VIV@0N09VIV@030000002c/k<0/k>c02@0/k>c
00<000000<c<c03<c<`0;P3<c<`00`000000i^KV0>KViP0d0>KViPD0oooo0@0000010?ooo`005@3o
ool00`000000oooo0?ooo`020?oooaL0C4a<00<0000006IVIP1VIVH0601VIVH2000001`0Ogmo00<0
000009VIV@2IVIT07P2IVIT00`000000/k>c0;>c/`0T0;>c/`030000003<c<`0c<c<02`0c<c<00<0
00000>KViP3Vi^H0=@3Vi^H50?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3ooolH
04a<C08000006P1VIVH00`000000Ogmo07moO`0J07moO`030000002IVIT0VIVI01h0VIVI00<00000
0;>c/`2c/k<08`2c/k<00`000000c<c<0<c<c00/0<c<c0030000003Vi^H0i^KV03D0i^KV1@3oool1
00000040oooo000E0?ooo`030000003oool0oooo0080oooo0P00000H04a<C0030000001VIVH0IVIV
01P0IVIV00<0000007moO`1oOgl06P1oOgl00`000000VIVI09VIV@0N09VIV@030000002c/k<0/k>c
0280/k>c00<000000<c<c03<c<`0;03<c<`00`000000i^KV0>KViP0e0>KViPD0oooo0@0000010?oo
o`005@3oool00`000000oooo0?ooo`020?ooo`80<c<c00<0000004a<C01<C4`05P1<C4`00`000000
IVIV06IVIP0H06IVIP030000001oOgl0Ogmo01X0Ogmo00<0000009VIV@2IVIT07@2IVIT00`000000
/k>c0;>c/`0S0;>c/`030000003<c<`0c<c<02/0c<c<00<000000>KViP3Vi^H0=@3Vi^H50?ooo`40
00000@3oool001D0oooo00<000000?ooo`3oool00P3oool303<c<`8000005`1<C4`2000001T0IVIV
0P00000K07moO`030000002IVIT0VIVI01d0VIVI00<000000;>c/`2c/k<08P2c/k<00`000000c<c<
0<c<c00Z0<c<c0030000003Vi^H0i^KV03D0i^KV0P0000040?ooo`4000000@3oool001D0oooo00<0
00000?ooo`3oool00P3oool503<c<`030000001<C4`0C4a<01H0C4a<00<0000006IVIP1VIVH0601V
IVH00`000000Ogmo07moO`0I07moO`030000002IVIT0VIVI01d0VIVI00<000000;>c/`2c/k<08P2c
/k<00`000000c<c<0<c<c00Y0<c<c0030000003Vi^H0i^KV03@0i^KV00<000000?ooo`3oool0103o
ool100000040oooo000E0?ooo`030000003oool0oooo0080oooo1P0c<c<2000001L0C4a<0P00000I
06IVIP030000001oOgl0Ogmo01T0Ogmo00<0000009VIV@2IVIT07@2IVIT00`000000/k>c0;>c/`0Q
0;>c/`030000003<c<`0c<c<02T0c<c<00<000000>KViP3Vi^H0<P3Vi^H2000000L0oooo0@000001
0?ooo`005@3oool2000000<0oooo200c<c<00`000000C4a<04a<C00F04a<C0030000001VIVH0IVIV
01L0IVIV00<0000007moO`1oOgl06@1oOgl00`000000VIVI09VIV@0M09VIV@030000002c/k<0/k>c
0200/k>c00<000000<c<c03<c<`0:03<c<`00`000000i^KV0>KViP0b0>KViP030000003oool0oooo
00H0oooo0P0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`T0<c<c0P00000G04a<C003
0000001VIVH0IVIV01L0IVIV0P00000J07moO`030000002IVIT0VIVI01d0VIVI00<000000;>c/`2c
/k<0802c/k<00`000000c<c<0<c<c00W0<c<c0030000003Vi^H0i^KV0340i^KV00<000000?ooo`3o
ool0203oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo2`0c<c<00`000000C4a<
04a<C00D04a<C0030000001VIVH0IVIV01T0IVIV00<0000007moO`1oOgl0601oOgl00`000000VIVI
09VIV@0L09VIV@030000002c/k<0/k>c0200/k>c00<000000<c<c03<c<`09`3<c<`00`000000i^KV
0>KViP0a0>KViP030000003oool0oooo00P0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`020?ooo``0<c<c00<0000004a<C01<C4`0501<C4`00`000000IVIV06IVIP0I06IVIP030000001o
Ogl0Ogmo01P0Ogmo00<0000009VIV@2IVIT0702IVIT00`000000/k>c0;>c/`0P0;>c/`030000003<
c<`0c<c<02H0c<c<00<000000>KViP3Vi^H0<03Vi^H00`000000oooo0?ooo`090?ooo`4000000@3o
ool001D0oooo00<000000?ooo`3oool00P3oool=03<c<`8000005@1<C4`2000001X0IVIV00<00000
07moO`1oOgl0601oOgl00`000000VIVI09VIV@0L09VIV@030000002c/k<0/k>c01l0/k>c00<00000
0<c<c03<c<`09P3<c<`00`000000i^KV0>KViP0_0>KViP030000003oool0oooo00X0oooo0@000001
0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`l0<c<c00<0000004a<C01<C4`0501<C4`00`00
0000IVIV06IVIP0H06IVIP030000001oOgl0Ogmo01L0Ogmo00<0000009VIV@2IVIT07@2IVIT00`00
0000/k>c0;>c/`0N0;>c/`030000003<c<`0c<c<02H0c<c<00<000000>KViP3Vi^H0;P3Vi^H00`00
0000oooo0?ooo`0;0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3oool@03<c<`03
0000001<C4`0C4a<01@0C4a<00<0000006IVIP1VIVH0601VIVH00`000000Ogmo07moO`0G07moO`03
0000002IVIT0VIVI01`0VIVI00<000000;>c/`2c/k<07`2c/k<00`000000c<c<0<c<c00U0<c<c003
0000003Vi^H0i^KV02d0i^KV00<000000?ooo`3oool0303oool100000040oooo000E0?ooo`030000
003oool0oooo0080oooo4@0c<c<00`000000C4a<04a<C00D04a<C0030000001VIVH0IVIV01P0IVIV
00<0000007moO`1oOgl05`1oOgl00`000000VIVI09VIV@0L09VIV@030000002c/k<0/k>c01h0/k>c
00<000000<c<c03<c<`09@3<c<`00`000000i^KV0>KViP0]0>KViP030000003oool0oooo00`0oooo
0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?oooa80<c<c0P00000E04a<C08000006@1V
IVH00`000000Ogmo07moO`0G07moO`030000002IVIT0VIVI01`0VIVI00<000000;>c/`2c/k<07P2c
/k<00`000000c<c<0<c<c00T0<c<c0030000003Vi^H0i^KV02`0i^KV00<000000?ooo`3oool03@3o
ool100000040oooo000E0?ooo`030000003oool0oooo0080oooo500c<c<00`000000C4a<04a<C00D
04a<C0030000001VIVH0IVIV01L0IVIV00<0000007moO`1oOgl05`1oOgl00`000000VIVI09VIV@0K
09VIV@030000002c/k<0/k>c01h0/k>c00<000000<c<c03<c<`0903<c<`00`000000i^KV0>KViP0[
0>KViP030000003oool0oooo00h0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?oo
oaD0<c<c00<0000004a<C01<C4`0501<C4`00`000000IVIV06IVIP0G06IVIP030000001oOgl0Ogmo
01L0Ogmo00<0000009VIV@2IVIT06`2IVIT00`000000/k>c0;>c/`0N0;>c/`030000003<c<`0c<c<
02<0c<c<00<000000>KViP3Vi^H0:P3Vi^H00`000000oooo0?ooo`0?0?ooo`4000000@3oool001D0
oooo00<000000?ooo`3oool00P3oool2000001@0<c<c00<0000004a<C01<C4`0501<C4`2000001P0
IVIV00<0000007moO`1oOgl05`1oOgl00`000000VIVI09VIV@0K09VIV@030000002c/k<0/k>c01d0
/k>c00<000000<c<c03<c<`08P3<c<`00`000000i^KV0>KViP0Z0>KViP030000003oool0oooo0100
oooo0@0000010?ooo`005@3oool2000000<0oooo0P0I6AT00`000000<c<c03<c<`0B03<c<`030000
001<C4`0C4a<01D0C4a<00<0000006IVIP1VIVH05P1VIVH00`000000Ogmo07moO`0G07moO`030000
002IVIT0VIVI01/0VIVI00<000000;>c/`2c/k<0702c/k<00`000000c<c<0<c<c00R0<c<c0030000
003Vi^H0i^KV02X0i^KV00<000000?ooo`3oool03`3oool200000040oooo000E0?ooo`030000003o
ool0oooo0080oooo0`0I6AT00`000000<c<c03<c<`0B03<c<`030000001<C4`0C4a<01D0C4a<00<0
000006IVIP1VIVH05P1VIVH00`000000Ogmo07moO`0F07moO`030000002IVIT0VIVI01/0VIVI00<0
00000;>c/`2c/k<07@2c/k<00`000000c<c<0<c<c00Q0<c<c0030000003Vi^H0i^KV02T0i^KV00<0
00000?ooo`3oool04@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo100I6AT0
0`000000<c<c03<c<`0B03<c<`8000005P1<C4`00`000000IVIV06IVIP0E06IVIP030000001oOgl0
Ogmo01L0Ogmo00<0000009VIV@2IVIT06`2IVIT00`000000/k>c0;>c/`0L0;>c/`030000003<c<`0
c<c<0240c<c<00<000000>KViP3Vi^H0:03Vi^H00`000000oooo0?ooo`0B0?ooo`4000000@3oool0
01D0oooo00<000000?ooo`3oool00P3oool501TI6@800000500c<c<00`000000C4a<04a<C00D04a<
C08000005P1VIVH00`000000Ogmo07moO`0G07moO`030000002IVIT0VIVI01X0VIVI00<000000;>c
/`2c/k<07@2c/k<00`000000c<c<0<c<c00P0<c<c0030000003Vi^H0i^KV02L0i^KV00<000000?oo
o`3oool04`3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo1`0I6AT00`000000
<c<c03<c<`0B03<c<`030000001<C4`0C4a<01D0C4a<00<0000006IVIP1VIVH0501VIVH00`000000
Ogmo07moO`0G07moO`030000002IVIT0VIVI01X0VIVI00<000000;>c/`2c/k<0702c/k<00`000000
c<c<0<c<c00P0<c<c0030000003Vi^H0i^KV02H0i^KV00<000000?ooo`3oool0503oool100000040
oooo000E0?ooo`030000003oool0oooo0080oooo200I6AT00`000000<c<c03<c<`0B03<c<`030000
001<C4`0C4a<01D0C4a<00<0000006IVIP1VIVH0501VIVH00`000000Ogmo07moO`0G07moO`030000
002IVIT0VIVI01T0VIVI00<000000;>c/`2c/k<07@2c/k<00`000000c<c<0<c<c00O0<c<c0030000
003Vi^H0i^KV02H0i^KV00<000000?ooo`3oool0503oool100000040oooo000E0?ooo`030000003o
ool0oooo0080oooo2@0I6AT00`000000<c<c03<c<`0B03<c<`030000001<C4`0C4a<01D0C4a<00<0
000006IVIP1VIVH0501VIVH00`000000Ogmo07moO`0G07moO`030000002IVIT0VIVI01T0VIVI00<0
00000;>c/`2c/k<0702c/k<00`000000c<c<0<c<c00O0<c<c0030000003Vi^H0i^KV02D0i^KV00<0
00000?ooo`3oool05@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo2P0I6AT0
0`000000<c<c03<c<`0B03<c<`030000001<C4`0C4a<01D0C4a<00<0000006IVIP1VIVH0501VIVH0
0`000000Ogmo07moO`0G07moO`030000002IVIT0VIVI01P0VIVI00<000000;>c/`2c/k<0702c/k<0
0`000000c<c<0<c<c00O0<c<c0030000003Vi^H0i^KV02D0i^KV00<000000?ooo`3oool05@3oool1
00000040oooo000E0?ooo`030000003oool0oooo0080oooo2`0I6AT2000001<0<c<c0P00000E04a<
C08000005P1VIVH00`000000Ogmo07moO`0G07moO`030000002IVIT0VIVI01P0VIVI00<000000;>c
/`2c/k<0702c/k<00`000000c<c<0<c<c00N0<c<c0030000003Vi^H0i^KV02@0i^KV00<000000?oo
o`3oool05P3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo3@0I6AT00`000000
<c<c03<c<`0B03<c<`030000001<C4`0C4a<01@0C4a<00<0000006IVIP1VIVH04`1VIVH00`000000
Ogmo07moO`0G07moO`030000002IVIT0VIVI01P0VIVI00<000000;>c/`2c/k<0702c/k<00`000000
c<c<0<c<c00N0<c<c0030000003Vi^H0i^KV02@0i^KV00<000000?ooo`3oool05P3oool100000040
oooo000E0?ooo`030000003oool0oooo0080oooo3P0I6AT2000001<0<c<c00<0000004a<C01<C4`0
501<C4`00`000000IVIV06IVIP0C06IVIP030000001oOgl0Ogmo01L0Ogmo00<0000009VIV@2IVIT0
602IVIT00`000000/k>c0;>c/`0L0;>c/`030000003<c<`0c<c<01d0c<c<00<000000>KViP3Vi^H0
903Vi^H00`000000oooo0?ooo`0F0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3o
ool@01TI6@030000000c<c<0<c<c0140<c<c0P00000E04a<C0030000001VIVH0IVIV01<0IVIV00<0
000007moO`1oOgl05`1oOgl00`000000VIVI09VIV@0H09VIV@030000002c/k<0/k>c01/0/k>c00<0
00000<c<c03<c<`07@3<c<`00`000000i^KV0>KViP0S0>KViP030000003oool0oooo01L0oooo0@00
00010?ooo`005@3oool00`000000oooo0?ooo`020?oooa406ATI00<0000003<c<`0c<c<04P0c<c<0
0`000000C4a<04a<C00C04a<C0030000001VIVH0IVIV01<0IVIV00<0000007moO`1oOgl05`1oOgl0
0`000000VIVI09VIV@0G09VIV@030000002c/k<0/k>c01/0/k>c00<000000<c<c03<c<`07@3<c<`0
0`000000i^KV0>KViP0S0>KViP030000003oool0oooo01L0oooo0@0000010?ooo`005@3oool20000
00<0oooo4P0I6AT2000001<0<c<c00<0000004a<C01<C4`04`1<C4`00`000000IVIV06IVIP0C06IV
IP030000001oOgl0Ogmo01L0Ogmo00<0000009VIV@2IVIT05`2IVIT00`000000/k>c0;>c/`0K0;>c
/`030000003<c<`0c<c<01d0c<c<00<000000>KViP3Vi^H08P3Vi^H00`000000oooo0?ooo`0F0?oo
o`8000000@3oool001D0oooo00<000000?ooo`3oool00P3ooolD01TI6@030000000c<c<0<c<c0140
<c<c00<0000004a<C01<C4`04`1<C4`00`000000IVIV06IVIP0C06IVIP030000001oOgl0Ogmo01H0
Ogmo00<0000009VIV@2IVIT05`2IVIT00`000000/k>c0;>c/`0K0;>c/`030000003<c<`0c<c<01d0
c<c<00<000000>KViP3Vi^H08@3Vi^H00`000000oooo0?ooo`0H0?ooo`4000000@3oool001D0oooo
00<000000?ooo`3oool00P3oool2000001<06ATI00<0000003<c<`0c<c<04@0c<c<00`000000C4a<
04a<C00C04a<C0030000001VIVH0IVIV01<0IVIV00<0000007moO`1oOgl05P1oOgl00`000000VIVI
09VIV@0G09VIV@030000002c/k<0/k>c01X0/k>c00<000000<c<c03<c<`07@3<c<`00`000000i^KV
0>KViP0Q0>KViP030000003oool0oooo01P0oooo0@0000010?ooo`005@3oool00`000000oooo0?oo
o`020?ooo`<000004`0I6AT00`000000<c<c03<c<`0A03<c<`030000001<C4`0C4a<01<0C4a<00<0
000006IVIP1VIVH04`1VIVH00`000000Ogmo07moO`0F07moO`030000002IVIT0VIVI01L0VIVI00<0
00000;>c/`2c/k<06P2c/k<00`000000c<c<0<c<c00L0<c<c0030000003Vi^H0i^KV0240i^KV00<0
00000?ooo`3oool0603oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo1000000C
01TI6@030000000c<c<0<c<c0140<c<c00<0000004a<C01<C4`04`1<C4`00`000000IVIV06IVIP0C
06IVIP030000001oOgl0Ogmo01H0Ogmo00<0000009VIV@2IVIT05P2IVIT00`000000/k>c0;>c/`0J
0;>c/`030000003<c<`0c<c<01`0c<c<00<000000>KViP3Vi^H08@3Vi^H00`000000oooo0?ooo`0H
0?ooo`4000000@3oool001D0oooo00<000000?ooo`3oool00P3oool5000001<06ATI00<0000003<c
<`0c<c<04@0c<c<2000001@0C4a<00<0000006IVIP1VIVH04`1VIVH00`000000Ogmo07moO`0E07mo
O`030000002IVIT0VIVI01L0VIVI00<000000;>c/`2c/k<06P2c/k<00`000000c<c<0<c<c00K0<c<
c0030000003Vi^H0i^KV0200i^KV00<000000?ooo`3oool06@3oool100000040oooo000E0?ooo`03
0000003oool0oooo0080oooo1`00000B01TI6@8000004`0c<c<00`000000C4a<04a<C00B04a<C003
0000001VIVH0IVIV01<0IVIV00<0000007moO`1oOgl05@1oOgl00`000000VIVI09VIV@0F09VIV@03
0000002c/k<0/k>c01X0/k>c00<000000<c<c03<c<`06`3<c<`00`000000i^KV0>KViP0P0>KViP03
0000003oool0oooo01T0oooo0@0000010?ooo`005@3oool00`000000oooo0?ooo`020?ooo`P00000
4`0I6AT00`000000<c<c03<c<`0A03<c<`030000001<C4`0C4a<0180C4a<00<0000006IVIP1VIVH0
4`1VIVH00`000000Ogmo07moO`0E07moO`030000002IVIT0VIVI01H0VIVI00<000000;>c/`2c/k<0
6@2c/k<00`000000c<c<0<c<c00K0<c<c0030000003Vi^H0i^KV0200i^KV00<000000?ooo`3oool0
6@3oool100000040oooo000E0?ooo`030000003oool0oooo0080oooo2@00000C01TI6@030000000c
<c<0<c<c0140<c<c00<0000004a<C01<C4`04P1<C4`00`000000IVIV06IVIP0C06IVIP030000001o
Ogl0Ogmo01D0Ogmo00<0000009VIV@2IVIT05P2IVIT00`000000/k>c0;>c/`0I0;>c/`030000003<
c<`0c<c<01X0c<c<00<000000>KViP3Vi^H0803Vi^H00`000000oooo0?ooo`0I0?ooo`4000000@3o
ool001D0oooo00<000000?ooo`3oool00P3oool;000001806ATI00<0000003<c<`0c<c<04@0c<c<0
0`000000C4a<04a<C00B04a<C0030000001VIVH0IVIV0180IVIV00<0000007moO`1oOgl05P1oOgl0
0`000000VIVI09VIV@0E09VIV@030000002c/k<0/k>c01T0/k>c00<000000<c<c03<c<`06`3<c<`0
0`000000i^KV0>KViP0N0>KViP030000003oool0oooo01X0oooo0@0000010?ooo`003@3oool30000
00D0oooo00<000000?ooo`3oool00P3oool<000001806ATI00<0000003<c<`0c<c<04@0c<c<00`00
0000C4a<04a<C00B04a<C0030000001VIVH0IVIV0180IVIV00<0000007moO`1oOgl05@1oOgl00`00
0000VIVI09VIV@0F09VIV@030000002c/k<0/k>c01T0/k>c00<000000<c<c03<c<`06P3<c<`00`00
0000i^KV0>KViP0N0>KViP030000003oool0oooo01X0oooo0@0000010?ooo`003P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo3@00000B01TI6@030000000c<c<0<c<c0140
<c<c00<0000004a<C01<C4`04P1<C4`00`000000IVIV06IVIP0B06IVIP030000001oOgl0Ogmo01D0
Ogmo00<0000009VIV@2IVIT05@2IVIT00`000000/k>c0;>c/`0I0;>c/`030000003<c<`0c<c<01X0
c<c<00<000000>KViP3Vi^H07P3Vi^H00`000000oooo0?ooo`0J0?ooo`4000000@3oool000h0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`h000004P0I6AT00`000000<c<c
03<c<`0A03<c<`030000001<C4`0C4a<0180C4a<00<0000006IVIP1VIVH04P1VIVH00`000000Ogmo
07moO`0E07moO`030000002IVIT0VIVI01D0VIVI00<000000;>c/`2c/k<0602c/k<00`000000c<c<
0<c<c00J0<c<c0030000003Vi^H0i^KV01d0i^KV00<000000?ooo`3oool06`3oool100000040oooo
000>0?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`l000004P0I6AT00`000000<c<c03<c
<`0A03<c<`030000001<C4`0C4a<0180C4a<00<0000006IVIP1VIVH04P1VIVH00`000000Ogmo07mo
O`0E07moO`030000002IVIT0VIVI01D0VIVI00<000000;>c/`2c/k<0602c/k<00`000000c<c<0<c<
c00I0<c<c0030000003Vi^H0i^KV01d0i^KV00<000000?ooo`3oool06P3oool200000040oooo000>
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3oool70?ooo`4000000@3oool0
00d0oooo0P0000060?ooo`030000003oool0oooo0?l0oooo1`3oool100000040oooo000>0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool00P3oool100000040oooo000E0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0080oooo0@0000010?ooo`005@3ooooo000000/000000@3oool00?l0oooo8@3oool0
0?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.1035, -0.0861209, 0.00391636, \
0.00391636}}]
}, Open  ]],

Cell[TextData[{
  "This is the derivative of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              
              FormBox[\({\(p\_1\%*\), \ \(p\_2\%*\), \ \(n\^*\)}\ with\ \
respect\ to\ {\),
                "TraditionalForm"], \(p\_1\)}], ",", \(p\_2\), ",", "n"}], 
          "}"}], TraditionalForm]]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StabilityDirect[AlleleFrequencies[{0.5, 0.5}, 100], 
        w[{0.1, 0.2, 0.3}, epi], 0] // MatrixForm\)], "Input",
  CellLabel->"In[147]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.9565217391304348`", "0.13043478260869565`", "0"},
            {"0.13043478260869565`", "0.9130434782608695`", "0"},
            {"0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[147]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "The deme size is included as an extra variable.  By default, the deme size \
stays the same, and so ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_n\( n\^*\) = 1\ \((lower\ right)\)\)]],
  ".  If DemeSize->F is used to include population regulation, then the last \
row and column are non-trivial, and may affect the overall stability."
}], "Text"],

Cell["\<\
There is an eigenvalue greater than 1, and so the central \
equilibrium {0.5,0.5} is unstable:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvalues[%]\)], "Input",
  CellLabel->"In[148]:="],

Cell[BoxData[
    \({1.0670165767456135`, 1.`, 0.8025486406456909`}\)], "Output",
  CellLabel->"Out[148]="]
}, Open  ]],

Cell["The eigenvalue of 1 corresponds to the constant deme size.", "Text"],

Cell[TextData[{
  "Element {i,j} is the derivative of variable ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " w.r.t. variable ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ".  For example, we can find ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(D[\(p\_1\%*\), p\_2]\)\(:\)\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(np = 
        IterateExact[AlleleFrequencies[{0.3, p2}, 100], 
          w[{0.1, 0.4, 0.1}, epi], 0];\)\), "\n", 
    \(D[np[\([\)\(1, 1\)\(]\)], p2] /. p2 -> 0.4\)}], "Input",
  CellLabel->"In[149]:="],

Cell[BoxData[
    \(0.033598605957354116`\)], "Output",
  CellLabel->"Out[143]="]
}, Open  ]],

Cell["This is the same as element {1,2} in the matrix above.", "Text"],

Cell["\<\
Symbolic expressions can be handled.  These are the \
equilibria:\
\>", "MathCaption"],

Cell[BoxData[{
    \(\(pop = AlleleFrequencies[{p1, p2}, n];\)\), "\n", 
    \(\(np = \(IterateExact[pop, w[{s1, s2, \[Epsilon]}, epi], 
            0]\)\[LeftDoubleBracket]1\[RightDoubleBracket];\)\), "\n", 
    \(\(eq = 
        Solve[{p1 == np[\([1]\)], p2 == np[\([2]\)]}, {p1, 
            p2}];\)\)}], "Input",
  CellLabel->"In[150]:="],

Cell["\<\
These are the eigenvalues associated with each possible \
equilibrium:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Prepend[
            Eigenvalues[
              StabilityDirect[pop, w[{s1, s2, \[Epsilon]}, epi], 0]], {p1, 
              p2}] /. eq // Simplify\) // MatrixForm\)], "Input",
  CellLabel->"In[155]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({0, 0}\), 
              "1", \(\(2 + 4\ \[Epsilon] + 2\ \[Epsilon]\^2 + 
                    s1\ \((1 + \[Epsilon])\)\^2 + 
                    s2\ \((1 + \[Epsilon])\)\^2 + \@\(\((s1 - s2)\)\^2\ \((1 \
+ \[Epsilon])\)\^4\)\)\/\(2\ \((1 + \[Epsilon])\)\^3\)\), \(\(2 + 
                    4\ \[Epsilon] + 2\ \[Epsilon]\^2 + 
                    s1\ \((1 + \[Epsilon])\)\^2 + 
                    s2\ \((1 + \[Epsilon])\)\^2 - \@\(\((s1 - s2)\)\^2\ \((1 \
+ \[Epsilon])\)\^4\)\)\/\(2\ \((1 + \[Epsilon])\)\^3\)\)},
            {\({0, 1}\), 
              "1", \(-\(\(2 + s1\ \((\(-1\) + \[Epsilon])\)\^2 + 
                      s2\ \((\(-1\) + \[Epsilon])\)\^2 + \@\(\((s1 - s2)\)\^2\
\ \((\(-1\) + \[Epsilon])\)\^4\) - 4\ \[Epsilon] + 
                      2\ \[Epsilon]\^2\)\/\(2\ \((\(-1\) + \[Epsilon])\)\^3\)\
\)\), \(-\(\(2 + s1\ \((\(-1\) + \[Epsilon])\)\^2 + 
                      s2\ \((\(-1\) + \[Epsilon])\)\^2 - \@\(\((s1 - s2)\)\^2\
\ \((\(-1\) + \[Epsilon])\)\^4\) - 4\ \[Epsilon] + 
                      2\ \[Epsilon]\^2\)\/\(2\ \((\(-1\) + \[Epsilon])\)\^3\)\
\)\)},
            {\({1\/2, 1\/2}\), 
              "1", \(\(16 + s1\^3 + 20\ s2 + 8\ s2\^2 + s2\^3 + 
                    s1\^2\ \((8 + 3\ s2)\) + 
                    s1\ \((20 + 16\ s2 + 
                          3\ s2\^2)\) + \@\(\((2 + s1 + s2)\)\^4\ \((s1\^2 - \
2\ s1\ s2 + s2\^2 + 4\ \[Epsilon]\^2)\)\)\)\/\(2\ \((2 + s1 + s2)\)\^3\)\), \
\(\(16 + s1\^3 + 20\ s2 + 8\ s2\^2 + s2\^3 + s1\^2\ \((8 + 3\ s2)\) + 
                    s1\ \((20 + 16\ s2 + 
                          3\ s2\^2)\) - \@\(\((2 + s1 + s2)\)\^4\ \((s1\^2 - \
2\ s1\ s2 + s2\^2 + 4\ \[Epsilon]\^2)\)\)\)\/\(2\ \((2 + s1 + s2)\)\^3\)\)},
            {\({1, 0}\), 
              "1", \(-\(\(2 + s1\ \((\(-1\) + \[Epsilon])\)\^2 + 
                      s2\ \((\(-1\) + \[Epsilon])\)\^2 + \@\(\((s1 - s2)\)\^2\
\ \((\(-1\) + \[Epsilon])\)\^4\) - 4\ \[Epsilon] + 
                      2\ \[Epsilon]\^2\)\/\(2\ \((\(-1\) + \[Epsilon])\)\^3\)\
\)\), \(-\(\(2 + s1\ \((\(-1\) + \[Epsilon])\)\^2 + 
                      s2\ \((\(-1\) + \[Epsilon])\)\^2 - \@\(\((s1 - s2)\)\^2\
\ \((\(-1\) + \[Epsilon])\)\^4\) - 4\ \[Epsilon] + 
                      2\ \[Epsilon]\^2\)\/\(2\ \((\(-1\) + \[Epsilon])\)\^3\)\
\)\)},
            {\({1, 1}\), 
              "1", \(\(2 + 4\ \[Epsilon] + 2\ \[Epsilon]\^2 + 
                    s1\ \((1 + \[Epsilon])\)\^2 + 
                    s2\ \((1 + \[Epsilon])\)\^2 + \@\(\((s1 - s2)\)\^2\ \((1 \
+ \[Epsilon])\)\^4\)\)\/\(2\ \((1 + \[Epsilon])\)\^3\)\), \(\(2 + 
                    4\ \[Epsilon] + 2\ \[Epsilon]\^2 + 
                    s1\ \((1 + \[Epsilon])\)\^2 + 
                    s2\ \((1 + \[Epsilon])\)\^2 - \@\(\((s1 - s2)\)\^2\ \((1 \
+ \[Epsilon])\)\^4\)\)\/\(2\ \((1 + \[Epsilon])\)\^3\)\)},
            {\({\(s1 + \[Epsilon]\)\/\(2\ s1\), 1}\), 
              "1", \(\(s1\^6 + 2\ s1\^5\ \((4 + s2)\) + 
                    2\ s1\ \((4 + s2)\)\ \[Epsilon]\^4 + \[Epsilon]\^6 + 
                    s1\^4\ \((20 + 8\ s2 + 3\ \[Epsilon]\^2)\) + 
                    s1\^2\ \[Epsilon]\^2\ \((20 + 8\ s2 + 
                          3\ \[Epsilon]\^2)\) + 
                    s1\^3\ \((16 + 16\ \[Epsilon]\^2 + 
                          4\ s2\ \((2 + \[Epsilon]\^2)\) + \@\(\(\((s1\^2 + 2\
\ s1\ s2 - 3\ \[Epsilon]\^2)\)\^2\ \((2\ s1 + s1\^2 + \
\[Epsilon]\^2)\)\^4\)\/s1\^6\))\)\)\/\(2\ \((2\ s1 + s1\^2 + \[Epsilon]\^2)\)\
\^3\)\), \(\(s1\^6 + 2\ s1\^5\ \((4 + s2)\) + 
                    2\ s1\ \((4 + s2)\)\ \[Epsilon]\^4 + \[Epsilon]\^6 + 
                    s1\^4\ \((20 + 8\ s2 + 3\ \[Epsilon]\^2)\) + 
                    s1\^2\ \[Epsilon]\^2\ \((20 + 8\ s2 + 
                          3\ \[Epsilon]\^2)\) + 
                    s1\^3\ \((16 + 16\ \[Epsilon]\^2 + 
                          4\ s2\ \((2 + \[Epsilon]\^2)\) - \@\(\(\((s1\^2 + 2\
\ s1\ s2 - 3\ \[Epsilon]\^2)\)\^2\ \((2\ s1 + s1\^2 + \
\[Epsilon]\^2)\)\^4\)\/s1\^6\))\)\)\/\(2\ \((2\ s1 + s1\^2 + \[Epsilon]\^2)\)\
\^3\)\)},
            {\({\(s1 - \[Epsilon]\)\/\(2\ s1\), 0}\), 
              "1", \(\(s1\^6 + 2\ s1\^5\ \((4 + s2)\) + 
                    2\ s1\ \((4 + s2)\)\ \[Epsilon]\^4 + \[Epsilon]\^6 + 
                    s1\^4\ \((20 + 8\ s2 + 3\ \[Epsilon]\^2)\) + 
                    s1\^2\ \[Epsilon]\^2\ \((20 + 8\ s2 + 
                          3\ \[Epsilon]\^2)\) + 
                    s1\^3\ \((16 + 16\ \[Epsilon]\^2 + 
                          4\ s2\ \((2 + \[Epsilon]\^2)\) + \@\(\(\((s1\^2 + 2\
\ s1\ s2 - 3\ \[Epsilon]\^2)\)\^2\ \((2\ s1 + s1\^2 + \
\[Epsilon]\^2)\)\^4\)\/s1\^6\))\)\)\/\(2\ \((2\ s1 + s1\^2 + \[Epsilon]\^2)\)\
\^3\)\), \(\(s1\^6 + 2\ s1\^5\ \((4 + s2)\) + 
                    2\ s1\ \((4 + s2)\)\ \[Epsilon]\^4 + \[Epsilon]\^6 + 
                    s1\^4\ \((20 + 8\ s2 + 3\ \[Epsilon]\^2)\) + 
                    s1\^2\ \[Epsilon]\^2\ \((20 + 8\ s2 + 
                          3\ \[Epsilon]\^2)\) + 
                    s1\^3\ \((16 + 16\ \[Epsilon]\^2 + 
                          4\ s2\ \((2 + \[Epsilon]\^2)\) - \@\(\(\((s1\^2 + 2\
\ s1\ s2 - 3\ \[Epsilon]\^2)\)\^2\ \((2\ s1 + s1\^2 + \
\[Epsilon]\^2)\)\^4\)\/s1\^6\))\)\)\/\(2\ \((2\ s1 + s1\^2 + \[Epsilon]\^2)\)\
\^3\)\)},
            {\({1, \(s2 + \[Epsilon]\)\/\(2\ s2\)}\), 
              "1", \(\(2\ \((4 + s1)\)\ s2\^5 + s2\^6 + 
                    2\ \((4 + s1)\)\ s2\ \[Epsilon]\^4 + \[Epsilon]\^6 + 
                    s2\^4\ \((20 + 8\ s1 + 3\ \[Epsilon]\^2)\) + 
                    s2\^2\ \[Epsilon]\^2\ \((20 + 8\ s1 + 
                          3\ \[Epsilon]\^2)\) + 
                    s2\^3\ \((16 + 16\ \[Epsilon]\^2 + 
                          4\ s1\ \((2 + \[Epsilon]\^2)\) + \@\(\(\((2\ s1\ s2 \
+ s2\^2 - 3\ \[Epsilon]\^2)\)\^2\ \((2\ s2 + s2\^2 + \
\[Epsilon]\^2)\)\^4\)\/s2\^6\))\)\)\/\(2\ \((2\ s2 + s2\^2 + \[Epsilon]\^2)\)\
\^3\)\), \(\(2\ \((4 + s1)\)\ s2\^5 + s2\^6 + 
                    2\ \((4 + s1)\)\ s2\ \[Epsilon]\^4 + \[Epsilon]\^6 + 
                    s2\^4\ \((20 + 8\ s1 + 3\ \[Epsilon]\^2)\) + 
                    s2\^2\ \[Epsilon]\^2\ \((20 + 8\ s1 + 
                          3\ \[Epsilon]\^2)\) + 
                    s2\^3\ \((16 + 16\ \[Epsilon]\^2 + 
                          4\ s1\ \((2 + \[Epsilon]\^2)\) - \@\(\(\((2\ s1\ s2 \
+ s2\^2 - 3\ \[Epsilon]\^2)\)\^2\ \((2\ s2 + s2\^2 + \
\[Epsilon]\^2)\)\^4\)\/s2\^6\))\)\)\/\(2\ \((2\ s2 + s2\^2 + \[Epsilon]\^2)\)\
\^3\)\)},
            {\({0, \(s2 - \[Epsilon]\)\/\(2\ s2\)}\), 
              "1", \(\(2\ \((4 + s1)\)\ s2\^5 + s2\^6 + 
                    2\ \((4 + s1)\)\ s2\ \[Epsilon]\^4 + \[Epsilon]\^6 + 
                    s2\^4\ \((20 + 8\ s1 + 3\ \[Epsilon]\^2)\) + 
                    s2\^2\ \[Epsilon]\^2\ \((20 + 8\ s1 + 
                          3\ \[Epsilon]\^2)\) + 
                    s2\^3\ \((16 + 16\ \[Epsilon]\^2 + 
                          4\ s1\ \((2 + \[Epsilon]\^2)\) + \@\(\(\((2\ s1\ s2 \
+ s2\^2 - 3\ \[Epsilon]\^2)\)\^2\ \((2\ s2 + s2\^2 + \
\[Epsilon]\^2)\)\^4\)\/s2\^6\))\)\)\/\(2\ \((2\ s2 + s2\^2 + \[Epsilon]\^2)\)\
\^3\)\), \(\(2\ \((4 + s1)\)\ s2\^5 + s2\^6 + 
                    2\ \((4 + s1)\)\ s2\ \[Epsilon]\^4 + \[Epsilon]\^6 + 
                    s2\^4\ \((20 + 8\ s1 + 3\ \[Epsilon]\^2)\) + 
                    s2\^2\ \[Epsilon]\^2\ \((20 + 8\ s1 + 
                          3\ \[Epsilon]\^2)\) + 
                    s2\^3\ \((16 + 16\ \[Epsilon]\^2 + 
                          4\ s1\ \((2 + \[Epsilon]\^2)\) - \@\(\(\((2\ s1\ s2 \
+ s2\^2 - 3\ \[Epsilon]\^2)\)\^2\ \((2\ s2 + s2\^2 + \
\[Epsilon]\^2)\)\^4\)\/s2\^6\))\)\)\/\(2\ \((2\ s2 + s2\^2 + \[Epsilon]\^2)\)\
\^3\)\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[155]//MatrixForm="]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(StabilityDirect[{AlleleFrequencies[p\_1, n\_1], \[Ellipsis]}, W, 
              m]\), \(generates\ the\ stability\ matrix\ for\ a\ clinal\ \
model . \ \ This\ is\ in\ block\ form\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell[TextData[{
  "With ",
  Cell[BoxData[
      \(TraditionalForm\`n\_g\ genes, \ plus\ deme\ size, \ 
      there\ are\ n\_g + 
        1\ variables\ for\ each\ deme . \ \ For\ a\ clinal\ model, 
      with\ \(n\_\(\(d\)\(\ \)\)\) demes, \ 
      the\ stability\ matrix\ is\ a\ \((n\_g + 1)\)\[Times]\((n\_g + 
            1)\)\)]],
  " array, with each element being an ",
  Cell[BoxData[
      \(TraditionalForm\`n\_d\[Times]n\_d\ \(\(array\)\(.\)\)\)]]
}], "Text"],

Cell["\<\
In this example,  selection \[Sigma] acts against heterozygotes at \
3 loci, along a cline with 20 demes.  Equilibrium is reached by 500 \
generations.  The fitness hetWfull[] is defined in the previous \
example.\
\>", "Text"],

Cell[BoxData[{
    \(\(\(\(hetW[\[Sigma]_]\)[_]\)[
          p_] := {1 - 
            2  \[Sigma] . \((p \((1 - p)\))\), \[Sigma]\ \((2  p - 
                1)\)};\)\), "\[IndentingNewLine]", 
    \(\(pop0 = 
        MakeCline[20, 3, 10, 
          NumericalModel -> AlleleFrequencies];\)\), "\[IndentingNewLine]", 
    \(\(StoreExact[\[Psi], pop0, hetW[{0.05, 0.1, 0.2}], 0.5, {500, 100}, 
        Compiled \[Rule] True];\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
This gives the stability matrix, as a 4\[Times]4 array of \
20\[Times]20 arrays:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(sm = 
        StabilityDirect[\[Psi][500], hetW[{0.05, 0.1, 0.2}], 
          0.5];\)\), "\n", 
    \(sm // Dimensions\)}], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \({4, 4, 20, 20}\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell[TextData[{
  "For example, this is the array of ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\(p\_\(i, 
              1\)\%*\)/\[PartialD]p\_\(j, 2\)\)]],
  " (with  ",
  Cell[BoxData[
      \(TraditionalForm\`p\_\(deme, gene\)\)]],
  "):"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sm\[LeftDoubleBracket]1, 2\[RightDoubleBracket] // 
      MatrixForm\)], "Input",
  CellLabel->"In[196]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-0.00015699200075508545`\), \(-0.000052330666918361826`\), "0",
               "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0"},
            {\(-0.00006164189466005351`\), \(-0.00012328378932010702`\), \
\(-0.00006164189466005351`\), "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0"},
            {
              "0", \(-0.00008084267333880412`\), \
\(-0.00016168534667760823`\), \(-0.00008084267333880412`\), "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0"},
            {"0", 
              "0", \(-0.00011028113385627034`\), \(-0.0002205622677125407`\), \
\(-0.00011028113385627034`\), "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0"},
            {"0", "0", 
              "0", \(-0.00014803986090004728`\), \
\(-0.00029607972180009456`\), \(-0.00014803986090004728`\), "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", 
              "0", \(-0.00018631460716637195`\), \(-0.0003726292143327439`\), \
\(-0.00018631460716637195`\), "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0"},
            {"0", "0", "0", "0", 
              "0", \(-0.00020756010085744308`\), \
\(-0.00041512020171488616`\), \(-0.00020756010085744308`\), "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", 
              "0", \(-0.00018630324227448001`\), \
\(-0.00037260648454896003`\), \(-0.00018630324227448001`\), "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", 
              "0", \(-0.00010808668484312547`\), \
\(-0.00021617336968625094`\), \(-0.00010808668484312547`\), "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", 
              "0", \(-0.000016169258148482853`\), \(-0.000032338516296965705`\
\), \(-0.000016169258148482853`\), "0", "0", "0", "0", "0", "0", "0", "0", 
              "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", 
              "0", \(-0.00001616925814850307`\), \
\(-0.00003233851629700614`\), \(-0.00001616925814850307`\), "0", "0", "0", 
              "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", \(-0.00010808668484315866`\), \
\(-0.00021617336968631732`\), \(-0.00010808668484315866`\), "0", "0", "0", 
              "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", \(-0.00018630324227449525`\), \(-0.0003726064845489905`\), \
\(-0.00018630324227449525`\), "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", \(-0.0002075601008574375`\), \(-0.000415120201714875`\), \
\(-0.0002075601008574375`\), "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", \(-0.00018631460716635482`\), \
\(-0.00037262921433270965`\), \(-0.00018631460716635482`\), "0", "0", "0", 
              "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", \(-0.0001480398609000276`\), \(-0.0002960797218000552`\), \
\(-0.0001480398609000276`\), "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", \(-0.0001102811338562524`\), \
\(-0.0002205622677125048`\), \(-0.0001102811338562524`\), "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", 
              "0", \(-0.00008084267333878902`\), \
\(-0.00016168534667757804`\), \(-0.00008084267333878902`\), "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", 
              "0", \(-0.00006164189466004101`\), \
\(-0.00012328378932008202`\), \(-0.00006164189466004101`\)},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", 
              "0", \(-0.0000523306669183503`\), \(-0.00015699200075505092`\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[196]//MatrixForm="]
}, Closed]],

Cell["\<\
Because migration is between nearest neighbours, there are entries \
only along the three diagonals.\
\>", "Text"],

Cell["\<\
These are the eigenvalues.  BlockMatrix[] has been used to collapse \
the 4\[Times]4 array of 20\[Times]20 arrays into a 80\[Times]80 array: \
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ev = Eigenvalues[BlockMatrix[sm]] // Chop\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \({1.0031154911409053`, 1.0019570757148726`, 1.0000379890506963`, 
      0.9999999999999993`, 0.9938441702975693`, 0.9755282581475764`, 
      0.9651087102041298`, 0.9496438532032452`, 0.9455032620941832`, 
      0.9266765616208512`, 0.9235818352736405`, 0.9045084971874737`, 
      0.8993193809357473`, 0.8878169419923054`, 0.88357737917165`, 
      0.8535533905932738`, 0.8488084177876377`, 0.8430782020914634`, 
      0.8381821918607635`, 0.8026958457215014`, 0.7978646806830664`, 
      0.7938926261462368`, 0.7885512243123075`, 0.7799195987370021`, 
      0.7601095985485702`, 0.7475087434632002`, 0.7269952498697736`, 
      0.7215888273751658`, 0.7143052193959079`, 0.6850506163115416`, 
      0.673287647239349`, 0.6545084971874728`, 0.6431785410803305`, 
      0.6180049513865512`, 0.6170693081893418`, 0.5782172325201153`, 
      0.5682540621850755`, 0.5572316982262209`, 0.5453380602078179`, 
      0.4999999999999996`, 0.4929043683661841`, 0.49141465036999304`, 
      0.4716832531374595`, 0.4264964140686352`, 0.4217827674798845`, 
      0.41456108383180634`, 0.39798636160528844`, 0.3601801768798435`, 
      0.34549150281252583`, 0.33958257406472786`, 0.3260186400832759`, 
      0.294908342537124`, 0.27300475013022696`, 0.26835190969242906`, 
      0.25769873069478566`, 0.23358354236328122`, 0.2061073738537634`, 
      0.20258201619556382`, 0.19447687776666095`, 0.17571181928047577`, 
      0.14644660940672607`, 0.14397265020585978`, 0.13835735579870764`, 
      0.12592072712385247`, 0.09549150281252619`, 0.09383274162198611`, 
      0.08995141552881425`, 0.0807811298129219`, 0.054496737905816016`, 
      0.053631896430591346`, 0.051755036706383595`, 0.04762558027384706`, 
      0.024471741852423186`, 0.023948604091480315`, 0.022753133929483166`, 
      0.02014849593312069`, 0.006156689491103301`, 0.006155829702431066`, 
      0.006008924181253368`, 0.005557210551637525`}\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell["\<\
There are three nearly neutral eigenvalues \
(1.00312,1.00196,1.00004), which correspond to the independent movement of \
clines at the three loci to left or right.  The fourth eigenvalue, of \
precisely 1, corresponds to the assumed constancy of deme size.\
\>", "Text"],

Cell["This shows the leading eigenvector:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Partition[\(Eigenvectors[
              BlockMatrix[sm]]\)\[LeftDoubleBracket]1\[RightDoubleBracket], 
          20] // MatrixForm\) // Chop\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-0.0019678618532253563`\), \(-0.00235662471884242`\), \
\(-0.0032001961117319334`\), \(-0.004630190903280647`\), \
\(-0.006833576459550762`\), \(-0.010008737955686563`\), \
\(-0.014238802209415995`\), \(-0.01921420683468655`\), \
\(-0.023876668504852445`\), \(-0.026650760963646696`\), \
\(-0.026650760963645857`\), \(-0.023876668504850335`\), \
\(-0.01921420683468322`\), \(-0.01423880220941268`\), \
\(-0.010008737955682967`\), \(-0.006833576459547067`\), \
\(-0.0046301909032770905`\), \(-0.0032001961117292844`\), \
\(-0.0023566247188401227`\), \(-0.0019678618532231154`\)},
            {\(-0.00436648147132714`\), \(-0.006334832830394062`\), \
\(-0.011136177737013685`\), \(-0.020820598544568046`\), \
\(-0.03926957396240846`\), \(-0.07294944939732437`\), \(-0.13059355707390322`\
\), \(-0.21827176491640363`\), \(-0.3248423333801`\), \(-0.40571943870380694`\
\), \(-0.405719438703796`\), \(-0.3248423333800743`\), \
\(-0.21827176491637848`\), \(-0.1305935570738837`\), \
\(-0.07294944939731238`\), \(-0.039269573962401313`\), \
\(-0.020820598544563744`\), \(-0.01113617773701042`\), \
\(-0.006334832830391994`\), \(-0.00436648147132573`\)},
            {"0.00017597178330450774`", "0.0003549264318084346`", 
              "0.0008945972999734979`", "0.0023413937955058593`", 
              "0.006145709451142566`", "0.016013193612802745`", 
              "0.0408039106635562`", "0.09806585060501233`", 
              "0.2046718711643715`", "0.3196532223436388`", 
              "0.3196532223436275`", "0.20467187116435306`", 
              "0.09806585060500041`", "0.04080391066355074`", 
              "0.016013193612800288`", "0.006145709451141877`", 
              "0.0023413937955056316`", "0.0008945972999734453`", 
              "0.0003549264318081359`", "0.00017597178330474753`"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "0", "0", "0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[8]//MatrixForm="]
}, Open  ]],

Cell["\<\
It corresponds to a decrease in the first two allele frequencies, \
and an increase of the third - that is, to a shift to the right for clines at \
the first two loci, and to the left for the cline at the third locus.  The \
next two eigenvectors correspond to similar shifts in position.  (Note that \
because these eigenvalues are equal, any mixture of shifts is an \
eigenvector).\
\>", "Text"],

Cell["\<\
This shows the neutral eigenvector.  It corresponds to an increase \
in '1' alleles at the expense of '0' alleles - that is, to shifts of all the \
clines to the right.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Partition[
          \(Eigenvectors[BlockMatrix[sm]]\)\[LeftDoubleBracket]3
            \[RightDoubleBracket], 20] // MatrixForm\) // Chop\)], "Input",
  CellLabel->"In[307]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\(-0.0330577656848836021`\), \(-0.0369980578737885945`\), 
              \(-0.0455419377011657555`\), \(-0.0602226961828095763`\), 
              \(-0.0838953029422603258`\), \(-0.121382730766238644`\), 
              \(-0.179511562072203396`\), \(-0.262309104326023456`\), 
              \(-0.348156229894556279`\), \(-0.35476941757295668`\), 
              \(-0.227014755978369242`\), \(-0.0837256535649378008`\), 
              \(-0.0193389471780339476`\), \(-0.00352983582797122386`\), 
              \(-0.000679842667297678726`\), \(-0.000167183332756404601`\), 
              \(-0.0000539509683413403529`\), \(-0.0000221792975011415016`\), 
              \(-0.000011687214294122159`\), \(-8.27952509971923866`*^-6\)},
            {"0.0105463803687377866`", "0.0117455768735771615`", 
              "0.0143034252018993335`", "0.0185553578037222504`", 
              "0.0249886433069068525`", "0.0339051925137327625`", 
              "0.043761410847336819`", "0.0461122767799452049`", 
              "0.021089885275181226`", \(-0.038111180375578634`\), 
              \(-0.0806960675746010025`\), \(-0.0670536401698517003`\), 
              \(-0.0348777756046193676`\), \(-0.0148991645690255536`\), 
              \(-0.00632910352056248193`\), \(-0.00292072989733568366`\), 
              \(-0.00150089060199937414`\), \(-0.000869827600099652009`\), 
              \(-0.00058321334695555107`\), \(-0.00047011501852091051`\)},
            {"0.0105463803685058632`", "0.0117455768733336141`", 
              "0.014303425201630679`", "0.018555357803415525`", 
              "0.0249886433065482416`", "0.033905192513312321`", 
              "0.0437614108468621143`", "0.0461122767794790711`", 
              "0.0210898852748927057`", \(-0.0381111803754932978`\), 
              \(-0.0806960675742208266`\), \(-0.0670536401694885419`\), 
              \(-0.0348777756044066045`\), \(-0.014899164568922667`\), 
              \(-0.00632910352051338342`\), \(-0.00292072989731054288`\), 
              \(-0.00150089060198510875`\), \(-0.000869827600090555641`\), 
              \(-0.000583213346948929789`\), \(-0.000470115018515302551`\)},
            {"0.0105463803670234845`", "0.0117455768717732578`", 
              "0.0143034251999122874`", "0.0185553578014524962`", 
              "0.0249886433042527977`", "0.0339051925106202345`", 
              "0.0437614108438227589`", "0.0461122767764956265`", 
              "0.021089885273046125`", \(-0.0381111803749445421`\), 
              \(-0.0806960675717832742`\), \(-0.0670536401671578818`\), 
              \(-0.0348777756030429975`\), \(-0.0148991645682633127`\), 
              \(-0.00632910352019882971`\), \(-0.00292072989714935857`\), 
              \(-0.001500890601893615`\), \(-0.000869827600032216885`\), 
              \(-0.00058321334690647264`\), \(-0.000470115018479339585`\)},
            {"0.000470115018531032635`", "0.000583213346967509949`", 
              "0.000869827600116065902`", "0.00150089060202507873`", 
              "0.00292072989738098307`", "0.00632910352065086101`", 
              "0.0148991645692108765`", "0.0348777756050028742`", 
              "0.0670536401705075224`", "0.0806960675752867473`", 
              "0.0381111803757328679`", \(-0.0210898852757011656`\), 
              \(-0.0461122767807852795`\), \(-0.0437614108481926322`\), 
              \(-0.033905192514490956`\), \(-0.02498864330755314`\), 
              \(-0.0185553578042747489`\), \(-0.0143034252023824581`\), 
              \(-0.0117455768740157839`\), \(-0.0105463803691550994`\)},
            {"0.000470115018495071534`", "0.000583213346925053777`", 
              "0.000869827600057747574`", "0.00150089060193362033`", 
              "0.00292072989721981812`", "0.0063291035203363366`", 
              "0.0148991645685515923`", "0.0348777756036391606`", 
              "0.0670536401681773419`", "0.0806960675728494614`", 
              "0.0381111803751847499`", \(-0.0210898852738536879`\), 
              \(-0.0461122767778009468`\), \(-0.043761410845152584`\), 
              \(-0.0339051925117981234`\), \(-0.0249886433052569634`\), 
              \(-0.0185553578023111498`\), \(-0.0143034252006636242`\), 
              \(-0.0117455768724553188`\), \(-0.0105463803676720702`\)},
            {"0.000470115018489465441`", "0.000583213346918419173`", 
              "0.000869827600048640015`", "0.00150089060191933176`", 
              "0.0029207298971946507`", "0.00632910352028724698`", 
              "0.0148991645684486861`", "0.034877775603426353`", 
              "0.0670536401678137661`", "0.0806960675724691967`", 
              "0.0381111803750993338`", \(-0.0210898852735655362`\), 
              \(-0.0461122767773353281`\), \(-0.043761410844678279`\), 
              \(-0.0339051925113779262`\), \(-0.0249886433048988765`\), 
              \(-0.0185553578020049556`\), \(-0.0143034252003956074`\), 
              \(-0.0117455768722119735`\), \(-0.0105463803674408551`\)},
            {"8.27952509971992078`*^-6", "0.0000116872142941228251`", 
              "0.0000221792975011414306`", "0.0000539509683413411789`", 
              "0.000167183332756406333`", "0.000679842667297724911`", 
              "0.00352983582797119277`", "0.0193389471780340809`", 
              "0.083725653564937712`", "0.227014755978369464`", 
              "0.35476941757295819`", "0.34815622989455548`", 
              "0.262309104326023767`", "0.179511562072206736`", 
              "0.121382730766239532`", "0.0838953029422607698`", 
              "0.060222696182810278`", "0.045541937701165267`", 
              "0.036998057873788106`", "0.0330577656848832335`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[307]//MatrixForm="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{1045, 670},
WindowMargins->{{33, Automatic}, {Automatic, 0}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\[Placeholder]", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", 
                BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->Utilities`Notation`Private`DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\nThe item above is horizontal 0.5 pt line", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\nThe item above is a ProgramTop line\n", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\nThe item above is a ProgramBottom line\n", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "StabilityDirect"->{
    Cell[2259, 66, 394, 8, 44, "DefinitionBox",
      CellTags->"StabilityDirect"]},
  "S5.24.1"->{
    Cell[3016, 86, 79, 1, 28, "MathCaption",
      CellTags->{"S5.24.1", "1.4"}]},
  "1.4"->{
    Cell[3016, 86, 79, 1, 28, "MathCaption",
      CellTags->{"S5.24.1", "1.4"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"StabilityDirect", 172582, 4850},
  {"S5.24.1", 172682, 4853},
  {"1.4", 172776, 4856}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 35, 0, 36, "SubsectionIcon"],
Cell[1777, 53, 199, 4, 22, "Text"],
Cell[1979, 59, 277, 5, 36, "Text"],
Cell[2259, 66, 394, 8, 44, "DefinitionBox",
  CellTags->"StabilityDirect"],
Cell[2656, 76, 357, 8, 36, "Text"],
Cell[3016, 86, 79, 1, 28, "MathCaption",
  CellTags->{"S5.24.1", "1.4"}],
Cell[3098, 89, 92, 2, 26, "Input"],
Cell[3193, 93, 236, 6, 28, "MathCaption"],
Cell[3432, 101, 437, 8, 42, "Input"],
Cell[3872, 111, 52, 0, 28, "MathCaption"],
Cell[3927, 113, 461, 10, 85, "DisplayMath"],
Cell[4391, 125, 182, 6, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[4598, 135, 210, 4, 26, "Input"],
Cell[4811, 141, 66784, 1524, 294, 10737, 827, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[71610, 1668, 380, 13, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[72015, 1685, 161, 3, 26, "Input"],
Cell[72179, 1690, 340, 8, 63, "Output"]
}, Open  ]],
Cell[72534, 1701, 377, 7, 36, "Text"],
Cell[72914, 1710, 125, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[73064, 1717, 73, 2, 26, "Input"],
Cell[73140, 1721, 107, 2, 20, "Output"]
}, Open  ]],
Cell[73262, 1726, 74, 0, 22, "Text"],
Cell[73339, 1728, 316, 10, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[73680, 1742, 225, 5, 42, "Input"],
Cell[73908, 1749, 81, 2, 20, "Output"]
}, Open  ]],
Cell[74004, 1754, 70, 0, 22, "Text"],
Cell[74077, 1756, 96, 3, 28, "MathCaption"],
Cell[74176, 1761, 342, 7, 58, "Input"],
Cell[74521, 1770, 101, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[74647, 1777, 223, 5, 26, "Input"],
Cell[74873, 1784, 7816, 133, 399, "Output"]
}, Closed]],
Cell[82704, 1920, 296, 5, 33, "DefinitionBox"],
Cell[83003, 1927, 469, 12, 22, "Text"],
Cell[83475, 1941, 237, 5, 22, "Text"],
Cell[83715, 1948, 463, 10, 58, "Input"],
Cell[84181, 1960, 104, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[84310, 1967, 179, 5, 42, "Input"],
Cell[84492, 1974, 72, 2, 20, "Output"]
}, Open  ]],
Cell[84579, 1979, 273, 9, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[84877, 1992, 127, 3, 26, "Input"],
Cell[85007, 1997, 4475, 79, 335, "Output"]
}, Closed]],
Cell[89497, 2079, 124, 3, 18, "Text"],
Cell[89624, 2084, 174, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[89823, 2092, 98, 2, 26, "Input"],
Cell[89924, 2096, 1957, 28, 95, "Output"]
}, Open  ]],
Cell[91896, 2127, 281, 5, 36, "Text"],
Cell[92180, 2134, 58, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[92263, 2138, 199, 4, 26, "Input"],
Cell[92465, 2144, 2115, 36, 79, "Output"]
}, Open  ]],
Cell[94595, 2183, 407, 7, 36, "Text"],
Cell[95005, 2192, 192, 4, 22, "Text"],

Cell[CellGroupData[{
Cell[95222, 2200, 199, 4, 26, "Input"],
Cell[95424, 2206, 5788, 85, 305, "Output"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

