(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     57043,       1555]*)
(*NotebookOutlinePosition[     57718,       1578]*)
(*  CellTagsIndexPosition[     57674,       1574]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Simulating the island model",
  FontColor->RGBColor[0, 0, 1]]], "SubsectionIcon"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Q1: ",
    FontColor->RGBColor[0, 0, 1]],
  " Compare the change in allele frequency with the theoretical expectation"
}], "SubsubsectionIcon"],

Cell[TextData[{
  "We expect the difference in allele frequency ",
  Cell[BoxData[
      \(TraditionalForm\`p\_t - P\)]],
  " to decrease as ",
  Cell[BoxData[
      \(TraditionalForm\`\((1 - m)\)\^t\)]],
  ", or roughly ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-m\)\[VeryThinSpace]t\)\)]],
  ".  "
}], "Text"],

Cell["\<\
This shows the deviations - rows correspond to the five loci:\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(delta = Transpose[tbl] - pl\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \({{\(-0.1`\), \(-0.034867844009999996`\), \(-0.01215766545905693`\), \
\(-0.004239115827521622`\), \(-0.0014780882941434481`\), \
\(-0.0005153775207319827`\), \(-0.00017970102999144422`\), \
\(-0.00006265787482176433`\), \(-0.00002184745005281985`\), \
\(-7.617734804579723`*^-6\), \(-2.656139888770892`*^-6\)}, {\(-0.3`\), \
\(-0.10460353202999995`\), \(-0.03647299637717072`\), \
\(-0.012717347482564811`\), \(-0.004434264882430372`\), \
\(-0.0015461325621959898`\), \(-0.0005391030899742355`\), \
\(-0.00018797362446526522`\), \(-0.0000655423501584873`\), \
\(-0.000022853204413642025`\), \(-7.96841966610451`*^-6\)}, {\(-0.4`\), \
\(-0.13947137603999998`\), \(-0.04863066183622772`\), \(-0.01695646331008649`\
\), \(-0.0059123531765737924`\), \(-0.002061510082927931`\), \
\(-0.0007188041199657769`\), \(-0.0002506314992870573`\), \
\(-0.0000873898002112794`\), \(-0.000030470939218318893`\), \
\(-0.000010624559555083568`\)}, {\(-0.5`\), \(-0.1743392200499999`\), \
\(-0.06078832729528466`\), \(-0.021195579137608056`\), \
\(-0.007390441470717213`\), \(-0.0025768876036599275`\), \
\(-0.0008985051499570962`\), \(-0.00031328937410873836`\), \
\(-0.000109237250264127`\), \(-0.000038088674022773716`\), \
\(-0.000013280699443785071`\)}, {\(-0.85`\), \(-0.296376674085`\), \
\(-0.1033401564019838`\), \(-0.036032484533933484`\), \
\(-0.012563750500219295`\), \(-0.004380708926221888`\), \
\(-0.0015274587549271024`\), \(-0.0005325919359848719`\), \
\(-0.00018570332544876056`\), \(-0.00006475074583867091`\), \
\(-0.00002257718905418482`\)}}\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell[TextData[{
  "Plotting the deviation on a log scale gives straight lines, implying an \
exponential decrease of the deviation, as predicted.  The slopes for all five \
loci are the same - ",
  Cell[BoxData[
      \(TraditionalForm\`\(-m\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[\(LinearLogListPlot[Transpose[{Range[0, 100, 10], \(-#\)}], 
              PlotJoined \[Rule] True] &\) /@ delta];\)\)], "Input",
  CellLabel->"In[22]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.731954 0.128636 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -6 -9 ]
[.21429 -0.0125 6 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[-0.0125 .08878 -46 -6 ]
[-0.0125 .08878 0 6 ]
[-0.0125 .21741 -40 -6 ]
[-0.0125 .21741 0 6 ]
[-0.0125 .34605 -34 -6 ]
[-0.0125 .34605 0 6 ]
[-0.0125 .47468 -28 -6 ]
[-0.0125 .47468 0 6 ]
[-0.0125 .60332 -22 -6 ]
[-0.0125 .60332 0 6 ]
[ -0.0005 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(20)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(40)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(60)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(80)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(100)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08878 m
.00625 .08878 L
s
gsave
-0.0125 .08878 -107 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00001) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .21741 m
.00625 .21741 L
s
gsave
-0.0125 .21741 -101 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .34605 m
.00625 .34605 L
s
gsave
-0.0125 .34605 -95 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.001) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .47468 m
.00625 .47468 L
s
gsave
-0.0125 .47468 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -83 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
0 .02152 m
.00375 .02152 L
s
0 .03759 m
.00375 .03759 L
s
0 .05005 m
.00375 .05005 L
s
0 .06024 m
.00375 .06024 L
s
0 .06885 m
.00375 .06885 L
s
0 .07631 m
.00375 .07631 L
s
0 .08289 m
.00375 .08289 L
s
0 .1275 m
.00375 .1275 L
s
0 .15015 m
.00375 .15015 L
s
0 .16622 m
.00375 .16622 L
s
0 .17869 m
.00375 .17869 L
s
0 .18887 m
.00375 .18887 L
s
0 .19749 m
.00375 .19749 L
s
0 .20495 m
.00375 .20495 L
s
0 .21153 m
.00375 .21153 L
s
0 .25614 m
.00375 .25614 L
s
0 .27879 m
.00375 .27879 L
s
0 .29486 m
.00375 .29486 L
s
0 .30732 m
.00375 .30732 L
s
0 .31751 m
.00375 .31751 L
s
0 .32612 m
.00375 .32612 L
s
0 .33358 m
.00375 .33358 L
s
0 .34016 m
.00375 .34016 L
s
0 .38477 m
.00375 .38477 L
s
0 .40742 m
.00375 .40742 L
s
0 .42349 m
.00375 .42349 L
s
0 .43596 m
.00375 .43596 L
s
0 .44615 m
.00375 .44615 L
s
0 .45476 m
.00375 .45476 L
s
0 .46222 m
.00375 .46222 L
s
0 .4688 m
.00375 .4688 L
s
0 .51341 m
.00375 .51341 L
s
0 .53606 m
.00375 .53606 L
s
0 .55213 m
.00375 .55213 L
s
0 .5646 m
.00375 .5646 L
s
0 .57478 m
.00375 .57478 L
s
0 .58339 m
.00375 .58339 L
s
0 .59085 m
.00375 .59085 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.11905 .54446 L
.21429 .4856 L
.30952 .42674 L
.40476 .36788 L
.5 .30902 L
.59524 .25016 L
.69048 .1913 L
.78571 .13244 L
.88095 .07358 L
.97619 .01472 L
s
.09931 .61803 m
.11905 .60583 L
.21429 .54697 L
.30952 .48811 L
.40476 .42925 L
.5 .37039 L
.59524 .31153 L
.69048 .25267 L
.78571 .19381 L
.88095 .13495 L
.97619 .07609 L
s
.12531 .61803 m
.21429 .56304 L
.30952 .50418 L
.40476 .44532 L
.5 .38646 L
.59524 .3276 L
.69048 .26874 L
.78571 .20988 L
.88095 .15102 L
.97619 .09216 L
s
.14548 .61803 m
.21429 .57551 L
.30952 .51665 L
.40476 .45779 L
.5 .39893 L
.59524 .34007 L
.69048 .28121 L
.78571 .22235 L
.88095 .16349 L
.97619 .10463 L
s
.19345 .61803 m
.21429 .60515 L
.30952 .54629 L
.40476 .48743 L
.5 .42857 L
.59524 .36971 L
.69048 .31085 L
.78571 .25199 L
.88095 .19313 L
.97619 .13427 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[22]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00=Oooool2o`0002Kooooo1Ol0
0003ooooo`;o00009?ooool3o`0000?ooooo0_l0000Tooooo`?o00001?ooool2o`0002Cooooo0ol0
0004ooooo`;o00008Oooool3o`0000Cooooo0_l00004ooooo`;o00000oooool003Cooooo00Co0000
oooooooooooo00009_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Co
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo023ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0002;ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`00027ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo000dooooo`04o`000?oooooooooo
o`0002Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Qooooo`Go00000_oo
ool01?l0003oooooooooool0000Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0000Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
000Qooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00=?ooool01?l0003oooooooooool0000Xooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
oooooooooooo00008_ooool4o`0000?ooooo00Co0000oooooooooooo00008oooool3o`0000?ooooo
00Co0000oooooooooooo00008Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool003Cooooo00Co0000oooooooooooo00009Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00008_ooool00ol0003ooooo
o`000003ooooo`04o`000?ooooooooooo`0002;ooooo00?o0000ooooooooool01?ooool01?l0003o
ooooooooool0000Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
000Qooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00=?ooool01?l0003oooooooooool0000Uooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool0000Sooooo`;o00000oooool01?l0003oooooooooool0
000Sooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00008_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00008?ooool2o`0000Cooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=Oooool2o`0002Oooooo0ol00004
ooooo`;o00009Oooool00ol0003oooooooooo`02ooooo`;o00009Oooool2o`0000Cooooo0_l0000T
ooooo`?o00001?ooool2o`0002;ooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00003
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00<?ooooo/
o`0000Cooooo000`ooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo000`ooooo`03o`000?oooooooooo00?o
oooo00<00000ooooooooool0:_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Oo
oooo000`ooooo`03o`000?oooooooooo0>gooooo000`ooooo`03o`000?oooooooooo0>;ooooo0_l0
0009ooooo`00<?ooool2o`000>7ooooo0_l0000;ooooo`00<?ooool00ol0003oooooooooo`3Ooooo
o`03o`000?oooooooooo00_ooooo000`ooooo`03o`000?oooooooooo0=gooooo0_l0000>ooooo`00
<?ooool00ol0003oooooooooo`3Kooooo`;o00004?ooool0033ooooo0_l0003Jooooo`;o00004_oo
ool0033ooooo00?o0000ooooooooool0eoooool2o`0001Cooooo000`ooooo`03o`000?oooooooooo
0=Kooooo00?o0000ooooooooool05?ooool0033ooooo0_l0003Eooooo`;o00005oooool0033ooooo
00?o0000ooooooooool0d_ooool2o`0001Wooooo000`ooooo`;o0000dOooool2o`0001_ooooo000`
ooooo`03o`000?oooooooooo0<oooooo00?o0000ooooooooool06oooool0033ooooo0_l0003>oooo
o`;o00007_ooool0033ooooo00?o0000ooooooooool0boooool2o`00023ooooo000`ooooo`;o0000
boooool00ol0003oooooooooo`0Eooooo`;o00002Oooool000Cooooo0_l00004ooooo`03o`000?oo
oooooooo00?ooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00003ooooo`?o00001_oo
ool00ol0003oooooooooo`38ooooo`;o00005oooool00ol0003oooooooooo`09ooooo`000oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool01Oooool2o`000<Oooooo0_l0000Gooooo`;o00003?ooool000?ooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00Gooooo0ol00035ooooo`03o`000?oooooooooo01Gooooo0_l0000>ooooo`000oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`33ooooo`;o00005oooool00ol0003oooooooooo`03ooooo`;o
00002Oooool000?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0`_ooool00ol0003ooooo
ooooo`0Eooooo`;o00001Oooool00ol0003oooooooooo`09ooooo`000oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo0_l00007ooooo`03o`000?oo
oooooooo0<3ooooo0_l0000Fooooo`;o00001Oooool2o`0000cooooo0004ooooo`;o00002_ooool2
o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2oooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool2
o`0000?ooooo0_l00009ooooo`00<?ooool00ol0003oooooooooo`2mooooo`;o00005_ooool2o`00
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`00<?ooool00ol0003o
ooooooooo`2kooooo`;o00005_ooool2o`0000Gooooo0_l00003ooooo`;o00003?ooool0033ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo
0_l00003ooooo`;o00003_ooool0033ooooo00?o0000ooooooooool0^?ooool2o`0001Kooooo0_l0
0005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool0033ooooo0_l0002h
ooooo`03o`000?oooooooooo01Cooooo0_l00005ooooo`;o00000oooool2o`00017ooooo000`oooo
o`03o`000?oooooooooo0;Gooooo0_l0000Fooooo`03o`000?oooooooooo00?ooooo0_l00003oooo
o`;o00004oooool0033ooooo00?o0000ooooooooool0]?ooool00ol0003oooooooooo`0Dooooo`;o
00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo0_l00009ooooo`00
<?ooool00ol0003oooooooooo`2booooo`;o00005_ooool00ol0003oooooooooo`03ooooo`;o0000
0oooool2o`0000[ooooo00?o0000ooooooooool02Oooool0033ooooo00?o0000ooooooooool0/?oo
ool2o`0001Kooooo0_l00004ooooo`;o00000oooool2o`0000[ooooo0_l0000<ooooo`00<?ooool2
o`000;3ooooo00?o0000ooooooooool05?ooool2o`0000Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`08ooooo`;o00003_ooool0033ooooo00?o0000ooooooooool0[Oooool2o`00
01Kooooo00?o0000ooooooooool00oooool2o`0000?ooooo0_l0000:ooooo`03o`000?oooooooooo
00kooooo000`ooooo`03o`000?oooooooooo0:_ooooo0_l0000Fooooo`;o00001?ooool2o`0000?o
oooo0_l0000:ooooo`;o00004Oooool0033ooooo00?o0000ooooooooool0Z_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`08ooooo`;o00004oooool0033ooooo0_l0002Yooooo`;o00005_ooool2o`0000Cooooo0_l0
0003ooooo`;o00002_ooool00ol0003oooooooooo`0Cooooo`00<?ooool00ol0003oooooooooo`2V
ooooo`;o00005oooool00ol0003oooooooooo`02ooooo`;o00000oooool2o`0000[ooooo0_l0000F
ooooo`00<?ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo01Gooooo0_l00004oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool2o`0001Sooooo000`ooooo`;o
0000Y?ooool2o`0001Kooooo0_l00004ooooo`;o00000oooool2o`0000[ooooo00?o0000oooooooo
ool06?ooool0033ooooo00?o0000ooooooooool0XOooool2o`0001Oooooo00?o0000ooooooooool0
0_ooool2o`0000?ooooo0_l0000:ooooo`;o00006oooool0033ooooo00?o0000ooooooooool0X?oo
ool00ol0003oooooooooo`0Eooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Sooooo0_l0000Mooooo`00<?ooool2o`0009oooooo0_l0000Gooooo`03o`000?oooooo
oooo00;ooooo0_l00003ooooo`;o00002_ooool00ol0003oooooooooo`0Mooooo`00<?ooool00ol0
003oooooooooo`2Mooooo`03o`000?oooooooooo01Gooooo0_l00003ooooo`;o00000oooool2o`00
00[ooooo0_l0000Pooooo`00<?ooool2o`0009cooooo0_l0000Gooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`;o00008_ooool0033ooooo
0_l0002Jooooo`;o00005oooool2o`0000?ooooo0_l00003ooooo`;o00002_ooool00ol0003ooooo
ooooo`0Rooooo`002_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0
0004ooooo`;o00000oooool3o`0000Kooooo00?o0000ooooooooool0V?ooool00ol0003ooooooooo
o`0Eooooo`;o00000oooool2o`0000?ooooo0_l0000:ooooo`;o00009Oooool000Wooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`;o0000Uoooool2o`00
01Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Sooooo0_l0000Wooooo`002Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00Gooooo0ol0002Eooooo`03o`000?oooooooooo01Gooooo0_l00003ooooo`;o0000
0oooool2o`0000[ooooo00?o0000ooooooooool09oooool000Wooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09?ooooo0_l0000F
ooooo`;o00000oooool2o`0000?ooooo0_l0000:ooooo`;o0000:_ooool000Wooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09;o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02?ooool2o`0002cooooo0009ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo0_l00007ooooo`03o`000?oooooooooo093ooooo0_l0000Fooooo`;o00000ooo
ool2o`0000?ooooo0_l0000:ooooo`03o`000?oooooooooo02cooooo000:ooooo`;o00002_ooool2
o`0000Cooooo0_l00004ooooo`;o00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo08kooooo0_l0000Fooooo`;o00000oooool2o`0000?ooooo0_l0000:ooooo`;o0000;oooool0
033ooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`;o0000<Oooool0033o
oooo00?o0000ooooooooool0Roooool2o`0001Kooooo0_l00003ooooo`;o00000oooool2o`0000[o
oooo00?o0000ooooooooool0<Oooool0033ooooo00?o0000ooooooooool0R_ooool00ol0003ooooo
ooooo`0Dooooo`;o00000oooool2o`0000?ooooo0_l0000:ooooo`;o0000=?ooool0033ooooo00?o
0000ooooooooool0R?ooool2o`0001Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Sooooo0_l0000fooooo`00<?ooool2o`0008Sooooo00?o0000
ooooooooool05?ooool2o`0000?ooooo0_l00003ooooo`;o00002_ooool00ol0003oooooooooo`0f
ooooo`00<?ooool00ol0003oooooooooo`25ooooo`;o00005Oooool2o`0000?ooooo0_l00003oooo
o`;o00002_ooool2o`0003Wooooo000`ooooo`03o`000?oooooooooo08?ooooo0_l0000Fooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`;o
0000>oooool0033ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0Dooooo`;o0000
0oooool2o`0000?ooooo0_l0000:ooooo`03o`000?oooooooooo03_ooooo000`ooooo`03o`000?oo
oooooooo083ooooo0_l0000Eooooo`;o00001?ooool01?l0003oooooooooooooool2o`0000[ooooo
0_l0000nooooo`00<?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool00_ooool2o`0000?ooooo00?o0000ooooooooool02?ooool2o`00043ooooo000`
ooooo`;o0000O_ooool2o`0001Gooooo0_l00003ooooo`;o00000oooool2o`0000[ooooo00?o0000
ooooooooool0@?ooool0033ooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0Coooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo0_l00013oooo
o`00<?ooool00ol0003oooooooooo`1jooooo`;o00005Oooool00ol0003oooooooooo`02ooooo`;o
00000oooool2o`0000Wooooo0_l00015ooooo`00<?ooool2o`0007Wooooo0_l0000Eooooo`;o0000
1?ooool01?l0003oooooooooooooool2o`0000[ooooo00?o0000ooooooooool0AOooool0033ooooo
00?o0000ooooooooool0Moooool00ol0003oooooooooo`0Cooooo`;o00001?ooool2o`0000?ooooo
00?o0000ooooooooool02?ooool2o`0004Sooooo000`ooooo`03o`000?oooooooooo07Gooooo0_l0
000Eooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00009ooooo`;o0000
B_ooool0033ooooo0_l0001eooooo`03o`000?oooooooooo01?ooooo0_l00004ooooo`;o00000ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04[ooooo000`ooooo`03o`000?oooooo
oooo07;ooooo0_l0000Dooooo`;o00001?ooool2o`0000?ooooo0_l00009ooooo`;o0000COooool0
033ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
04gooooo000`ooooo`;o0000L?ooool2o`0001Cooooo0_l00004ooooo`;o00000oooool2o`0000Wo
oooo0_l0001@ooooo`00<?ooool00ol0003oooooooooo`1]ooooo`;o00005?ooool2o`0000Gooooo
00Co0000oooooooooooooooo0_l00009ooooo`;o0000D_ooool0033ooooo0_l0001]ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool00oooool2o`0000?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`1Booooo`00<?ooool2o`0006_ooooo0_l0000Dooooo`;o00001Ooo
ool01?l0003oooooooooooooool2o`0000Wooooo0_l0001Eooooo`004?ooool2o`0000Cooooo00?o
0000ooooooooool00oooool2o`0000Cooooo0_l00003ooooo`?o00001_ooool00ol0003ooooooooo
o`1Xooooo`;o00005Oooool00ol0003oooooooooo`03ooooo`;o00000oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05Gooooo000?ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Go
oooo0_l0001Xooooo`03o`000?oooooooooo01?ooooo0_l00004ooooo`;o00000oooool2o`0000Wo
oooo0_l0001Hooooo`003oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`?o0000IOooool2
o`0001Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F?ooool000oooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Sooooo`;o00005Oooool2o`0000Cooooo0_l00003ooooo`;o0000
2Oooool2o`0005_ooooo000?ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`0Cooooo`;o00001Oooool01?l0003oooooooooooooool2
o`0000Wooooo0_l0001Mooooo`003oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool2o`0000Oooooo00?o0000ooooooooool0
H?ooool2o`0001Gooooo00?o0000ooooooooool00oooool2o`0000?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`1Mooooo`004?ooool2o`0000[ooooo0_l00004ooooo`;o00001?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05kooooo0_l0000Eooooo`;o00001Ooo
ool01?l0003oooooooooooooool2o`0000Wooooo0_l0001Pooooo`00<?ooool00ol0003ooooooooo
o`1Mooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1Pooooo`00<?ooool00ol0003oooooooooo`1K
ooooo`;o00005Oooool2o`0000Cooooo0_l00003ooooo`;o00002Oooool2o`0006?ooooo000`oooo
o`03o`000?oooooooooo05Wooooo0_l0000Fooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06?ooooo000`ooooo`03
o`000?oooooooooo05Sooooo00?o0000ooooooooool05?ooool2o`0000Cooooo0_l00003ooooo`;o
00002Oooool2o`0006Kooooo000`ooooo`;o0000Eoooool2o`0001Gooooo0_l00005ooooo`04o`00
0?ooooooooooooooo`;o00002Oooool2o`0006Sooooo000`ooooo`03o`000?oooooooooo05Cooooo
0_l0000Fooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0J?ooool0033ooooo00?o0000ooooooooool0Doooool00ol0003ooooooooo
o`0Dooooo`;o00001Oooool01?l0003oooooooooooooool2o`0000Wooooo0_l0001[ooooo`00<?oo
ool00ol0003oooooooooo`1Aooooo`;o00005Oooool2o`0000Gooooo0_l00003ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0Joooool0033ooooo00?o0000ooooooooool0Coooool2
o`0001Kooooo00?o0000ooooooooool00oooool2o`0000?ooooo0_l00009ooooo`;o0000K_ooool0
033ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Dooooo`;o00001Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0K_ooool0033o
oooo0_l0001=ooooo`;o00005Oooool2o`0000Gooooo0_l00003ooooo`;o00002Oooool2o`00077o
oooo000`ooooo`03o`000?oooooooooo04[ooooo0_l0000Fooooo`03o`000?oooooooooo00?ooooo
0_l00003ooooo`;o00002Oooool2o`0007?ooooo000`ooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool05?ooool2o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo07?ooooo000`ooooo`03o`000?oooooooooo04Oooooo0_l0000E
ooooo`;o00001Oooool2o`0000?ooooo0_l00009ooooo`;o0000M_ooool0033ooooo0_l00016oooo
o`;o00005_ooool00ol0003oooooooooo`03ooooo`;o00000oooool2o`0000[ooooo00?o0000oooo
ooooool0M_ooool0033ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Dooooo`;o
00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo0_l0001iooooo`00
<?ooool00ol0003oooooooooo`12ooooo`;o00005_ooool00ol0003oooooooooo`03ooooo`;o0000
0oooool2o`0000[ooooo00?o0000ooooooooool0NOooool0033ooooo0_l00011ooooo`;o00005_oo
ool2o`0000Cooooo0_l00003ooooo`;o00002_ooool2o`0007cooooo000`ooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool05?ooool2o`0000Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`08ooooo`;o0000O_ooool0033ooooo0_l0000nooooo`;o00005_ooool00ol0
003oooooooooo`03ooooo`;o00000oooool2o`0000[ooooo00?o0000ooooooooool0O_ooool0033o
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Dooooo`;o00001Oooool01?l0003o
ooooooooooooool2o`0000[ooooo0_l00021ooooo`00<?ooool2o`0003_ooooo0_l0000Fooooo`03
o`000?oooooooooo00?ooooo0_l00003ooooo`03o`000?oooooooooo00Sooooo0_l00023ooooo`00
<?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo01Cooooo0_l00004ooooo`;o0000
0oooool2o`0000[ooooo00?o0000ooooooooool0Poooool0033ooooo0_l0000hooooo`;o00005_oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00002_ooool2o`0008Kooooo
000Fooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0000Kooooo0_l0
000fooooo`;o00005_ooool2o`0000Cooooo0_l00003ooooo`03o`000?oooooooooo00Sooooo0_l0
0028ooooo`005Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01Cooooo
0_l00005ooooo`04o`000?ooooooooooooooo`;o00002_ooool00ol0003oooooooooo`28ooooo`00
5Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool01Oooool3o`0003;ooooo0_l0000Fooooo`03o`000?oooooooooo00?ooooo0_l00002oooo
o`;o00002_ooool2o`0008_ooooo000Eooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool05?ooool2o`0000Gooooo00Go0000ooooooooooooooooo`00000:ooooo`;o0000SOoo
ool001Gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0;oooool2o`0001Kooooo00?o0000ooooooooool0
0oooool2o`0000;ooooo0_l0000:ooooo`03o`000?oooooooooo08gooooo000Eooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool2o`0000Oooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Dooooo`;o00001?ooool2o`0000;ooooo0_l0000:ooooo`;o
0000T?ooool001Kooooo0_l0000:ooooo`;o00001?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02cooooo0_l0000Fooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`00000:ooooo`;o0000T_ooool0033ooooo00?o0000ooooooooool0:_ooool2o`0001Kooooo
0_l00004ooooo`;o00000_ooool2o`0000[ooooo00?o0000ooooooooool0T_ooool0033ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Dooooo`;o00001Oooool00ol0003ooooooooo
o`02o`0000[ooooo0_l0002Eooooo`00<?ooool00ol0003oooooooooo`0Wooooo`;o00005_ooool0
0ol0003oooooooooo`03ooooo`;o00000_ooool00ol0003oooooooooo`08ooooo`;o0000Uoooool0
033ooooo00?o0000ooooooooool09Oooool2o`0001Kooooo0_l00004ooooo`;o00000_ooool2o`00
00[ooooo00?o0000ooooooooool0Uoooool0033ooooo0_l0000Uooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02o`0000[ooooo0_l0002Jooooo`00
<?ooool00ol0003oooooooooo`0Rooooo`;o00005_ooool2o`0000Cooooo0_l00002ooooo`03o`00
0?oooooooooo00Sooooo0_l0002Looooo`00<?ooool00ol0003oooooooooo`0Pooooo`;o00005ooo
ool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000[ooooo00?o0000ooooooooool0W?oo
ool0033ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Eooooo`;o00001?ooool0
0ol0003oooooooooo`02o`0000[ooooo0_l0002Oooooo`00<?ooool00ol0003oooooooooo`0Moooo
o`;o00005_ooool2o`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00Sooooo0_l0002Qoooo
o`00<?ooool2o`0001cooooo0_l0000Gooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o
00002_ooool00ol0003oooooooooo`2Qooooo`00<?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Gooooo0_l00004ooooo`05o`000?ooooooooooooooool000002_ooool2o`000:Co
oooo000`ooooo`03o`000?oooooooooo01Sooooo0_l0000Gooooo`03o`000?oooooooooo00;ooooo
0_l00002ooooo`;o00002Oooool2o`000:Kooooo000`ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool05Oooool2o`0000?ooooo0_l00003ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0Y_ooool0033ooooo0_l0000Fooooo`;o00005_ooool2o`0000Cooooo00Co0000
oooooooooooooooo0_l00009ooooo`;o0000ZOooool0033ooooo00?o0000ooooooooool04oooool2
o`0001Oooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00009ooooo`;o0000Zoooool0
033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Eooooo`;o00000oooool2o`00
00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2[ooooo`00<?ooool2o`00017o
oooo0_l0000Fooooo`;o00001?ooool01?l0003oooooooooooooool2o`0000Wooooo0_l0002^oooo
o`00<?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo0_l00004ooooo`;o
00000oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:kooooo000`ooooo`;o0000
3_ooool2o`0001Gooooo0_l00004ooooo`;o00000oooool2o`0000Wooooo0_l0002aooooo`00<?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0/Ooo
ool0033ooooo0_l0000;ooooo`;o00005Oooool2o`0000Cooooo0_l00003ooooo`;o00002Oooool2
o`000;Cooooo000`ooooo`03o`000?oooooooooo00Sooooo0_l0000Eooooo`;o00001?ooool2o`00
00?ooooo0_l00009ooooo`;o0000]_ooool0033ooooo0_l00008ooooo`03o`000?oooooooooo01?o
oooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`2fooooo`007?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Kooooo
0_l00006ooooo`;o00005Oooool00ol0003oooooooooo`03ooooo`;o00000oooool2o`0000Wooooo
0_l0002iooooo`006oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`;o00001Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0^Oooool001_ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`05ooooo`?o00000oooool00ol0003ooooo
ooooo`0Booooo`;o00001Oooool2o`0000?ooooo0_l00009ooooo`;o0000_?ooool001_ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool00oooool2o`0000?ooooo0_l00009ooooo`;o0000__ooool001_ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0__ooool001_ooooo00Co0000oooooooooooo00002?ooool2o`0000Oooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`2oooooo`007?ooool2o`0000[ooooo00?o
0000ooooooooool0mOooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-24.3967, -6.37425, \
0.447472, 0.0331294}}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Random drift",
  FontColor->RGBColor[0, 0, 1]]], "SubsectionIcon"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Q2:",
    FontColor->RGBColor[0, 0, 1]],
  " Calculate ",
  Cell[BoxData[
      \(TraditionalForm\`F\_ST\)]],
  " for each locus.  How does it compare with theory?  "
}], "SubsubsectionIcon"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`F\_\(S\[VeryThinSpace]T\)\)]],
  " is estimated as ",
  Cell[BoxData[
      \(TraditionalForm\`\(var(p)\)\/\(p\[VeryThinSpace]q\)\)]],
  "for each locus:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fl = Variance /@ Transpose[tbl]\/\(pObs \((1 - pObs)\)\)\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \({0.03924626549505444`, 0.0689154900240331`, 0.06235103738403433`, 
      0.04287639336381274`, 0.04658441879004252`}\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell[TextData[{
  "Note that the overall mean (P={0.1, \[Ellipsis]0.85}) is estimated here \
from the mean across ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  ", and the variance of allele frequency is estimated from the 20 values.  \
The average of these estimates of ",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(S\[VeryThinSpace]T\)\)]],
  "is cklose to the expected ",
  Cell[BoxData[
      \(TraditionalForm\`1\/\(1 + 4  N\[VeryThinSpace]m\)\)]],
  ".  (Recall that deme size is 2N=100)"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Mean[fl], 1\/\(1 + 2\[Times]100\[Times]0.1\)}\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \({0.05199472101139543`, 0.047619047619047616`}\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Estimating ",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(TraditionalForm\`F\_\(S\[VeryThinSpace]T\)\)],
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" from samples",
    FontColor->RGBColor[0, 0, 1]]
}], "SubsectionIcon"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Q3: ",
    FontColor->RGBColor[0, 0, 1]],
  "Estimate ",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(S\[VeryThinSpace]T\)\)]],
  " for the sampled data, allowing for sampling error."
}], "SubsubsectionIcon"],

Cell["These are the allele frequencies estimated from samples:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pObs = Mean /@ Transpose[stbl] // N\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \({0.09615384615384616`, 0.2846153846153846`, 0.3628205128205128`, 
      0.5166666666666667`, 0.8589743589743589`}\)], "Output",
  CellLabel->"Out[41]="]
}, Open  ]],

Cell[TextData[{
  "These are the estimates of ",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(S\[VeryThinSpace]T\)\)]],
  ".  The sampling error is expected to contribute ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\[VeryThinSpace]q\)\/k\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`k = 20\)]],
  "genes were sampled.  Thus, a simple estimate of ",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(\(S\)\(\[VeryThinSpace]\)\(T\)\(\ \)\)\)]],
  "is:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Variance /@ Transpose[stbl]\/\(pObs \((1 - pObs)\)\) - 1\/20\)], "Input",\

  CellLabel->"In[43]:="],

Cell[BoxData[
    \({0.0550481522956327`, 0.07676088652319553`, 0.07107010671056281`, 
      0.04975996721503424`, 0.05087695493822747`}\)], "Output",
  CellLabel->"Out[43]="]
}, Open  ]],

Cell[TextData[{
  "There is a good deal of variability across loci, and on average, ",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(S\[VeryThinSpace]T\)\)]],
  " is overestimated in this example."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Mean[%], 1\/\(1 + 2\[Times]100\[Times]0.1\)}\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \({0.06070321353653054`, 0.047619047619047616`}\)], "Output",
  CellLabel->"Out[44]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Maximum likelihood estimation of Nm",
  FontColor->RGBColor[0, 0, 1]]], "SubsectionIcon"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Q4:  ",
    FontColor->RGBColor[0, 0, 1]],
  "What is the maximum likelihood when Nm is constrained to have the same \
value across all loci?  Is there any significant difference between loci?"
}], "SubsubsectionIcon"],

Cell["\<\
This is the list of likelihoods when five values of Nm are \
estimated, separately for each locus:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(llList = 
      MapThread[
        logLikNm[#1, 20, #2] &, {Transpose[stbl], MLEList}]\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    \({\(-240.66200518963166`\), \(-454.05180829225594`\), \
\(-500.5330523016182`\), \(-534.2770090380668`\), \
\(-311.7825859761649`\)}\)], "Output",
  CellLabel->"Out[53]="]
}, Open  ]],

Cell["This is the total:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus @@ llList\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \(\(-2041.3064607977376`\)\)], "Output",
  CellLabel->"Out[57]="]
}, Open  ]],

Cell["\<\
This is the best estimate when Nm is constrained to be the same \
across all loci:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fm = 
      FindMinimum[\(-Plus @@ \((\(logLikNm[#, 20, Nm] &\) /@ 
                Transpose[stbl])\)\), {Nm, 5}]\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \({2041.9309065618108`, {Nm \[Rule] 3.966090405853825`}}\)], "Output",
  CellLabel->"Out[58]="]
}, Open  ]],

Cell["This is twice the difference in log likelihood:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(dd = 2 \((Plus @@ llList + fm[\([1]\)])\)\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \(1.248891528146487`\)], "Output",
  CellLabel->"Out[62]="]
}, Open  ]],

Cell["The difference is nowhere near significant (P=87%)::", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(1 - CDF[ChiSquareDistribution[4], dd]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(0.869985203689857`\)], "Output",
  CellLabel->"Out[64]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Replicate samples",
  FontColor->RGBColor[0, 0, 1]]], "SubsectionIcon"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Q5: ",
    FontColor->RGBColor[0, 0, 1]],
  "Using the methods above, find the MLE for Nm for each locus across the 20 \
replicates.  How biased are the estimates of Nm?  Fst = ",
  Cell[BoxData[
      \(TraditionalForm\`1\/\(1 + 4  Nm\)\)]],
  ".  Are estimates of Fst biased? How accurate are the estimates?"
}], "SubsubsectionIcon"],

Cell[TextData[{
  "This takes samples of 20 genes from replicate ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ", makes a table of alelle frequencies, and estimates Nm.  "
}], "Text"],

Cell[BoxData[
    \(\(gg[
          k_] := \(gg[
            k] = \((stbl = 
              Table[AlleleFrequencyTable[
                  MakeIndividuals[\(res[k]\)[t], 20]], {t, 100, 2000, 
                  50}]; \[IndentingNewLine]\(NmMLE[#, 20] &\) /@ 
                Transpose[stbl] // N)\)\);\)\)], "Input",
  CellLabel->"In[69]:="],

Cell["This tabulates the estimates for each replicate:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tbl = Table[gg[j], {j, 20}]; tbl // TableForm\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"4.404486675210919`", "2.7825105825126206`", "4.176178459373512`", 
            "4.941947668587928`", "4.114535887805326`"},
          {"5.517408191849952`", "4.136269229656088`", "3.416200096593854`", 
            "3.8521688117740474`", "8.871004602078804`"},
          {"5.14622970229132`", "3.6987353287906872`", "6.310380387872157`", 
            "3.53931301543061`", "4.367386631056778`"},
          {"5.087230752698113`", "8.426853649671424`", "5.747752714756338`", 
            "6.816878837655964`", "3.1367634681084144`"},
          {"5.521384016569135`", "20.219790414744132`", "6.84821274484905`", 
            "7.463149849590107`", "6.81529952567235`"},
          {"5.327109982854055`", "5.717484844790522`", "5.703331654768083`", 
            "8.429721767516215`", "4.943213284624048`"},
          {"6.256874323750673`", "7.8706494894580885`", "3.898777570259821`", 
            "6.770247632752018`", "4.630091944815598`"},
          {"5.969091838564338`", "4.335332513259057`", "4.929573677349087`", 
            "3.026105015341514`", "2.25880740239198`"},
          {"4.074162922754439`", "7.43994564828937`", "2.0790749602714196`", 
            "2.888570204234889`", "7.930459170936779`"},
          {"3.0996896542913377`", "6.20693777587849`", "8.989210500055137`", 
            "2.814055216287089`", "5.365064276954764`"},
          {"3.7383505670606216`", "4.647037365572806`", "8.51661265377796`", 
            "5.981561817878983`", "2.7553013947524216`"},
          {"5.174655431811711`", "9.380953253631153`", "3.9605488665892343`", 
            "7.7708145190980105`", "3.6941953716718583`"},
          {"5.987144981632509`", "4.86601350530744`", "6.628121846626768`", 
            "20.176608666103366`", "6.524575886157907`"},
          {"8.95866454429614`", "11.326576306019636`", "7.474931947711776`", 
            "6.1407201306288375`", "5.982689008267077`"},
          {"3.7738187941391983`", "11.872628171877802`", 
            "3.3822642854190685`", "6.074332358751162`", 
            "2.7206471829052163`"},
          {"5.956920177005791`", "10.587444048273428`", "8.543234667682297`", 
            "8.461747799374733`", "5.538881161374791`"},
          {"2.058057225468398`", "5.372469452220834`", "5.878743429758207`", 
            "5.9642335455713855`", "3.908523540207944`"},
          {"2.9169646654097607`", "4.2715692666882035`", 
            "23.680512986284082`", "2.72450593062854`", 
            "2.9771191271792845`"},
          {"3.018378020663118`", "11.553641564665023`", "4.438139691910209`", 
            "3.4564902962638993`", "4.240188623680543`"},
          {"12.254240446005134`", "4.725967271884655`", "12.008277694407656`",
             "3.7035104560541336`", "4.60592372852292`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[70]//TableForm="]
}, Open  ]],

Cell["\<\
The estimates for extreme allele frequencies tend to be somewhat \
lower than those for intermediate frequencies, and closer to the true value \
of 0.5.  Surprisingly, estimates based on extreme allele frequencies show \
less variation (last row).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({pl, Mean[tbl], StandardDeviation[tbl]} // TableForm\)], "Input",
  CellLabel->"In[75]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0.1`", "0.3`", "0.4`", "0.5`", "0.85`"},
          {"5.212043145716334`", "7.471940484159572`", "6.830504041815788`", 
            "6.049834176976171`", "4.769033560958239`"},
          {"2.2635558420925177`", "4.146319992086182`", "4.614521276054884`", 
            "3.8552050751585525`", "1.7737806579246473`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[75]//TableForm="]
}, Open  ]],

Cell["\<\
There is no significant deviation between the mean and the true \
value, using a t-test (apart from t=2.66).  The distribution of estimates is \
highly skewed, so t-tests are not reliable with such a small # of replicates. \
 Note that the 100 estimates range from 2.06 to 23.68.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((Mean[tbl] - 5)\)/StandardErrorOfSampleMean[tbl]\)], "Input",
  CellLabel->"In[84]:="],

Cell[BoxData[
    \({0.4189363294402312`, 2.6661844572847215`, 1.7740221469246669`, 
      1.217834350731507`, \(-0.5823230238880845`\)}\)], "Output",
  CellLabel->"Out[84]="]
}, Open  ]],

Cell["\<\
The main points to take from this are that the bias is small \
relative to the standard deviations of the estimates; and that the estimates \
vary over a wide range.\
\>", "Text"],

Cell[TextData[{
  "We can ask about ",
  Cell[BoxData[
      \(TraditionalForm\`\(F\_\(\(S\)\(\[VeryThinSpace]\)\(T\)\(\ \)\)\) 
        instead\ of\ N\[VeryThinSpace]m\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fstTable = tbl /. Nm_ \[Rule] 1\/\(1 + 4  Nm\); 
    fstTable // TableForm\)], "Input",
  CellLabel->"In[82]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0.05371161579030006`", "0.08243994314204824`", 
            "0.05648213290419053`", "0.04815148687120596`", 
            "0.05727985894181995`"},
          {"0.04334702724063824`", "0.05699604536577925`", 
            "0.06819049517571799`", "0.06094337202370849`", 
            "0.027409261469183068`"},
          {"0.04632864310684296`", "0.06331140964987474`", 
            "0.03810754639504781`", "0.06597501947766395`", 
            "0.05414318097568162`"},
          {"0.046840770351482056`", "0.028812287275292125`", 
            "0.04168227866162642`", "0.035376296345689624`", 
            "0.07381678772495759`"},
          {"0.043317166087418896`", "0.012213119672194012`", 
            "0.03522013343167506`", "0.03241217983250844`", 
            "0.03538420403715431`"},
          {"0.04482608389803779`", "0.04189369667494745`", 
            "0.041993292915198585`", "0.02880276657434146`", 
            "0.0481397520760787`"},
          {"0.03842090496315222`", "0.030785714901811766`", 
            "0.06025871374549095`", "0.0356112794132302`", 
            "0.051228542992020745`"},
          {"0.040198795336926864`", "0.054521673025259135`", 
            "0.04826652067780805`", "0.07631013011771205`", 
            "0.09964894067262466`"},
          {"0.057814657880825876`", "0.032509982701322805`", 
            "0.10733875219321673`", "0.07965410480946825`", 
            "0.030560631717127862`"},
          {"0.07463377978306773`", "0.03871804385879909`", 
            "0.027058589042701007`", "0.08159121894119811`", 
            "0.044523087834638875`"},
          {"0.06268255405247582`", "0.051051274747779575`", 
            "0.028517285965892748`", "0.0401183535213796`", 
            "0.08318633213844269`"},
          {"0.046085876447364636`", "0.025957970453832555`", 
            "0.0593746820001909`", "0.031168904280822845`", 
            "0.06338428410406821`"},
          {"0.040082441683849564`", "0.04886617280049119`", 
            "0.03634713161160518`", "0.01223893814614752`", 
            "0.036902679105095024`"},
          {"0.02714834477870631`", "0.021595331244005533`", 
            "0.03236274464191923`", "0.03911922207355376`", 
            "0.04011109806191171`"},
          {"0.06213003437533813`", "0.020622590782744008`", 
            "0.06882759082360014`", "0.039529864311142304`", 
            "0.08415674585613578`"},
          {"0.04027762446924195`", "0.02306816984580685`", 
            "0.02843094827422529`", "0.028696882159277296`", 
            "0.04318623807102441`"},
          {"0.10831620517955957`", "0.044464447895088494`", 
            "0.040791395963179204`", "0.04023022278880461`", 
            "0.06011749063887683`"},
          {"0.07893993978857781`", "0.055290538583988344`", 
            "0.01044691353433539`", "0.08404757153977929`", 
            "0.07746847579764325`"},
          {"0.07649054008424575`", "0.021179904407500092`", 
            "0.05332605605404563`", "0.06744925253196998`", 
            "0.05567694833164461`"},
          {"0.019993217587228197`", "0.05024148800426337`", 
            "0.020394382166268953`", "0.06323494089086504`", 
            "0.05148351044550802`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[82]//TableForm="]
}, Open  ]],

Cell["\<\
The estimates for extreme allele frequencies tend to be somewhat \
higher than those for intermediate frequencies, and closer to the true value \
of 0.0477.  Surprisingly, estimates based on extreme allele frequencies show \
less variation (last row).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({pl, Mean[fstTable], StandardDeviation[fstTable]} // 
      TableForm\)], "Input",
  CellLabel->"In[83]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0.1`", "0.3`", "0.4`", "0.5`", "0.85`"},
          {"0.05257931114426402`", "0.04022699025164143`", 
            "0.04517087930889679`", "0.04953310033252344`", 
            "0.0558904025495819`"},
          {"0.02025721847160202`", "0.017768141373467036`", 
            "0.021429597708027062`", "0.021048153290515008`", 
            "0.01946592489155016`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[83]//TableForm="]
}, Open  ]],

Cell["\<\
There is no significant deviation between the mean and the true \
value, using a t-test.  Note that the 100 estimates range from 0.01 to 0.11\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((Mean[fstTable] - 1\/21)\)/
      StandardErrorOfSampleMean[fstTable]\)], "Input",
  CellLabel->"In[85]:="],

Cell[BoxData[
    \({1.0950650943756608`, \(-1.8605370612123968`\), \
\(-0.5109074688609295`\), 0.4066819469410235`, 
      1.9002756862306833`}\)], "Output",
  CellLabel->"Out[85]="]
}, Open  ]],

Cell[TextData[{
  "The main point here is that even if estimates of (say) ",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(S\[VeryThinSpace]T\)\)]],
  " are unbiased, estimates of a function of ",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(S\[VeryThinSpace]T\)\)]],
  " (say, ",
  Cell[BoxData[
      \(TraditionalForm\`N\[VeryThinSpace]m\)]],
  ") may be."
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1276}, {0, 832}},
WindowSize->{962, 724},
WindowMargins->{{Automatic, 14}, {Automatic, 24}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 105, 1, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[1906, 58, 171, 4, 24, "SubsubsectionIcon"],
Cell[2080, 64, 334, 11, 24, "Text"],
Cell[2417, 77, 87, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[2529, 84, 85, 2, 26, "Input"],
Cell[2617, 88, 1602, 26, 137, "Output"]
}, Open  ]],
Cell[4234, 117, 266, 7, 24, "Text"],

Cell[CellGroupData[{
Cell[4525, 128, 181, 3, 26, "Input"],
Cell[4709, 133, 34237, 867, 184, 10611, 570, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[39007, 1007, 90, 1, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[39122, 1012, 219, 7, 24, "SubsubsectionIcon"],
Cell[39344, 1021, 223, 7, 30, "Text"],

Cell[CellGroupData[{
Cell[39592, 1032, 114, 2, 43, "Input"],
Cell[39709, 1036, 175, 3, 21, "Output"]
}, Open  ]],
Cell[39899, 1042, 515, 13, 44, "Text"],

Cell[CellGroupData[{
Cell[40439, 1059, 104, 2, 42, "Input"],
Cell[40546, 1063, 104, 2, 21, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[40711, 1072, 266, 8, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[41002, 1084, 237, 7, 24, "SubsubsectionIcon"],
Cell[41242, 1093, 72, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[41339, 1097, 93, 2, 26, "Input"],
Cell[41435, 1101, 172, 3, 21, "Output"]
}, Open  ]],
Cell[41622, 1107, 476, 14, 27, "Text"],

Cell[CellGroupData[{
Cell[42123, 1125, 120, 3, 43, "Input"],
Cell[42246, 1130, 175, 3, 21, "Output"]
}, Open  ]],
Cell[42436, 1136, 209, 5, 24, "Text"],

Cell[CellGroupData[{
Cell[42670, 1145, 103, 2, 42, "Input"],
Cell[42776, 1149, 104, 2, 21, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[42941, 1158, 113, 1, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[43079, 1163, 246, 5, 24, "SubsubsectionIcon"],
Cell[43328, 1170, 122, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[43475, 1177, 144, 4, 26, "Input"],
Cell[43622, 1183, 190, 4, 21, "Output"]
}, Open  ]],
Cell[43827, 1190, 34, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[43886, 1194, 72, 2, 26, "Input"],
Cell[43961, 1198, 83, 2, 21, "Output"]
}, Open  ]],
Cell[44059, 1203, 106, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[44190, 1210, 172, 4, 26, "Input"],
Cell[44365, 1216, 113, 2, 21, "Output"]
}, Open  ]],
Cell[44493, 1221, 63, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[44581, 1225, 99, 2, 26, "Input"],
Cell[44683, 1229, 77, 2, 21, "Output"]
}, Open  ]],
Cell[44775, 1234, 68, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[44868, 1238, 95, 2, 26, "Input"],
Cell[44966, 1242, 77, 2, 21, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[45104, 1251, 95, 1, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[45224, 1256, 363, 8, 46, "SubsubsectionIcon"],
Cell[45590, 1266, 190, 5, 24, "Text"],
Cell[45783, 1273, 338, 8, 42, "Input"],
Cell[46124, 1283, 64, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[46213, 1287, 103, 2, 26, "Input"],
Cell[46319, 1291, 3020, 51, 335, "Output"]
}, Open  ]],
Cell[49354, 1345, 271, 5, 40, "Text"],

Cell[CellGroupData[{
Cell[49650, 1354, 110, 2, 26, "Input"],
Cell[49763, 1358, 601, 14, 63, "Output"]
}, Open  ]],
Cell[50379, 1375, 303, 5, 40, "Text"],

Cell[CellGroupData[{
Cell[50707, 1384, 108, 2, 26, "Input"],
Cell[50818, 1388, 175, 3, 21, "Output"]
}, Open  ]],
Cell[51008, 1394, 189, 4, 24, "Text"],
Cell[51200, 1400, 191, 6, 24, "Text"],

Cell[CellGroupData[{
Cell[51416, 1410, 132, 3, 41, "Input"],
Cell[51551, 1415, 3464, 69, 335, "Output"]
}, Open  ]],
Cell[55030, 1487, 275, 5, 40, "Text"],

Cell[CellGroupData[{
Cell[55330, 1496, 127, 3, 26, "Input"],
Cell[55460, 1501, 646, 16, 63, "Output"]
}, Open  ]],
Cell[56121, 1520, 167, 4, 24, "Text"],

Cell[CellGroupData[{
Cell[56313, 1528, 129, 3, 41, "Input"],
Cell[56445, 1533, 183, 4, 21, "Output"]
}, Open  ]],
Cell[56643, 1540, 372, 11, 24, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

