(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     49179,       1053]*)
(*NotebookOutlinePosition[    121215,       3648]*)
(*  CellTagsIndexPosition[    120970,       3637]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< NumericalModels`ExactModel`;\)\)], "Input",
  CellLabel->"In[2]:="],

Cell[CellGroupData[{

Cell["Mean fitness and marginal fitness", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(\(\ \)\(MeanW[\[Phi], 
              W]\)\), \(gives\ the\ mean\ fitness; \ \[Phi]\ represents\ any\ \
kind\ of\ population\)}
          }], TraditionalForm]],
  CellTags->"MeanW"]], "DefinitionBox",
  CellTags->"MeanW"],

Cell["\<\
This is the mean fitness of a population of 10 haploid individuals, \
with fitness function W[X]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(hp = 
        MakePopulation[3, {0.1, 0.2, 0.5}, 10, 
          NumericalModel -> HaploidIndividuals];\)\), "\n", 
    \(MeanW[hp, W]\)}], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \(1\/10\ \((5\ W[{0, 0, 0}] + 2\ W[{0, 0, 1}] + W[{0, 1, 0}] + 
          W[{0, 1, 1}] + W[{1, 0, 0}])\)\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell["\<\
This is the mean fitness of a haploid population with 10% selection \
against '1' alleles:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MeanW[hp, 0.9\^Plus @@ # &]\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \(0.9410000000000001`\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["The fitness W[X] is given as a pure function.", "Text"],

Cell["\<\
This is the mean fitness of a diploid population with 10% selection \
against heterozygotes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dp = 
        MakePopulation[3, {0.1, 0.2, 0.5}, 10, 
          NumericalModel -> DiploidIndividuals];\)\), "\n", 
    \(MeanW[dp, 0.9\^CountHeterozygotes[#1, #2] &]\)}], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \(0.93`\)], "Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell[TextData[{
  "The function W[X,Y] specifies the fitness of a diploid individual with \
genotype {X,Y}; here,",
  Cell[BoxData[
      \(\(\(\ \)\(0.9\^CountHeterozygotes[#1, #2] &\)\)\)]],
  " is used. "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(FitnessTable[n, W, 
              NumericalModel \[Rule] 
                HaploidIndividuals]\), \(gives\ a\ table\ of\ fitnesses, \ 
            appropriate\ for\ haploids\ with\ n\ genes; \ 
            fitness\ is\ W[X]\)},
          {\(FitnessTable[n, W, 
              NumericalModel -> 
                DiploidIndividuals]\), \(gives\ a\ table\ of\ fitnesses, \ 
            appropriate\ for\ diploids\ with\ n\ genes; \ 
            fitness\ is\ W[X, Y]\)},
          {\(MeanW[\[Psi], {{\(W\_\(X, 
                        Y\)\) \[Ellipsis]}, \[Ellipsis]}]\), \(calculates\ \
mean\ fitness\ from\ an\ appropriate\ table\ of\ \(\(fitnesses\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->"MeanW"]], "DefinitionBox",
  CellTags->"FitnessTable"],

Cell[TextData[{
  "This gives the fitness of all ",
  Cell[BoxData[
      \(TraditionalForm\`2\^3 = \ 8\ haploid\ \(\(genotypes\)\(:\)\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(hwt = 
      FitnessTable[0.9\^Plus @@ # &, 3, 
        NumericalModel \[Rule] HaploidIndividuals]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \({1, 0.9`, 0.9`, 0.81`, 0.9`, 0.81`, 0.81`, 
      0.7290000000000001`}\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell["\<\
This is the same table as would be used with the default, \
NumericalModel\[Rule]HaploidFrequencies.\
\>", "Text"],

Cell["\<\
Mean fitness can be calculated from this table of fitnesses, which \
may be much faster:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MeanW[hp, hwt]\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(0.9410000000000001`\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell[TextData[{
  "This gives the fitness of all ",
  Cell[BoxData[
      \(TraditionalForm\`2\^6 = \ 64\ diploid\ \(\(genotypes\)\(:\)\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(dwt = 
      FitnessTable[0.9\^CountHeterozygotes[#1, #2] &, 3, 
        NumericalModel -> DiploidIndividuals]; dwt // MatrixForm\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0.9`", "0.9`", "0.81`", "0.9`", "0.81`", "0.81`", 
              "0.7290000000000001`"},
            {"0.9`", "1", "0.81`", "0.9`", "0.81`", "0.9`", 
              "0.7290000000000001`", "0.81`"},
            {"0.9`", "0.81`", "1", "0.9`", "0.81`", "0.7290000000000001`", 
              "0.9`", "0.81`"},
            {"0.81`", "0.9`", "0.9`", "1", "0.7290000000000001`", "0.81`", 
              "0.81`", "0.9`"},
            {"0.9`", "0.81`", "0.81`", "0.7290000000000001`", "1", "0.9`", 
              "0.9`", "0.81`"},
            {"0.81`", "0.9`", "0.7290000000000001`", "0.81`", "0.9`", "1", 
              "0.81`", "0.9`"},
            {"0.81`", "0.7290000000000001`", "0.9`", "0.81`", "0.9`", "0.81`",
               "1", "0.9`"},
            {"0.7290000000000001`", "0.81`", "0.81`", "0.9`", "0.81`", "0.9`",
               "0.9`", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[30]//MatrixForm="]
}, Open  ]],

Cell["\<\
This is the same table as would be used with the default, \
NumericalModel\[Rule]HaploidFrequencies.\
\>", "Text"],

Cell[TextData[{
  "These are sorted in binary order; SortByClass->True can be used as an \
option to FitnessTable, but ",
  StyleBox["must",
    FontWeight->"Bold"],
  " be used consistently throughout."
}], "Text"],

Cell["Mean fitness can be calculated from this table of fitnesses:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MeanW[dp, dwt]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(0.93`\)], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MarginalW[\[Psi], 
              W]\), \(cannot\ be\ calculated\ for\ a\ population\ of\ \
individuals\)}
          }], TraditionalForm]],
  CellTags->"MarginalW"]], "DefinitionBox",
  CellTags->"MarginalW"],

Cell["\<\
This lists the marginal fitnesses of each haploid genotype, given a \
set of diploid frequencies, and fitness W[X,Y]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MarginalW[dp, 0.9\^CountHeterozygotes[#1, #2] &]\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \(MarginalW::"badOption" \(\(:\)\(\ \)\) 
      "Marginal fitnesses cannot be calculated for a set of individuals."\)], \
"Message",
  CellLabel->"From In[32]:="],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell["\<\
It is unclear how marginal fitnesses of haploid genotypes should be \
calculated, given a finite population of diploid individuals.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Selection", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(SelectionExact[\[Psi], 
              W]\), \(gives\ the\ population\ after\ selection, \ 
            with\ fitness\ W\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"SelectionExact"],

Cell["\<\
This represents 10% selection against '1' alleles in \
haploids:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(hp = 
        MakePopulation[3, {0.1, 0.2, 0.5}, 100, 
          NumericalModel \[Rule] HaploidIndividuals];\)\), "\n", 
    \(SelectionExact[hp, 0.9\^Plus @@ # &]\)}], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \(HaploidIndividuals[{{0, 0, 1}, {0, 0, 0}, {1, 0, 1}, {0, 1, 1}, {1, 0, 
          1}, {0, 0, 0}, {0, 0, 1}, {1, 0, 1}, {0, 1, 1}, {0, 0, 0}, {0, 1, 
          1}, {0, 0, 1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 1}, {1, 0, 
          1}, {0, 0, 0}, {0, 1, 1}, {0, 0, 1}, {0, 0, 0}, {0, 1, 1}, {0, 1, 
          0}, {0, 0, 0}, {0, 1, 1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          1}, {0, 0, 1}, {0, 1, 0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 0}, {0, 1, 
          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 1, 0}, {0, 0, 1}, {0, 0, 
          0}, {0, 0, 1}, {0, 1, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}, {0, 0, 0}, {0, 0, 1}, {1, 0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 1, 
          1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 1, 0}, {0, 0, 0}, {0, 0, 
          0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 1, 
          0}, {0, 1, 1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 
          1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 1, 1}, {0, 0, 
          0}, {0, 1, 0}, {1, 0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 
          1}, {0, 1, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 
          0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 1, 1}, {0, 0, 1}, {0, 0, 
          1}}, 95]\)], "Output",
  CellLabel->"Out[4]="]
}, Closed]],

Cell[TextData[{
  "Each individual survives with probability equal to its fitness: thus, \
fitness represents ",
  StyleBox["absolute",
    FontWeight->"Bold"],
  " viability, and must not be outside {0,1}.  The new deme size is reduced \
by a factor which has expectation ",
  Cell[BoxData[
      \(TraditionalForm\`W\&_\)]],
  "."
}], "Text"],

Cell["\<\
This represents 10% selection against heterozygotes in a population \
of 1000 diploid individualss:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dp = 
        MakePopulation[3, {0.1, 0.5, 0.8}, 1000, 
          NumericalModel -> DiploidIndividuals];\)\), "\n", 
    \(ndp = SelectionExact[dp, 0.9\^CountHeterozygotes[#1, #2] &]\)}], "Input",\

  CellLabel->"In[41]:="],

Cell[BoxData[
    \(DiploidIndividuals[{{{0, 1, 1}, {0, 1, 0}}, {{0, 1, 0}, {0, 0, 
            0}}, {{0, 1, 0}, {0, 0, 0}}, {{0, 0, 1}, {0, 1, 1}}, {{1, 0, 
            1}, {0, 0, 1}}, {{0, 0, 0}, {0, 1, 1}}, {{0, 1, 1}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 1, 0}, {0, 1, 0}}, {{0, 1, 1}, {0, 1, 
            0}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 0, 0}, {0, 1, 0}}, {{0, 1, 1}, {0, 0, 
            1}}, {{0, 1, 1}, {1, 0, 1}}, {{0, 1, 0}, {0, 0, 1}}, {{0, 1, 
            0}, {0, 0, 0}}, {{0, 1, 1}, {1, 0, 1}}, {{0, 0, 1}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 1, 0}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 1, 0}}, {{0, 1, 1}, {0, 1, 0}}, {{0, 1, 1}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{1, 1, 0}, {0, 1, 0}}, {{0, 0, 
            1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{1, 0, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {0, 1, 0}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 
            0}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 0}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{1, 0, 1}, {0, 1, 
            1}}, {{1, 0, 0}, {0, 1, 1}}, {{0, 1, 0}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 0, 1}}, {{0, 1, 1}, {1, 1, 0}}, {{0, 1, 0}, {0, 1, 
            0}}, {{0, 0, 0}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 
            1}, {0, 0, 0}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 1}, {1, 0, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{1, 1, 0}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 0}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 0, 0}}, {{0, 0, 1}, {0, 0, 0}}, {{0, 0, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 0, 0}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 
            0}}, {{0, 0, 0}, {0, 0, 1}}, {{1, 1, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 0}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 0}, {0, 1, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {1, 0, 1}}, {{0, 1, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {1, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 0}, {0, 1, 
            1}}, {{0, 1, 0}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 
            1}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 
            1}}, {{0, 1, 0}, {0, 1, 0}}, {{0, 1, 1}, {0, 1, 0}}, {{0, 1, 
            1}, {0, 1, 1}}, {{1, 1, 1}, {0, 0, 1}}, {{1, 0, 1}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 0}, {0, 1, 1}}, {{1, 1, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{1, 0, 1}, {0, 0, 
            0}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{1, 1, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{1, 1, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 0, 
            1}, {1, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {1, 0, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 0}}, {{0, 1, 1}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 1}, {1, 0, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {1, 0, 1}}, {{0, 1, 1}, {0, 0, 
            1}}, {{0, 0, 0}, {0, 1, 0}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 
            1}}, {{1, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {1, 1, 1}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 0, 1}, {1, 1, 
            1}}, {{0, 0, 0}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 
            0}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{1, 1, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 
            0}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {1, 0, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 
            1}, {1, 0, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{1, 0, 1}, {1, 1, 
            1}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{1, 1, 0}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 
            0}}, {{0, 0, 0}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 
            1}, {0, 0, 0}}, {{0, 0, 1}, {1, 1, 1}}, {{0, 1, 1}, {0, 1, 
            0}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 
            1}, {1, 1, 1}}, {{0, 0, 0}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {1, 0, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 0}}, {{0, 1, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {0, 1, 1}}, {{1, 0, 1}, {0, 1, 1}}, {{1, 1, 
            1}, {0, 1, 1}}, {{0, 0, 0}, {0, 1, 1}}, {{0, 0, 1}, {1, 0, 
            1}}, {{0, 1, 0}, {0, 0, 1}}, {{0, 0, 0}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 0, 0}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 
            0}, {0, 0, 0}}, {{0, 0, 1}, {0, 0, 0}}, {{0, 0, 1}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 0}, {0, 0, 1}}, {{0, 0, 
            0}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 
            0}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 0, 0}}, {{0, 1, 0}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 
            0}}, {{0, 1, 1}, {0, 1, 0}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 
            0}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 0}}, {{1, 0, 1}, {0, 0, 
            0}}, {{0, 1, 1}, {1, 0, 1}}, {{0, 0, 1}, {0, 1, 0}}, {{0, 0, 
            1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 
            0}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 0}}, {{1, 0, 0}, {0, 1, 
            0}}, {{1, 1, 1}, {1, 1, 1}}, {{0, 0, 0}, {0, 1, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 1, 0}, {0, 0, 1}}, {{0, 1, 0}, {0, 1, 
            1}}, {{0, 1, 1}, {0, 1, 0}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 
            0}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 0}}, {{0, 0, 0}, {0, 1, 
            0}}, {{1, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 0, 1}, {1, 1, 1}}, {{0, 0, 1}, {1, 0, 
            1}}, {{1, 0, 1}, {0, 0, 1}}, {{0, 1, 1}, {1, 0, 1}}, {{0, 1, 
            0}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 0}}, {{0, 1, 1}, {0, 0, 
            1}}, {{0, 0, 0}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 
            1}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 1, 1}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 0}}, {{0, 0, 
            1}, {0, 0, 0}}, {{1, 1, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 
            0}}, {{0, 1, 1}, {0, 0, 0}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 0}}, {{0, 0, 0}, {0, 1, 
            1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 
            0}, {0, 1, 1}}, {{0, 1, 1}, {1, 1, 1}}, {{0, 1, 1}, {0, 1, 
            0}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{1, 0, 
            1}, {0, 1, 1}}, {{0, 1, 0}, {0, 1, 0}}, {{0, 0, 0}, {0, 1, 
            1}}, {{0, 1, 0}, {0, 0, 0}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 
            1}}, {{1, 0, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {1, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 
            1}}, {{1, 1, 0}, {0, 1, 0}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 
            1}, {0, 1, 0}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 1, 0}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 0}}, {{0, 0, 
            1}, {0, 1, 0}}, {{0, 0, 0}, {0, 1, 1}}, {{0, 0, 0}, {0, 0, 
            0}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 1, 0}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 1, 1}}, {{1, 0, 1}, {0, 0, 0}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 0}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 0}, {0, 1, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 0, 
            1}}, {{1, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 
            0}}, {{0, 0, 1}, {0, 0, 0}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 0}, {0, 0, 
            0}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 
            1}, {0, 0, 1}}, {{0, 1, 1}, {1, 1, 1}}, {{0, 0, 1}, {0, 0, 
            0}}, {{0, 1, 0}, {0, 1, 0}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 
            1}, {0, 1, 0}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 0}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 
            1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 1}, {1, 0, 1}}, {{0, 1, 
            0}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 0, 0}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 0}}, {{1, 1, 1}, {1, 1, 
            1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 0}}, {{0, 1, 1}, {1, 1, 
            1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 0}}, {{0, 0, 1}, {1, 1, 
            1}}, {{1, 1, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 0}}, {{0, 0, 
            1}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 0}}, {{0, 1, 1}, {0, 0, 
            1}}, {{0, 0, 0}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 0}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 1, 0}, {0, 1, 0}}, {{0, 1, 1}, {1, 0, 
            1}}, {{0, 0, 0}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 
            0}, {0, 1, 1}}, {{0, 0, 0}, {0, 0, 1}}, {{1, 0, 1}, {0, 0, 
            1}}, {{0, 0, 1}, {1, 1, 1}}, {{1, 1, 0}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 0, 
            1}}, {{1, 1, 1}, {1, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{1, 1, 
            0}, {1, 1, 0}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 
            1}}, {{0, 1, 1}, {0, 1, 0}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {1, 1, 1}}, {{0, 0, 0}, {0, 0, 1}}, {{0, 1, 
            0}, {0, 0, 0}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 1, 1}}, {{1, 1, 1}, {0, 0, 0}}, {{0, 1, 
            0}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 0}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 0}}, {{0, 1, 1}, {0, 1, 
            1}}, {{0, 1, 0}, {0, 1, 0}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 0, 1}}, {{0, 1, 1}, {1, 1, 0}}, {{0, 0, 1}, {0, 1, 
            1}}, {{1, 1, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 
            0}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 0}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 0}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{1, 1, 1}, {0, 1, 
            1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{1, 1, 
            1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 
            0}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 
            1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 1}, {1, 1, 1}}, {{0, 1, 
            0}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 
            1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 0}}, {{0, 0, 0}, {0, 1, 
            1}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 0}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 1, 0}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 1, 0}}, {{0, 0, 1}, {0, 1, 0}}, {{1, 0, 1}, {0, 1, 
            0}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 1, 1}, {1, 0, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 1}, {1, 1, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 0, 0}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 0}}, {{1, 0, 
            1}, {1, 0, 0}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 
            1}}, {{0, 1, 1}, {1, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 
            1}, {1, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{1, 1, 0}, {0, 1, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 0}, {1, 0, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 1, 0}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 0}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 0}, {0, 1, 0}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{1, 0, 1}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 1, 0}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 0}, {0, 1, 
            1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{1, 1, 1}, {0, 0, 0}}, {{0, 0, 1}, {0, 1, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 0}}, {{0, 0, 1}, {0, 1, 
            0}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 
            0}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 0}}, {{0, 0, 1}, {0, 1, 
            1}}, {{0, 1, 1}, {0, 1, 0}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 0, 1}}, {{1, 1, 1}, {0, 0, 1}}, {{0, 0, 0}, {0, 1, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 0}, {0, 1, 1}}, {{0, 1, 
            0}, {0, 0, 1}}, {{0, 0, 0}, {0, 0, 1}}, {{0, 1, 1}, {1, 1, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{1, 0, 
            0}, {1, 1, 0}}, {{0, 0, 0}, {0, 1, 1}}, {{1, 0, 1}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 0, 0}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 0, 1}}, {{0, 1, 1}, {1, 1, 1}}, {{0, 0, 1}, {0, 0, 
            1}}, {{1, 1, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 0}}, {{0, 0, 
            1}, {0, 1, 0}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 
            0}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 0}}, {{0, 1, 0}, {1, 0, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 0}}, {{0, 0, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 0, 0}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 
            1}}, {{1, 1, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 0, 0}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 
            1}}, {{0, 0, 0}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {1, 1, 0}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 
            1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 0, 0}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 1, 0}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {1, 0, 
            0}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 
            0}, {1, 0, 1}}, {{0, 0, 1}, {0, 0, 0}}, {{0, 0, 1}, {0, 0, 
            1}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 1, 0}}, {{1, 0, 1}, {1, 0, 0}}, {{0, 1, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {0, 0, 0}}, {{1, 1, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 
            0}}, {{0, 1, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 0}}, {{1, 1, 
            1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 0}}, {{0, 0, 1}, {0, 1, 
            1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 1, 0}, {0, 0, 1}}, {{0, 0, 0}, {0, 0, 
            0}}, {{0, 1, 1}, {0, 0, 0}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 0, 
            1}, {1, 1, 1}}, {{0, 1, 1}, {0, 0, 0}}, {{0, 0, 1}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 
            1}}, {{0, 1, 1}, {1, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{1, 0, 
            0}, {0, 0, 0}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{1, 0, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 0}, {0, 0, 1}}, {{0, 0, 
            0}, {1, 0, 0}}, {{0, 0, 1}, {0, 1, 1}}, {{1, 0, 1}, {0, 1, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 
            1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 1, 0}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 
            0}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 1, 1}, {1, 0, 1}}, {{0, 1, 1}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 0}}, {{0, 0, 
            1}, {0, 1, 1}}, {{1, 1, 0}, {0, 1, 0}}, {{0, 0, 1}, {0, 0, 
            1}}, {{0, 0, 1}, {1, 1, 1}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 0, 
            1}, {0, 0, 1}}, {{0, 0, 0}, {1, 0, 1}}, {{0, 0, 0}, {0, 1, 
            1}}, {{0, 1, 1}, {0, 0, 0}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 
            1}}, {{0, 1, 1}, {1, 0, 1}}, {{0, 0, 1}, {1, 1, 1}}, {{0, 1, 
            0}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 0}}, {{1, 0, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {1, 0, 1}}, {{0, 1, 
            0}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 0}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 0, 0}, {0, 1, 1}}, {{0, 1, 0}, {1, 1, 
            1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 0}, {0, 1, 0}}, {{0, 1, 
            1}, {0, 0, 1}}, {{1, 0, 1}, {0, 0, 1}}, {{0, 0, 0}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 0, 
            0}}, {{0, 0, 1}, {0, 0, 1}}, {{1, 0, 1}, {0, 1, 1}}, {{0, 0, 
            1}, {0, 1, 0}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 
            1}}, {{1, 1, 0}, {1, 1, 1}}, {{0, 0, 0}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 
            0}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 
            0}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 0}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 0}, {0, 1, 0}}, {{0, 0, 
            0}, {0, 1, 1}}, {{0, 1, 0}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 
            1}}, {{0, 1, 1}, {1, 0, 1}}, {{0, 1, 0}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{1, 1, 1}, {0, 1, 1}}, {{0, 0, 1}, {1, 1, 
            1}}, {{0, 0, 0}, {1, 0, 1}}, {{0, 1, 0}, {0, 1, 0}}, {{0, 0, 
            0}, {0, 0, 0}}, {{1, 1, 1}, {0, 1, 1}}, {{0, 0, 0}, {0, 1, 
            1}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 1, 1}, {1, 0, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 0}}, {{0, 1, 1}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {1, 1, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 1, 1}, {1, 1, 1}}, {{0, 1, 1}, {0, 1, 
            0}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 0, 1}}, {{0, 0, 0}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 0, 0}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 0}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 0, 0}}, {{0, 1, 0}, {0, 0, 1}}, {{1, 0, 
            0}, {0, 0, 1}}, {{0, 0, 1}, {1, 0, 1}}, {{0, 0, 0}, {0, 1, 
            1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 0}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 0, 1}, {1, 0, 1}}, {{0, 1, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {1, 1, 1}}, {{0, 0, 1}, {0, 0, 0}}, {{0, 1, 
            1}, {0, 0, 1}}, {{1, 1, 1}, {0, 0, 0}}, {{0, 0, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{1, 1, 1}, {0, 0, 1}}, {{1, 1, 1}, {0, 0, 
            0}}, {{1, 0, 0}, {0, 0, 1}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 1, 0}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 
            1}}, {{1, 1, 0}, {0, 0, 1}}, {{0, 1, 0}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 0, 0}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 0}, {0, 0, 1}}, {{1, 0, 
            1}, {0, 0, 1}}, {{0, 0, 0}, {1, 0, 1}}, {{0, 1, 1}, {0, 1, 
            1}}, {{1, 1, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 
            1}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 0}, {0, 1, 1}}, {{1, 1, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 0}}, {{0, 1, 0}, {0, 1, 
            0}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 
            1}, {0, 0, 1}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 
            1}}, {{0, 0, 0}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{1, 0, 
            0}, {0, 0, 1}}, {{1, 0, 1}, {0, 1, 0}}, {{0, 0, 1}, {0, 1, 
            0}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {1, 1, 1}}, {{0, 0, 
            1}, {0, 1, 0}}, {{0, 1, 0}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 
            0}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 
            1}}, {{0, 1, 1}, {1, 0, 1}}, {{0, 0, 1}, {0, 0, 0}}, {{0, 0, 
            1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {1, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 0}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 
            0}}, {{0, 1, 1}, {1, 1, 1}}, {{0, 0, 0}, {0, 0, 0}}, {{0, 0, 
            1}, {1, 0, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{1, 0, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {0, 1, 0}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 
            1}}, {{0, 0, 0}, {0, 0, 1}}, {{0, 0, 1}, {1, 1, 1}}, {{0, 1, 
            1}, {0, 0, 0}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 0}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 0, 0}}, {{1, 0, 
            1}, {1, 0, 1}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 
            0}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 0}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{1, 1, 1}, {0, 0, 
            1}}, {{1, 1, 0}, {0, 0, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 1, 1}, {0, 0, 0}}, {{0, 0, 1}, {0, 1, 
            1}}, {{1, 0, 1}, {0, 0, 1}}, {{1, 1, 1}, {0, 0, 0}}, {{0, 0, 
            0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 1}}, {{1, 0, 1}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 0}}, {{0, 1, 
            1}, {0, 1, 0}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {1, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 0}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 0}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 
            0}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 0}}, {{1, 0, 1}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 
            1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 0, 
            0}, {0, 1, 0}}, {{0, 1, 1}, {0, 0, 0}}, {{0, 1, 1}, {0, 1, 
            1}}, {{0, 0, 0}, {1, 0, 1}}, {{0, 1, 0}, {0, 1, 1}}, {{0, 0, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 0}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{1, 0, 1}, {0, 1, 
            1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 0, 1}}, {{0, 0, 
            0}, {0, 1, 0}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {1, 0, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 1, 
            1}}, {{1, 1, 1}, {0, 1, 1}}, {{0, 1, 0}, {1, 0, 0}}, {{0, 1, 
            1}, {0, 1, 1}}, {{0, 0, 0}, {0, 0, 0}}, {{0, 0, 1}, {0, 0, 
            1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 1, 1}}, {{0, 1, 
            1}, {0, 0, 1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 0, 1}, {0, 1, 
            1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 0}, {0, 0, 1}}, {{0, 0, 
            1}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 1}}, {{0, 1, 1}, {0, 0, 
            1}}, {{0, 0, 1}, {0, 1, 1}}, {{0, 1, 1}, {0, 0, 1}}}, 
      909]\)], "Output",
  CellLabel->"Out[42]="]
}, Closed]],

Cell["\<\
On average, rare alleles get rarer; no new linkage disequilibrium \
is generated.  However, random fluctuations necessarily arise when \
individuals are sampled:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({AlleleFrequencyTable[ndp] // MatrixForm, 
          DisequilibriumTable[ndp] // MatrixForm} // N\) // Chop\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0.0924092409240924`"},
                {"0.49944994499449946`"},
                {"0.8052805280528053`"}
                }], "\[NoBreak]", ")"}],
          
          MatrixForm[ {0.092409240924092403, 0.49944994499449946, 
            0.80528052805280526}]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0.08391593149408502`", \(-0.0010498573247528385`\), 
                  "0.0025937651552717187`"},
                {\(-0.0010498573247528385`\), 
                  "0.25013728670610597`", \(-0.004510027227268682`\)},
                {"0.0025937651552717187`", \(-0.004510027227268682`\), 
                  "0.15689009737517506`"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output",
  CellLabel->"Out[43]="]
}, Open  ]],

Cell["\<\
With individual representations, and this form of SelectionExact[], \
population regulation is not included: numbers are determined by the absolute \
viabilities.\
\>", "Text",
  CellTags->"DemeSize"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(SelectionExact[\[Psi], W, 
              f]\), \(gives\ the\ population\ after\ selection, \ 
            with\ fitness\ W, \ and\ new\ deme\ size\ f[n, W\&_]\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"SelectionExact"],

Cell[TextData[{
  "Now, the number of individuals after selection is determined by ",
  Cell[BoxData[
      \(TraditionalForm\`f[n, W\&_]\)]],
  ", and individuals are chosen to contribute with probability proportional \
to W; sampling is without replacement.   "
}], "Text"],

Cell["\<\
In this example, there is multiplicative selection 0.5 against each \
'1' allele.  50 individuals are sampled, without replacement, from the \
original population of 100, with probabilities proportional to fitness:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(np = SelectionExact[hp, 0.5\^Plus @@ # &, 50 &]\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \(HaploidIndividuals[{{0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 1, 
          0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 1, 0}, {0, 0, 
          0}, {0, 0, 0}, {0, 0, 1}, {0, 1, 0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 
          1}, {0, 0, 0}, {0, 1, 0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 
          1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 1, 0}, {0, 0, 1}, {0, 0, 
          0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 0}, {0, 1, 0}, {0, 1, 0}, {0, 0, 
          1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {1, 0, 1}, {0, 1, 0}, {0, 0, 
          0}, {0, 1, 1}, {0, 0, 0}, {0, 0, 0}}, 50]\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["\<\
The new genotype class proportions are close to the original \
proportions, multiplied by W:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(c0 = \(Count[\(\((Plus @@ #)\) &\) /@ 
                hp\[LeftDoubleBracket]1\[RightDoubleBracket], #] &\) /@ {0, 
            1, 2, 3};\)\), "\n", 
    \(cn = \(Count[\(\((Plus @@ #)\) &\) /@ 
              np\[LeftDoubleBracket]1\[RightDoubleBracket], #] &\) /@ {0, 1, 
          2, 3}\), "\n", 
    \(dd = c0 {1, 0.5, 0.25, 0.125}; {c0, cn, 50  dd/\((Plus @@ dd)\)} // 
      TableForm\)}], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \({25, 23, 2, 0}\)], "Output",
  CellLabel->"Out[31]="],

Cell[BoxData[
    TagBox[GridBox[{
          {"35", "51", "14", "0"},
          {"25", "23", "2", "0"},
          {"27.34375`", "19.921875`", "2.734375`", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[32]//TableForm="]
}, Open  ]],

Cell["\<\
This relation is not exact: as a larger proportion of the \
population is sampled without replacement, selection becomes weaker. When 90 \
are sampled from 100, proportions hardly change:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(np = SelectionExact[hp, 0.5\^Plus @@ # &, 90 &];\)\), "\n", 
    \(\(c0 = \(Count[\(\((Plus @@ #)\) &\) /@ 
                hp\[LeftDoubleBracket]1\[RightDoubleBracket], #] &\) /@ {0, 
            1, 2, 3};\)\), "\n", 
    \(cn = \(Count[\(\((Plus @@ #)\) &\) /@ 
              np\[LeftDoubleBracket]1\[RightDoubleBracket], #] &\) /@ {0, 1, 
          2, 3}\), "\n", 
    \(dd = c0 {1, 0.5, 0.25, 0.125}; {c0, cn, 90  dd/\((Plus @@ dd)\)} // 
      TableForm\)}], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \({34, 45, 11, 0}\)], "Output",
  CellLabel->"Out[35]="],

Cell[BoxData[
    TagBox[GridBox[{
          {"35", "51", "14", "0"},
          {"34", "45", "11", "0"},
          {"49.21875`", "35.859375`", "4.921875`", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[36]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "Since there is no reproduction, ",
  Cell[BoxData[
      \(TraditionalForm\`necessarilyf[n, W\&_]\)]],
  "\[LessEqual]n."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SelectionExact[hp, 0.9\^Plus @@ # &, 200 &]\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(SelectionExact::"badN" \(\(:\)\(\ \)\) 
      "New deme size \!\(200\) is greater than original size `2`"\)], \
"Message",
  CellLabel->"From In[29]:="],

Cell[BoxData[
    \(HaploidIndividuals[{{0, 0, 0}, {1, 0, 1}, {0, 0, 1}, {0, 1, 0}, {0, 0, 
          1}, {0, 0, 1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 1, 
          0}, {0, 1, 0}, {1, 0, 0}, {0, 0, 1}, {0, 1, 0}, {0, 0, 1}, {0, 0, 
          1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 1, 0}, {0, 1, 0}, {0, 0, 
          0}, {0, 0, 0}, {0, 0, 0}, {0, 1, 1}, {0, 0, 0}, {0, 1, 0}, {0, 0, 
          1}, {0, 0, 1}, {0, 1, 1}, {0, 0, 1}, {0, 0, 1}, {0, 1, 1}, {0, 0, 
          1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}, {0, 1, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 
          0}, {0, 1, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 1, 0}, {0, 0, 
          0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 
          1}, {0, 0, 1}, {1, 0, 1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 1}, {0, 1, 
          1}, {0, 0, 0}, {0, 1, 1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          1}, {0, 1, 0}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 1}, {0, 0, 
          1}, {1, 0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 
          0}, {1, 0, 1}, {0, 1, 1}, {1, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          1}, {0, 0, 0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}, {0, 0, 1}, {0, 1, 0}, {0, 1, 1}, {0, 1, 1}, {0, 1, 0}}, 
      100]\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell[TextData[{
  "This form is equivalent to SelectionExact[\[Psi], W] if ",
  Cell[BoxData[
      \(TraditionalForm\`f[n, W\&_]\)]],
  " is Random[BinomialDistribution[",
  Cell[BoxData[
      \(TraditionalForm\`n, W\&_\)]],
  "]].  However, SelectionExact[\[Psi],W] is much faster, because it does not \
rely on sampling without replacement."
}], "Text"],

Cell[TextData[{
  "Note: ",
  StyleBox["SelectionExact[] is not used by IterateExact[] or StoreExact[].  \
There, NewGametes[] is used to implement selection more efficiently.  \
NewGametes[] has a slightly different effect from \
SelectionExact[DiploidIndividuals[],W,f], because there, parents are chosen \
for gametes.  Here, diploid parents are chosen to survive: there is no \
reproduction.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(SelectionExact[\[Psi], W, f, 
              TruncationSelection -> 
                True]\), \(implements\ truncation\ selection, \ 
            with\ the\ f[n, 
                W\&_]\ individuals\ with\ highest\ W\ surviving . \ \n
                If\ f\ is\ larger\ than\ the\ deme\ size, \ 
            then\ all\ individuals\ survive\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"TruncationSelection"],

Cell["\<\
With truncation selection, those individuals with the highest value \
of W are chosen to survive.  In order to use this option, the new deme size \
must be specified by f.\
\>", "Text"],

Cell["The 50 'fittest' individuals are chosen:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(np = 
      SelectionExact[hp, 0.5\^Plus @@ # &, 50 &, 
        TruncationSelection -> True]\)], "Input",
  CellLabel->"In[89]:="],

Cell[BoxData[
    \(HaploidIndividuals[{{0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}, {0, 0, 1}, {0, 0, 1}, {0, 1, 0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 
          1}, {0, 0, 1}, {0, 1, 0}, {0, 0, 1}, {0, 1, 0}, {0, 0, 1}, {0, 1, 
          0}, {0, 0, 1}, {0, 0, 1}, {0, 0, 1}}, 50]\)], "Output",
  CellLabel->"Out[89]="]
}, Open  ]],

Cell["\<\
This includes all of the {0,0,0} genotypes, and some of the {0,1,0} \
etc.  \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(c0 = \(Count[\(\((Plus @@ #)\) &\) /@ 
                hp\[LeftDoubleBracket]1\[RightDoubleBracket], #] &\) /@ {0, 
            1, 2, 3};\)\), "\n", 
    \(\(cn = \(Count[\(\((Plus @@ #)\) &\) /@ 
                np\[LeftDoubleBracket]1\[RightDoubleBracket], #] &\) /@ {0, 
            1, 2, 3};\)\), "\n", 
    \({c0, cn} // TableForm\)}], "Input",
  CellLabel->"In[90]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"35", "51", "14", "0"},
          {"35", "15", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[92]//TableForm="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Note: ",
    FontWeight->"Bold"],
  "  Genotypes are returned in random order, to avoid artefacts - for \
example, when using MakeDiploid[], which unites adjacent haploid \
individuals."
}], "Text"],

Cell[TextData[{
  "Note:  ",
  StyleBox["Truncation selection is not yet implemented for the case where \
fitness is supplied as a list",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1248}, {0, 832}},
AutoGeneratedPackage->None,
WindowSize->{915, 736},
WindowMargins->{{61, Automatic}, {Automatic, 0}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "MeanW"->{
    Cell[1982, 61, 283, 7, 37, "DefinitionBox",
      CellTags->"MeanW"]},
  "FitnessTable"->{
    Cell[3865, 135, 820, 17, 76, "DefinitionBox",
      CellTags->"FitnessTable"]},
  "MarginalW"->{
    Cell[7655, 260, 270, 7, 37, "DefinitionBox",
      CellTags->"MarginalW"]},
  "SelectionExact"->{
    Cell[8699, 301, 267, 6, 39, "DefinitionBox",
      CellTags->"SelectionExact"],
    Cell[39572, 785, 306, 6, 40, "DefinitionBox",
      CellTags->"SelectionExact"]},
  "DemeSize"->{
    Cell[39359, 778, 210, 5, 24, "Text",
      CellTags->"DemeSize"]},
  "TruncationSelection"->{
    Cell[46217, 965, 490, 10, 58, "DefinitionBox",
      CellTags->"TruncationSelection"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"MeanW", 120271, 3613},
  {"FitnessTable", 120366, 3616},
  {"MarginalW", 120467, 3619},
  {"SelectionExact", 120569, 3622},
  {"DemeSize", 120755, 3627},
  {"TruncationSelection", 120853, 3630}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 46, 0, 30, "MathCaption"],
Cell[1803, 53, 92, 2, 26, "Input"],

Cell[CellGroupData[{
Cell[1920, 59, 59, 0, 36, "SubsectionIcon"],
Cell[1982, 61, 283, 7, 37, "DefinitionBox",
  CellTags->"MeanW"],
Cell[2268, 70, 128, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2421, 77, 195, 5, 42, "Input"],
Cell[2619, 84, 161, 3, 36, "Output"]
}, Open  ]],
Cell[2795, 90, 121, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2941, 97, 85, 2, 28, "Input"],
Cell[3029, 101, 78, 2, 20, "Output"]
}, Open  ]],
Cell[3122, 106, 61, 0, 22, "Text"],
Cell[3186, 108, 123, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3334, 115, 227, 5, 42, "Input"],
Cell[3564, 122, 64, 2, 20, "Output"]
}, Open  ]],
Cell[3643, 127, 219, 6, 24, "Text"],
Cell[3865, 135, 820, 17, 76, "DefinitionBox",
  CellTags->"FitnessTable"],
Cell[4688, 154, 159, 4, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[4872, 162, 156, 4, 28, "Input"],
Cell[5031, 168, 129, 3, 20, "Output"]
}, Open  ]],
Cell[5175, 174, 124, 3, 22, "Text"],
Cell[5302, 179, 119, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5446, 186, 72, 2, 27, "Input"],
Cell[5521, 190, 78, 2, 20, "Output"]
}, Open  ]],
Cell[5614, 195, 160, 4, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[5799, 203, 187, 4, 28, "Input"],
Cell[5989, 209, 1042, 21, 143, "Output"]
}, Open  ]],
Cell[7046, 233, 124, 3, 22, "Text"],
Cell[7173, 238, 215, 6, 24, "Text"],
Cell[7391, 246, 85, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7501, 251, 72, 2, 27, "Input"],
Cell[7576, 255, 64, 2, 20, "Output"]
}, Open  ]],
Cell[7655, 260, 270, 7, 37, "DefinitionBox",
  CellTags->"MarginalW"],
Cell[7928, 269, 148, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[8101, 276, 106, 2, 28, "Input"],
Cell[8210, 280, 180, 4, 20, "Message"],
Cell[8393, 286, 61, 2, 20, "Output"]
}, Open  ]],
Cell[8469, 291, 155, 3, 22, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8661, 299, 35, 0, 26, "SubsectionIcon"],
Cell[8699, 301, 267, 6, 39, "DefinitionBox",
  CellTags->"SelectionExact"],
Cell[8969, 309, 95, 3, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[9089, 316, 224, 5, 46, "Input"],
Cell[9316, 323, 1303, 18, 98, "Output"]
}, Closed]],
Cell[10634, 344, 344, 10, 36, "Text"],
Cell[10981, 356, 130, 3, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[11136, 363, 246, 6, 46, "Input"],
Cell[11385, 371, 26626, 366, 3425, "Output"]
}, Closed]],
Cell[38026, 740, 192, 4, 20, "MathCaption"],

Cell[CellGroupData[{
Cell[38243, 748, 167, 3, 26, "Input"],
Cell[38413, 753, 931, 22, 51, "Output"]
}, Open  ]],
Cell[39359, 778, 210, 5, 24, "Text",
  CellTags->"DemeSize"],
Cell[39572, 785, 306, 6, 40, "DefinitionBox",
  CellTags->"SelectionExact"],
Cell[39881, 793, 275, 6, 24, "Text"],
Cell[40159, 801, 247, 5, 46, "MathCaption"],

Cell[CellGroupData[{
Cell[40431, 810, 105, 2, 30, "Input"],
Cell[40539, 814, 721, 10, 85, "Output"]
}, Open  ]],
Cell[41275, 827, 123, 3, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[41423, 834, 451, 9, 58, "Input"],
Cell[41877, 845, 73, 2, 21, "Output"],
Cell[41953, 849, 363, 11, 63, "Output"]
}, Open  ]],
Cell[42331, 863, 218, 4, 46, "MathCaption"],

Cell[CellGroupData[{
Cell[42574, 871, 520, 10, 79, "Input"],
Cell[43097, 883, 74, 2, 21, "Output"],
Cell[43174, 887, 364, 11, 63, "Output"]
}, Open  ]],
Cell[43553, 901, 159, 5, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[43737, 910, 101, 2, 30, "Input"],
Cell[43841, 914, 172, 4, 21, "Message"],
Cell[44016, 920, 1367, 19, 165, "Output"]
}, Open  ]],
Cell[45398, 942, 357, 9, 40, "Text"],
Cell[45758, 953, 456, 10, 40, "Text"],
Cell[46217, 965, 490, 10, 58, "DefinitionBox",
  CellTags->"TruncationSelection"],
Cell[46710, 977, 195, 4, 24, "Text"],
Cell[46908, 983, 63, 0, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[46996, 987, 150, 4, 30, "Input"],
Cell[47149, 993, 721, 10, 85, "Output"]
}, Open  ]],
Cell[47885, 1006, 107, 3, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[48017, 1013, 397, 8, 58, "Input"],
Cell[48417, 1023, 306, 10, 47, "Output"]
}, Open  ]],
Cell[48738, 1036, 226, 6, 24, "Text"],
Cell[48967, 1044, 196, 6, 24, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

