(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     85607,       2704]*)
(*NotebookOutlinePosition[    159250,       5338]*)
(*  CellTagsIndexPosition[    158764,       5319]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Iterating one deme", "SubsectionIcon"],

Cell["This loads this package, as well as the Graphics package:", \
"MathCaption"],

Cell[BoxData[
    \(<< NumericalModels`ExactModel`; << Graphics`;\)], "Input",
  CellLabel->"In[51]:=  (6:57:45 on 4/29/01)"],

Cell[CellGroupData[{

Cell["A single deme", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, 
              0]\), \(gives\ genotype\ frequencies\ after\ one\ generation\ \
of\ selection\ and\ recombination . \ \ \[Psi]\ must\ represent\ a\ haploid\ \
\(\(population\)\(.\)\)\)},
          {
            RowBox[{"StoreExact", "[", 
              RowBox[{"\[Psi]", ",", \(\[Psi]\_0\), ",", "W", ",", "0", ",", 
                RowBox[{"{", 
                  RowBox[{"t", ",", 
                    StyleBox["dt",
                      FontSlant->"Italic"]}], 
                  StyleBox["}",
                    FontSlant->"Italic"]}]}], 
              "]"}], \(stores\ results\ at\ intervals\ dt\ in\ \[Psi][t], \ 
            starting\ with\ \[Psi][
                  0] = \[Psi]\_0 . \ \ Options\ are\ passed\ directly\ to\ \(\
\(IterateExact[]\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->{"IterateExact", "StoreExact"}],

Cell["\<\
This shows the allele frequency at three loci, with selection s=10% \
against heterozygotes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(hp = 
        MakePopulation[3, {0.4, 0.49, 0.51}, 
          100];\)\), "\[IndentingNewLine]", 
    \(\(\(w[s_, het]\)[x_, 
          y_] := \((1 - s)\)\^CountHeterozygotes[x, y];\)\), "\n", 
    \(\(hpc = 
        NestList[IterateExact[#, w[0.1, het], 0] &, hp, 100];\)\), "\n", 
    \(\(DisplayTogether @@ \((ListPlot /@ 
            Transpose[AlleleFrequencyTable[hpc]])\);\)\)}], "Input",
  CellLabel->"In[11]:=  (19:00:28 on 4/24/01)"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00942951 0.0147151 0.600185 [
[.2124 .00222 -6 -9 ]
[.2124 .00222 6 0 ]
[.40099 .00222 -6 -9 ]
[.40099 .00222 6 0 ]
[.58958 .00222 -6 -9 ]
[.58958 .00222 6 0 ]
[.77817 .00222 -6 -9 ]
[.77817 .00222 6 0 ]
[.96676 .00222 -9 -9 ]
[.96676 .00222 9 0 ]
[.01131 .13475 -18 -4.5 ]
[.01131 .13475 0 4.5 ]
[.01131 .25479 -18 -4.5 ]
[.01131 .25479 0 4.5 ]
[.01131 .37483 -18 -4.5 ]
[.01131 .37483 0 4.5 ]
[.01131 .49486 -18 -4.5 ]
[.01131 .49486 0 4.5 ]
[.01131 .6149 -6 -4.5 ]
[.01131 .6149 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2124 .01472 m
.2124 .02097 L
s
[(20)] .2124 .00222 0 1 Mshowa
.40099 .01472 m
.40099 .02097 L
s
[(40)] .40099 .00222 0 1 Mshowa
.58958 .01472 m
.58958 .02097 L
s
[(60)] .58958 .00222 0 1 Mshowa
.77817 .01472 m
.77817 .02097 L
s
[(80)] .77817 .00222 0 1 Mshowa
.96676 .01472 m
.96676 .02097 L
s
[(100)] .96676 .00222 0 1 Mshowa
.125 Mabswid
.07096 .01472 m
.07096 .01847 L
s
.1181 .01472 m
.1181 .01847 L
s
.16525 .01472 m
.16525 .01847 L
s
.25955 .01472 m
.25955 .01847 L
s
.30669 .01472 m
.30669 .01847 L
s
.35384 .01472 m
.35384 .01847 L
s
.44814 .01472 m
.44814 .01847 L
s
.49529 .01472 m
.49529 .01847 L
s
.54243 .01472 m
.54243 .01847 L
s
.63673 .01472 m
.63673 .01847 L
s
.68388 .01472 m
.68388 .01847 L
s
.73102 .01472 m
.73102 .01847 L
s
.82532 .01472 m
.82532 .01847 L
s
.87247 .01472 m
.87247 .01847 L
s
.91961 .01472 m
.91961 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13475 m
.03006 .13475 L
s
[(0.2)] .01131 .13475 1 0 Mshowa
.02381 .25479 m
.03006 .25479 L
s
[(0.4)] .01131 .25479 1 0 Mshowa
.02381 .37483 m
.03006 .37483 L
s
[(0.6)] .01131 .37483 1 0 Mshowa
.02381 .49486 m
.03006 .49486 L
s
[(0.8)] .01131 .49486 1 0 Mshowa
.02381 .6149 m
.03006 .6149 L
s
[(1)] .01131 .6149 1 0 Mshowa
.125 Mabswid
.02381 .04472 m
.02756 .04472 L
s
.02381 .07473 m
.02756 .07473 L
s
.02381 .10474 m
.02756 .10474 L
s
.02381 .16476 m
.02756 .16476 L
s
.02381 .19477 m
.02756 .19477 L
s
.02381 .22478 m
.02756 .22478 L
s
.02381 .2848 m
.02756 .2848 L
s
.02381 .31481 m
.02756 .31481 L
s
.02381 .34482 m
.02756 .34482 L
s
.02381 .40484 m
.02756 .40484 L
s
.02381 .43484 m
.02756 .43484 L
s
.02381 .46485 m
.02756 .46485 L
s
.02381 .52487 m
.02756 .52487 L
s
.02381 .55488 m
.02756 .55488 L
s
.02381 .58489 m
.02756 .58489 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.03324 .25479 Mdot
.04267 .25176 Mdot
.0521 .2486 Mdot
.06153 .24529 Mdot
.07096 .24184 Mdot
.08039 .23824 Mdot
.08982 .23448 Mdot
.09925 .23057 Mdot
.10868 .22651 Mdot
.1181 .22228 Mdot
.12753 .21789 Mdot
.13696 .21335 Mdot
.14639 .20865 Mdot
.15582 .20379 Mdot
.16525 .19879 Mdot
.17468 .19363 Mdot
.18411 .18834 Mdot
.19354 .18292 Mdot
.20297 .17737 Mdot
.2124 .17172 Mdot
.22183 .16597 Mdot
.23126 .16014 Mdot
.24069 .15424 Mdot
.25012 .1483 Mdot
.25955 .14233 Mdot
.26898 .13636 Mdot
.27841 .1304 Mdot
.28784 .12447 Mdot
.29727 .11861 Mdot
.30669 .11283 Mdot
.31612 .10715 Mdot
.32555 .10159 Mdot
.33498 .09618 Mdot
.34441 .09093 Mdot
.35384 .08585 Mdot
.36327 .08096 Mdot
.3727 .07628 Mdot
.38213 .07181 Mdot
.39156 .06755 Mdot
.40099 .06351 Mdot
.41042 .0597 Mdot
.41985 .05612 Mdot
.42928 .05275 Mdot
.43871 .0496 Mdot
.44814 .04667 Mdot
.45757 .04394 Mdot
.467 .0414 Mdot
.47643 .03906 Mdot
.48586 .0369 Mdot
.49529 .0349 Mdot
.50471 .03307 Mdot
.51414 .03139 Mdot
.52357 .02985 Mdot
.533 .02844 Mdot
.54243 .02716 Mdot
.55186 .02599 Mdot
.56129 .02492 Mdot
.57072 .02395 Mdot
.58015 .02306 Mdot
.58958 .02226 Mdot
.59901 .02153 Mdot
.60844 .02087 Mdot
.61787 .02027 Mdot
.6273 .01973 Mdot
.63673 .01924 Mdot
.64616 .0188 Mdot
.65559 .0184 Mdot
.66502 .01804 Mdot
.67445 .01771 Mdot
.68388 .01741 Mdot
.69331 .01715 Mdot
.70273 .01691 Mdot
.71216 .01669 Mdot
.72159 .01649 Mdot
.73102 .01632 Mdot
.74045 .01616 Mdot
.74988 .01602 Mdot
.75931 .01589 Mdot
.76874 .01577 Mdot
.77817 .01566 Mdot
.7876 .01557 Mdot
.79703 .01549 Mdot
.80646 .01541 Mdot
.81589 .01534 Mdot
.82532 .01528 Mdot
.83475 .01522 Mdot
.84418 .01517 Mdot
.85361 .01513 Mdot
.86304 .01508 Mdot
.87247 .01505 Mdot
.8819 .01501 Mdot
.89132 .01498 Mdot
.90075 .01496 Mdot
.91018 .01493 Mdot
.91961 .01491 Mdot
.92904 .01489 Mdot
.93847 .01487 Mdot
.9479 .01486 Mdot
.95733 .01484 Mdot
.96676 .01483 Mdot
.97619 .01482 Mdot
.03324 .30881 Mdot
.04267 .30849 Mdot
.0521 .30816 Mdot
.06153 .30781 Mdot
.07096 .30744 Mdot
.08039 .30705 Mdot
.08982 .30664 Mdot
.09925 .30622 Mdot
.10868 .30576 Mdot
.1181 .30529 Mdot
.12753 .30479 Mdot
.13696 .30426 Mdot
.14639 .30371 Mdot
.15582 .30312 Mdot
.16525 .30251 Mdot
.17468 .30186 Mdot
.18411 .30118 Mdot
.19354 .30047 Mdot
.20297 .29971 Mdot
.2124 .29892 Mdot
.22183 .29809 Mdot
.23126 .29721 Mdot
.24069 .29629 Mdot
.25012 .29532 Mdot
.25955 .2943 Mdot
.26898 .29322 Mdot
.27841 .29209 Mdot
.28784 .2909 Mdot
.29727 .28965 Mdot
.30669 .28834 Mdot
.31612 .28696 Mdot
.32555 .2855 Mdot
.33498 .28398 Mdot
.34441 .28237 Mdot
.35384 .28069 Mdot
.36327 .27892 Mdot
.3727 .27706 Mdot
.38213 .2751 Mdot
.39156 .27305 Mdot
.40099 .2709 Mdot
.41042 .26864 Mdot
.41985 .26627 Mdot
.42928 .26378 Mdot
.43871 .26118 Mdot
.44814 .25845 Mdot
.45757 .2556 Mdot
.467 .25261 Mdot
.47643 .24948 Mdot
.48586 .24621 Mdot
.49529 .2428 Mdot
.50471 .23924 Mdot
.51414 .23553 Mdot
.52357 .23166 Mdot
.533 .22764 Mdot
.54243 .22346 Mdot
.55186 .21911 Mdot
.56129 .21461 Mdot
.57072 .20996 Mdot
.58015 .20514 Mdot
.58958 .20018 Mdot
.59901 .19506 Mdot
.60844 .18981 Mdot
.61787 .18442 Mdot
.6273 .17891 Mdot
.63673 .17328 Mdot
.64616 .16756 Mdot
.65559 .16175 Mdot
.66502 .15587 Mdot
.67445 .14993 Mdot
.68388 .14397 Mdot
.69331 .138 Mdot
.70273 .13203 Mdot
.71216 .12609 Mdot
.72159 .12021 Mdot
.73102 .11441 Mdot
.74045 .1087 Mdot
.74988 .1031 Mdot
.75931 .09765 Mdot
.76874 .09235 Mdot
.77817 .08723 Mdot
.7876 .08229 Mdot
.79703 .07754 Mdot
.80646 .07301 Mdot
.81589 .0687 Mdot
.82532 .0646 Mdot
.83475 .06073 Mdot
.84418 .05708 Mdot
.85361 .05365 Mdot
.86304 .05044 Mdot
.87247 .04745 Mdot
.8819 .04466 Mdot
.89132 .04208 Mdot
.90075 .03968 Mdot
.91018 .03747 Mdot
.91961 .03543 Mdot
.92904 .03356 Mdot
.93847 .03184 Mdot
.9479 .03026 Mdot
.95733 .02882 Mdot
.96676 .0275 Mdot
.97619 .0263 Mdot
.03324 .32081 Mdot
.04267 .32113 Mdot
.0521 .32146 Mdot
.06153 .32181 Mdot
.07096 .32218 Mdot
.08039 .32256 Mdot
.08982 .32297 Mdot
.09925 .3234 Mdot
.10868 .32385 Mdot
.1181 .32433 Mdot
.12753 .32483 Mdot
.13696 .32536 Mdot
.14639 .32591 Mdot
.15582 .32649 Mdot
.16525 .32711 Mdot
.17468 .32775 Mdot
.18411 .32843 Mdot
.19354 .32915 Mdot
.20297 .3299 Mdot
.2124 .33069 Mdot
.22183 .33153 Mdot
.23126 .33241 Mdot
.24069 .33333 Mdot
.25012 .3343 Mdot
.25955 .33532 Mdot
.26898 .33639 Mdot
.27841 .33752 Mdot
.28784 .33871 Mdot
.29727 .33996 Mdot
.30669 .34128 Mdot
.31612 .34266 Mdot
.32555 .34411 Mdot
.33498 .34564 Mdot
.34441 .34724 Mdot
.35384 .34893 Mdot
.36327 .3507 Mdot
.3727 .35256 Mdot
.38213 .35451 Mdot
.39156 .35657 Mdot
.40099 .35872 Mdot
.41042 .36098 Mdot
.41985 .36335 Mdot
.42928 .36583 Mdot
.43871 .36844 Mdot
.44814 .37116 Mdot
.45757 .37402 Mdot
.467 .37701 Mdot
.47643 .38013 Mdot
.48586 .3834 Mdot
.49529 .38681 Mdot
.50471 .39037 Mdot
.51414 .39409 Mdot
.52357 .39795 Mdot
.533 .40198 Mdot
.54243 .40616 Mdot
.55186 .4105 Mdot
.56129 .415 Mdot
.57072 .41966 Mdot
.58015 .42447 Mdot
.58958 .42944 Mdot
.59901 .43455 Mdot
.60844 .43981 Mdot
.61787 .4452 Mdot
.6273 .45071 Mdot
.63673 .45633 Mdot
.64616 .46206 Mdot
.65559 .46787 Mdot
.66502 .47375 Mdot
.67445 .47968 Mdot
.68388 .48564 Mdot
.69331 .49162 Mdot
.70273 .49759 Mdot
.71216 .50352 Mdot
.72159 .5094 Mdot
.73102 .51521 Mdot
.74045 .52092 Mdot
.74988 .52651 Mdot
.75931 .53197 Mdot
.76874 .53726 Mdot
.77817 .54239 Mdot
.7876 .54733 Mdot
.79703 .55207 Mdot
.80646 .5566 Mdot
.81589 .56092 Mdot
.82532 .56502 Mdot
.83475 .56889 Mdot
.84418 .57254 Mdot
.85361 .57596 Mdot
.86304 .57917 Mdot
.87247 .58216 Mdot
.8819 .58495 Mdot
.89132 .58754 Mdot
.90075 .58993 Mdot
.91018 .59214 Mdot
.91961 .59418 Mdot
.92904 .59606 Mdot
.93847 .59778 Mdot
.9479 .59935 Mdot
.95733 .6008 Mdot
.96676 .60212 Mdot
.97619 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[14]:=  (19:00:41 on 4/24/01)",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0014Ool5
0003Ool2000ZOol30003Ool2000YOol30004Ool2000ZOol30004Ool2000VOol30004Ool20004Ool2
0006Ool004Eoo`04001oogoo0002Ool01000Oomoo`00:Woo00D007ooOomoo`00009oo`03001oogoo
02Eoo`05001oogooOol00002Ool01000Oomoo`00:7oo00D007ooOomoo`00009oo`04001oogoo000V
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Eoo`00AWoo00<007ooOol00Woo00@0
07ooOol002Moo`D0009oo`04001oogoo000WOol01@00Oomoogoo00000Woo00@007ooOol002Qoo`05
001oogooOol00002Ool01000Oomoo`009Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0005Ool004Moo`05001oogooOol00002Ool00`00Oomoo`0UOol01000Oomoo`000goo00@007ooOol0
02Moo`@000=oo`04001oogoo000YOol30003Ool01000Oomoo`009Woo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo0005Ool004Aoo`05001oogooOol00002Ool01000Oomoo`00:7oo00<007oo
00000goo00@007ooOol002Moo`03001oogoo00Aoo`04001oogoo000XOol01@00Oomoogoo00000Woo
00@007ooOol002Ioo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`001Goo0014Ool01@00
Oomoogoo00000Woo00@007ooOol002Uoo`8000=oo`04001oogoo000XOol00`00Oomoo`03Ool01000
Oomoo`00:7oo00D007ooOomoo`00009oo`04001oogoo000UOol20004Ool01000Oomoo`000Woo00@0
07ooOol000Eoo`00AGoo0`0017oo0P00:goo00<007ooOol00Woo0P00:Woo0P0017oo0P00:Woo0`00
17oo0P009goo00<007ooOol00goo0P0017oo0P001Woo000GOol00`00Oomoo`3oOol7Ool001Moo`03
001oogoo0?moo`Moo`005goo00<007ooOol0ogoo1goo000GOol00`00Oomoo`3aOol400000goo0000
000200000goo00000009Ool0015oool000d000=oo`005goo00<007ooOol02Woo00<007ooOol02Woo
00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo
00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo
100000=oo`0000000P0000=oo`0000000P0000=oo`0000000P0000=oo`0000000P0000=oo`000000
0P0000=oo`0000000P0000=oo`0000000P0000Aoo`00001oo`@00003Ool0000000800003Ool00000
00800003Ool0000000800003Ool0000000800003Ool0000000800003Ool0000000800003Ool00000
00800003Ool0000000800003Ool00000008000Uoo`03001oogoo00Yoo`005goo00<007ooOol0<7oo
00<007ooOol0;goo00<007ooOol09Goo100000=oo`0000000P0000=oo`0000000P0000=oo`000000
0P0000=oo`0000000P0000=oo`0000008Woo00<007ooOol0;goo00<007ooOol02Woo000GOol00`00
Oomoo`22Ool200000goo0000000200000goo0000000200000goo00000002001SOol400000goo0000
0009Ool001Moo`03001oogoo07eoo`800003Ool0000000800003Ool00000008006Eoo`800003Ool0
000000800003Ool0000000800003Ool0000000Uoo`005goo00<007ooOol0N7oo0P0000=oo`000000
0P0000=oo`000000JWoo100000=oo`0000000P004Goo000GOol00`00Oomoo`1fOol400000goo0000
001ZOol400000goo0000000HOol001Moo`03001oogoo075oo`@00003Ool0000006Yoo`@00003Ool0
0000008001]oo`005goo0P00Kgoo0P0000=oo`0000000P00JWoo0P0000=oo`0000000P0087oo000G
Ool00`00Oomoo`1/Ool4001]Ool4000UOol001Moo`03001oogoo06Uoo`800003Ool0000006aoo`80
0003Ool0000002Moo`005goo00<007ooOol0I7oo100000=oo`000000KGoo1000:Woo000GOol00`00
Oomoo`1QOol200000goo00000002001]Ool200000goo0000000/Ool001Moo`03001oogoo065oo`80
071oo`@002moo`005goo00<007ooOol0Ggoo0P00Kgoo0P0000=oo`000000<Goo000GOol00`00Oomo
o`1LOol200000goo0000001]Ool4000dOol001Moo`8005]oo`@006eoo`800003Ool0000003Ioo`00
5goo00<007ooOol0Egoo0P0000=oo`000000KGoo1000>Goo000GOol00`00Oomoo`1EOol4001`Ool2
000kOol001Moo`03001oogoo05Eoo`8006moo`8003ioo`005goo00<007ooOol0DWoo0P00L7oo1000
?Woo000GOol00`00Oomoo`1@Ool4001`Ool20010Ool001Moo`03001oogoo051oo`8006moo`8004=o
o`005goo00<007ooOol0CGoo0P00L7oo1000@goo000GOol2001<Ool4001`Ool20015Ool001Moo`03
001oogoo04]oo`8006moo`8004Qoo`005goo00<007ooOol0B7oo0P00Kgoo0P0000=oo`000000B7oo
000GOol00`00Oomoo`16Ool4001_Ool2001;Ool001Moo`03001oogoo04Ioo`8006moo`8004eoo`00
17oo0P0017oo00@007ooOomoo`D000Aoo`03001oogoo04=oo`8006moo`800003Ool0000004eoo`00
0goo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`11Ool4001_Ool2001@Ool000=oo`04
001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`11Ool2001_Ool2001BOol000=oo`04001oogoo
000:Ool00`00Oomoo`03Ool3000nOol2001_Ool200000goo0000001BOol000=oo`04001oogoo0007
Ool01@00Oomoogoo000017oo00<007ooOol0?7oo1000Kgoo0P00EGoo0003Ool01000Oomoo`001goo
00D007ooOomoo`0000Aoo`03001oogoo03aoo`8006moo`8005Moo`0017oo0P002Goo0`001Goo00<0
07ooOol0>Goo0P00LWoo0P00Egoo000GOol00`00Oomoo`0iOol2001_Ool2001JOol001Moo`03001o
ogoo03Moo`8006moo`@005Yoo`005goo00<007ooOol0=7oo0P0000=oo`000000Kgoo0P00G7oo000G
Ool00`00Oomoo`0dOol2001_Ool2001OOol001Moo`8003=oo`8006moo`@005moo`005goo00<007oo
Ool0;goo0P0000=oo`000000Kgoo0P00HGoo000GOol00`00Oomoo`0_Ool2001_Ool2001TOol001Mo
o`03001oogoo02eoo`8006moo`@006Aoo`005goo00<007ooOol0:Woo0P0000=oo`000000Kgoo0P00
IWoo000GOol00`00Oomoo`0ZOol2001_Ool2001YOol001Moo`03001oogoo02Qoo`8006moo`@006Uo
o`005goo00<007ooOol09Goo0P0000=oo`000000Kgoo0P00Jgoo000GOol2000VOol2001_Ool2001^
Ool001Moo`03001oogoo02=oo`8006moo`@006ioo`005goo00<007ooOol087oo0P0000=oo`000000
K7oo0P0000=oo`000000L7oo000GOol00`00Oomoo`0NOol4001_Ool2001cOol001Moo`03001oogoo
01]oo`800003Ool0000006moo`8007Eoo`005goo00<007ooOol06goo0P00Kgoo0P0000=oo`000000
MGoo000GOol00`00Oomoo`0IOol2001_Ool4001hOol001Moo`03001oogoo01Ioo`800003Ool00000
06aoo`800003Ool0000007Yoo`005goo0P0057oo0P0000=oo`000000KGoo1000OGoo000GOol00`00
Oomoo`0AOol4001]Ool200000goo0000001oOol001Moo`03001oogoo00ioo`800003Ool0000006eo
o`@0089oo`005goo00<007ooOol037oo1000KGoo0P0000=oo`000000Q7oo000GOol00`00Oomoo`09
Ool200000goo0000001]Ool40027Ool000Aoo`8000Aoo`03001oogoo00=oo`<000Aoo`03001oogoo
00Moo`@006eoo`800003Ool0000008Uoo`000goo00@007ooOol000Yoo`03001oogoo00=oo`03001o
ogoo00Aoo`800003Ool0000006eoo`@008aoo`000goo00@007ooOol000Moo`D000Aoo`05001oo`00
001oo`04001]Ool200000goo0000002>Ool000=oo`04001oogoo0007Ool01000Oomoo`001Goo1000
00=oo`000000JWoo0P0000=oo`0000000P00TGoo0003Ool01000Oomoo`0027oo00<007oo00001Goo
00<007ooOol0K7oo100000=oo`000000Tgoo0003Ool01000Oomoo`002Goo0P001Goo00<007ooOol0
JGoo0P0000=oo`000000V7oo0004Ool2000;Ool00`00Oomoo`03Ool00`00Oomoo`1TOol400000goo
0000002KOol001Moo`03001oogoo05moo`@00003Ool00000008009ioo`005goo00<007ooOol0FWoo
100000=oo`0000000P00Xgoo000GOol00`00Oomoo`1EOol400000goo00000002002XOol001Moo`03
001oogoo051oo`@00003Ool0000000800:eoo`005goo0P00BGoo0P0000=oo`0000000P0000=oo`00
00000P00/Woo000GOol00`00Oomoo`11Ool400000goo0000000200000goo00000002002gOol001Mo
o`03001oogoo03Uoo`800003Ool0000000800003Ool0000000800003Ool000000;ioo`005goo00<0
07ooOol0;Goo100000=oo`0000000P0000=oo`0000000P0000=oo`0000000P00aWoo000GOol00`00
Oomoo`0POol200000goo0000000200000goo0000000200000goo0000000200000goo000000020000
0goo0000003=Ool001Moo`03001oogoo00aoo`@00003Ool0000000800004Ool00000Ool400000goo
0000000200000goo0000000200000goo00000002003JOol001Moo`05001oo`00001oo`0400000goo
0000000200000goo0000000200000goo00000002000017oo000007oo100000=oo`000000iWoo000G
Ool01@00Ool00000Ool0100000=oo`0000000P00ngoo000GOol2003oOol8Ool001Moo`05001oo`00
001oo`0400000goo00000002003kOol001Moo`05001oo`00001oo`0400000goo0000000200000goo
0000000200000goo00000002000017oo000007oo100000=oo`000000iWoo000GOol00`00Oomoo`0<
Ool400000goo00000002000017oo000007oo100000=oo`0000000P0000=oo`0000000P0000=oo`00
00000P00fWoo000GOol00`00Oomoo`0POol200000goo0000000200000goo0000000200000goo0000
000200000goo0000000200000goo0000003=Ool001Moo`03001oogoo02eoo`@00003Ool000000080
0003Ool0000000800003Ool0000000800<Ioo`005goo00<007ooOol0>Goo0P0000=oo`0000000P00
00=oo`0000000P0000=oo`000000_Woo000GOol00`00Oomoo`11Ool400000goo0000000200000goo
00000002002gOol001Moo`8004Uoo`800003Ool0000000800003Ool0000000800;9oo`005goo00<0
07ooOol0D7oo100000=oo`0000000P00[Goo000GOol00`00Oomoo`1EOol400000goo00000002002X
Ool001Moo`03001oogoo05Yoo`@00003Ool0000000800:=oo`005goo00<007ooOol0Ggoo100000=o
o`0000000P00WWoo0004Ool20004Ool00`00Oomoo`02Ool30005Ool00`00Oomoo`1TOol400000goo
0000002KOol000=oo`04001oogoo0007Ool01@00Oomoogoo000017oo00<007ooOol0JGoo0P0000=o
o`000000V7oo0003Ool01000Oomoo`001goo00D007ooOomoo`0000Aoo`03001oogoo06aoo`@00003
Ool0000009=oo`000goo00@007ooOol000Moo`@000Eoo`<006ioo`800003Ool000000080095oo`00
0goo00@007ooOol000Moo`03001oogoo00Ioo`03001oogoo07=oo`800003Ool0000008ioo`000goo
00@007ooOol000Qoo`03001oogoo00Eoo`03001oogoo07Ioo`@008aoo`0017oo0P002Woo0P001Goo
00<007ooOol0N7oo0P0000=oo`000000RGoo000GOol00`00Oomoo`1kOol40027Ool001Moo`03001o
ogoo07eoo`800003Ool0000008Aoo`005goo00<007ooOol0P7oo1000PWoo000GOol00`00Oomoo`22
Ool200000goo0000001oOol001Moo`8008Ioo`@007eoo`005goo00<007ooOol0Qgoo0P0000=oo`00
0000NWoo000GOol00`00Oomoo`2:Ool4001hOol001Moo`03001oogoo08aoo`800003Ool0000007Eo
o`005goo00<007ooOol0Sgoo0P00MGoo000GOol00`00Oomoo`2AOol2001cOol001Moo`03001oogoo
095oo`800003Ool00000071oo`005goo00<007ooOol0U7oo1000KWoo000GOol2002GOol2001^Ool0
01Moo`03001oogoo09Uoo`8006]oo`005goo00<007ooOol0VGoo1000JGoo000GOol00`00Oomoo`2K
Ool2001YOol001Moo`03001oogoo09ioo`8006Ioo`005goo00<007ooOol0WWoo1000I7oo000GOol0
0`00Oomoo`2POol2001TOol001Moo`03001oogoo0:=oo`80065oo`005goo0P00Y7oo1000Ggoo000G
Ool00`00Oomoo`2UOol2001OOol001Moo`03001oogoo0:Qoo`8005aoo`005goo00<007ooOol0Z7oo
1000FWoo000GOol00`00Oomoo`2ZOol2001JOol000Aoo`8000Aoo`03001oogoo009oo`<000Eoo`03
001oogoo0:eoo`8005Moo`000goo00@007ooOol000Moo`05001oogooOol00004Ool00`00Oomoo`2]
Ool2001GOol000=oo`04001oogoo0007Ool01@00Oomoogoo000017oo00<007ooOol0[goo0P00EGoo
0003Ool01000Oomoo`0027oo0`001Goo0`00[goo0P0000=oo`000000DWoo0003Ool01000Oomoo`00
1goo00D007ooOomoo`0000Aoo`03001oogoo0;9oo`80059oo`000goo00@007ooOol000Moo`05001o
ogooOol00004Ool00`00Oomoo`2dOol2001@Ool000Aoo`8000Uoo`<000Eoo`03001oogoo0;Aoo`80
0003Ool0000004eoo`005goo00<007ooOol0]goo0P00CGoo000GOol00`00Oomoo`2iOol2001;Ool0
01Moo`03001oogoo0;Uoo`800003Ool0000004Qoo`005goo00<007ooOol0_7oo0P00B7oo000GOol2
0030Ool20015Ool001Moo`03001oogoo0;moo`@004=oo`005goo00<007ooOol0`Goo0P00@goo000G
Ool00`00Oomoo`34Ool20010Ool001Moo`03001oogoo0<Aoo`@003ioo`005goo00<007ooOol0aWoo
0P00?Woo000GOol00`00Oomoo`39Ool2000kOol001Moo`03001oogoo0<Uoo`@003Uoo`005goo0P00
c7oo0P0000=oo`000000=Woo000GOol00`00Oomoo`3>Ool4000dOol001Moo`03001oogoo0=1oo`80
0003Ool00000035oo`005goo00<007ooOol0dgoo1000;goo000GOol00`00Oomoo`3EOol200000goo
0000000/Ool001Moo`03001oogoo0=Qoo`@002Yoo`005goo00<007ooOol0fWoo0P0000=oo`000000
9goo000GOol00`00Oomoo`3MOol4000UOol001Moo`800>1oo`800003Ool000000080021oo`005goo
00<007ooOol0hWoo100000=oo`0000000P006goo000GOol00`00Oomoo`3WOol400000goo0000000H
Ool001Moo`03001oogoo0>aoo`@00003Ool000000080015oo`005goo00<007ooOol0kWoo0P0000=o
o`0000000P0000=oo`0000000P0000=oo`0000002Goo000?Ool30005Ool00`00Oomoo`3fOol40000
0goo00000009Ool0011oo`03001oogoo00Aoo`03001oogoo0?moo`Moo`0047oo00<007ooOol017oo
00<007ooOol0ogoo1goo000@Ool00`00Oomoo`04Ool3003oOol7Ool0011oo`03001oogoo00Aoo`03
001oogoo0?moo`Moo`003goo0P00ogoo47oo000@Ool00`00Oomoo`3oOol>Ool00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-9.50095, -0.0770378, \
0.397555, 0.00624599}}]
}, Closed]],

Cell["\<\
This stores genotype frequencies in pop[t], every 10 generations:\
\
\>", "MathCaption"],

Cell[BoxData[
    \(\(StoreExact[pop[0.1, hp], hp, w[0.1, het], 0, {100, 10}];\)\)], "Input",\

  CellLabel->"In[7]:=  (20:01:27 on 4/24/01)"],

Cell[CellGroupData[{

Cell[BoxData[
    \(?? pop\)], "Input",
  CellLabel->"In[10]:=  (20:02:16 on 4/24/01)"],

Cell[BoxData[
    \("Global`pop"\)], "Print",
  CellLabel->"From In[10]:=  (20:02:16 on 4/24/01)"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(pop[0] = 
                    HaploidFrequencies[{0.14994`, 0.15606`, 0.14406`, 
                        0.14994`, 0.09996000000000001`, 0.10404000000000001`, 
                        0.09604`, 0.09996000000000001`}, 100]\)},
                {" "},
                {\(pop[10] = 
                    HaploidFrequencies[{0.1651836783171056`, 
                        0.17659640168225993`, 0.15450851389068818`, 
                        0.16518367831710545`, 0.0845375651235772`, 
                        0.0903783591690213`, 0.07907423837666518`, 
                        0.08453756512357717`}, 100]\)},
                {" "},
                {\(pop[20] = 
                    HaploidFrequencies[{0.1864164383332783`, 
                        0.20841511494829706`, 0.16673977071905682`, 
                        0.18641643833327812`, 0.06280747644256243`, 
                        0.07021927647274617`, 0.05617800830821856`, 
                        0.06280747644256236`}, 100]\)},
                {" "},
                {\(pop[30] = 
                    HaploidFrequencies[{0.20967649430850177`, 
                        0.2525763536558432`, 0.174063136272084`, 
                        0.20967649430850152`, 0.038170265120300875`, 
                        0.04597991021338581`, 0.03168708100108248`, 
                        0.03817026512030083`}, 100]\)},
                {" "},
                {\(pop[40] = 
                    HaploidFrequencies[{0.22578668519818473`, 
                        0.3078943871483181`, 0.1655750456672867`, 
                        0.2257866851981841`, 0.018295733922528916`, 
                        0.02494900785917125`, 0.013416721083797583`, 
                        0.01829573392252887`}, 100]\)},
                {" "},
                {\(pop[50] = 
                    HaploidFrequencies[{0.22698621250847795`, 
                        0.3797753781052504`, 0.13566635342711653`, 
                        0.22698621250847711`, 0.007161608600764642`, 
                        0.01198223708894046`, 0.004280389160208243`, 
                        0.007161608600764616`}, 100]\)},
                {" "},
                {\(pop[60] = 
                    HaploidFrequencies[{0.20780659512120825`, 
                        0.48376434414566033`, 0.08926573754031594`, 
                        0.20780659512120725`, 0.002387112783031482`, 
                        0.005557090472568406`, 0.0010254120329767833`, 
                        0.0023871127830314707`}, 100]\)},
                {" "},
                {\(pop[70] = 
                    HaploidFrequencies[{0.16255212398533228`, 
                        0.6288231472437549`, 0.04202007055236481`, 
                        0.16255212398533117`, 0.0006614285088074977`, 
                        0.0025586965361498715`, 0.00017098067945236077`, 
                        0.0006614285088074931`}, 100]\)},
                {" "},
                {\(pop[80] = 
                    HaploidFrequencies[{0.09976550449911406`, 
                        0.7863874770176454`, 0.01265680873468349`, 
                        0.09976550449911309`, 0.00014233922942066525`, 
                        0.0011219688415021931`, 0.000018057949100388623`, 
                        0.00014233922942066392`}, 100]\)},
                {" "},
                {\(pop[90] = 
                    HaploidFrequencies[{0.047386674670129476`, 
                        0.9022396462629495`, 0.0024888032194034563`, 
                        0.04738667467012894`, 0.0000236198645575029`, 
                        0.00044972090553915985`, 1.2405427340450732`*^-6, 
                        0.00002361986455750263`}, 100]\)},
                {" "},
                {\(pop[100] = 
                    HaploidFrequencies[{0.018920852493087763`, 
                        0.9616121174208009`, 0.0003722900872187338`, 
                        0.01892085249308754`, 3.290672054477563`*^-6, 
                        0.00016724141384219542`, 6.474785354503738`*^-8, 
                        3.290672054477525`*^-6}, 100]\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ pop],
      Editable->False]], "Print",
  CellLabel->"From In[10]:=  (20:02:16 on 4/24/01)"]
}, Closed]],

Cell["\<\
Storing large numbers of genotypes in every generation would waste \
memory.  \
\>", "Text"],

Cell["\<\
It is useful to store results in the form pop[pars] so that results \
for different parameter sets can be kept tidily.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Immigration into one deme", "SubsubsectionIcon",
  CellTags->"Immigration"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, 
              m]\), \(allows\ for\ immigration\ from\ a\ source\ of\ the\ \
same\ size, \ fixed\ for\ \(\({1, 1  \[Ellipsis]}\)\(.\)\(\ \)\)\)},
          {\(IterateExact[\[Psi], W, m, 
              FixedEnds -> {\[Psi]\_s}]\), \(allows\ for\ immigration\ from\ \
a\ haploid\ source\ \[Psi]\_s\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->{"IterateExact", "FixedEnds"}],

Cell["\<\
This shows the allele frequency at three loci, with additive \
selection \[Sigma]={-0.05,-0.1,-0.2} against '1' alleles, and immigration at \
10% from a source fixed for '1':\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(hp = MakePopulation[3, {0, 0, 0}, 100];\)\), "\n", 
    \(\(\(w[\[Sigma]_List]\)[x_, y_] := 
        1 + \[Sigma] . \((x + y - 1)\);\)\), "\n", 
    \(\(StoreExact[pop[{\(-0.05\), \(-0.1\), \(-0.2\)}, 0.1, hp], hp, 
        w[{\(-0.05\), \(-0.1\), \(-0.2\)}], 0.1, {300, 10}];\)\), "\n", 
    \(\(pt[i_] := 
        Table[{t, \(AlleleFrequencyTable[\(pop[{\(-0.05\), \(-0.1\), \
\(-0.2\)}, 0.1, hp]\)[t]]\)\[LeftDoubleBracket]i\[RightDoubleBracket]}, {t, 
            0, 300, 10}];\)\), "\n", 
    \(\(DisplayTogether @@ 
        Table[ListPlot[pt[i], PlotJoined -> True], {i, 3}];\)\)}], "Input",
  CellLabel->"In[115]:=  (7:20:49 on 5/1/01)"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0031746 0.0147151 0.627087 [
[.18254 .00222 -6 -9 ]
[.18254 .00222 6 0 ]
[.34127 .00222 -9 -9 ]
[.34127 .00222 9 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.65873 .00222 -9 -9 ]
[.65873 .00222 9 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[.01131 .14013 -18 -4.5 ]
[.01131 .14013 0 4.5 ]
[.01131 .26555 -18 -4.5 ]
[.01131 .26555 0 4.5 ]
[.01131 .39097 -18 -4.5 ]
[.01131 .39097 0 4.5 ]
[.01131 .51638 -18 -4.5 ]
[.01131 .51638 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(50)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(100)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(150)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(200)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(250)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(300)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .14013 m
.03006 .14013 L
s
[(0.2)] .01131 .14013 1 0 Mshowa
.02381 .26555 m
.03006 .26555 L
s
[(0.4)] .01131 .26555 1 0 Mshowa
.02381 .39097 m
.03006 .39097 L
s
[(0.6)] .01131 .39097 1 0 Mshowa
.02381 .51638 m
.03006 .51638 L
s
[(0.8)] .01131 .51638 1 0 Mshowa
.125 Mabswid
.02381 .04607 m
.02756 .04607 L
s
.02381 .07742 m
.02756 .07742 L
s
.02381 .10878 m
.02756 .10878 L
s
.02381 .17149 m
.02756 .17149 L
s
.02381 .20284 m
.02756 .20284 L
s
.02381 .2342 m
.02756 .2342 L
s
.02381 .2969 m
.02756 .2969 L
s
.02381 .32826 m
.02756 .32826 L
s
.02381 .35961 m
.02756 .35961 L
s
.02381 .42232 m
.02756 .42232 L
s
.02381 .45368 m
.02756 .45368 L
s
.02381 .48503 m
.02756 .48503 L
s
.02381 .54774 m
.02756 .54774 L
s
.02381 .57909 m
.02756 .57909 L
s
.02381 .61045 m
.02756 .61045 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.05556 .1961 L
.0873 .29797 L
.11905 .36483 L
.15079 .41119 L
.18254 .44492 L
.21429 .47044 L
.24603 .49034 L
.27778 .50628 L
.30952 .5193 L
.34127 .53013 L
.37302 .53928 L
.40476 .54709 L
.43651 .55385 L
.46825 .55974 L
.5 .56493 L
.53175 .56953 L
.56349 .57364 L
.59524 .57732 L
.62698 .58065 L
.65873 .58367 L
.69048 .58642 L
.72222 .58894 L
.75397 .59125 L
.78571 .59338 L
.81746 .59535 L
.84921 .59718 L
.88095 .59887 L
.9127 .60046 L
.94444 .60193 L
.97619 .60332 L
s
.02381 .01472 m
.05556 .18288 L
.0873 .25586 L
.11905 .2955 L
.15079 .31882 L
.18254 .33332 L
.21429 .34267 L
.24603 .34889 L
.27778 .35312 L
.30952 .35606 L
.34127 .35814 L
.37302 .35965 L
.40476 .36076 L
.43651 .36159 L
.46825 .36224 L
.5 .36275 L
.53175 .36315 L
.56349 .36349 L
.59524 .36377 L
.62698 .364 L
.65873 .36421 L
.69048 .36439 L
.72222 .36455 L
.75397 .36469 L
.78571 .36482 L
.81746 .36493 L
.84921 .36504 L
.88095 .36514 L
.9127 .36523 L
.94444 .36531 L
.97619 .36538 L
s
.02381 .01472 m
.05556 .16042 L
.0873 .19595 L
.11905 .20825 L
.15079 .2135 L
.18254 .21623 L
.21429 .21789 L
.24603 .21901 L
.27778 .21983 L
.30952 .22044 L
.34127 .22091 L
.37302 .22129 L
.40476 .2216 L
.43651 .22185 L
.46825 .22207 L
.5 .22225 L
.53175 .22241 L
.56349 .22255 L
.59524 .22267 L
.62698 .22278 L
.65873 .22288 L
.69048 .22297 L
.72222 .22305 L
.75397 .22312 L
.78571 .22319 L
.81746 .22325 L
.84921 .22331 L
.88095 .22336 L
.9127 .22341 L
.94444 .22346 L
.97619 .2235 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[115]:=  (7:21:07 on 5/1/01)",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool003]oo`<000Aoo`8001ioo`<000Aoo`8000Aoo`8001aoo`<000=oo`<000Aoo`8001]oo`D000=o
o`8000Aoo`8001]oo`D0009oo`<000Aoo`8001aoo`<000Aoo`8000Aoo`8000=oo`00>Woo00D007oo
Oomoo`00009oo`04001oogoo000NOol00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol001ao
o`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol06Goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`006goo00H007ooOol007oo0003Ool01000Oomoo`000Woo00<007ooOol0
67oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo000nOol01000Oomoo`00
0Woo00<007ooOol077oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo000LOol00`00Oomo
o`05Ool01000Oomoo`000Woo00<007ooOol06Woo00<007ooOol00Woo00@007ooOol0009oo`04001o
ogoo000LOol00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol077oo00@007ooOol0009oo`04
001oogoo0002Ool10001Ool1Ool003ioo`04001oogoo0002Ool00`00Oomoo`0LOol00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol001aoo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomo
o`0KOol01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo01]oo`03001oogoo00Aoo`04
001oogoo0002Ool00`00Oomoo`0JOol20003Ool01000Oomoo`000Woo00@007ooOol0009oo`00>Woo
10000goo00@007ooOol001ioo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0077oo00@0
07ooOomoo`@000=oo`04001oogoo000JOol01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo000JOol01P00Oomoogoo001oo`@000=oo`04001oogoo000NOol01000Oomoo`000Woo00@007oo
Ool0009oo`40005oo`5oo`00>Woo00<007ooOol017oo00@007ooOol001eoo`8000Aoo`04001oogoo
0002Ool01000Oomoo`006goo0P000goo00<007ooOol017oo00@007ooOol001Yoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol001Yoo`07001oogooOol007oo00001Woo00@007ooOol0
01Yoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`00>Woo1@000goo0P00
7goo00<007ooOol00goo0P0017oo0P007Goo00@007ooOomoo`D000=oo`8001aoo`<000Aoo`8000Ao
o`8001aoo`<0009oo`D000=oo`8001aoo`<000Aoo`8000Aoo`8000=oo`005Goo00<007ooOol0ogoo
2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo
2Goo000>Oooo000@0003Ool001Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03
001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03
001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03
001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03
001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03
001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03
001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Moo`005Goo00<007ooOol0:7oo00<007ooOol0
9goo00<007ooOol0:7oo00<007ooOol0:7oo00<007ooOol0:7oo00<007ooOol0:7oo00<007ooOol0
1goo000EOol2003oOol:Ool001Eoo`800?moo`Yoo`005Goo0P00ogoo2Woo000EOol2003oOol:Ool0
01Eoo`800?moo`Yoo`005Goo0`00ogoo2Goo000EOol3003oOol9Ool001Eoo`03001oo`000?moo`Uo
o`005Goo00<007oo0000ogoo2Goo000EOol00`00Ool0003oOol9Ool001Eoo`04001oo`00003oOol8
Ool001Eoo`04001oo`00003oOol8Ool001Eoo`04001oo`00003oOol8Ool001Eoo`04001oogoo003o
Ool8Ool001Eoo`800003Ool007oo0?moo`Moo`005Goo00<007ooOol00P00ogoo1goo000EOol00`00
Oomoo`02003oOol7Ool001Eoo`03001oogoo00800?moo`Moo`005Goo00<007ooOol00P00ogoo1goo
000EOol01@00Oomoogoo0000ogoo1goo000EOol01000Oomoogoo0P00ogoo1Woo000EOol01000Oomo
ogoo0P00ogoo1Woo000EOol20002Ool2003oOol6Ool001Eoo`04001oogooOol2003oOol6Ool001Eo
o`04001oogooOol2003oOol6Ool001Eoo`04001oogooOol3003oOol5Ool001Eoo`03001oogoo009o
o`800?moo`Eoo`005Goo00<007ooOol00Woo0P00ogoo1Goo0002Ool20004Ool01000Oomoogoo1@00
17oo00<007ooOol00Woo0P00ogoo1Goo00001Goo001oogoo000027oo00@007ooOol000Aoo`03001o
ogoo009oo`800?moo`Eoo`0000Eoo`00Oomoo`0000Uoo`03001oogoo00Aoo`03001oogoo009oo`<0
0?moo`Aoo`0000Eoo`00Oomoo`0000Yoo`03001oogoo00=oo`<0009oo`<00?moo`Aoo`0000Eoo`00
Oomoo`0000Moo`05001oogooOol00004Ool00`00Oomoo`03Ool2003oOol4Ool00005Ool007ooOol0
0007Ool01@00Oomoogoo000017oo00<007ooOol00goo0P00ogoo17oo0002Ool20009Ool30005Ool0
0`00Oomoo`03Ool2003oOol4Ool001Eoo`03001oogoo00=oo`<00?moo`=oo`005Goo00<007ooOol0
0goo0`00ogoo0goo000EOol00`00Oomoo`03Ool3003oOol3Ool001Eoo`03001oogoo00Aoo`03001o
o`000?moo`9oo`005Goo0P001Goo00@007ooOol00?moo`5oo`005Goo00<007ooOol017oo0P000Woo
00<007ooOol0oGoo000EOol00`00Oomoo`04Ool20003Ool00`00Oomoo`3lOol001Eoo`03001oogoo
00Aoo`8000Aoo`03001oogoo0?]oo`005Goo00<007ooOol017oo0P001Goo00<007ooOol0nWoo000E
Ool00`00Oomoo`05Ool20005Ool00`00Oomoo`3iOol001Eoo`03001oogoo00Eoo`8000Ioo`03001o
ogoo0?Qoo`005Goo00<007ooOol01Goo00<007oo00001Woo0`00mgoo000EOol00`00Oomoo`05Ool0
0`00Ool00009Ool3003dOol001Eoo`8000Moo`8000aoo`<00?5oo`005Goo00<007ooOol01Woo00<0
07oo00003Woo1@00k7oo000EOol00`00Oomoo`06Ool00`00Ool0000COol9003SOol001Eoo`03001o
ogoo00Moo`03001oo`0001]oo`P00=]oo`005Goo00<007ooOol01goo00<007oo00008goo:`00/7oo
000EOol00`00Oomoo`07Ool01000Oomoo`00CGooY`002Goo000EOol00`00Oomoo`08Ool00`00Ool0
003mOol001Eoo`03001oogoo00Qoo`04001oogoo003lOol001Eoo`8000Uoo`04001oogoo003lOol0
01Eoo`03001oogoo00Uoo`04001oogoo003kOol001Eoo`03001oogoo00Uoo`04001oogoo003kOol0
01Eoo`03001oogoo00Uoo`04001oogoo003kOol001Eoo`03001oogoo00Yoo`04001oogoo003jOol0
01Eoo`03001oogoo00Yoo`04001oogoo003jOol0009oo`8000Aoo`03001oogoo00=oo`<000Aoo`03
001oogoo00Yoo`05001oogooOol0003iOol00005Ool007ooOol0000:Ool00`00Oomoo`03Ool00`00
Oomoo`0;Ool01000Oomoo`00nGoo00001Goo001oogoo00001goo1@0017oo00<007ooOol02goo00D0
07ooOomoo`000?Qoo`0000Eoo`00Oomoo`0000Moo`04001oogoo0005Ool3000;Ool00`00Oomoo`02
Ool00`00Oomoo`3eOol00005Ool007ooOol00008Ool00`00Ool00005Ool00`00Oomoo`0<Ool00`00
Oomoo`02Ool00`00Oomoo`3dOol00005Ool007ooOol00009Ool20005Ool00`00Oomoo`0<Ool00`00
Oomoo`03Ool00`00Oomoo`3cOol0009oo`8000]oo`03001oogoo00=oo`03001oogoo00aoo`03001o
ogoo00Aoo`03001oogoo0?9oo`005Goo00<007ooOol03Goo00<007ooOol00goo00<007ooOol0lWoo
000EOol00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`3aOol001Eoo`03001oogoo00eoo`03
001oogoo00Eoo`03001oogoo0?1oo`005Goo00<007ooOol03Woo00<007ooOol01Goo00<007ooOol0
kgoo000EOol2000?Ool00`00Oomoo`06Ool2003_Ool001Eoo`03001oogoo00ioo`03001oogoo00Qo
o`03001oogoo0>aoo`005Goo00<007ooOol03goo00<007ooOol027oo00<007ooOol0jgoo000EOol0
0`00Oomoo`0?Ool00`00Oomoo`09Ool2003[Ool001Eoo`03001oogoo011oo`03001oogoo00Yoo`03
001oogoo0>Qoo`005Goo00<007ooOol047oo00<007ooOol02goo00<007ooOol0igoo000EOol00`00
Oomoo`0AOol00`00Oomoo`0;Ool2003WOol001Eoo`03001oogoo015oo`03001oogoo00eoo`800>Eo
o`005Goo0P004goo00<007ooOol03Woo0`00hWoo000EOol00`00Oomoo`0BOol00`00Oomoo`0AOol2
003POol001Eoo`03001oogoo01=oo`03001oogoo019oo`<00=eoo`005Goo00<007ooOol04goo00<0
07ooOol05Goo1000fGoo000EOol00`00Oomoo`0DOol00`00Oomoo`0HOol4003EOol001Eoo`03001o
ogoo01Aoo`03001oogoo01aoo`D00=1oo`005Goo00<007ooOol05Goo00<007ooOol087oo1P00bWoo
000EOol00`00Oomoo`0EOol00`00Oomoo`0VOol90031Ool001Eoo`03001oogoo01Ioo`03001oogoo
02iooa400;1oo`005Goo0P005goo00<007ooOol0?goo6P00UWoo000EOol00`00Oomoo`0GOol00`00
Oomoo`1HOon=0009Ool001Eoo`03001oogoo01Moo`03001oogoo0>ioo`005Goo00<007ooOol067oo
00<007ooOol0kGoo000EOol00`00Oomoo`0IOol00`00Oomoo`3/Ool001Eoo`03001oogoo01Uoo`03
001oogoo0>aoo`000Woo0P0017oo00<007ooOol00Woo0`001Goo00<007ooOol06Woo00<007ooOol0
jgoo00001Goo001oogoo00001goo00D007ooOomoo`0000Aoo`03001oogoo01Yoo`03001oogoo0>]o
o`0000Eoo`00Oomoo`0000Moo`05001oogooOol00004Ool3000KOol00`00Oomoo`3ZOol00005Ool0
07ooOol00007Ool40005Ool00`00Oomoo`0LOol00`00Oomoo`3YOol00005Ool007ooOol00007Ool0
0`00Oomoo`06Ool00`00Oomoo`0LOol00`00Oomoo`3YOol00005Ool007ooOol00008Ool00`00Oomo
o`05Ool00`00Oomoo`0MOol00`00Oomoo`3XOol0009oo`8000Yoo`8000Eoo`03001oogoo01eoo`03
001oogoo0>Qoo`005Goo00<007ooOol07Woo00<007ooOol0igoo000EOol00`00Oomoo`0OOol00`00
Oomoo`3VOol001Eoo`03001oogoo021oo`03001oogoo0>Eoo`005Goo00<007ooOol08Goo00<007oo
Ool0i7oo000EOol2000SOol00`00Oomoo`3SOol001Eoo`03001oogoo02=oo`03001oogoo0>9oo`00
5Goo00<007ooOol097oo00<007ooOol0hGoo000EOol00`00Oomoo`0UOol00`00Oomoo`3POol001Eo
o`03001oogoo02Ioo`03001oogoo0=moo`005Goo00<007ooOol09goo00<007ooOol0gWoo000EOol0
0`00Oomoo`0XOol2003NOol001Eoo`03001oogoo02Yoo`03001oogoo0=]oo`005Goo0P00;7oo00<0
07ooOol0fWoo000EOol00`00Oomoo`0/Ool00`00Oomoo`3IOol001Eoo`03001oogoo02eoo`03001o
ogoo0=Qoo`005Goo00<007ooOol0;Woo00<007ooOol0egoo000EOol00`00Oomoo`0_Ool00`00Oomo
o`3FOol001Eoo`03001oogoo031oo`800=Ioo`005Goo00<007ooOol0<Woo0P00e7oo000EOol00`00
Oomoo`0dOol2003BOol001Eoo`03001oogoo03Ioo`03001oogoo0<moo`005Goo0P00>7oo0P00cgoo
000EOol00`00Oomoo`0iOol2003=Ool001Eoo`03001oogoo03]oo`800<]oo`005Goo00<007ooOol0
?Goo0P00bGoo000EOol00`00Oomoo`0oOol20037Ool001Eoo`03001oogoo045oo`800<Eoo`000Woo
0P0017oo00<007ooOol00Woo0`001Goo00<007ooOol0@goo0P00`goo00001Goo001oogoo00001goo
00D007ooOomoo`0000Aoo`03001oogoo04Eoo`<00<1oo`0000Eoo`00Oomoo`0000Moo`05001oogoo
Ool00004Ool30018Ool2002nOol00005Ool007ooOol00008Ool30005Ool00`00Oomoo`1:Ool2002l
Ool00005Ool007ooOol00007Ool01@00Oomoogoo000017oo00<007ooOol0C7oo0`00^Goo00001Goo
001oogoo00001goo00D007ooOomoo`0000Aoo`03001oogoo04moo`<00;Ioo`000Woo0P002Goo0`00
1Goo00<007ooOol0DWoo0`00/goo000EOol00`00Oomoo`1EOol5002^Ool001Eoo`03001oogoo05Yo
o`@00:Yoo`005Goo00<007ooOol0GWoo1@00YGoo000EOol00`00Oomoo`1SOol4002QOol001Eoo`80
06Qoo`@009eoo`005Goo00<007ooOol0Jgoo1000VGoo000EOol00`00Oomoo`1_Ool5002DOol001Eo
o`03001oogoo07Aoo`H008ioo`005Goo00<007ooOol0NWoo2@00QGoo000EOol00`00Oomoo`23Ool6
001oOol001Eoo`03001oogoo08Uoo`@007]oo`005Goo00<007ooOol0SGoo1`00M7oo000EOol2002E
OolA001SOol001Eoo`03001oogoo0:Eoo`T005Yoo`005Goo00<007ooOol0[Woo2000DWoo000EOol0
0`00Oomoo`2fOolA0011Ool001Eoo`03001oogoo0<Mooa40031oo`005Goo00<007ooOol0f7oo4@00
7goo000EOol00`00Oomoo`3YOolB000=Ool001Eoo`03001oogoo0?]oo`@000Uoo`005Goo0P00ogoo
2Woo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-24.9809, -0.0791082, 1.169, \
0.00591802}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\((pt[#] // Last)\) &\) /@ {1, 2, 3}\)], "Input",
  CellLabel->"In[122]:=  (7:21:39 on 5/1/01)"],

Cell[BoxData[
    \({{300, 0.9386316575020541`}, {300, 0.5592038966410809`}, {300, 
        0.3329487680635552`}}\)], "Output",
  CellLabel->"Out[122]=  (7:21:39 on 5/1/01)"]
}, Closed]],

Cell["\<\
An equilibrium is reached at p=0.33, 0.56 for the most strongly \
selected loci, but migration swamps selection at the weakly selected locus.\
\
\>", "Text"],

Cell[TextData[{
  ButtonBox["Note",
    ButtonData:>{"Potential problems", "Redefining fitness"},
    ButtonStyle->"AddOnsLink"],
  ": ",
  StyleBox["by default, a table of offspring frequencies is stored for each \
fitness function w[] that is supplied.  Thus, if one uses \
IterateExact[\[Psi],W,m], and then redefines W without changing its name, the \
wrong results will be produced.  It is ",
    FontWeight->"Plain"],
  "essential",
  StyleBox[" that fitness functions have unique names.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell["IterateExact can be used to find algebraic solutions:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(newP = \(AlleleFrequencyTable[
            IterateExact[MakePopulation[1, p, 100], w[{\[Sigma]}], 
              m]]\)\[LeftDoubleBracket]1\[RightDoubleBracket] // 
        Simplify\)], "Input",
  CellLabel->"In[123]:=  (7:22:34 on 5/1/01)"],

Cell[BoxData[
    \(\(\(-p\)\ \((1 + p\ \[Sigma])\) + m\ \((\(-1\) + p)\)\ \((1 + \[Sigma] \
+ p\ \[Sigma])\)\)\/\(\(-1\) + \((1 + 2\ m\ \((\(-1\) + p)\) - 2\ p)\)\ \
\[Sigma]\)\)], "Output",
  CellLabel->"Out[123]=  (7:22:34 on 5/1/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(soln = Solve[p == newP, p] // Simplify\)], "Input",
  CellLabel->"In[124]:=  (7:22:39 on 5/1/01)"],

Cell[BoxData[
    \({{p \[Rule] 
          1}, {p \[Rule] \(m\ \((1 + \[Sigma])\)\)\/\(\((\(-1\) + m)\)\ \
\[Sigma]\)}}\)], "Output",
  CellLabel->"Out[124]=  (7:22:39 on 5/1/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(p /. soln\) /. {m -> 0.1, \[Sigma] -> \(-0.2\)}\)], "Input",
  CellLabel->"In[126]:=  (7:22:58 on 5/1/01)"],

Cell[BoxData[
    \({1, 0.44444444444444453`}\)], "Output",
  CellLabel->"Out[126]=  (7:22:58 on 5/1/01)"]
}, Closed]],

Cell[TextData[{
  "With one locus, and  m<s, there is one stable equilibrium at approximately \
",
  Cell[BoxData[
      \(TraditionalForm\`\(m\/\[Sigma]\) . \ \ In\ the\ example\ above, 
      with\ three\ loci, \ the\ equilibrium\ is\)]],
  " substantially lower, and an equilibrium is possible even for m=\[Sigma].  \
 This is because migration generates positive linkage disequilibria, which \
assists selection; also, the effective selection coefficient is higher, \
because mean fitness is lower ",
  Cell[BoxData[
      \(TraditionalForm\`\((s = \[Sigma]\/W\&_)\)\)]],
  "."
}], "Text",
  CellTags->"Immigration example"],

Cell[TextData[{
  "Note:  ",
  StyleBox["If the option ",
    FontWeight->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(FixedEnds -> {\[Psi]\_s}\ \ is\ used\ to\ specify\ a\ \
source\ population, \ 
          this\ is\ passed\ directly\ to\ MigrateExact . \ \ Thus, \ 
          even\ if\ selection\ in\ the\ target\ deme\ acts\ before\ migration\
\ \((MigrationOrder \[Rule] USM)\), \ 
          the\ source\ population\ is\ assumed\ not\ to\ be\ affected\ by\ \(\
\(selection\)\(.\)\)\),
          FontWeight->"Plain"], TraditionalForm]]]
}], "Text",
  FontWeight->"Bold"]
}, Closed]],

Cell[CellGroupData[{

Cell["Varying deme size", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, m, 
              DemeSize -> F]\), \(changes\ deme\ size\ to\ F[n, W\&_]\)},
          {\(\(ExponentialF[r, \[Beta], \[Lambda]]\)[n, 
              W\&_]\), \(represents\ r\[VeryThinSpace]n\[VeryThinSpace]\(W\&_\
\^\[Beta]\) Exp[\(-\[Lambda]\)\[VeryThinSpace]n]\)},
          {\(\(PowerF[r, \[Beta], \[Lambda]]\)[n, 
              W\&_]\), \(represents\ r\[VeryThinSpace]n\^\(1 - \[Lambda]\)\
\[VeryThinSpace]W\&_\^\[Beta]\)},
          {\(StoreExact[\[Psi], \[Psi]\_0, W, m, {t, dt}, 
              DemeSize -> 
                F]\), \(stores\ results\ in\ \[Psi]\ for\ t\ generations\ at\ \
intervals\ dt\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->{"DemeSize", "ExponentialF", "PowerF"}],

Cell["\<\
This sets deme size to decrease with density and increase with mean \
fitness, and iterates for 30 generations:\
\>", "MathCaption"],

Cell[BoxData[
    \(\(\(\(\(\(\(w[s_, add]\)[x_, 
                y_] := \((1 - s)\)\^Plus @@ \((x + y)\);\)\n
          \(hp = MakePopulation[3, {0.1, 0.2, 0.7}, 1];\)\n
          \(\(StoreExact\)\([\)\(pop2[0.2], hp, w[0.2, add], 0, {30, 1}, 
            DemeSize -> 
              ExponentialF[2, 1, 1]\)\)\)\()\)\)\(]\)\);\)\)], "Input",
  CellLabel->"In[28]:=  (14:58:05 on 4/25/01)"],

Cell["This plots deme size and allele frequencies:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tn = Table[{t, DemeSize[\(pop2[0.2]\)[t]]}, {t, 0, 30}];\)\), "\n", 
    \(\(tp = 
        Table[AlleleFrequencyTable[\(pop2[0.2]\)[t]], {t, 30}] // 
          Transpose;\)\), "\n", 
    \(\(tw = 
        Table[MeanW[MakeDiploid[\(pop2[0.2]\)[t]], w[0.2, add]], {t, 
            30}];\)\), "\[IndentingNewLine]", 
    \(\(Show[
        GraphicsArray[{DisplayTogether[
              ListPlot[tn, PlotJoined -> True], \[IndentingNewLine]ListPlot[
                tw, PlotJoined -> True, 
                PlotStyle -> Red], \[IndentingNewLine]ListPlot[Log[2  tw], 
                PlotJoined -> True, PlotStyle -> Dashing[{0.05, 0.05}]], 
              PlotRange -> {{0, 30}, {0, 1}}], 
            DisplayTogether @@ 
              MapThread[
                ListPlot[#1, PlotJoined -> True, 
                    PlotStyle -> #2] &, {tp, {Red, Green, 
                    Blue}}]}]];\)\)}], "Input",
  CellLabel->"In[43]:=  (15:09:26 on 4/25/01)"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.0333333 0 0.618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .61803 m
.03333 .29767 L
.06667 .25157 L
.1 .23888 L
.13333 .24093 L
.16667 .25142 L
.2 .26708 L
.23333 .28559 L
.26667 .30506 L
.3 .324 L
.33333 .34138 L
.36667 .35666 L
.4 .3697 L
.43333 .38062 L
.46667 .38964 L
.5 .39704 L
.53333 .40308 L
.56667 .40799 L
.6 .41197 L
.63333 .41518 L
.66667 .41778 L
.7 .41987 L
.73333 .42156 L
.76667 .42291 L
.8 .424 L
.83333 .42487 L
.86667 .42557 L
.9 .42613 L
.93333 .42658 L
.96667 .42694 L
1 .42723 L
s
1 0 0 r
.03333 .42274 m
.06667 .44084 L
.1 .45873 L
.13333 .47621 L
.16667 .49306 L
.2 .50905 L
.23333 .52398 L
.26667 .53766 L
.3 .54998 L
.33333 .5609 L
.36667 .57044 L
.4 .57865 L
.43333 .58563 L
.46667 .5915 L
.5 .5964 L
.53333 .60046 L
.56667 .6038 L
.6 .60653 L
.63333 .60875 L
.66667 .61056 L
.7 .61202 L
.73333 .6132 L
.76667 .61416 L
.8 .61492 L
.83333 .61554 L
.86667 .61604 L
.9 .61643 L
.93333 .61675 L
.96667 .61701 L
1 .61721 L
s
0 g
[ .05 .05 ] 0 setdash
.03333 .19367 m
.06667 .21958 L
.1 .24416 L
.13333 .26727 L
.16667 .28877 L
.2 .3085 L
.23333 .32635 L
.26667 .34228 L
.3 .35629 L
.33333 .36844 L
.36667 .37886 L
.4 .38769 L
.43333 .3951 L
.46667 .40127 L
.5 .40637 L
.53333 .41056 L
.56667 .41398 L
.6 .41677 L
.63333 .41904 L
.66667 .42087 L
.7 .42235 L
.73333 .42354 L
.76667 .4245 L
.8 .42527 L
.83333 .42589 L
.86667 .42639 L
.9 .42679 L
.93333 .4271 L
.96667 .42736 L
1 .42757 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0147151 2.08612 [
[.18254 .00222 -3 -9 ]
[.18254 .00222 3 0 ]
[.34127 .00222 -6 -9 ]
[.34127 .00222 6 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.65873 .00222 -6 -9 ]
[.65873 .00222 6 0 ]
[.81746 .00222 -6 -9 ]
[.81746 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .11902 -24 -4.5 ]
[.01131 .11902 0 4.5 ]
[.01131 .22333 -18 -4.5 ]
[.01131 .22333 0 4.5 ]
[.01131 .32763 -24 -4.5 ]
[.01131 .32763 0 4.5 ]
[.01131 .43194 -18 -4.5 ]
[.01131 .43194 0 4.5 ]
[.01131 .53625 -24 -4.5 ]
[.01131 .53625 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(10)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(15)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(20)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(25)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(30)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11902 m
.03006 .11902 L
s
[(0.05)] .01131 .11902 1 0 Mshowa
.02381 .22333 m
.03006 .22333 L
s
[(0.1)] .01131 .22333 1 0 Mshowa
.02381 .32763 m
.03006 .32763 L
s
[(0.15)] .01131 .32763 1 0 Mshowa
.02381 .43194 m
.03006 .43194 L
s
[(0.2)] .01131 .43194 1 0 Mshowa
.02381 .53625 m
.03006 .53625 L
s
[(0.25)] .01131 .53625 1 0 Mshowa
.125 Mabswid
.02381 .03558 m
.02756 .03558 L
s
.02381 .05644 m
.02756 .05644 L
s
.02381 .0773 m
.02756 .0773 L
s
.02381 .09816 m
.02756 .09816 L
s
.02381 .13988 m
.02756 .13988 L
s
.02381 .16074 m
.02756 .16074 L
s
.02381 .1816 m
.02756 .1816 L
s
.02381 .20247 m
.02756 .20247 L
s
.02381 .24419 m
.02756 .24419 L
s
.02381 .26505 m
.02756 .26505 L
s
.02381 .28591 m
.02756 .28591 L
s
.02381 .30677 m
.02756 .30677 L
s
.02381 .34849 m
.02756 .34849 L
s
.02381 .36936 m
.02756 .36936 L
s
.02381 .39022 m
.02756 .39022 L
s
.02381 .41108 m
.02756 .41108 L
s
.02381 .4528 m
.02756 .4528 L
s
.02381 .47366 m
.02756 .47366 L
s
.02381 .49452 m
.02756 .49452 L
s
.02381 .51538 m
.02756 .51538 L
s
.02381 .55711 m
.02756 .55711 L
s
.02381 .57797 m
.02756 .57797 L
s
.02381 .59883 m
.02756 .59883 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.05556 .18501 m
.0873 .15321 L
.11905 .127 L
.15079 .10552 L
.18254 .088 L
.21429 .07376 L
.24603 .06222 L
.27778 .05289 L
.30952 .04537 L
.34127 .03931 L
.37302 .03444 L
.40476 .03052 L
.43651 .02738 L
.46825 .02486 L
.5 .02284 L
.53175 .02122 L
.56349 .01992 L
.59524 .01888 L
.62698 .01805 L
.65873 .01738 L
.69048 .01685 L
.72222 .01642 L
.75397 .01608 L
.78571 .01581 L
.81746 .01559 L
.84921 .01542 L
.88095 .01528 L
.9127 .01516 L
.94444 .01507 L
.97619 .015 L
s
0 1 0 r
.05556 .3624 m
.0873 .30246 L
.11905 .25144 L
.15079 .20849 L
.18254 .17267 L
.21429 .14302 L
.24603 .11864 L
.27778 .09869 L
.30952 .08244 L
.34127 .06925 L
.37302 .05857 L
.40476 .04995 L
.43651 .043 L
.46825 .0374 L
.5 .0329 L
.53175 .02929 L
.56349 .02639 L
.59524 .02407 L
.62698 .0222 L
.65873 .02071 L
.69048 .01951 L
.72222 .01856 L
.75397 .01779 L
.78571 .01718 L
.81746 .01668 L
.84921 .01629 L
.88095 .01598 L
.9127 .01572 L
.94444 .01552 L
.97619 .01536 L
s
0 0 1 r
.27249 .61803 m
.27778 .60161 L
.30952 .51223 L
.34127 .43266 L
.37302 .36303 L
.40476 .30299 L
.43651 .25189 L
.46825 .20887 L
.5 .17299 L
.53175 .14328 L
.56349 .11885 L
.59524 .09887 L
.62698 .08258 L
.65873 .06936 L
.69048 .05867 L
.72222 .05002 L
.75397 .04306 L
.78571 .03745 L
.81746 .03294 L
.84921 .02932 L
.88095 .02642 L
.9127 .02409 L
.94444 .02222 L
.97619 .02072 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[43]:=  (15:09:29 on 4/25/01)",
  ImageSize->{554, 163},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008Z0000Xa000`40O003h00Oogooogoo;7oo003o
OoooOol/Ool00?mooomoobaoo`00ogooogoo;7oo003oOoooOol/Ool00?mooomoobaoo`00AWoo0`00
7goo0`0017oo0P0077oo0`000goo0`006goo1@000goo0P006goo1@000Woo0`007Goo0`0017oo0P00
ogoo9Goo0015Ool01@00Oomoogoo00007goo00<007ooOol00Woo00@007ooOol001aoo`05001oogoo
Ool00003Ool00`00Oomoo`0IOol01000Oomoo`000Woo00@007ooOol001]oo`06001oogoo001oo`00
0goo00<007ooOol06Goo00D007ooOomoo`00009oo`04001oogoo003oOolTOol004Uoo`03001oogoo
01eoo`03001oogoo009oo`04001oogoo000LOol00`00Oomoo`05Ool00`00Oomoo`0JOol00`00Oomo
o`02Ool01000Oomoo`0077oo00<007ooOol01Goo00<007ooOol07Goo00@007ooOol0009oo`03001o
ogoo05Aoo`<001moo`<000Aoo`8001]oo`<000=oo`<001Yoo`D000=oo`8001Yoo`D0009oo`<001]o
o`<000Aoo`80019oo`00BGoo00<007ooOol07Goo00<007ooOol00Woo00@007ooOol001aoo`03001o
ogoo00Eoo`03001oogoo01]oo`05001oogooOol00002Ool00`00Oomoo`0KOol00`00Oomoo`04Ool0
0`00Oomoo`0KOol20003Ool01000Oomoo`00EGoo00D007ooOomoo`0001moo`03001oogoo009oo`04
001oogoo000KOol01@00Oomoogoo00000goo00<007ooOol067oo00@007ooOol0009oo`04001oogoo
000JOol01P00Oomoo`00Ool000=oo`03001oogoo01Moo`05001oogooOol00002Ool01000Oomoo`00
4Goo0015Ool4000POol00`00Oomoo`02Ool01000Oomoo`0077oo00@007ooOomoo`@001]oo`05001o
ogooOol00002Ool01000Oomoo`006Woo00H007ooOomoo`00Ool4000POol01000Oomoo`000Woo00<0
07ooOol0Egoo00<007ooOol07Goo00<007ooOol00Woo00@007ooOol001]oo`03001oogoo00Eoo`03
001oogoo01Uoo`03001oogoo009oo`04001oogoo000KOol00`00Oomoo`05Ool00`00Oomoo`0KOol0
1000Oomoo`000Woo00<007ooOol03goo0015Ool00`00Oomoo`0POol20004Ool01000Oomoo`006goo
0P000goo00<007ooOol077oo00D007ooOomoo`00009oo`04001oogoo000JOol01`00Oomoogoo001o
o`0001moo`05001oogooOol00002Ool01000Oomoo`00FGoo00<007ooOol07Goo00<007ooOol00Woo
00@007ooOol001]oo`03001oogoo00Eoo`03001oogoo01Yoo`05001oogooOol00002Ool00`00Oomo
o`0JOol00`00Oomoo`04Ool00`00Oomoo`0IOol20003Ool01000Oomoo`004Goo0015Ool5000OOol0
0`00Oomoo`03Ool2000MOol01000Oomoogoo1@006goo0`0017oo0P0077oo0`000Woo1@0077oo0`00
17oo0P00EWoo100087oo00<007ooOol00Woo00@007ooOol001]oo`04001oogooOol4000JOol01@00
Oomoogoo00000Woo00@007ooOol001Uoo`06001oogooOol007oo10007Woo00@007ooOol0009oo`03
001oogoo00moo`00ogooGGoo00<007ooOol087oo0P0017oo00@007ooOol001Yoo`8000=oo`03001o
ogoo01]oo`05001oogooOol00002Ool01000Oomoo`006Goo00L007ooOomoo`00Ool0000MOol01@00
Oomoogoo00000Woo00@007ooOol0015oo`00ogooGGoo1@007goo00<007ooOol00goo0P0077oo00@0
07ooOomoo`D001Yoo`<000Aoo`8001]oo`<0009oo`D001Yoo`<000Aoo`80019oo`00ogoo?7oo00<0
07ooOol0k7oo000SOooP000hOol00`00Oomoo`3/Ool002=oo`03001oogoo00Aoo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo03Ioo`03001oogoo0>ao
o`008goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007oo
Ool08Woo00<007ooOol08goo00<007ooOol0=Woo00<007ooOol0k7oo000SOol00`00Oomoo`3oOolA
OonC000EO00g0n05000@Ool002=oo`03001oogoo0?mooaIoo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ao
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`04001oogooOolEO00M0n03Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`05Ool01000
Oomoogoo2`0O5Goo000SOol00`00Oomoo`3oOolFOol00`00Oomoo`1OOol?O007Ool>0n0jOol?01lP
Ool002=oo`03001oogoo0?mooaIoo`03001oogoo055oo`il00moo`L3h45oo`L07bmoo`008goo00<0
07ooOol0ogoo5Woo00<007ooOol0BWoo1g`05Goo20?P@Goo1`0O=Woo000SOol00`00Oomoo`3oOolF
Ool20015Ool6O00EOol70n11Ool801lmOol002=oo`03001oogoo0?mooaIoo`03001oogoo041oo`Al
01Eoo`H3h49oo`H07dEoo`008goo00<007ooOol0ogoo5Woo00<007ooOol0>goo1G`05Woo0`?PAGoo
0`0OBgoo000SOol00`00Oomoo`3oOolFOol00`00Oomoo`0fOol5O00GOol40n14Ool401m>Ool002=o
o`03001oogoo0?mooaIoo`8003Aoo`=l01Uoo`<3h4Eoo`<07e9oo`008goo00<007ooOol0ogoo5Woo
00<007ooOol0<Goo0W`067oo10?PA7oo100OEGoo000SOol00`00Oomoo`3oOolFOol00`00Oomoo`0^
Ool3O00GOol30n15Ool301mIOol002=oo`03001oogoo0?mooaIoo`03001oogoo02]oo`=l01Moo`<3
h4Eoo`<07eaoo`008goo00<007ooOol0ogoo5Woo00<007ooOol0:7oo0g`05goo0`?PAGoo0`0OGgoo
000SOol00`00Oomoo`3oOolFOol2000VOol3O00GOol30n16Ool201mROol002=oo`03001oogoo0?mo
oaIoo`03001oogoo029oo`=l01Qoo`83h4Moo`807fAoo`008goo00<007ooOol0ogoo5Woo00<007oo
Ool087oo0W`06Goo0P?PAgoo0P0OIWoo000SOol00`00Oomoo`3oOolFOol00`00Oomoo`0NOol2O00J
Ool00`?POomoo`15Ool201mXOol002=oo`03001oogoo0?mooaIoo`03001oogoo01eoo`03O01oogoo
01Qoo`83h4Ioo`807fYoo`008goo00<007ooOol0ogoo5Woo0P0077oo0W`06Goo0P?PAWoo0P0OK7oo
000SOol00`00Oomoo`3oOolFOol00`00Oomoo`0IOol2O00IOol20n16Ool201m^Ool002=oo`03001o
ogoo0?aoo`8000Aoo`03001oogoo00=oo`8000=oo`<000Eoo`03001oogoo01Qoo`03O01oogoo01Qo
o`030n1oogoo04Eoo`0301moogoo06ioo`0047oo0P0017oo00@007ooOomoo`D000Aoo`03001oogoo
0?]oo`04001oogoo0008Ool01P00Oomoo`00Ool000=oo`03001oogoo009oo`03001oogoo01Ioo`9l
01Uoo`83h4Ioo`807g5oo`003goo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`3kOol0
1000Oomoo`0027oo00@007ooOol000Eoo`03001oogoo009oo`03001oogoo01Eoo`03O01oogoo01Mo
o`83h4Ioo`807g=oo`003goo00@007ooOol000Uoo`03001oogoo00Aoo`03001oogoo0?]oo`04001o
ogoo0008Ool01000Oomoo`001Goo00<007ooOol00Woo0`0057oo00=l07ooOol05goo00<3h7ooOol0
AGoo00<07gooOol0Lgoo000?Ool01000Oomoo`002Woo00<007ooOol00goo0P00o7oo00@007ooOol0
00Qoo`05001oogoo001oo`040005Ool00`00Oomoo`0BOol2O00IOol00`?POomoo`15Ool00`0OOomo
o`1dOol000moo`04001oogoo0007Ool01@00Oomoogoo000017oo00<007ooOol0ngoo00@007ooOol0
00Qoo`06001oogoo001oo`0027oo00<007ooOol04Goo00=l07ooOol067oo00<3h7ooOol0AGoo00<0
7gooOol0MGoo000?Ool01000Oomoo`001goo00D007ooOomoo`0000Aoo`03001oogoo0?aoo`8000Yo
o`80009oo`D000Aoo`03001oogoo011oo`03O01oogoo01Qoo`030n1oogoo04Eoo`0301moogoo07Io
o`0047oo0P002Goo0`001Goo00<007ooOol0ogoo5Woo0P0047oo00=l07ooOol067oo00<3h7ooOol0
AGoo00<07gooOol0Mgoo000SOol00`00Oomoo`3oOolFOol00`00Oomoo`0>Ool00g`0Oomoo`0GOol2
0n17Ool00`0OOomoo`1hOol002=oo`03001oogoo0?mooaIoo`03001oogoo00eoo`03O01oogoo01Mo
o`030n1oogoo04Ioo`0301moogoo07Uoo`008goo00<007ooOol0ogoo5Woo00<007ooOol037oo00=l
07ooOol05goo00<3h7ooOol0AWoo00<07gooOol0NWoo000SOol00`00Oomoo`3oOolFOol00`00Oomo
o`0<Ool00g`0Oomoo`0FOol00`?POomoo`16Ool00`0OOomoo`1kOol002=oo`03001oogoo0?mooaIo
o`8000aoo`03O01oogoo01Ioo`030n1oogoo04Ioo`0301moogoo07aoo`008goo00<007ooOol0ogoo
5Woo00<007ooOol02Woo00=l07ooOol05Woo00<3h7ooOol0AWoo00<07gooOol0OGoo000SOol00`00
Oomoo`3oOolFOol00`00Oomoo`09Ool00g`0Oomoo`0FOol00`?POomoo`16Ool00`0OOomoo`1nOol0
02=oo`03001oogoo0?mooaIoo`03001oogoo00Qoo`03O01oogoo01Ioo`030n1oogoo04Ioo`0301mo
ogoo07moo`008goo00<007ooOol0ogoo5Woo00<007ooOol01goo00=l07ooOol05goo00<3h7ooOol0
AGoo00<07gooOol0P7oo000SOol00`00Oomoo`3oOolFOol20007Ool00g`0Oomoo`0GOol00`?POomo
o`15Ool00`0OOomoo`21Ool002=oo`03001oogoo0?mooaIoo`03001oogoo00Eoo`03O01oogoo01Mo
o`030n1oogoo04Eoo`0301moogoo089oo`008goo00<007ooOol017oo0P00ogoo47oo00<007ooOol0
7Woo00<3h7ooOol0AGoo00<07gooOol0Pgoo000SOol00`00Oomoo`06Ool00`00Oomoo`3oOol=Ool0
0`00Oomoo`0MOol00`?POomoo`15Ool00`0OOomoo`24Ool002=oo`03001oogoo00Moo`03001oogoo
0?moo`aoo`03001oogoo01aoo`030n1oogoo04Eoo`0301moogoo08Eoo`008goo00<007ooOol027oo
0P00ogoo37oo0P0077oo00<3h7ooOol0AGoo00<07gooOol0QWoo000SOol00`00Oomoo`0:Ool00`00
Oomoo`3oOol9Ool00`00Oomoo`0JOol00`?POomoo`15Ool00`0OOomoo`27Ool002=oo`03001oogoo
00]oo`03001oogoo0?Aoo`8000Aoo`03001oogoo009oo`<000Eoo`03001oogoo01Yoo`030n1oogoo
04Eoo`0301moogoo08Moo`008goo00<007ooOol037oo00<007ooOol0lWoo00@007ooOol000Uoo`03
001oogoo00Aoo`03001oogoo01Uoo`030n1oogoo04Eoo`0301moogoo08Qoo`008goo00<007ooOol0
3Goo00<007ooOol0lGoo00@007ooOol000Uoo`03001oogoo00Aoo`<001Qoo`030n1oogoo04Eoo`03
01moogoo08Uoo`008goo00<007ooOol0ogoo0Woo00@007ooOol000Uoo`03001oogoo00Aoo`03001o
ogoo01Qoo`030n1oogoo04Eoo`0301moogoo08Uoo`008goo00<007ooOol0ogoo0Woo00@007ooOol0
00Uoo`03001oogoo00Aoo`03001oogoo01Moo`030n1oogoo04Eoo`0301moogoo08Yoo`0047oo0P00
17oo00<007ooOol00goo0`0017oo00<007ooOol0ogoo0Woo00@007ooOol000Qoo`8000Ioo`03001o
ogoo01Ioo`030n1oogoo04Eoo`0301moogoo08]oo`003goo00@007ooOol000Yoo`03001oogoo00=o
o`03001oogoo015oo``00>Eoo`8000Yoo`03001oogoo00Aoo`03001oogoo01Eoo`030n1oogoo04Eo
o`0301moogoo08aoo`003goo00@007ooOol000Moo`D000Aoo`8000moo`<000aoo`@00?Aoo`8001Io
o`030n1oogoo04Eoo`0301moogoo08aoo`003goo00@007ooOol000Moo`04001oogoo0005Ool00`00
Oomoo`0<Ool2000COol3003aOol00`00Oomoo`0DOol00`?POomoo`15Ool00`0OOomoo`2=Ool000mo
o`04001oogoo0008Ool00`00Ool00005Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool2000<Ool2003_
Ool00`00Oomoo`0COol00`?POomoo`15Ool00`0OOomoo`2>Ool000moo`04001oogoo0009Ool20005
Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`3/Ool00`00Oomoo`0C
Ool00`?POomoo`15Ool00`0OOomoo`2>Ool0011oo`8000]oo`03001oogoo00=oo`03001oogoo00Yo
o`03001oogoo00aoo`03001oogoo00]oo`800>aoo`03001oogoo019oo`030n1oogoo04Eoo`0301mo
ogoo08moo`008goo00<007ooOol02Goo00<007ooOol03Woo0P003Goo0P00jWoo0P004Woo00<3h7oo
Ool0AGoo00<07gooOol0T7oo000SOol00`00Oomoo`09Ool00`00Oomoo`0@Ool2000=Ool2003XOol0
0`00Oomoo`0AOol00`?POomoo`15Ool00`0OOomoo`2@Ool002=oo`03001oogoo00Qoo`03001oogoo
01=oo`03001oogoo00aoo`800>Ioo`03001oogoo011oo`030n1oogoo04Eoo`0301moogoo095oo`00
8goo00<007ooOol01goo00<007ooOol05Goo00<007ooOol03Goo0P00i7oo00<007ooOol03goo00<3
h7ooOol0AGoo00<07gooOol0TWoo000SOol00`00Oomoo`07Ool00`00Oomoo`0WOol2003ROol00`00
Oomoo`0?Ool00`?POomoo`15Ool00`0OOomoo`2BOol002=oo`03001oogoo00Ioo`03001oogoo02Yo
o`800>1oo`8000moo`030n1oogoo04Eoo`0301moogoo09=oo`008goo00<007ooOol01Goo00<007oo
Ool0;Goo00<007ooOol0gGoo00<007ooOol03Woo00<3h7ooOol0AGoo00<07gooOol0Tgoo000SOol0
0`00Oomoo`04Ool00`00Oomoo`0_Ool2003MOol00`00Oomoo`0=Ool00`?POomoo`15Ool00`0OOomo
o`2DOol002=oo`03001oogoo00Aoo`03001oogoo035oo`800=]oo`03001oogoo00aoo`030n1oogoo
04Eoo`0301moogoo09Eoo`008goo00<007ooOol017oo00<007ooOol08Woo0P003goo00<007ooOol0
f7oo0P003Goo00<3h7ooOol0AGoo00<07gooOol0UGoo000SOol00`00Oomoo`04Ool00`00Oomoo`0T
Ool2000>Ool2003HOol00`00Oomoo`0;Ool00`?POomoo`15Ool00`0OOomoo`2FOol002=oo`03001o
ogoo00Aoo`03001oogoo02Ioo`8000ioo`800=Ioo`03001oogoo00]oo`030n1oogoo04Eoo`0301mo
ogoo09Ioo`008goo00<007ooOol017oo00<007ooOol0:7oo0P003Woo00<007ooOol0^Woo0P0017oo
00<007ooOol00Woo0`000goo0`001Goo00<007ooOol02Woo00<3h7ooOol0AGoo00<07gooOol0Ugoo
000SOol00`00Oomoo`03Ool00`00Oomoo`0[Ool2000=Ool2002iOol01000Oomoo`002Goo00D007oo
Oomoo`0000=oo`03001oogoo009oo`03001oogoo00Yoo`030n1oogoo04Eoo`0301moogoo09Moo`00
8goo00<007ooOol00goo00<007ooOol0;Goo00<007ooOol037oo0`00]Woo00@007ooOol000Uoo`03
001oogoo00Eoo`03001oogoo009oo`<000Uoo`030n1oogoo04Eoo`0301moogoo09Qoo`008goo00<0
07ooOol00goo00<007ooOol0?goo0P00]7oo00@007ooOol000Uoo`03001oogoo00Eoo`03001oogoo
009oo`03001oogoo00Uoo`030n1oogoo04Eoo`0301moogoo09Qoo`008goo00<007ooOol00goo00<0
07ooOol0@Goo0P00/Woo00@007ooOol000Uoo`04001oogooOol40005Ool00`00Oomoo`08Ool00`?P
Oomoo`15Ool00`0OOomoo`2IOol002=oo`03001oogoo00=oo`03001oogoo04=oo`800;1oo`04001o
ogoo0008Ool20003Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`?POomoo`15Ool00`0OOomoo`2I
Ool002=oo`03001oogoo00=oo`03001oogoo04Eoo`03001oogoo0:ioo`8000Yoo`04001oogooOol5
0004Ool00`00Oomoo`07Ool00`?POomoo`15Ool00`0OOomoo`2JOol002=oo`03001oogoo00=oo`03
001oogoo03Moo`<000aoo`800<Moo`8000Qoo`030n1oogoo04Eoo`0301moogoo09Yoo`0047oo0P00
17oo00<007ooOol00Woo0`001Goo00<007ooOol00goo00<007ooOol0>Woo0`002goo0P00aGoo00<0
07ooOol01Woo00<3h7ooOol0AGoo00<07gooOol0Vgoo000?Ool01000Oomoo`001goo00D007ooOomo
o`0000Aoo`03001oogoo00=oo`03001oogoo03eoo`<000Yoo`<00<9oo`03001oogoo00Ioo`030n1o
ogoo04Eoo`0301moogoo09]oo`003goo00@007ooOol000Moo`05001oogooOol00004Ool00`00Oomo
o`03Ool00`00Oomoo`10Ool2000;Ool3002oOol00`00Oomoo`05Ool00`?POomoo`15Ool00`0OOomo
o`2LOol000moo`04001oogoo0007Ool40005Ool20003Ool00`00Oomoo`1AOol3002lOol00`00Oomo
o`1=Ool00`0OOomoo`2LOol000moo`04001oogoo0007Ool00`00Oomoo`06Ool00`00Oomoo`02Ool0
0`00Oomoo`1DOol3002iOol2001=Ool00`0OOomoo`2MOol000moo`04001oogoo0008Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool00`00Oomoo`1GOol4002eOol00`00Oomoo`1<Ool00`0OOomoo`2MOol0
011oo`8000Yoo`8000Eoo`03001oogoo009oo`03001oogoo04eoo`<000]oo`@00;5oo`03001oogoo
04]oo`0301moogoo09ioo`008goo00<007ooOol00Woo00<007ooOol0D7oo1P002Goo1000[Goo00<0
07ooOol0Bgoo00<07gooOol0WWoo000SOol00`00Oomoo`02Ool00`00Oomoo`1FOol3000:Ool3002Z
Ool2001<Ool00`0OOomoo`2NOol002=oo`03001oogoo009oo`03001oogoo06Ioo`H00:Aoo`03001o
ogoo04Yoo`0301moogoo09moo`008goo00<007ooOol00Woo00<007ooOol0Hgoo0`001Woo2000W7oo
00<007ooOol0BWoo00<07gooOol0Wgoo000SOol00`00Oomoo`02Ool00`00Oomoo`1VOol60008Ool7
002EOol00`00Oomoo`19Ool00`0OOomoo`2POol002=oo`03001oogoo009oo`03001oogoo06aoo`<0
00aoo`L008ioo`03001oogoo04Uoo`0301moogoo0:1oo`008goo00D007ooOomoo`0007aooaP007mo
o`8004Uoo`0301moogoo0:5oo`008goo00D007ooOomoo`0008Eoo`<000Yooa40071oo`03001oogoo
04Qoo`0301moogoo0:5oo`008goo00D007ooOomoo`00009oo`9l09Moo`<000Eooc@002Uoo`8000Ao
o`04001oogooOol50004Ool00`00Oomoo`18Ool00`0OOomoo`2QOol002=oo`05001oogooOol00004
Ool2O03?Ool6000TOol01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo04Moo`0301moogoo
0:9oo`008goo00D007ooOomoo`0000Ioo`9l0?Moo`04001oogoo0009Ool00`00Oomoo`04Ool00`00
Oomoo`17Ool00`0OOomoo`2ROol002=oo`05001oogooOol00008Ool2O03eOol01000Oomoo`002Woo
00<007ooOol00goo0`00AWoo00<07gooOol0Xgoo000SOol01@00Oomoogoo00002Woo0W`0lgoo00@0
07ooOol000Moo`05001oogooOol00004Ool00`00Oomoo`16Ool00`0OOomoo`2SOol002=oo`05001o
ogooOol0000<Ool2O03aOol01000Oomoo`001goo00D007ooOomoo`0000Aoo`03001oogoo04Eoo`03
01moogoo0:Aoo`008goo00D007ooOomoo`0000ioo`03O01oogoo0>moo`8000Uoo`<000Eoo`03001o
ogoo04Eoo`0301moogoo0:Aoo`008goo00D007ooOomoo`0000moo`9l0?moo`=oo`03001oogoo04Ao
o`0301moogoo0:Eoo`008goo00@007ooOol0019oo`9l0?moo`5oo`8004Eoo`0301moogoo0:Eoo`00
8goo00@007ooOol001Aoo`=l0?eoo`03001oogoo04Aoo`0301moogoo0:Eoo`008goo00@007ooOol0
01Moo`9l0?]oo`03001oogoo04=oo`0301moogoo0:Ioo`008goo00@007ooOol001Uoo`9l0?Uoo`03
001oogoo04=oo`0301moogoo0:Ioo`008goo00@007ooOol001]oo`9l0?Moo`8004=oo`0301moogoo
0:Moo`0047oo0P0017oo00<007ooOol00Woo0`001Goo00@007ooOol001eoo`9l0?Eoo`03001oogoo
049oo`0301moogoo0:Moo`003goo00@007ooOol000Moo`05001oogooOol00004Ool01000Oomoo`00
7goo0W`0lgoo00<007ooOol0@Goo00<07gooOol0Z7oo000?Ool01000Oomoo`001goo00D007ooOomo
o`0000Aoo`800003Ool007oo021oo`9l0?5oo`03001oogoo045oo`0301moogoo0:Qoo`003goo00@0
07ooOol000Qoo`<000Eoo`04001oogoo000SOol2O03_Ool00`00Oomoo`10Ool00`0OOomoo`2YOol0
00moo`04001oogoo0007Ool01@00Oomoogoo000017oo00@007ooOol002Eoo`03O01oogoo0>aoo`80
045oo`0301moogoo0:Uoo`003goo00@007ooOol000Moo`05001oogooOol00004Ool01000Oomoo`00
9Woo0W`0k7oo00<007ooOol0@7oo00<07gooOol0ZGoo000@Ool20009Ool30005Ool00`00Ool0000Y
Ool2O03ZOol00`00Oomoo`0oOol00`0OOomoo`2ZOol002=oo`03001oo`0002]oo`=l0>Moo`03001o
ogoo03moo`0301moogoo0:Yoo`008goo00<007oo0000;Woo0g`0i7oo00<007ooOol0?Woo00<07goo
Ool0Zgoo000SOol00`00Ool0000aOol2O03ROol2000oOol00`0OOomoo`2[Ool002=oo`03001oo`00
03=oo`=l0=moo`03001oogoo03eoo`0301moogoo0:aoo`008goo00<007oo0000=Woo0W`0a7oo0P00
17oo00@007ooOomoo`D0009oo`<000Eoo`03001oogoo03eoo`0301moogoo0:aoo`008goo00<007oo
0000>7oo0W`0`Goo00@007ooOol000Qoo`06001oogoo001oo`000goo00<007ooOol00Woo00<007oo
Ool0?Goo00<07gooOol0[7oo000SOol00`00Ool0000jOol3O02nOol01000Oomoo`002Goo00<007oo
Ool01Goo00<007ooOol00Woo0`00?7oo00<07gooOol0[Goo000SOol00`00Ool0000mOol3O02kOol0
1000Oomoo`002Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0?7oo00<07gooOol0[Goo
000SOol00`00Ool00010Ool3O02hOol01000Oomoo`001goo00H007ooOomoo`00Ool40005Ool00`00
Oomoo`0lOol00`0OOomoo`2]Ool002=oo`8004Aoo`=l0;Eoo`04001oogoo0007Ool01`00Oomoogoo
001oo`0000Qoo`03001oogoo03]oo`0301moogoo0:ioo`008goo0P00Agoo17`0/Woo0P002Goo0`00
0Woo1@0017oo00<007ooOol0>goo00<07gooOol0[Woo000SOol2001;Ool3O038Ool2000lOol00`0O
Oomoo`2^Ool002=oo`8004ioo`Al0<Aoo`03001oogoo03Yoo`0301moogoo0:moo`008goo0P00DWoo
17`0`7oo00<007ooOol0>Woo00<07gooOol0[goo000SOol2001FOol4O02lOol00`00Oomoo`0jOol0
0`0OOomoo`2_Ool002=oo`8005Yoo`=l0;Uoo`03001oogoo03Uoo`0301moogoo0;1oo`008goo0P00
GGoo1W`0/goo0P00>Woo00<07gooOol0/7oo000SOol2001SOol8O02[Ool00`00Oomoo`0iOol00`0O
Oomoo`2`Ool002=oo`8006]oo`Ml0:Aoo`03001oogoo03Qoo`0301moogoo0;5oo`008goo00<007oo
Ool0LGoo27`0W7oo00<007ooOol0>7oo00<07gooOol0/Goo000SOol00`00Oomoo`1iOol>O02>Ool0
0`00Oomoo`0hOol00`0OOomoo`2aOol001]oo`<000Eoo`03001oogoo08Moo`ml07moo`8003Qoo`03
01moogoo0;9oo`0077oo00<007ooOol017oo00<007ooOol0UWoo9G`0FWoo00<007ooOol0=goo00<0
7gooOol0/Woo000LOol00`00Oomoo`04Ool2002lOolRO00hOol00`00Oomoo`0gOol00`0OOomoo`2b
Ool001aoo`03001oogoo0?mooaeoo`03001oogoo03Ioo`0301moogoo0;=oo`0077oo00<007ooOol0
ogoo7Goo00<007ooOol0=Woo00<07gooOol0/goo000KOol2003oOoooOol?Ool001aoo`03001oogoo
0?mooomoo`eoo`00ogooogoo;7oo003oOoooOol/Ool00?mooomoobaoo`00ogooogoo;7oo0000\
\>"],
  ImageRangeCache->{{{0, 553}, {162, 0}} -> {-0.0548581, -0.0147182, \
0.00381504, 0.00381504}, {{14.375, 264}, {158.125, 3.8125}} -> {-4.73372, \
-0.114826, 0.134628, 0.00726106}, {{288.938, 538.562}, {158.125, 3.8125}} -> \
{-43.7015, -0.0385207, 0.138391, 0.00210599}}]
}, Closed]],

Cell[TextData[{
  "Initially, ",
  StyleBox["mean fitness",
    FontColor->RGBColor[1, 0, 0]],
  " is low, because deleterious alleles are present at the three loci.  \
Population size therefore decreases to a minimum of ~0.4.  As the deleterious \
alleles are eliminated, ",
  StyleBox["mean fitness",
    FontColor->RGBColor[1, 0, 0]],
  " increases, and population size increases to its equilibrium value of \
0.7."
}], "Text"],

Cell[TextData[{
  "In this example, the recursion for deme size is given by ",
  "ExponentialF[2,1,1]",
  ", which represents ",
  Cell[BoxData[
      \(TraditionalForm\`\(n\^*\) = 
        2  n\ Exp[\(-n\)]\ \(\(W\&_\)\(.\)\(\ \)\)\)]],
  "The equilibrium density is ",
  Cell[BoxData[
      \(TraditionalForm\`n = Log[2  W\&_]\ for\ W\&_ > 1\/2; \ 
      if\ W\&_ < 1\/2, \ the\ population\ goes\ \(\(extinct\)\(.\)\)\)]],
  "  In this example, the population density soon approaches a \
quasi-equilibrium of ",
  Cell[BoxData[
      \(TraditionalForm\`n = Log[2  W\&_]\)]],
  " (dashed line)."
}], "Text"],

Cell[TextData[{
  "The option DemeSize->F is passed to ",
  ButtonBox["NewGametes",
    ButtonData:>{"Recursions: reproduction", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ", which changes deme size accordingly.  Note that deme size is assumed to \
remain constant through meiosis and random union, but changes as a result of \
",
  ButtonBox["migration",
    ButtonData:>{"Recursions: migration", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "Text"],

Cell[TextData[{
  "When ",
  ButtonBox["compiled",
    ButtonData:>{"Recursions: compiling", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  " code is used, only certain settings for F can be used."
}], "Text"],

Cell[TextData[{
  "The logistic model ",
  Cell[BoxData[
      \(TraditionalForm\`f[n, W\&_] = 
        n + r\[VeryThinSpace]n \((1 - n\/K)\)\)]],
  " should be avoided,because in discrete time, it can lead to negative \
population sizes."
}], "Text"],

Cell[TextData[{
  StyleBox["Note: ",
    FontWeight->"Bold"],
  " In ",
  ButtonBox["MigrateExact",
    ButtonData:>{"Recursions: migration", "DemeSize"},
    ButtonStyle->"AddOnsLink"],
  ", m denotes the fraction of the population that migrates: it is the \
forward migration rate.  The deme size after migration is ",
  Cell[BoxData[
      \(TraditionalForm\`\(n\^*\) m + n \((1 - m)\), \ 
      and\ the\ proportion\ of\ immigrants\ is\ \(\(n\^*\) m\)\/\(\(n\^*\) m \
+ n \((1 - m)\)\)\)]],
  "; this increases as deme size, n, decreases.  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The life cycle", "SubsubsectionIcon",
  CellTags->"Life cycle"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(\(\ \)\(IterateExact[\[Psi], W, m, 
              MigrationOrder \[Rule] 
                UMS]\)\), \(represents\ the\ default\ order\ of\ events\ \
random\ union \[Rule] \(migration \[Rule] \(selection \[Rule] 
                  meiosis . \ \ \n
                      Regulation\ of\ population\ size\ always\ occurs\ \
immediately\ after\ \(\(selection\)\(.\)\)\)\)\)},
          {\(\(\ \)\(IterateExact[\[Psi], W, m, 
              MigrationOrder \[Rule] 
                MUS]\)\), \(\(represents\ migration\)\(\[Rule]\)\(random\ \
union \[Rule] \(selection \[Rule] \(\(meiosis\)\(.\)\)\)\)\(\ \)\)},
          {\(\(\ \)\(IterateExact[\[Psi], W, m, 
              MigrationOrder \[Rule] 
                USM]\)\), \(represents\ random\ union \[Rule] \(selection \
\[Rule] \(migration \[Rule] \(\(meiosis\)\(.\)\)\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}],

Cell["\<\
The default order of events in the life cycle is MigrationOrder\
\[Rule]UMS, representing random union of gametes\[Rule]diploid migration\
\[Rule]selection\[Rule]meiosis.  For a single deme with immigration from a \
population \[Psi]s, this is implemented by:\
\>", "Text"],

Cell[BoxData[
    \(NewGametes[
      MigrateExact[MakeDiploid[HaploidFrequencies[\[Psi], nd]], 
        MakeDiploid[\[Psi]s], m], W, opts]\)], "Input"],

Cell["\<\
In this example, there are 3 loci with 10% selection aaginst '1' \
alleles, balanced by immigration of m=0.05:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ppUMS = 
        Nest[IterateExact[#, 0.9\^Plus @@ \((#1 + #2)\) &, 0.05] &, 
          MakePopulation[3, 0], 100];\)\), "\[IndentingNewLine]", 
    \({AlleleFrequencyMean[ppUMS], DisequilibriumMean[ppUMS]}\)}], "Input",
  CellLabel->"In[49]:=  (15:30:27 on 4/25/01)"],

Cell[BoxData[
    \({0.23842150867099912`, 0.0316317554401611`}\)], "Output",
  CellLabel->"Out[50]=  (15:30:30 on 4/25/01)"]
}, Closed]],

Cell["\<\
MigrationOrder\[Rule]MUS represents haploid migration\[Rule]random \
union of gametes\[Rule]selection\[Rule]meiosis.  For a single deme with \
immigration from a population fixed for '1' alleles, this is implemented \
by:\
\>", "Text"],

Cell[BoxData[
    \(\(\(\ \ \)\(NewGametes[
      MakeDiploid[MigrateExact[HaploidFrequencies[\[Psi], nd], \[Psi]s, m]], 
      W, opts]\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ppMUS = 
        Nest[IterateExact[#, 0.9\^Plus @@ \((#1 + #2)\) &, 0.05, 
              MigrationOrder \[Rule] MUS] &, MakePopulation[3, 0], 
          100];\)\), "\[IndentingNewLine]", 
    \({AlleleFrequencyMean[ppMUS], DisequilibriumMean[ppMUS]}\)}], "Input",
  CellLabel->"In[51]:=  (15:31:58 on 4/25/01)"],

Cell[BoxData[
    \({0.3658278205113203`, 0.015429956791798219`}\)], "Output",
  CellLabel->"Out[52]=  (15:32:05 on 4/25/01)"]
}, Closed]],

Cell["\<\
With strong selection (s=10% on each of 3 loci), this leads to a \
substantially higher equilibrium frequency than \
MigrationOrder\[Rule]UMS.\
\>", "Text"],

Cell["\<\
MigrationOrder\[Rule]USM represents random union of \
gametes\[Rule]selection\[Rule]diploid migration\[Rule]meiosis.  For a single \
deme with immigration from a population fixed for '1' alleles, this is \
implemented by:\
\>", "Text"],

Cell[BoxData[
    \(MigrateExact[
      NewGametes[MakeDiploid[HaploidFrequencies[\[Psi], nd]], W, 
        opts], \[Psi]s, m]\)], "Input"],

Cell["\<\
Note that this really implements random union of \
gametes\[Rule]selection\[Rule]meiosis\[Rule]haploid migration.  However, the \
two are equivalent, since migration is a linear process.  With strong \
selection (s=10% on each of 3 loci), this leads to a slightly higher \
equilibrium frequency than MigrationOrder\[Rule]MUS, and much stronger \
disequilibrium.  This is because the final step was migration, rather than \
selection:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ppUSM = 
        Nest[IterateExact[#, 0.9\^Plus @@ \((#1 + #2)\) &, 0.05, 
              MigrationOrder \[Rule] USM] &, MakePopulation[3, 0], 
          100];\)\), "\[IndentingNewLine]", 
    \({AlleleFrequencyMean[ppUSM], DisequilibriumMean[ppUSM]}\)}], "Input",
  CellLabel->"In[55]:=  (15:34:09 on 4/25/01)"],

Cell[BoxData[
    \({0.39749432198123946`, 0.03376608301096519`}\)], "Output",
  CellLabel->"Out[56]=  (15:34:11 on 4/25/01)"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Random drift", "SubsubsectionIcon",
  CellTags->"Random drift"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, m, 
              RandomDrift -> True]\), \(allows\ for\ random\ drift\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->"IterateExact"],

Cell["\<\
This simulates 100 replicates of a population of 100 individuals, \
evolving over one generation, with no selection or immigration:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p0 = {0.1, 0.2, 0.3};\)\), "\n", 
    \(\(tt = 
        Table[IterateExact[MakePopulation[3, p0, 100], 1 &, 0, 
            RandomDrift -> True], {100}];\)\), "\n", 
    \(\(pt = AlleleFrequencyTable /@ tt;\)\), "\n", 
    \({p0, Mean[pt], \(p0 \((1 - p0)\)\)\/100, Variance[pt]} // 
      MatrixForm\)}], "Input",
  CellLabel->"In[17]:=  (19:55:25 on 4/28/01)"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.1`", "0.2`", "0.3`"},
            {"0.10399999999999998`", "0.20079999999999998`", "0.2955`"},
            {"0.0009000000000000002`", "0.0016`", "0.0021`"},
            {"0.0008505050505050509`", "0.001625616161616163`", 
              "0.002037121212121212`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[29]//MatrixForm=  (19:56:38 on 4/28/01)"]
}, Closed]],

Cell[TextData[{
  "The option RandomDrift->True is passed to ",
  Cell[BoxData[
      FormBox[
        ButtonBox["NewGametes",
          ButtonData:>{"Recursions: reproduction", "RandomDrift"},
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  ", and ensures that haploid gametes are sampled from a multinomial \
distribution, immediately after selection and population regulation.  Other \
options, such as Compiled->True, and MigrationOrder->MUS, can be used with \
RandomDrift->True."
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{901, 692},
WindowMargins->{{2, Automatic}, {Automatic, 2}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "IterateExact"->{
    Cell[2066, 64, 991, 21, 70, "DefinitionBox",
      CellTags->{"IterateExact", "StoreExact"}],
    Cell[28238, 873, 524, 10, 56, "DefinitionBox",
      CellTags->{"IterateExact", "FixedEnds"}],
    Cell[83712, 2650, 284, 6, 37, "DefinitionBox",
      CellTags->"IterateExact"]},
  "StoreExact"->{
    Cell[2066, 64, 991, 21, 70, "DefinitionBox",
      CellTags->{"IterateExact", "StoreExact"}]},
  "Immigration"->{
    Cell[28154, 870, 81, 1, 20, "SubsubsectionIcon",
      CellTags->"Immigration"]},
  "FixedEnds"->{
    Cell[28238, 873, 524, 10, 56, "DefinitionBox",
      CellTags->{"IterateExact", "FixedEnds"}]},
  "Immigration example"->{
    Cell[46287, 1433, 628, 14, 73, "Text",
      CellTags->"Immigration example"]},
  "DemeSize"->{
    Cell[47592, 1471, 845, 16, 108, "DefinitionBox",
      CellTags->{"DemeSize", "ExponentialF", "PowerF"}]},
  "ExponentialF"->{
    Cell[47592, 1471, 845, 16, 108, "DefinitionBox",
      CellTags->{"DemeSize", "ExponentialF", "PowerF"}]},
  "PowerF"->{
    Cell[47592, 1471, 845, 16, 108, "DefinitionBox",
      CellTags->{"DemeSize", "ExponentialF", "PowerF"}]},
  "Life cycle"->{
    Cell[79077, 2520, 69, 1, 20, "SubsubsectionIcon",
      CellTags->"Life cycle"]},
  "MigrationOrder"->{
    Cell[79149, 2523, 990, 18, 90, "DefinitionBox",
      CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}]},
  "UMS"->{
    Cell[79149, 2523, 990, 18, 90, "DefinitionBox",
      CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}]},
  "MUS"->{
    Cell[79149, 2523, 990, 18, 90, "DefinitionBox",
      CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}]},
  "USM"->{
    Cell[79149, 2523, 990, 18, 90, "DefinitionBox",
      CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}]},
  "Random drift"->{
    Cell[83640, 2647, 69, 1, 20, "SubsubsectionIcon",
      CellTags->"Random drift"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"IterateExact", 156913, 5269},
  {"StoreExact", 157213, 5276},
  {"Immigration", 157331, 5279},
  {"FixedEnds", 157434, 5282},
  {"Immigration example", 157561, 5285},
  {"DemeSize", 157661, 5288},
  {"ExponentialF", 157792, 5291},
  {"PowerF", 157917, 5294},
  {"Life cycle", 158046, 5297},
  {"MigrationOrder", 158154, 5300},
  {"UMS", 158276, 5303},
  {"MUS", 158398, 5306},
  {"USM", 158520, 5309},
  {"Random drift", 158651, 5312}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 44, 0, 36, "SubsectionIcon"],
Cell[1786, 53, 82, 1, 28, "MathCaption"],
Cell[1871, 56, 125, 2, 39, "Input"],

Cell[CellGroupData[{
Cell[2021, 62, 42, 0, 24, "SubsubsectionIcon"],
Cell[2066, 64, 991, 21, 70, "DefinitionBox",
  CellTags->{"IterateExact", "StoreExact"}],
Cell[3060, 87, 123, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3208, 94, 464, 10, 84, "Input"],
Cell[3675, 106, 19217, 639, 184, 8558, 503, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[22907, 748, 98, 3, 28, "MathCaption"],
Cell[23008, 753, 142, 3, 39, "Input"],

Cell[CellGroupData[{
Cell[23175, 760, 87, 2, 39, "Input"],
Cell[23265, 764, 98, 2, 20, "Print"],
Cell[23366, 768, 4489, 86, 345, "Print"]
}, Closed]],
Cell[27870, 857, 102, 3, 18, "Text"],
Cell[27975, 862, 142, 3, 22, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[28154, 870, 81, 1, 20, "SubsubsectionIcon",
  CellTags->"Immigration"],
Cell[28238, 873, 524, 10, 56, "DefinitionBox",
  CellTags->{"IterateExact", "FixedEnds"}],
Cell[28765, 885, 205, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[28995, 893, 667, 12, 99, "Input"],
Cell[29665, 907, 14317, 447, 184, 4638, 323, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[44019, 1359, 118, 2, 35, "Input"],
Cell[44140, 1363, 174, 3, 32, "Output"]
}, Closed]],
Cell[44329, 1369, 167, 4, 18, "Text"],
Cell[44499, 1375, 554, 14, 40, "Text"],
Cell[45056, 1391, 76, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[45157, 1395, 261, 5, 39, "Input"],
Cell[45421, 1402, 238, 4, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[45696, 1411, 118, 2, 35, "Input"],
Cell[45817, 1415, 180, 4, 50, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[46034, 1424, 129, 2, 35, "Input"],
Cell[46166, 1428, 106, 2, 32, "Output"]
}, Closed]],
Cell[46287, 1433, 628, 14, 73, "Text",
  CellTags->"Immigration example"],
Cell[46918, 1449, 588, 15, 36, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[47543, 1469, 46, 0, 20, "SubsubsectionIcon"],
Cell[47592, 1471, 845, 16, 108, "DefinitionBox",
  CellTags->{"DemeSize", "ExponentialF", "PowerF"}],
Cell[48440, 1489, 142, 3, 28, "MathCaption"],
Cell[48585, 1494, 389, 7, 70, "Input"],
Cell[48977, 1503, 67, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[49069, 1507, 968, 20, 129, "Input"],
Cell[50040, 1529, 26451, 907, 169, 9464, 693, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[76506, 2439, 430, 11, 32, "Text"],
Cell[76939, 2452, 608, 16, 64, "Text"],
Cell[77550, 2470, 464, 12, 38, "Text"],
Cell[78017, 2484, 209, 6, 23, "Text"],
Cell[78229, 2492, 251, 7, 34, "Text"],
Cell[78483, 2501, 557, 14, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[79077, 2520, 69, 1, 20, "SubsubsectionIcon",
  CellTags->"Life cycle"],
Cell[79149, 2523, 990, 18, 90, "DefinitionBox",
  CellTags->{"MigrationOrder", "UMS", "MUS", "USM"}],
Cell[80142, 2543, 283, 5, 36, "Text"],
Cell[80428, 2550, 152, 3, 27, "Input"],
Cell[80583, 2555, 141, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[80749, 2562, 291, 5, 55, "Input"],
Cell[81043, 2569, 125, 2, 20, "Output"]
}, Closed]],
Cell[81183, 2574, 245, 5, 32, "Text"],
Cell[81431, 2581, 153, 3, 27, "Input"],

Cell[CellGroupData[{
Cell[81609, 2588, 334, 6, 55, "Input"],
Cell[81946, 2596, 126, 2, 20, "Output"]
}, Closed]],
Cell[82087, 2601, 166, 4, 18, "Text"],
Cell[82256, 2607, 245, 5, 36, "Text"],
Cell[82504, 2614, 139, 3, 27, "Input"],
Cell[82646, 2619, 457, 8, 50, "Text"],

Cell[CellGroupData[{
Cell[83128, 2631, 334, 6, 55, "Input"],
Cell[83465, 2639, 126, 2, 20, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[83640, 2647, 69, 1, 20, "SubsubsectionIcon",
  CellTags->"Random drift"],
Cell[83712, 2650, 284, 6, 37, "DefinitionBox",
  CellTags->"IterateExact"],
Cell[83999, 2658, 164, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[84188, 2666, 385, 8, 98, "Input"],
Cell[84576, 2676, 479, 10, 79, "Output"]
}, Closed]],
Cell[85070, 2689, 509, 11, 32, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

