(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     70027,       1654]*)
(*NotebookOutlinePosition[    142028,       4246]*)
(*  CellTagsIndexPosition[    141856,       4237]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Iterating a cline", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["A simple example", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, 
              m]\), \(iterates\ a\ cline; \ \ \[Psi]\ represents\ a\ list\ of\
\ haploid\ \(\(populations\)\(.\)\)\)},
          {
            RowBox[{"StoreExact", "[", 
              RowBox[{"\[Psi]", ",", \(\[Psi]\_0\), ",", "W", ",", "m", ",", 
                RowBox[{"{", 
                  RowBox[{"t", ",", 
                    StyleBox["dt",
                      FontSlant->"Italic"]}], 
                  StyleBox["}",
                    FontSlant->"Italic"]}]}], 
              "]"}], \(stores\ results\ at\ intervals\ dt\ in\ \[Psi][t], \ 
            starting\ with\ \[Psi][
                  0] = \[Psi]\_0 . \ \ Options\ are\ passed\ directly\ to\ \(\
\(IterateExact[]\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->{"IterateExact", "StoreExact"}],

Cell["\<\
This shows a cline at three loci, maintained by 10% selection \
against heterozygotes.  Clines are plotted every 10 generations:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(hp[ng_] := MakeCline[10, ng, 100];\)\), "\n", 
    \(\(\(\(w[s_]\)[_]\)[x_, 
          y_] := \((1 - s)\)\^CountHeterozygotes[x, y];\)\), "\n", 
    \(\(StoreExact[cline[3, 0.2], hp[3], w[0.2], 0.5, {30, 10}];\)\), "\n", 
    \(\(DisplayTogether @@ 
        Table[ListPlot[AlleleFrequencyMean[\(cline[3, 0.2]\)[t]], 
            PlotJoined -> True], {t, 0, 30, 10}];\)\)}], "Input",
  CellLabel->"In[32]:=  (10:42:46 on 4/27/01)"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.588604 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.11905 .01472 m
.21429 .01472 L
.30952 .01472 L
.40476 .01472 L
.5 .01472 L
.59524 .60332 L
.69048 .60332 L
.78571 .60332 L
.88095 .60332 L
.97619 .60332 L
s
.11905 .01679 m
.21429 .02118 L
.30952 .03681 L
.40476 .08664 L
.5 .21517 L
.59524 .40286 L
.69048 .53139 L
.78571 .58122 L
.88095 .59685 L
.97619 .60125 L
s
.11905 .01976 m
.21429 .02558 L
.30952 .04401 L
.40476 .09654 L
.5 .22099 L
.59524 .39704 L
.69048 .5215 L
.78571 .57402 L
.88095 .59245 L
.97619 .59827 L
s
.11905 .02058 m
.21429 .02663 L
.30952 .04551 L
.40476 .09844 L
.5 .22207 L
.59524 .39596 L
.69048 .5196 L
.78571 .57252 L
.88095 .5914 L
.97619 .59745 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[32]:=  (10:43:07 on 4/27/01)",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool5
000aOol3000_Ool3000aOol3000^Ool30004Ool20004Ool004Moo`04001oogoo000bOol00`00Oomo
o`0]Ool01@00Oomoogoo0000;goo00D007ooOomoo`0002ioo`03001oogoo009oo`04001oogoo0003
Ool004Qoo`03001oogoo02moo`D002ioo`05001oogooOol0000_Ool01@00Oomoogoo0000;Woo00<0
07ooOol00Woo00@007ooOol000=oo`00BGoo00<007ooOol0;Woo00@007ooOol002moo`@0035oo`<0
02moo`03001oogoo009oo`04001oogoo0003Ool004Ioo`05001oogooOol0000`Ool00`00Ool0000_
Ool00`00Oomoo`0aOol01@00Oomoogoo0000;Woo00<007ooOol00Woo00@007ooOol000=oo`00AWoo
00D007ooOomoo`00035oo`80031oo`03001oogoo031oo`05001oogooOol0000]Ool20004Ool01000
Oomoo`000goo0017Ool3000cOol00`00Oomoo`0_Ool2000aOol3000_Ool00`00Oomoo`03Ool20004
Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9
Ool001Eoo`03001oogoo0?moo`Uoo`003gooo`004@000Goo000EOol00`00Oomoo`0:Ool00`00Oomo
o`0:Ool>000<Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool001Eoo`03001oogoo01Mooah0031oo`03
001oogoo01Ioo`03001oogoo01Moo`03001oogoo035oo`03001oogoo035oo`03001oogoo00Eoo`00
5Goo00<007ooOol09Goo5`00@Woo00<007ooOol0Qgoo000EOol00`00Oomoo`0eOol50002Ool6000m
Ool00`00Oomoo`26Ool001Eoo`03001oogoo03Yoo`D000=oo`L003Ioo`03001oogoo08Ioo`005Goo
00<007ooOol0?goo1@001Goo1000<Woo00<007ooOol0QWoo000EOol00`00Oomoo`14Ool50004Ool2
000`Ool00`00Oomoo`26Ool001Eoo`8004Yoo`@0009oo`8002ioo`03001oogoo08Ioo`005Goo00<0
07ooOol0CGoo0P000Woo0P00;7oo00<007ooOol0QWoo000EOol00`00Oomoo`1?Ool20002Ool00`00
Oomoo`0ZOol00`00Oomoo`25Ool001Eoo`03001oogoo051oo`<00003Ool0000002Yoo`03001oogoo
08Eoo`005Goo00<007ooOol0DWoo0P000Woo0P00:7oo00<007ooOol0QGoo000EOol00`00Oomoo`1D
Ool20002Ool2000VOol00`00Oomoo`25Ool001Eoo`03001oogoo05Ioo`80009oo`8002Aoo`03001o
ogoo08Eoo`005Goo00<007ooOol0Egoo0`000Woo0P008Woo00<007ooOol0QGoo000EOol2001JOol3
0002Ool2000QOol00`00Oomoo`24Ool001Eoo`03001oogoo05]oo`<0009oo`03001oogoo01ioo`03
001oogoo08Aoo`005Goo00<007ooOol0G7oo100000=oo`0000007Woo00<007ooOol0Q7oo000EOol0
0`00Oomoo`1NOol30002Ool2000LOol00`00Oomoo`24Ool001Eoo`03001oogoo061oo`<0009oo`03
001oogoo01Uoo`03001oogoo08Aoo`005Goo00<007ooOol0HWoo10006goo00<007ooOol0Q7oo000E
Ool00`00Oomoo`1SOol4000JOol00`00Oomoo`24Ool001Eoo`03001oogoo06Eoo`03001oo`0001Yo
o`03001oogoo08=oo`005Goo0P00IWoo0P0000=oo`00Ool067oo00<007ooOol0Pgoo000EOol00`00
Oomoo`1VOol3000IOol00`00Oomoo`23Ool001Eoo`03001oogoo06Moo`<001Qoo`03001oogoo08=o
o`005Goo00<007ooOol0J7oo00<007oo00005goo00<007ooOol0Pgoo000EOol00`00Oomoo`1XOol2
00000goo001oo`0EOol00`00Oomoo`23Ool0009oo`8000Aoo`04001oogooOol50004Ool00`00Oomo
o`1YOol3000GOol00`00Oomoo`22Ool00005Ool007ooOol00008Ool01000Oomoo`0017oo00<007oo
Ool0JWoo0`005Woo00<007ooOol0PWoo00001Goo001oogoo00002Goo00<007ooOol017oo00<007oo
Ool0Jgoo00<007oo00005Goo00<007ooOol0PWoo00001Goo001oogoo00002Woo00<007ooOol00goo
0`00Jgoo0`005Goo00<007ooOol0PWoo00001Goo001oogoo00001goo00D007ooOomoo`0000Aoo`03
001oogoo06aoo`<001Aoo`03001oogoo089oo`0000Eoo`00Oomoo`0000Moo`05001oogooOol00004
Ool00`00Oomoo`1]Ool00`00Ool0000COol00`00Oomoo`22Ool0009oo`8000Uoo`<000Eoo`03001o
ogoo06ioo`03001oo`0001=oo`03001oogoo085oo`005Goo00<007ooOol0KWoo0`004goo00<007oo
Ool0PGoo000EOol00`00Oomoo`1_Ool3000BOol00`00Oomoo`21Ool001Eoo`03001oogoo071oo`03
001oo`00015oo`03001oogoo085oo`005Goo00<007ooOol0LGoo00<007oo000047oo00<007ooOol0
PGoo000EOol2001cOol2000@Ool00`00Oomoo`21Ool001Eoo`03001oogoo079oo`<0011oo`03001o
ogoo081oo`005Goo00<007ooOol0Lgoo00<007oo00003goo00<007ooOol0P7oo000EOol00`00Oomo
o`1dOol00`00Ool0000>Ool00`00Oomoo`20Ool001Eoo`03001oogoo07Eoo`8000ioo`03001oogoo
081oo`005Goo00<007ooOol0MGoo0`003Goo00<007ooOol0P7oo000EOol00`00Oomoo`1fOol00`00
Ool0000<Ool00`00Oomoo`20Ool001Eoo`03001oogoo07Moo`8000eoo`03001oogoo07moo`005Goo
0P00NGoo0P0037oo00<007ooOol0Ogoo000EOol00`00Oomoo`1hOol00`00Ool0000;Ool00`00Oomo
o`1oOol001Eoo`03001oogoo07Uoo`03001oo`0000Yoo`03001oogoo07moo`005Goo00<007ooOol0
NWoo0P002Woo00<007ooOol0Ogoo000EOol00`00Oomoo`1kOol20009Ool00`00Oomoo`1oOol001Eo
o`03001oogoo07]oo`03001oo`0000Uoo`03001oogoo07ioo`005Goo00<007ooOol0O7oo00<007oo
000027oo00<007ooOol0OWoo000EOol00`00Oomoo`1mOol20008Ool00`00Oomoo`1nOol001Eoo`80
07moo`8000Moo`03001oogoo07ioo`005Goo00<007ooOol0OWoo0P001goo00<007ooOol0OWoo000E
Ool00`00Oomoo`1oOol20006Ool00`00Oomoo`1nOol001Eoo`03001oogoo07moo`8000Moo`03001o
ogoo07eoo`005Goo00<007ooOol0P7oo0P001Woo00<007ooOol0OGoo0002Ool20004Ool00`00Oomo
o`03Ool30004Ool00`00Oomoo`20Ool20006Ool00`00Oomoo`1mOol00005Ool007ooOol0000:Ool0
0`00Oomoo`03Ool00`00Oomoo`21Ool20005Ool00`00Oomoo`1mOol00005Ool007ooOol00007Ool5
0004Ool00`00Oomoo`22Ool00`00Oomoo`03Ool00`00Oomoo`1mOol00005Ool007ooOol00007Ool0
1000Oomoo`001Goo0`00PWoo0P0017oo00<007ooOol0OGoo00001Goo001oogoo000027oo00<007oo
00001Goo00<007ooOol0Pgoo00<007ooOol00Woo00<007ooOol0OGoo00001Goo001oogoo00002Goo
0P001Goo00<007ooOol0Pgoo0P0017oo00<007ooOol0O7oo0002Ool2000;Ool00`00Oomoo`03Ool0
0`00Oomoo`24Ool00`00Oomoo`02Ool00`00Oomoo`1lOol001Eoo`03001oogoo08Aoo`8000=oo`03
001oogoo07aoo`005Goo00<007ooOol0QGoo00D007ooOomoo`0007ioo`005Goo00<007ooOol0QGoo
0P000Woo00<007ooOol0O7oo000EOol00`00Oomoo`26Ool01000Oomoo`00OWoo000EOol20027Ool2
0002Ool00`00Oomoo`1kOol001Eoo`03001oogoo08Moo`04001oogoo001mOol001Eoo`03001oogoo
08Moo`800003Ool007oo07aoo`005Goo00<007ooOol0R7oo00<007oo0000OGoo000EOol00`00Oomo
o`29Ool2001mOol001Eoo`03001oogoo08Uoo`8007eoo`005Goo00<007ooOol0RWoo0P00O7oo000E
Ool00`00Oomoo`2:Ool2001lOol001Eoo`8008aoo`03001oogoo07Yoo`005Goo00<007ooOol0Rgoo
0P00Ngoo000EOol00`00Oomoo`2;Ool2001kOol001Eoo`03001oogoo08]oo`<007Yoo`005Goo00<0
07ooOol0S7oo0P00NWoo000EOol00`00Oomoo`2<Ool3001iOol001Eoo`03001oogoo08aoo`03001o
o`0007Uoo`005Goo00<007ooOol0S7oo00@007ooOol007Qoo`005Goo0P00SGoo00@007ooOol007Qo
o`005Goo00<007ooOol0S7oo00D007ooOomoo`0007Moo`005Goo00<007ooOol0SGoo00@007ooOol0
07Moo`005Goo00<007ooOol0SGoo00D007ooOomoo`0007Ioo`005Goo00<007ooOol0SGoo00D007oo
Oomoo`0007Ioo`000Woo0P0017oo00<007ooOol00Woo0`001Goo00<007ooOol0SGoo00<007ooOol0
0Woo00<007ooOol0Lgoo00001Goo001oogoo00001goo00D007ooOomoo`0000Aoo`03001oogoo08eo
o`03001oogoo009oo`03001oogoo07=oo`0000Eoo`00Oomoo`0000Moo`05001oogooOol00004Ool0
0`00Oomoo`2=Ool00`00Oomoo`03Ool00`00Oomoo`1bOol00005Ool007ooOol00007Ool40005Ool3
002>Ool00`00Oomoo`02Ool00`00Oomoo`1bOol00005Ool007ooOol00007Ool00`00Oomoo`06Ool0
0`00Oomoo`2>Ool00`00Oomoo`03Ool00`00Oomoo`1aOol00005Ool007ooOol00008Ool00`00Oomo
o`05Ool00`00Oomoo`2>Ool00`00Oomoo`03Ool00`00Oomoo`1aOol0009oo`8000Yoo`8000Eoo`03
001oogoo08ioo`03001oogoo00Aoo`03001oogoo071oo`005Goo00<007ooOol0SWoo00<007ooOol0
17oo0P00LGoo000EOol00`00Oomoo`2>Ool00`00Oomoo`05Ool00`00Oomoo`1_Ool001Eoo`03001o
ogoo08ioo`03001oogoo00Eoo`80071oo`005Goo00<007ooOol0Sgoo00<007ooOol01Goo00<007oo
Ool0KWoo000EOol2002@Ool00`00Oomoo`05Ool2001_Ool001Eoo`03001oogoo08moo`03001oogoo
00Ioo`03001oogoo06eoo`005Goo00<007ooOol0Sgoo00<007ooOol01Woo0P00KWoo000EOol00`00
Oomoo`2?Ool00`00Oomoo`07Ool2001]Ool001Eoo`03001oogoo08moo`03001oogoo00Qoo`8006ao
o`005Goo00<007ooOol0T7oo00<007ooOol027oo0P00Jgoo000EOol00`00Oomoo`2@Ool00`00Oomo
o`08Ool2001[Ool001Eoo`03001oogoo091oo`03001oogoo00Uoo`8006Yoo`005Goo0P00TGoo00<0
07ooOol02Woo0P00JGoo000EOol00`00Oomoo`2@Ool00`00Oomoo`0;Ool2001XOol001Eoo`03001o
ogoo091oo`03001oogoo00]oo`8006Qoo`005Goo00<007ooOol0TGoo00<007ooOol02goo0P00Igoo
000EOol00`00Oomoo`2AOol00`00Oomoo`0<Ool2001VOol001Eoo`03001oogoo095oo`03001oogoo
00eoo`8006Eoo`005Goo00<007ooOol0TGoo00<007ooOol03Goo0`00I7oo000EOol00`00Oomoo`2A
Ool00`00Oomoo`0>Ool2001TOol001Eoo`80099oo`03001oogoo00moo`8006=oo`005Goo00<007oo
Ool0TWoo00<007ooOol03goo0P00HWoo000EOol00`00Oomoo`2BOol00`00Oomoo`0?Ool3001QOol0
01Eoo`03001oogoo099oo`03001oogoo011oo`<0061oo`005Goo00<007ooOol0TWoo00<007ooOol0
4Goo0P00H7oo0002Ool20004Ool00`00Oomoo`02Ool30005Ool00`00Oomoo`2BOol00`00Oomoo`0A
Ool00`00Ool0001OOol00005Ool007ooOol00007Ool01@00Oomoogoo000017oo00<007ooOol0TWoo
00<007ooOol04Woo0`00GWoo00001Goo001oogoo00001goo00D007ooOomoo`0000Aoo`03001oogoo
09=oo`03001oogoo019oo`<005eoo`0000Eoo`00Oomoo`0000Qoo`<000Eoo`<009=oo`03001oogoo
01=oo`<005aoo`0000Eoo`00Oomoo`0000Moo`05001oogooOol00004Ool00`00Oomoo`2COol00`00
Oomoo`0COol00`00Ool0001LOol00005Ool007ooOol00007Ool01@00Oomoogoo000017oo00<007oo
Ool0Tgoo00<007ooOol057oo00<007oo0000Fgoo0002Ool20009Ool30005Ool00`00Oomoo`2COol0
0`00Oomoo`0EOol3001JOol001Eoo`03001oogoo09=oo`03001oogoo01Ioo`<005Uoo`005Goo00<0
07ooOol0U7oo00<007ooOol05Goo00<007oo0000FGoo000EOol00`00Oomoo`2DOol00`00Oomoo`0F
Ool00`00Ool0001HOol001Eoo`03001oogoo09Aoo`03001oogoo01Moo`<005Moo`005Goo0P00UGoo
00<007ooOol067oo0`00EWoo000EOol00`00Oomoo`2DOol00`00Oomoo`0HOol00`00Ool00002001D
Ool001Eoo`03001oogoo09Aoo`03001oogoo01Uoo`03001oo`0000<0059oo`005Goo00<007ooOol0
UGoo00<007ooOol06Goo00<007ooOol00`00DGoo000EOol00`00Oomoo`2EOol00`00Oomoo`0JOol2
0002Ool3001?Ool001Eoo`03001oogoo09Eoo`03001oogoo01aoo`80009oo`<004eoo`005Goo00<0
07ooOol0UGoo00<007ooOol07Woo0P000Woo0`00Bgoo000EOol00`00Oomoo`2EOol00`00Oomoo`0P
Ool2000017oo00000000BWoo000EOol2002FOol00`00Oomoo`0ROol00`00Oomoo`030018Ool001Eo
o`03001oogoo09Eoo`03001oogoo02=oo`80009oo`<004Ioo`005Goo00<007ooOol0UWoo00<007oo
Ool097oo0P000Woo0P00AGoo000EOol00`00Oomoo`2FOol00`00Oomoo`0VOol20002Ool20013Ool0
01Eoo`03001oogoo09Ioo`03001oogoo02Qoo`80009oo`80045oo`005Goo00<007ooOol0UWoo00<0
07ooOol0:Woo0P000Woo0P00?goo000EOol00`00Oomoo`2FOol00`00Oomoo`0/Ool200000goo0000
000nOol001Eoo`03001oogoo09Ioo`03001oogoo02ioo`03001oogoo008003aoo`005Goo0P00V7oo
00<007ooOol0;Woo0P000Woo1000>7oo000EOol00`00Oomoo`2GOol00`00Oomoo`0`Ool20004Ool5
000cOol001Eoo`03001oogoo09Moo`03001oogoo039oo`@000Eoo`D002ioo`005Goo00<007ooOol0
Ugoo00<007ooOol0=Woo1`000goo1@00:Goo000EOol00`00Oomoo`2GOol00`00Oomoo`0mOol60002
Ool5000TOol000eoo`<000Eoo`03001oogoo09Moo`03001oogoo04=ooaL001Aoo`003Woo00<007oo
Ool017oo00<007ooOol0V7oo00<007ooOol0BGoo7@001goo000>Ool00`00Oomoo`04Ool00`00Oomo
o`2HOol00`00Oomoo`1IOol=0007Ool000ioo`03001oogoo00Aoo`<009QoofT000Moo`003Woo00<0
07ooOol017oo00<007ooOol0ogoo2Goo000=Ool20006Ool00`00Oomoo`3oOol9Ool000ioo`03001o
ogoo00Aoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.829852, -0.07747, \
0.0386179, 0.00624851}}]
}, Open  ]],

Cell["\<\
This compares cline widths as the number of loci increases from 1 \
to 5:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Do[Print[ng]; 
        StoreExact[cline[ng, 0.2], hp[ng], w[0.2], 0.5, {20, 10}], {ng, 
          5}];\)\), "\n", 
    \(\(DisplayTogether @@ 
        MapThread[\[IndentingNewLine]ListPlot[
              AlleleFrequencyMean[\(cline[#1, 0.2]\)[20]], 
              PlotJoined -> True, PlotStyle -> #2] &, {{1, 2, 3, 4, 5}, {Red, 
              Orange, Green, Blue, Black}}];\)\)}], "Input",
  CellLabel->"In[88]:=  (6:50:42 on 4/25/01)"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.591 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .13292 -18 -4.5 ]
[.01131 .13292 0 4.5 ]
[.01131 .25112 -18 -4.5 ]
[.01131 .25112 0 4.5 ]
[.01131 .36932 -18 -4.5 ]
[.01131 .36932 0 4.5 ]
[.01131 .48751 -18 -4.5 ]
[.01131 .48751 0 4.5 ]
[.01131 .60571 -6 -4.5 ]
[.01131 .60571 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13292 m
.03006 .13292 L
s
[(0.2)] .01131 .13292 1 0 Mshowa
.02381 .25112 m
.03006 .25112 L
s
[(0.4)] .01131 .25112 1 0 Mshowa
.02381 .36932 m
.03006 .36932 L
s
[(0.6)] .01131 .36932 1 0 Mshowa
.02381 .48751 m
.03006 .48751 L
s
[(0.8)] .01131 .48751 1 0 Mshowa
.02381 .60571 m
.03006 .60571 L
s
[(1)] .01131 .60571 1 0 Mshowa
.125 Mabswid
.02381 .04427 m
.02756 .04427 L
s
.02381 .07382 m
.02756 .07382 L
s
.02381 .10337 m
.02756 .10337 L
s
.02381 .16247 m
.02756 .16247 L
s
.02381 .19202 m
.02756 .19202 L
s
.02381 .22157 m
.02756 .22157 L
s
.02381 .28067 m
.02756 .28067 L
s
.02381 .31022 m
.02756 .31022 L
s
.02381 .33977 m
.02756 .33977 L
s
.02381 .39886 m
.02756 .39886 L
s
.02381 .42841 m
.02756 .42841 L
s
.02381 .45796 m
.02756 .45796 L
s
.02381 .51706 m
.02756 .51706 L
s
.02381 .54661 m
.02756 .54661 L
s
.02381 .57616 m
.02756 .57616 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.11905 .02469 m
.21429 .03528 L
.30952 .0649 L
.40476 .13006 L
.5 .24205 L
.59524 .37838 L
.69048 .49037 L
.78571 .55553 L
.88095 .58515 L
.97619 .59574 L
s
1 .5 0 r
.11905 .0219 m
.21429 .02989 L
.30952 .05382 L
.40476 .11361 L
.5 .23267 L
.59524 .38776 L
.69048 .50682 L
.78571 .56661 L
.88095 .59054 L
.97619 .59853 L
s
0 1 0 r
.11905 .01978 m
.21429 .02563 L
.30952 .04413 L
.40476 .09687 L
.5 .22183 L
.59524 .3986 L
.69048 .52356 L
.78571 .5763 L
.88095 .5948 L
.97619 .60065 L
s
0 0 1 r
.11905 .01823 m
.21429 .02237 L
.30952 .03609 L
.40476 .08087 L
.5 .21006 L
.59524 .41037 L
.69048 .53956 L
.78571 .58434 L
.88095 .59806 L
.97619 .6022 L
s
0 0 0 r
.11905 .01711 m
.21429 .01997 L
.30952 .02979 L
.40476 .06669 L
.5 .19839 L
.59524 .42204 L
.69048 .55374 L
.78571 .59064 L
.88095 .60047 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[89]:=  (7:04:26 on 4/25/01)",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0016Ool5
000aOol3000_Ool3000aOol3000]Ool30004Ool20005Ool004Moo`04001oogoo000bOol00`00Oomo
o`0]Ool01@00Oomoogoo0000;goo00D007ooOomoo`0002eoo`03001oogoo009oo`04001oogoo0004
Ool004Qoo`03001oogoo02moo`D002ioo`05001oogooOol0000_Ool01@00Oomoogoo0000;Goo00<0
07ooOol00Woo00@007ooOol000Aoo`00BGoo00<007ooOol0;Woo00@007ooOol002moo`@0035oo`<0
02ioo`03001oogoo009oo`04001oogoo0004Ool004Ioo`05001oogooOol0000`Ool00`00Ool0000_
Ool00`00Oomoo`0aOol01@00Oomoogoo0000;Goo00<007ooOol00Woo00@007ooOol000Aoo`00AWoo
00D007ooOomoo`00035oo`80031oo`03001oogoo031oo`05001oogooOol0000/Ool20004Ool01000
Oomoo`0017oo0017Ool3000cOol00`00Oomoo`0_Ool2000aOol3000^Ool00`00Oomoo`03Ool20005
Ool001Ioo`03001oogoo0?moo`Qoo`005Woo00<007ooOol0ogoo27oo000FOol00`00Oomoo`3oOol8
Ool001Ioo`03001oogoo0?moo`Qoo`003gooo`004@000Goo000FOol00`00Oomoo`09Ool00`00Oomo
o`0:OolO0008Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`09Ool00`00Oomoo`06Ool001Ioo`03001oogoo01Ioo`Qmh0H3h1007`03Ool0000000L0
02Ioo`03001oogoo031oo`03001oogoo035oo`03001oogoo031oo`03001oogoo00Ioo`005Woo00<0
07ooOol05Woo1G`00goo3GgP2@?P1`0O0goo2@00`7oo000FOol00`00Oomoo`0KOol9O007Ool8ON00
0goo0n03h0030n02Ool601l6Ool5002kOol001Ioo`03001oogoo02Aoo`Ul00Ioo`Amh09oo`D3h0=o
o`L07`Aoo`<00;Qoo`005Woo00<007ooOol0;Goo1W`017oo0ggP17oo1@?P1Goo100O0goo0`00]Goo
000FOol00`00Oomoo`0cOol3O004Ool4ON05Ool50n04Ool201l4Ool2002cOol001Ioo`8003Moo`=l
00Eoo`Amh0Ioo`@3h09oo`807`Aoo`<00;1oo`005Woo00<007ooOol0>Goo0g`01Woo0ggP1goo0P?P
0Woo0`0O17oo0P00[Woo000FOol00`00Oomoo`0lOol4O005Ool4ON05Ool20n03Ool201l4Ool3002[
Ool001Ioo`03001oogoo041oo`=l00Ioo`=mh0Aoo`83h0=oo`807`Eoo`<00:Qoo`005Woo00<007oo
Ool0@goo0g`01Woo00=mh7ooOol00goo00<3h7ooOol00Woo0P0O1Woo0P00YWoo000FOol00`00Oomo
o`16Ool3O004Ool2ON04Ool20n04Ool201l6Ool3002SOol001Ioo`03001oogoo04Uoo`=l00=oo`9m
h0Aoo`83h0Aoo`807`Moo`03001oogoo0:1oo`005Woo00<007ooOol0C7oo00=l07ooOol00Woo00=m
h7ooOol00goo0P?P17oo0`0O17oo00<007ooOol0X7oo000FOol2001>Ool2O003Ool2ON05Ool20n05
Ool201l3Ool00`00Oomoo`2OOol001Ioo`03001oogoo04moo`03O01oogoo009oo`9mh0Eoo`83h0Eo
o`807`9oo`03001oogoo09ioo`005Woo00<007ooOol0D7oo0W`017oo00=mh7ooOol017oo0P?P1Goo
00<07goo0000X7oo000FOol00`00Oomoo`1BOol00g`0Oomoo`02Ool2ON06Ool00`?POomoo`02Ool0
100OOomoo`00Wgoo000FOol00`00Oomoo`1COol2O004Ool00ggPOomoo`04Ool20n03Ool0100OOomo
o`00WWoo000FOol00`00Oomoo`1EOol00g`0Oomoo`02Ool2ON06Ool20n02Ool0100OOomoo`00WGoo
000FOol00`00Oomoo`1FOol2O004Ool2ON06Ool01P?POomoo`0OOol009eoo`005Woo00<007ooOol0
F7oo0W`017oo00=mh7ooOol00goo00@3h7ooOol07`9oo`03001oogoo09Yoo`005Woo0P00Fgoo00=l
07ooOol00Woo0WgP17oo00@3h7ooOol07`9oo`03001oogoo09Uoo`005Woo00<007ooOol0Fgoo0W`0
17oo0WgP0goo00H3h7ooOol07goo002KOol001Ioo`03001oogoo05eoo`03O01oogoo00=oo`07ON1o
ogooOol3h7oo01l00Woo00<007ooOol0V7oo000FOol00`00Oomoo`1NOol2O004Ool017gPOomoo`?P
0Woo00@07gooOol009Uoo`005Woo00<007ooOol0H7oo00El07ooOomooggP00=oo`060n1oogoo01mo
o`00VGoo0002Ool20004Ool01000Oomoogoo1@001Goo00<007ooOol0HGoo0W`00Woo00Emh7ooOomo
o`?P009oo`0301moo`0009Qoo`0000Eoo`00Oomoo`0000Qoo`04001oogoo0005Ool00`00Oomoo`1S
Ool017`0OomooggP0goo00<3h7oo01l00Woo00<007ooOol0UGoo00001Goo001oogoo00002Goo00<0
07ooOol01Goo00<007ooOol0I7oo00Al07ooOommh09oo`060n1oogoo01moo`00Ugoo00001Goo001o
ogoo00002Woo00<007ooOol017oo0P00IGoo00El07ooOomooggP009oo`060n1oogoo01moo`00UWoo
00001Goo001oogoo00001goo00D007ooOomoo`0000Eoo`03001oogoo06Eoo`04O01oogooON03Ool0
0`?POol07`02Ool00`00Oomoo`2COol00005Ool007ooOol00007Ool01@00Oomoogoo00001Goo00<0
07ooOol0IWoo00Al07ooOommh09oo`040n1oogoo01l2Ool00`00Oomoo`2BOol0009oo`8000Uoo`<0
00Ioo`03001oogoo06Moo`04O01oogooON02Ool01P?POomoo`0OOol009Aoo`005Woo00<007ooOol0
J7oo00Al07ooOommh09oo`060n1oogoo01moo`00Tgoo000FOol00`00Oomoo`1XOol017`0OomooggP
0goo00<3h7oo01l00Woo00<007ooOol0T7oo000FOol00`00Oomoo`1YOol017`0OomooggP0Woo00H3
h7ooOol07goo002BOol001Ioo`03001oogoo06Yoo`04O01oogooON02Ool01P?POomoo`0OOol0095o
o`005Woo0P00K7oo00Al07ooOommh09oo`030n1oo`0O009oo`03001oogoo08ioo`005Woo00<007oo
Ool0K7oo00Al07ooOommh09oo`050n1oo`0OOol0002@Ool001Ioo`03001oogoo06aoo`04O01oogoo
ON02Ool01P?POomoo`0OOol008moo`005Woo00<007ooOol0KGoo00Al07ooOommh09oo`060n1oogoo
01moo`00SWoo000FOol00`00Oomoo`1^Ool017`0OomooggP0Woo00D3h7oo01moo`0008ioo`005Woo
00<007ooOol0Kgoo00Al07ooOommh09oo`050n1oo`0OOol0002=Ool001Ioo`03001oogoo071oo`03
O01ooggP009oo`060n1oogoo01moo`00S7oo000FOol00`00Oomoo`1aOol00g`0Oommh002Ool00`?P
Ool07`02Ool00`00Oomoo`29Ool001Ioo`80079oo`04O01oogooON02Ool01@?POol07goo0000Rgoo
000FOol00`00Oomoo`1bOol01W`0OomooggPOol3h09oo`0301moo`0008Yoo`005Woo00<007ooOol0
Lgoo00Il07ooOommh7oo0n02Ool00`0OOol00029Ool001Ioo`03001oogoo07Aoo`03O01ooggP009o
o`050n1oo`0OOol00029Ool001Ioo`03001oogoo07Eoo`03O01ooggP009oo`050n1oo`0OOol00028
Ool001Ioo`03001oogoo07Eoo`06O01oogooON1oo`?P0Woo00<07`00Ool0Qgoo000FOol00`00Oomo
o`1fOol02W`0OomooggPOol3h7oo01moo`00Qgoo000FOol00`00Oomoo`1gOol00g`0Oommh002Ool0
10?POol07`00Qgoo000FOol2001iOol00g`0Oommh002Ool00`?P01l00027Ool001Ioo`03001oogoo
07Uoo`08O01ooggPOol3h7oo01l008Ioo`005Woo00<007ooOol0NGoo00Ql07ooOommh7oo0n007`00
QWoo000FOol00`00Oomoo`1jOol027`0OomooggP0n1oo`0O0025Ool001Ioo`03001oogoo07]oo`07
O01ooggPOol3h00O0000QGoo0002Ool20004Ool00`00Oomoo`03Ool30005Ool00`00Oomoo`1lOol0
1g`0Oommh0?POol07`0008Aoo`0000Eoo`00Oomoo`0000Yoo`03001oogoo00Aoo`03001oogoo07eo
o`06O01ooggP0n007`00Q7oo00001Goo001oogoo00001goo1@001Goo00<007ooOol0OGoo00Il07oo
ON1oo`?P0024Ool00005Ool007ooOol00007Ool01000Oomoo`001Woo0P00Ogoo00Il07ooON03h00O
0023Ool00005Ool007ooOol00008Ool00`00Ool00006Ool00`00Oomoo`1oOol01G`0ON1oo`?P0000
Pgoo00001Goo001oogoo00002Goo0P001Woo00<007ooOol0P7oo00El07gP0n007`00089oo`000Woo
0P002goo00<007ooOol017oo00<007ooOol0P7oo00El07ooON03h000089oo`005Woo00<007ooOol0
PGoo00El07gP0n007`00085oo`005Woo00<007ooOol0PWoo00Al07gP01l0085oo`005Woo00<007oo
Ool0PWoo00Al07oo0n00085oo`005Woo00<007ooOol0Pgoo00Al07gP01l0081oo`005Woo0P00QGoo
00=l00?P0000P7oo000FOol00`00Oomoo`25Ool00ggP01l0001oOol001Ioo`03001oogoo08Eoo`03
O003h00007moo`005Woo00<007ooOol0QWoo00=l000O0000OWoo000FOol00`00Oomoo`27Ool00ggP
001oo`1mOol001Ioo`03001oogoo08Moo`03O00007oo07eoo`005Woo00<007ooOol0R7oo00=mh000
Ool0O7oo000FOol00`00Oomoo`29Ool00`00Oomoo`1kOol001Ioo`8008]oo`03001oogoo07Yoo`00
5Woo00<007ooOol0RWoo00<007ooOol0NWoo000FOol00`00Oomoo`2;Ool00`00Oomoo`1iOol001Io
o`03001oogoo08]oo`03001mh7oo07Uoo`005Woo00<007ooOol0S7oo00<007`0Ool0N7oo000FOol0
0`00Oomoo`2<Ool00`00ON1oo`1hOol001Ioo`03001oogoo08aoo`0300007g`007Qoo`005Woo00<0
07ooOol0SGoo00<000?PO000Mgoo000FOol2002>Ool00`0001mmh01gOol001Ioo`03001oogoo08io
o`030003h7`007Ioo`005Woo00<007ooOol0SWoo00@0000OON1l07Eoo`005Woo00<007ooOol0Sgoo
00@000?PON1l07Aoo`005Woo00<007ooOol0Sgoo00@0000OON1l07Aoo`000Woo0P0017oo00<007oo
Ool00Woo0`001Woo00<007ooOol0Sgoo00D0000O0n1mh7`007=oo`0000Eoo`00Oomoo`0000Moo`05
001oogooOol00005Ool00`00Oomoo`2@Ool01@0001mmh7ooO000LWoo00001Goo001oogoo00001goo
00D007ooOomoo`0000Eoo`03001oogoo091oo`0500007`?PON1l001bOol00005Ool007ooOol00007
Ool40006Ool2002BOol01@000n1ooggPO000LGoo00001Goo001oogoo00001goo00<007ooOol01goo
00<007ooOol0TGoo00H0000O0n1mh7ooO01`Ool00005Ool007ooOol00008Ool00`00Oomoo`06Ool0
0`00Oomoo`2BOol01P000n1ooggPOoml06moo`000Woo0P002Woo0P001Woo00<007ooOol0TWoo00H0
000O0n1mh7ooO01_Ool001Ioo`03001oogoo099oo`0700007goo0n1mh7ooO000KWoo000FOol00`00
Oomoo`2COol01`0001l3h7ooON1oog`006eoo`005Woo00<007ooOol0Tgoo00D0000OOol3h7gP009o
o`03O01oogoo06Yoo`005Woo00<007ooOol0U7oo00D0000O0n1ooggP009oo`03O01oogoo06Uoo`00
5Woo0P00UGoo00H0000OOol3h7ooON02Ool00g`0Oomoo`1XOol001Ioo`03001oogoo09Eoo`030000
7`?P009oo`03ON1oog`006Yoo`005Woo00<007ooOol0UGoo00@0000OOol3h09oo`03ON1oog`006Uo
o`005Woo00<007ooOol0UGoo00L007oo01moo`?POommh002Ool00g`0Oomoo`1VOol001Ioo`03001o
ogoo09Ioo`0700007gooOol3h7ooON000Woo00=l07ooOol0IGoo000FOol00`00Oomoo`2FOol01@00
Ool07goo0n000Woo00Amh7ooOoml06Ioo`005Woo00<007ooOol0Ugoo00D007oo01moo`?P009oo`04
ON1oogooO01UOol001Ioo`03001oogoo09Moo`06001oogoo01moo`?P0Woo00=mh7ooO000IGoo000F
Ool2002IOol00`00Ool07`02Ool01P?POomooggPOoml06Aoo`005Woo00<007ooOol0VGoo00<007oo
01l00Woo00<3h7ooON000Woo00=l07ooOol0HGoo000FOol00`00Oomoo`2JOol01@00Ool07goo0n00
0Woo00Amh7ooOoml069oo`005Woo00<007ooOol0VWoo00H007ooOol07goo0n02Ool017gPOomoog`0
HGoo000FOol00`00Oomoo`2KOol00`00Ool07`02Ool010?POomooggP0Woo00=l07ooOol0GWoo000F
Ool00`00Oomoo`2LOol00`00Ool07`02Ool010?POomooggP0Woo00=l07ooOol0GGoo000FOol00`00
Oomoo`2LOol01P00Oomoo`0OOol3h09oo`04ON1oogooO01OOol001Ioo`03001oogoo09eoo`06001o
ogoo01moo`?P0Woo00Amh7ooOoml05ioo`005Woo0P00Wgoo00<007oo01l00Woo00@3h7ooOommh09o
o`03O01oogoo05]oo`005Woo00<007ooOol0Wgoo00<007oo01l00Woo00@3h7ooOommh09oo`03O01o
ogoo05Yoo`005Woo00<007ooOol0Wgoo00H007ooOol07goo0n03Ool017gPOomoog`0Fgoo000FOol0
0`00Oomoo`2POol01P00Oomoo`0OOol3h09oo`05ON1oogooOoml001JOol001Ioo`03001oogoo0:5o
o`03001oo`0O009oo`040n1oogooON02Ool00g`0Oomoo`1HOol0009oo`8000Aoo`03001oogoo009o
o`<000Ioo`03001oogoo0:5oo`04001oogoo01l2Ool010?POomooggP0Woo00=l07ooOol0Egoo0000
1Goo001oogoo00001goo00D007ooOomoo`0000Eoo`03001oogoo0:9oo`06001oogoo01moo`?P0goo
00Amh7ooOoml05Qoo`0000Eoo`00Oomoo`0000Moo`05001oogooOol00005Ool00`00Oomoo`2SOol0
0`00Ool07`02Ool01@?POomoogooON000Woo00=l07ooOol0EGoo00001Goo001oogoo000027oo0`00
1Woo0P00YGoo00<007oo01l00Woo00D3h7ooOomooggP009oo`03O01oogoo05Aoo`0000Eoo`00Oomo
o`0000Moo`05001oogooOol00005Ool00`00Oomoo`2TOol01000Oomoo`0O0Woo00@3h7ooOommh0=o
o`9l05Aoo`0000Eoo`00Oomoo`0000Moo`05001oogooOol00005Ool00`00Oomoo`2UOol01000Oomo
o`0O0Woo00@3h7ooOommh0Aoo`03O01oogoo055oo`000Woo0P002Goo0`001Woo00<007ooOol0YWoo
00<007oo01l00Woo00D3h7ooOomooggP00Aoo`9l055oo`005Woo00<007ooOol0Ygoo00<007oo01l0
0Woo00D3h7ooOomooggP00Eoo`03O01oogoo04ioo`005Woo00<007ooOol0Ygoo00@007ooOol07`9o
o`040n1oogooOol2ON04Ool2O01>Ool001Ioo`03001oogoo0:Qoo`04001oogoo01l2Ool00`?POomo
o`02Ool00ggPOomoo`03Ool00g`0Oomoo`1;Ool001Ioo`03001oogoo0:Uoo`03001oo`0O009oo`03
0n1oogoo00=oo`9mh0Aoo`9l04]oo`005Woo0P00ZWoo00@007ooOol07`9oo`030n1oogoo00Aoo`9m
h0Aoo`03O01oogoo04Qoo`005Woo00<007ooOol0ZWoo00@007ooOol07`9oo`030n1oogoo00Eoo`03
ON1oogoo009oo`9l04Qoo`005Woo00<007ooOol0Zgoo00@007ooOol07`9oo`83h0Ioo`9mh0Aoo`9l
04Ioo`005Woo00<007ooOol0[7oo00<007oo01l017oo0P?P1Woo0WgP17oo00=l07ooOol0@goo000F
Ool00`00Oomoo`2/Ool01000Oomoo`0O1Goo0P?P1Woo00=mh7ooOol00Woo0W`0@goo000FOol00`00
Oomoo`2]Ool01000Oomoo`0O1Woo0P?P1Goo0WgP17oo00=l07ooOol0@7oo000FOol00`00Oomoo`2^
Ool00`00Oomoo`0201l6Ool00`?POomoo`04Ool00ggPOomoo`02Ool2O010Ool001Ioo`03001oogoo
0:ioo`03001oogoo009oo`807`Eoo`83h0Eoo`9mh0Aoo`03O01oogoo03eoo`005Woo0P00/7oo00<0
07ooOol00goo0P0O1Goo0P?P1Goo0WgP0goo0W`0?Goo000FOol00`00Oomoo`2`Ool00`00Oomoo`04
Ool301l4Ool20n05Ool00ggPOomoo`02Ool00g`0Oomoo`0jOol001Ioo`03001oogoo0;5oo`8000Mo
o`807`Aoo`83h0Aoo`9mh0=oo`=l03Uoo`005Woo00<007ooOol0/goo0`001Woo0P0O17oo0P?P17oo
0WgP17oo0g`0=Woo000FOol00`00Oomoo`2fOol30005Ool201l4Ool20n04Ool00ggPOomoo`04Ool3
O00cOol001Ioo`03001oogoo0;Uoo`8000Eoo`807`Aoo`030n1oogoo009oo`=mh0Ioo`=l031oo`00
5Woo00<007ooOol0^goo0`0017oo0P0O0goo0P?P1Goo17gP1Goo17`0;7oo000FOol00`00Oomoo`2n
Ool20004Ool301l2Ool20n07Ool3ON06Ool3O00YOol001Ioo`800<5oo`<000Aoo`807`9oo`@3h0Io
o`Amh0Eoo`=l02Ioo`005Woo00<007ooOol0`goo0`000goo0P0O17oo1@?P1Goo17gP17oo0g`08goo
000FOol00`00Oomoo`36Ool20003Ool401l5Ool50n04Ool3ON04Ool6O00MOol001Ioo`03001oogoo
0<Qoo`<000Aoo`L07`=oo`D3h09oo`Amh0Ioo`Ul01Aoo`005Woo00<007ooOol0bgoo1@001Woo1P0O
0Woo1@?P00=ooggPON001WgP1goo27`037oo000=Ool30006Ool00`00Oomoo`3@Ool90003Ool701l9
0n0=ON02Ool4O008Ool000ioo`03001oogoo00Eoo`03001oogoo0=Uoo`T00003Ool07`0O00h07`H3
h0Imh0Qoo`003Woo00<007ooOol01Goo00<007ooOol0hWoo7@0027oo000>Ool00`00Oomoo`05Ool2
003oOol9Ool000ioo`03001oogoo00Eoo`03001oogoo0?moo`Qoo`003Goo0P001goo00<007ooOol0
ogoo27oo000>Ool00`00Oomoo`05Ool00`00Oomoo`3oOol8Ool00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.853268, -0.0773787, \
0.0387714, 0.00624792}}]
}, Open  ]],

Cell["\<\
Clines get steeper as the number of loci increases, because linkage \
disequilibrium between the clines makes selection more effective.\
\>", "Text"],

Cell[TextData[{
  "The function becomes much slower as the number of loci, n,  increases, \
because the number of diploid genotypes increases as ",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(2  n\)\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Compiling", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, m, 
              Compiled -> 
                True]\), \(compiles\ the\ \(\(recursions\)\(.\)\(\ \)\)\)},
          {
            RowBox[{"StoreExact", "[", 
              RowBox[{"\[Psi]", ",", \(\[Psi]\_0\), ",", "W", ",", "m", ",", 
                RowBox[{"{", 
                  RowBox[{"t", ",", 
                    StyleBox["dt",
                      FontSlant->"Italic"]}], 
                  StyleBox["}",
                    FontSlant->"Italic"]}], 
                StyleBox[",",
                  FontSlant->"Italic"], \(Compiled -> True\)}], 
              "]"}], \(stores\ calculations\ made\ using\ compiled\ \
\(\(code\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->"Compiled"],

Cell[TextData[{
  "Functions can be greatly speeded by ",
  ButtonBox["compiling",
    ButtonData:>{"Compile"},
    ButtonStyle->"RefGuideLink"],
  ".  This requires that only numbers, or rectangular arrays of numbers, are \
used internally.  However, an arbitrary fitness function can still be \
supplied.  This isused to calculate and store a table of fitnesses, which is \
then used by the compiled code. "
}], "Text"],

Cell["Other options can be set as for uncompiled code.", "Text"],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  "  Compilation cannot be used if fitnesses change in every generation.  The \
option ",
  ButtonBox["StoreResults",
    ButtonData:>{"Reproduction recursions", "StoreResults"},
    ButtonStyle->"AddOnsLink"],
  "->False should also be set, to prevent all the fitness tables being \
stored."
}], "Text"],

Cell[BoxData[{
    \(\(hp[ng_] := MakeCline[10, ng, 100];\)\), "\n", 
    \(\(\(\(w[s_]\)[_]\)[x_, 
          y_] := \((1 - s)\)\^CountHeterozygotes[x, y];\)\)}], "Input",
  CellLabel->"In[2]:=  (11:37:21 on 4/27/01)"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[Nest[IterateExact[#, w[0.2], 0.5] &, hp[3], 10]]\)], "Input",
  CellLabel->"In[36]:=  (10:44:01 on 4/27/01)"],

Cell[BoxData[
    \({3.4500000000000455`\ Second, {HaploidFrequencies[{0.9896481720037588`, 
            0.0033836411095531068`, 0.003383641109553107`, 
            0.00006582898171966885`, 0.003383641109553107`, 
            0.00006582898171966886`, 0.00006582898171966886`, 
            3.417722423400428`*^-6}, 100.`], 
        HaploidFrequencies[{0.9688971553793487`, 0.009776573532680818`, 
            0.00977657353268082`, 0.00056331737527227`, 
            0.009776573532680822`, 0.0005633173752722703`, 
            0.0005633173752722703`, 0.00008317189679187148`}, 100.`], 
        HaploidFrequencies[{0.9032379901784269`, 0.027531602880934213`, 
            0.027531602880934217`, 0.004158641911617931`, 
            0.027531602880934224`, 0.00415864191161793`, 
            0.00415864191161793`, 0.001691275443916697`}, 100.`], 
        HaploidFrequencies[{0.7405451521006794`, 0.05831547457913654`, 
            0.05831547457913655`, 0.020621243539227445`, 
            0.05831547457913656`, 0.020621243539227452`, 
            0.020621243539227452`, 0.022644693544228836`}, 100.`], 
        HaploidFrequencies[{0.44482457049094926`, 0.07892381047867539`, 
            0.07892381047867539`, 0.05676898686787304`, 0.0789238104786754`, 
            0.056768986867873045`, 0.056768986867873045`, 
            0.14809703746940556`}, 100.`], 
        HaploidFrequencies[{0.14809703746940564`, 0.05676898686787305`, 
            0.05676898686787306`, 0.07892381047867537`, 
            0.056768986867873066`, 0.07892381047867536`, 
            0.07892381047867536`, 0.4448245704909491`}, 100.`], 
        HaploidFrequencies[{0.022644693544228905`, 0.02062124353922747`, 
            0.02062124353922747`, 0.05831547457913655`, 0.02062124353922747`, 
            0.05831547457913655`, 0.05831547457913655`, 0.7405451521006791`}, 
          100.`], HaploidFrequencies[{0.001691275443916703`, 
            0.004158641911617936`, 0.004158641911617938`, 
            0.027531602880934244`, 0.004158641911617938`, 
            0.027531602880934244`, 0.02753160288093424`, 
            0.9032379901784268`}, 100.`], 
        HaploidFrequencies[{0.00008317189679187174`, 0.0005633173752722709`, 
            0.0005633173752722711`, 0.009776573532680827`, 
            0.0005633173752722711`, 0.009776573532680827`, 
            0.009776573532680827`, 0.968897155379349`}, 100.`], 
        HaploidFrequencies[{3.4177224234004327`*^-6, 0.00006582898171966889`, 
            0.00006582898171966889`, 0.0033836411095531063`, 
            0.00006582898171966889`, 0.0033836411095531063`, 
            0.0033836411095531063`, 0.9896481720037583`}, 
          100.`]}}\)], "Output",
  CellLabel->"Out[36]=  (10:44:04 on 4/27/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      Nest[IterateExact[#, w[0.2], 0.5, Compiled -> True] &, hp[3], 
        10]]\)], "Input",
  CellLabel->"In[5]:=  (11:37:51 on 4/27/01)"],

Cell[BoxData[
    \({0.23333333333332718`\ Second, \
{HaploidFrequencies[{0.9896481720037582`, 0.0033836411095531094`, 
            0.003383641109553108`, 0.00006582898171966894`, 
            0.003383641109553108`, 0.00006582898171966894`, 
            0.00006582898171966893`, 3.417722423400436`*^-6}, 100.`], 
        HaploidFrequencies[{0.968897155379349`, 0.009776573532680837`, 
            0.009776573532680835`, 0.0005633173752722718`, 
            0.009776573532680837`, 0.0005633173752722719`, 
            0.0005633173752722718`, 0.00008317189679187186`}, 100.`], 
        HaploidFrequencies[{0.9032379901784268`, 0.027531602880934272`, 
            0.027531602880934265`, 0.004158641911617937`, 
            0.027531602880934262`, 0.004158641911617937`, 
            0.004158641911617937`, 0.0016912754439167`}, 100.`], 
        HaploidFrequencies[{0.7405451521006792`, 0.05831547457913655`, 
            0.05831547457913655`, 0.020621243539227452`, 
            0.05831547457913655`, 0.020621243539227452`, 
            0.020621243539227452`, 0.022644693544228846`}, 100.`], 
        HaploidFrequencies[{0.44482457049094914`, 0.07892381047867539`, 
            0.07892381047867539`, 0.056768986867873045`, 
            0.07892381047867537`, 0.056768986867873045`, 
            0.056768986867873045`, 0.14809703746940558`}, 100.`], 
        HaploidFrequencies[{0.14809703746940556`, 0.05676898686787305`, 
            0.05676898686787305`, 0.07892381047867537`, 0.05676898686787303`, 
            0.07892381047867539`, 0.07892381047867539`, 0.4448245704909493`}, 
          100.`], HaploidFrequencies[{0.02264469354422885`, 
            0.020621243539227455`, 0.020621243539227455`, 
            0.058315474579136536`, 0.020621243539227452`, 
            0.058315474579136536`, 0.058315474579136536`, 
            0.7405451521006792`}, 100.`], 
        HaploidFrequencies[{0.0016912754439166976`, 0.0041586419116179316`, 
            0.0041586419116179316`, 0.027531602880934224`, 
            0.0041586419116179316`, 0.027531602880934234`, 
            0.027531602880934234`, 0.9032379901784268`}, 100.`], 
        HaploidFrequencies[{0.0000831718967918716`, 0.0005633173752722706`, 
            0.0005633173752722708`, 0.009776573532680827`, 
            0.0005633173752722706`, 0.009776573532680825`, 
            0.009776573532680827`, 0.968897155379349`}, 100.`], 
        HaploidFrequencies[{3.4177224234004285`*^-6, 0.00006582898171966885`, 
            0.00006582898171966885`, 0.003383641109553107`, 
            0.00006582898171966884`, 0.003383641109553107`, 
            0.003383641109553107`, 0.9896481720037583`}, 100.`]}}\)], "Output",\

  CellLabel->"Out[5]=  (11:37:51 on 4/27/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      Nest[IterateExact[#, w[0.2], 0.5, MigrationOrder -> MUS] &, hp[3], 
        10]]\)], "Input",
  CellLabel->"In[8]:=  (11:38:55 on 4/27/01)"],

Cell[BoxData[
    \({2.683333333333337`\ Second, {HaploidFrequencies[{0.988488768648842`, 
            0.0037926547827438887`, 0.003792654782743889`, 
            0.000044062029522818786`, 0.00379265478274389`, 
            0.00004406202952281878`, 0.00004406202952281878`, 
            1.0809143577869338`*^-6}, 100.`], 
        HaploidFrequencies[{0.964469872042419`, 0.011435430712425634`, 
            0.011435430712425636`, 0.000398793359308955`, 
            0.011435430712425636`, 0.000398793359308955`, 
            0.000398793359308955`, 0.000027455742377372006`}, 100.`], 
        HaploidFrequencies[{0.8873217322362366`, 0.03403861340891865`, 
            0.034038613408918665`, 0.0033157865549471506`, 
            0.034038613408918665`, 0.0033157865549471506`, 
            0.0033157865549471514`, 0.0006150678721659459`}, 100.`], 
        HaploidFrequencies[{0.6966778628071439`, 0.07767093386885837`, 
            0.07767093386885839`, 0.020087461863461477`, 
            0.07767093386885837`, 0.020087461863461477`, 
            0.020087461863461477`, 0.010046949995896814`}, 100.`], 
        HaploidFrequencies[{0.3695114440764019`, 0.10914667153957144`, 
            0.10914667153957149`, 0.07019792172927204`, 0.10914667153957147`, 
            0.07019792172927203`, 0.07019792172927204`, 
            0.09245477611706782`}, 100.`], 
        HaploidFrequencies[{0.0924547761170677`, 0.070197921729272`, 
            0.070197921729272`, 0.10914667153957147`, 0.070197921729272`, 
            0.10914667153957144`, 0.10914667153957143`, 0.3695114440764021`}, 
          100.`], HaploidFrequencies[{0.010046949995896802`, 
            0.02008746186346146`, 0.02008746186346146`, 0.07767093386885836`, 
            0.020087461863461463`, 0.07767093386885832`, 
            0.07767093386885832`, 0.6966778628071439`}, 100.`], 
        HaploidFrequencies[{0.0006150678721659457`, 0.003315786554947149`, 
            0.003315786554947149`, 0.034038613408918665`, 
            0.003315786554947148`, 0.03403861340891865`, 
            0.03403861340891865`, 0.8873217322362364`}, 100.`], 
        HaploidFrequencies[{0.000027455742377371982`, 
            0.00039879335930895465`, 0.00039879335930895465`, 
            0.011435430712425629`, 0.00039879335930895465`, 
            0.011435430712425629`, 0.011435430712425629`, 
            0.9644698720424189`}, 100.`], 
        HaploidFrequencies[{1.0809143577869328`*^-6, 
            0.000044062029522818746`, 0.00004406202952281875`, 
            0.0037926547827438874`, 0.000044062029522818746`, 
            0.0037926547827438874`, 0.0037926547827438865`, 
            0.988488768648842`}, 100.`]}}\)], "Output",
  CellLabel->"Out[8]=  (11:38:58 on 4/27/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      Nest[IterateExact[#, w[0.2], 0.5, Compiled -> True, 
            MigrationOrder -> MUS] &, hp[3], 10]]\)], "Input",
  CellLabel->"In[9]:=  (11:39:01 on 4/27/01)"],

Cell[BoxData[
    \({0.21666666666666856`\ Second, {HaploidFrequencies[{0.988488768648842`, 
            0.003792654782743888`, 0.003792654782743888`, 
            0.000044062029522818766`, 0.0037926547827438887`, 
            0.00004406202952281877`, 0.000044062029522818766`, 
            1.0809143577869334`*^-6}, 100.`], 
        HaploidFrequencies[{0.9644698720424187`, 0.011435430712425629`, 
            0.011435430712425629`, 0.00039879335930895476`, 
            0.011435430712425632`, 0.00039879335930895476`, 
            0.00039879335930895465`, 0.000027455742377371976`}, 100.`], 
        HaploidFrequencies[{0.8873217322362366`, 0.03403861340891865`, 
            0.034038613408918665`, 0.0033157865549471506`, 
            0.034038613408918665`, 0.0033157865549471506`, 
            0.00331578655494715`, 0.000615067872165946`}, 100.`], 
        HaploidFrequencies[{0.6966778628071438`, 0.07767093386885837`, 
            0.07767093386885837`, 0.02008746186346148`, 0.07767093386885837`, 
            0.020087461863461473`, 0.020087461863461484`, 
            0.010046949995896812`}, 100.`], 
        HaploidFrequencies[{0.36951144407640196`, 0.10914667153957142`, 
            0.10914667153957143`, 0.07019792172927199`, 0.10914667153957142`, 
            0.07019792172927197`, 0.070197921729272`, 0.09245477611706775`}, 
          100.`], HaploidFrequencies[{0.09245477611706773`, 
            0.07019792172927199`, 0.07019792172927199`, 0.10914667153957143`, 
            0.07019792172927201`, 0.10914667153957142`, 0.10914667153957144`, 
            0.3695114440764019`}, 100.`], 
        HaploidFrequencies[{0.010046949995896802`, 0.02008746186346146`, 
            0.02008746186346146`, 0.07767093386885834`, 0.02008746186346146`, 
            0.0776709338688583`, 0.0776709338688583`, 0.6966778628071439`}, 
          100.`], HaploidFrequencies[{0.0006150678721659454`, 
            0.0033157865549471475`, 0.0033157865549471475`, 
            0.03403861340891866`, 0.003315786554947147`, 
            0.03403861340891866`, 0.03403861340891866`, 0.8873217322362367`}, 
          100.`], HaploidFrequencies[{0.000027455742377371952`, 
            0.00039879335930895443`, 0.0003987933593089545`, 
            0.011435430712425625`, 0.0003987933593089543`, 
            0.011435430712425625`, 0.011435430712425625`, 
            0.9644698720424189`}, 100.`], 
        HaploidFrequencies[{1.0809143577869321`*^-6, 0.00004406202952281874`, 
            0.00004406202952281874`, 0.0037926547827438874`, 
            0.000044062029522818746`, 0.0037926547827438865`, 
            0.0037926547827438874`, 0.9884887686488422`}, 
          100.`]}}\)], "Output",
  CellLabel->"Out[9]=  (11:39:01 on 4/27/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      Nest[IterateExact[#, w[0.2], 0.5, MigrationOrder -> USM] &, hp[3], 
        10]]\)], "Input",
  CellLabel->"In[13]:=  (11:40:54 on 4/27/01)"],

Cell[BoxData[
    \({2.6666666666666856`\ Second, {HaploidFrequencies[{0.9857236344796863`, 
            0.004645614351092715`, 0.004645614351092716`, 
            0.00011097187195870596`, 0.004645614351092717`, 
            0.00011097187195870594`, 0.00011097187195870593`, 
            6.606851159108004`*^-6}, 100.`], 
        HaploidFrequencies[{0.9566067938234152`, 0.013476478765077767`, 
            0.013476478765077769`, 0.0009364588098653878`, 
            0.013476478765077769`, 0.0009364588098653878`, 
            0.0009364588098653878`, 0.00015439345175541274`}, 100.`], 
        HaploidFrequencies[{0.8678248073915444`, 0.03674326570656174`, 
            0.036743265706561744`, 0.0064025004658450095`, 
            0.036743265706561744`, 0.0064025004658450095`, 
            0.00640250046584501`, 0.002737894091235351`}, 100.`], 
        HaploidFrequencies[{0.6731255963658009`, 0.07189867741800018`, 
            0.0718986774180002`, 0.02759701975014905`, 0.07189867741800018`, 
            0.02759701975014905`, 0.02759701975014905`, 
            0.028387312129751336`}, 100.`], 
        HaploidFrequencies[{0.3896155218892273`, 0.08949189011186677`, 
            0.08949189011186678`, 0.06608589884438534`, 0.08949189011186676`, 
            0.06608589884438533`, 0.06608589884438533`, 
            0.14365111124201618`}, 100.`], 
        HaploidFrequencies[{0.14365111124201607`, 0.06608589884438533`, 
            0.06608589884438533`, 0.08949189011186678`, 0.06608589884438532`, 
            0.08949189011186677`, 0.08949189011186676`, 
            0.38961552188922755`}, 100.`], 
        HaploidFrequencies[{0.028387312129751312`, 0.02759701975014904`, 
            0.02759701975014904`, 0.0718986774180002`, 0.02759701975014904`, 
            0.07189867741800017`, 0.07189867741800017`, 0.6731255963658009`}, 
          100.`], HaploidFrequencies[{0.00273789409123535`, 
            0.006402500465845006`, 0.006402500465845007`, 
            0.03674326570656173`, 0.006402500465845005`, 
            0.036743265706561716`, 0.036743265706561716`, 
            0.8678248073915444`}, 100.`], 
        HaploidFrequencies[{0.00015439345175541258`, 0.0009364588098653868`, 
            0.0009364588098653868`, 0.013476478765077755`, 
            0.0009364588098653868`, 0.013476478765077755`, 
            0.013476478765077755`, 0.956606793823415`}, 100.`], 
        HaploidFrequencies[{6.606851159108`*^-6, 0.00011097187195870587`, 
            0.00011097187195870587`, 0.004645614351092716`, 
            0.00011097187195870587`, 0.004645614351092715`, 
            0.004645614351092714`, 0.9857236344796866`}, 100.`]}}\)], "Output",\

  CellLabel->"Out[13]=  (11:40:57 on 4/27/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      Nest[IterateExact[#, w[0.2], 0.5, Compiled -> True, 
            MigrationOrder -> USM] &, hp[3], 10]]\)], "Input",
  CellLabel->"In[85]:=  (13:33:36 on 4/27/01)"],

Cell[BoxData[
    \({0.21666666666624224`\ Second, \
{HaploidFrequencies[{0.9857236344796866`, 0.004645614351092716`, 
            0.004645614351092716`, 0.00011097187195870594`, 
            0.004645614351092717`, 0.00011097187195870594`, 
            0.00011097187195870594`, 6.606851159108004`*^-6}, 100.`], 
        HaploidFrequencies[{0.9566067938234152`, 0.013476478765077765`, 
            0.013476478765077765`, 0.0009364588098653876`, 
            0.013476478765077769`, 0.0009364588098653875`, 
            0.0009364588098653872`, 0.0001543934517554126`}, 100.`], 
        HaploidFrequencies[{0.8678248073915444`, 0.03674326570656174`, 
            0.036743265706561744`, 0.006402500465845011`, 
            0.036743265706561744`, 0.0064025004658450095`, 
            0.0064025004658450095`, 0.0027378940912353516`}, 100.`], 
        HaploidFrequencies[{0.6731255963658009`, 0.0718986774180002`, 
            0.0718986774180002`, 0.02759701975014905`, 0.0718986774180002`, 
            0.027597019750149047`, 0.027597019750149054`, 
            0.028387312129751336`}, 100.`], 
        HaploidFrequencies[{0.38961552188922755`, 0.08949189011186678`, 
            0.08949189011186678`, 0.06608589884438533`, 0.08949189011186678`, 
            0.06608589884438532`, 0.06608589884438536`, 
            0.14365111124201618`}, 100.`], 
        HaploidFrequencies[{0.14365111124201616`, 0.06608589884438533`, 
            0.06608589884438533`, 0.08949189011186677`, 0.06608589884438533`, 
            0.08949189011186676`, 0.08949189011186678`, 
            0.38961552188922755`}, 100.`], 
        HaploidFrequencies[{0.02838731212975132`, 0.027597019750149037`, 
            0.027597019750149037`, 0.07189867741800018`, 
            0.027597019750149037`, 0.07189867741800017`, 
            0.07189867741800017`, 0.673125596365801`}, 100.`], 
        HaploidFrequencies[{0.002737894091235349`, 0.0064025004658450025`, 
            0.006402500465845003`, 0.036743265706561716`, 
            0.0064025004658450025`, 0.036743265706561716`, 
            0.036743265706561716`, 0.8678248073915444`}, 100.`], 
        HaploidFrequencies[{0.00015439345175541236`, 0.0009364588098653865`, 
            0.0009364588098653865`, 0.013476478765077751`, 
            0.0009364588098653862`, 0.013476478765077751`, 
            0.013476478765077751`, 0.956606793823415`}, 100.`], 
        HaploidFrequencies[{6.606851159107994`*^-6, 0.00011097187195870585`, 
            0.00011097187195870585`, 0.004645614351092714`, 
            0.00011097187195870585`, 0.004645614351092713`, 
            0.004645614351092714`, 0.9857236344796866`}, 100.`]}}\)], "Output",\

  CellLabel->"Out[85]=  (13:33:36 on 4/27/01)"]
}, Closed]],

Cell["\<\
Note that the time taken to do the calculation includes a \
substantial overhead in calculating the fitness table; this is not compiled.  \
Discounting this overhead, there is an order of magnitude increase in speed \
on compiling.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Varying deme size", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            FormBox[\(DemeSize -> F\),
              
              "TraditionalForm"], \(sets\ deme\ size\ to\ \(F[deme]\)[n, 
                W\&_]\)},
          {
            RowBox[{
              FormBox[\(DemeSize -> \(n\^*\)\),
                "TraditionalForm"], 
              "&"}], \(fixes\ deme\ size\ at\ \(n\^*\), \ 
            a\ fixed\ \(\(number\)\(.\)\)\)},
          {\(DemeSize -> ExponentialF[r, \[Beta], \[Lambda]]\), 
            RowBox[{
              RowBox[{
              "sets", " ", "deme", " ", "size", " ", "to", " ", "r", " ", "n",
                 
                
                FormBox[\(\(\(\(W\&_\)\(\ \)\)\^\[Beta]\) \(\(Exp\)\([\)\(-\
\[Lambda]\)\)\),
                  "TraditionalForm"], "n"}], "]"}]},
          {\(DemeSize -> PowerF[r, \[Beta], \[Lambda]]\), 
            RowBox[{
            "sets", " ", "deme", " ", "size", " ", "to", " ", "r", 
              " ", \(n\^\(1 - \[Lambda]\)\), 
              FormBox[\(\(\(W\&_\)\(\ \)\)\^\[Beta]\),
                "TraditionalForm"]}]},
          {\(DemeSize -> {{r\_1, \[Beta]\_1, \[Gamma]\_1, \[Lambda]\_1}, \
\[Ellipsis]}\), 
            RowBox[{
            "sets", " ", "the", " ", "new", " ", "size", " ", "of", " ", 
              "deme", " ", "i", " ", "to", " ", \(r\_i\), 
              " ", \(n\_i\%\(1 - \[Lambda]\_i\)\), 
              FormBox[\(\(\(W\&_\_i\)\(\ \)\)\^\[Beta]\_i\),
                "TraditionalForm"], \(Exp[\(-\[Lambda]\_i\) n\_i]\)}]}
          }], TraditionalForm]],
  CellTags->{"DemeSize", "ExponentialF", "PowerF"}]], "DefinitionBox",
  CellTags->"DemeSize"],

Cell["\<\
DemeSize->F is a general form which allows deme size to change as a \
function of location, current numbers immediately before selection, and mean \
fitness.  \
\>", "Text"],

Cell[TextData[{
  "Compiled code can only be used with certain definite versions of DemeSize: \
arbitrary functions cannot be supplied.  The general form is  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"r", " ", \(n\^\(1 - \[Lambda]\)\), 
            
            FormBox[\(\(\(\(W\&_\)\(\ \)\)\^\[Beta]\) \(\(Exp\)\([\)\(-\
\[Lambda]\)\)\),
              "TraditionalForm"], "n"}], "]"}], TraditionalForm]]],
  " or ",
  Cell[BoxData[
      FormBox[
        RowBox[{"r", " ", \(n\^\(1 - \[Lambda]\)\), 
          FormBox[\(\(\(W\&_\)\(\ \)\)\^\[Beta]\),
            "TraditionalForm"]}], TraditionalForm]]],
  ".   If these functions are the same in every deme, they can be supplied in \
forms such asDemeSize\[Rule]ExponentialF[r, \[Beta], \[Lambda]]. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      Nest[IterateExact[#, w[0.2], 0.5, 
            DemeSize -> ExponentialF[2, 1, 0.01]] &, hp[3], 10]]\)], "Input",
  CellLabel->"In[88]:=  (13:37:54 on 4/27/01)"],

Cell[BoxData[
    \({3.399999999999636`\ Second, {HaploidFrequencies[{0.9920087261316621`, 
            0.0026211982427458173`, 0.0026211982427458173`, 
            0.00004192270172021305`, 0.0026211982427458156`, 
            0.00004192270172021305`, 0.00004192270172021305`, 
            1.9110349392991684`*^-6}, 68.85160501501773`], 
        HaploidFrequencies[{0.9770079377220887`, 0.007298343370847261`, 
            0.00729834337084726`, 0.00035016655240219604`, 
            0.00729834337084726`, 0.000350166552402196`, 
            0.000350166552402196`, 0.00004653250816328345`}, 
          67.9411940176384`], 
        HaploidFrequencies[{0.9288491271896019`, 0.0206561724900023`, 
            0.020656172490002303`, 0.0027134226317838935`, 
            0.020656172490002303`, 0.0027134226317838935`, 
            0.0027134226317838935`, 0.0010420874450393616`}, 
          64.99334363596282`], 
        HaploidFrequencies[{0.7965211612328101`, 0.046666492994263724`, 
            0.04666649299426373`, 0.015286416487316417`, 
            0.04666649299426373`, 0.015286416487316415`, 
            0.015286416487316419`, 0.017620110322449378`}, 
          58.176165514866476`], 
        HaploidFrequencies[{0.49776084082038796`, 0.06899552626608663`, 
            0.06899552626608664`, 0.0484681058473859`, 0.06899552626608664`, 
            0.04846810584738589`, 0.0484681058473859`, 0.14984826283919456`}, 
          50.15928199782554`], 
        HaploidFrequencies[{0.14984826283919436`, 0.04846810584738585`, 
            0.048468105847385874`, 0.06899552626608664`, 
            0.04846810584738585`, 0.06899552626608661`, 0.06899552626608661`, 
            0.4977608408203882`}, 50.15928199782555`], 
        HaploidFrequencies[{0.01762011032244934`, 0.015286416487316396`, 
            0.015286416487316396`, 0.04666649299426369`, 
            0.015286416487316394`, 0.04666649299426368`, 
            0.046666492994263675`, 0.7965211612328105`}, 58.17616551486652`], 
        HaploidFrequencies[{0.0010420874450393594`, 0.0027134226317838887`, 
            0.0027134226317838887`, 0.020656172490002275`, 
            0.0027134226317838887`, 0.020656172490002275`, 
            0.020656172490002275`, 0.9288491271896021`}, 64.99334363596289`], 
        HaploidFrequencies[{0.00004653250816328338`, 0.00035016655240219545`, 
            0.00035016655240219555`, 0.00729834337084725`, 
            0.00035016655240219555`, 0.00729834337084725`, 
            0.00729834337084725`, 0.9770079377220884`}, 67.94119401763845`], 
        HaploidFrequencies[{1.9110349392991655`*^-6, 0.00004192270172021302`, 
            0.00004192270172021302`, 0.002621198242745814`, 
            0.00004192270172021302`, 0.0026211982427458147`, 
            0.0026211982427458143`, 0.9920087261316626`}, 
          68.85160501501774`]}}\)], "Output",
  CellLabel->"Out[88]=  (13:37:57 on 4/27/01)"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      Nest[IterateExact[#, w[0.2], 0.5, DemeSize -> ExponentialF[2, 1, 0.01], 
            Compiled -> True] &, hp[3], 10]]\)], "Input",
  CellLabel->"In[89]:=  (13:37:58 on 4/27/01)"],

Cell[BoxData[
    \({0.25`\ Second, {HaploidFrequencies[{0.9920087261316625`, 
            0.0026211982427458143`, 0.0026211982427458143`, 
            0.000041922701720213033`, 0.0026211982427458143`, 
            0.00004192270172021302`, 0.00004192270172021302`, 
            1.911034939299167`*^-6}, 68.85160501501774`], 
        HaploidFrequencies[{0.9770079377220886`, 0.007298343370847249`, 
            0.00729834337084725`, 0.0003501665524021956`, 
            0.007298343370847252`, 0.0003501665524021955`, 
            0.0003501665524021956`, 0.000046532508163283406`}, 
          67.94119401763847`], 
        HaploidFrequencies[{0.9288491271896021`, 0.020656172490002286`, 
            0.02065617249000229`, 0.00271342263178389`, 
            0.020656172490002293`, 0.00271342263178389`, 
            0.002713422631783891`, 0.0010420874450393592`}, 
          64.99334363596289`], 
        HaploidFrequencies[{0.7965211612328104`, 0.046666492994263675`, 
            0.046666492994263675`, 0.01528641648731639`, 
            0.046666492994263675`, 0.01528641648731639`, 
            0.01528641648731639`, 0.017620110322449332`}, 
          58.17616551486653`], 
        HaploidFrequencies[{0.4977608408203879`, 0.0689955262660866`, 
            0.06899552626608658`, 0.048468105847385874`, 
            0.06899552626608661`, 0.048468105847385874`, 
            0.048468105847385874`, 0.14984826283919453`}, 
          50.159281997825545`], 
        HaploidFrequencies[{0.1498482628391944`, 0.04846810584738587`, 
            0.04846810584738587`, 0.06899552626608661`, 0.04846810584738587`, 
            0.06899552626608661`, 0.06899552626608661`, 
            0.49776084082038824`}, 50.15928199782555`], 
        HaploidFrequencies[{0.017620110322449346`, 0.0152864164873164`, 
            0.0152864164873164`, 0.046666492994263675`, 0.0152864164873164`, 
            0.04666649299426368`, 0.04666649299426368`, 0.7965211612328104`}, 
          58.17616551486652`], 
        HaploidFrequencies[{0.0010420874450393605`, 0.0027134226317838918`, 
            0.0027134226317838918`, 0.020656172490002286`, 
            0.0027134226317838918`, 0.020656172490002286`, 
            0.020656172490002286`, 0.9288491271896021`}, 64.99334363596286`], 
        HaploidFrequencies[{0.00004653250816328342`, 0.0003501665524021957`, 
            0.0003501665524021957`, 0.007298343370847255`, 
            0.0003501665524021957`, 0.007298343370847255`, 
            0.007298343370847255`, 0.9770079377220884`}, 67.94119401763845`], 
        HaploidFrequencies[{1.911034939299169`*^-6, 0.00004192270172021306`, 
            0.00004192270172021306`, 0.0026211982427458164`, 
            0.00004192270172021307`, 0.0026211982427458164`, 
            0.002621198242745816`, 0.9920087261316627`}, 
          68.85160501501775`]}}\)], "Output",
  CellLabel->"Out[89]=  (13:37:59 on 4/27/01)"]
}, Closed]],

Cell["\<\
In these examples, deme size is lower in the centre, where mean \
fitness is reduced.\
\>", "Text"],

Cell["\<\
 A list of parameters can be given; this allows for variation in \
population regulation across demes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tbl = Array[{2, 1, 0, 0.01} &, 10];\)\), "\n", 
    \(Timing[
      Nest[IterateExact[#, w[0.2], 0.5, DemeSize -> tbl, Compiled -> True] &, 
        hp[3], 10]]\)}], "Input",
  CellLabel->"In[99]:=  (13:42:34 on 4/27/01)"],

Cell[BoxData[
    \({9.283333333332848`\ Second, {HaploidFrequencies[{0.9920087261316625`, 
            0.0026211982427458143`, 0.0026211982427458143`, 
            0.000041922701720213033`, 0.0026211982427458143`, 
            0.00004192270172021302`, 0.00004192270172021302`, 
            1.911034939299167`*^-6}, 68.85160501501774`], 
        HaploidFrequencies[{0.9770079377220886`, 0.007298343370847249`, 
            0.00729834337084725`, 0.0003501665524021956`, 
            0.007298343370847252`, 0.0003501665524021955`, 
            0.0003501665524021956`, 0.000046532508163283406`}, 
          67.94119401763847`], 
        HaploidFrequencies[{0.9288491271896021`, 0.020656172490002286`, 
            0.02065617249000229`, 0.00271342263178389`, 
            0.020656172490002293`, 0.00271342263178389`, 
            0.002713422631783891`, 0.0010420874450393592`}, 
          64.99334363596289`], 
        HaploidFrequencies[{0.7965211612328104`, 0.046666492994263675`, 
            0.046666492994263675`, 0.01528641648731639`, 
            0.046666492994263675`, 0.01528641648731639`, 
            0.01528641648731639`, 0.017620110322449332`}, 
          58.17616551486653`], 
        HaploidFrequencies[{0.4977608408203879`, 0.0689955262660866`, 
            0.06899552626608658`, 0.048468105847385874`, 
            0.06899552626608661`, 0.048468105847385874`, 
            0.048468105847385874`, 0.14984826283919453`}, 
          50.159281997825545`], 
        HaploidFrequencies[{0.1498482628391944`, 0.04846810584738587`, 
            0.04846810584738587`, 0.06899552626608661`, 0.04846810584738587`, 
            0.06899552626608661`, 0.06899552626608661`, 
            0.49776084082038824`}, 50.15928199782555`], 
        HaploidFrequencies[{0.017620110322449346`, 0.0152864164873164`, 
            0.0152864164873164`, 0.046666492994263675`, 0.0152864164873164`, 
            0.04666649299426368`, 0.04666649299426368`, 0.7965211612328104`}, 
          58.17616551486652`], 
        HaploidFrequencies[{0.0010420874450393605`, 0.0027134226317838918`, 
            0.0027134226317838918`, 0.020656172490002286`, 
            0.0027134226317838918`, 0.020656172490002286`, 
            0.020656172490002286`, 0.9288491271896021`}, 64.99334363596286`], 
        HaploidFrequencies[{0.00004653250816328342`, 0.0003501665524021957`, 
            0.0003501665524021957`, 0.007298343370847255`, 
            0.0003501665524021957`, 0.007298343370847255`, 
            0.007298343370847255`, 0.9770079377220884`}, 67.94119401763845`], 
        HaploidFrequencies[{1.911034939299169`*^-6, 0.00004192270172021306`, 
            0.00004192270172021306`, 0.0026211982427458164`, 
            0.00004192270172021307`, 0.0026211982427458164`, 
            0.002621198242745816`, 0.9920087261316627`}, 
          68.85160501501775`]}}\)], "Output",
  CellLabel->"Out[100]=  (13:42:45 on 4/27/01)"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Random drift", "SubsubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(IterateExact[\[Psi], W, m, 
              RandomDrift -> True]\), \(allows\ for\ random\ drift\)}
          }], TraditionalForm]],
  CellTags->{"IterateExact", "StoreExact"}]], "DefinitionBox",
  CellTags->"IterateExact"],

Cell["\<\
This iterates 10 replicate clines of 10 demes, each over one \
generation; population size is 2N=100 per deme:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(p0 = {0.1, 0.2, 0.3}; \(w[_]\)[x_, y_] := 
      0.7\^CountHeterozygotes[x, y];\), "\n", 
    \(\(tt = 
        Table[IterateExact[MakeCline[10, 3, 100, 1], w, 0.5, 
            RandomDrift -> True, MigrationOrder -> USM], {10}];\)\), "\n", 
    \(\(pt = AlleleFrequencyTable /@ tt;\)\), "\n", 
    \({Table[
          Mean[pt\[LeftDoubleBracket]Range[10], d, 
              l\[RightDoubleBracket]], {l, 3}, {d, 10}] // MatrixForm, 
      Table[StandardDeviation[
            pt\[LeftDoubleBracket]Range[10], d, l\[RightDoubleBracket]], {l, 
            3}, {d, 10}] // MatrixForm}\)}], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0.02275`", "0.09675`", "0.20650000000000004`", "0.32725`", 
                  "0.45725000000000005`", "0.58575`", "0.6985`", "0.8045`", 
                  "0.9075`", "0.9782500000000003`"},
                {"0.02175`", "0.0925`", "0.19549999999999998`", "0.3165`", 
                  "0.43599999999999994`", "0.548`", "0.6825`", "0.80525`", 
                  "0.89975`", "0.97325`"},
                {"0.0235`", "0.09425`", "0.20275000000000004`", "0.324`", 
                  "0.43374999999999997`", "0.54775`", "0.6775`", "0.8035`", 
                  "0.9139999999999999`", "0.982`"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0.005458174297937606`", "0.0159447831942335`", 
                  "0.023634955280497385`", "0.025067963175690558`", 
                  "0.025588897331981032`", "0.0375841648097233`", 
                  "0.026331223544175327`", "0.024686928615047378`", 
                  "0.0265622957508487`", "0.009863653819283523`"},
                {"0.007075976571784592`", "0.015275252316519466`", 
                  "0.02488305983328148`", "0.031118054780678913`", 
                  "0.03204163957519443`", "0.031596413298558654`", 
                  "0.020412414523193177`", "0.021390872923853412`", 
                  "0.022835462187863278`", "0.00799739540934006`"},
                {"0.006368324391514266`", "0.02091816063721771`", 
                  "0.021520339216657337`", "0.017802933590968784`", 
                  "0.021513884405709307`", "0.03302881738388128`", 
                  "0.03454063629343785`", "0.021055482263138327`", 
                  "0.012974333637352365`", "0.004830458915396456`"}
                }], "\[NoBreak]", ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell[TextData[{
  "The option RandomDrift->True is passed to ",
  Cell[BoxData[
      FormBox[
        ButtonBox["NewGametes",
          ButtonData:>{"Recursions: reproduction", "RandomDrift"},
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  ", and ensures that haploid gametes are sampled from a multinomial \
distribution, immediately after selection and population regulation.  Other \
options, such as Compiled->True, and MigrationOrder->MUS, can be used with \
RandomDrift->True."
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{938, 674},
WindowMargins->{{23, Automatic}, {Automatic, 2}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "IterateExact"->{
    Cell[1855, 57, 925, 20, 56, "DefinitionBox",
      CellTags->{"IterateExact", "StoreExact"}],
    Cell[66388, 1571, 284, 6, 37, "DefinitionBox",
      CellTags->"IterateExact"]},
  "StoreExact"->{
    Cell[1855, 57, 925, 20, 56, "DefinitionBox",
      CellTags->{"IterateExact", "StoreExact"}]},
  "Compiled"->{
    Cell[34126, 929, 855, 20, 56, "DefinitionBox",
      CellTags->"Compiled"]},
  "DemeSize"->{
    Cell[53974, 1315, 1654, 38, 136, "DefinitionBox",
      CellTags->"DemeSize"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"IterateExact", 141334, 4219},
  {"StoreExact", 141535, 4224},
  {"Compiled", 141650, 4227},
  {"DemeSize", 141747, 4230}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 43, 0, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[1807, 55, 45, 0, 24, "SubsubsectionIcon"],
Cell[1855, 57, 925, 20, 56, "DefinitionBox",
  CellTags->{"IterateExact", "StoreExact"}],
Cell[2783, 79, 161, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2969, 87, 453, 8, 72, "Input"],
Cell[3425, 97, 13896, 377, 184, 3496, 244, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[17336, 477, 104, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[17465, 484, 459, 9, 57, "Input"],
Cell[17927, 495, 15721, 413, 184, 3696, 260, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[33663, 911, 159, 3, 22, "Text"],
Cell[33825, 916, 223, 6, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[34085, 927, 38, 0, 20, "SubsubsectionIcon"],
Cell[34126, 929, 855, 20, 56, "DefinitionBox",
  CellTags->"Compiled"],
Cell[34984, 951, 421, 9, 37, "Text"],
Cell[35408, 962, 64, 0, 22, "Text"],
Cell[35475, 964, 365, 10, 24, "Text"],
Cell[35843, 976, 218, 4, 56, "Input"],

Cell[CellGroupData[{
Cell[36086, 984, 136, 2, 38, "Input"],
Cell[36225, 988, 2722, 43, 142, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[38984, 1036, 169, 4, 34, "Input"],
Cell[39156, 1042, 2711, 43, 142, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[41904, 1090, 174, 4, 34, "Input"],
Cell[42081, 1096, 2724, 43, 142, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[44842, 1144, 196, 4, 34, "Input"],
Cell[45041, 1150, 2722, 42, 142, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[47800, 1197, 175, 4, 34, "Input"],
Cell[47978, 1203, 2702, 43, 142, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[50717, 1251, 197, 4, 34, "Input"],
Cell[50917, 1257, 2701, 43, 142, "Output"]
}, Closed]],
Cell[53633, 1303, 255, 5, 32, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[53925, 1313, 46, 0, 20, "SubsubsectionIcon"],
Cell[53974, 1315, 1654, 38, 136, "DefinitionBox",
  CellTags->"DemeSize"],
Cell[55631, 1355, 183, 4, 22, "Text"],
Cell[55817, 1361, 792, 19, 39, "Text"],

Cell[CellGroupData[{
Cell[56634, 1384, 194, 4, 38, "Input"],
Cell[56831, 1390, 2893, 46, 142, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[59761, 1441, 212, 4, 34, "Input"],
Cell[59976, 1447, 2886, 47, 142, "Output"]
}, Closed]],
Cell[62877, 1497, 109, 3, 18, "Text"],
Cell[62989, 1502, 133, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[63147, 1509, 245, 5, 54, "Input"],
Cell[63395, 1516, 2900, 47, 216, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[66344, 1569, 41, 0, 24, "SubsubsectionIcon"],
Cell[66388, 1571, 284, 6, 37, "DefinitionBox",
  CellTags->"IterateExact"],
Cell[66675, 1579, 141, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[66841, 1586, 641, 13, 92, "Input"],
Cell[67485, 1601, 1990, 35, 104, "Output"]
}, Open  ]],
Cell[69490, 1639, 509, 11, 36, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

