(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     17361,        414]*)
(*NotebookOutlinePosition[     18923,        465]*)
(*  CellTagsIndexPosition[     18726,        455]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Linkage", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(Linkage \[Rule] {r\_\(1, 2\), 
                r\_\(2, 3\), \[Ellipsis]}\), \(is\ an\ option\ for\ Gametes[]\
\ and\ GameteTable[]\ which\ specifies\ the\ recombination\ rates\ in\ each\ \
interval\)},
          {\(Linkage \[Rule] False\), \(gives\ unlinked\ loci\)}
          }], TraditionalForm]],
  CellTags->"Linkage"]], "DefinitionBox",
  CellTags->"Linkage"],

Cell["\<\
This option assumes no interference and a linear genetic map; \
otherwise, specifying the recombination rates amongst all sets of loci would \
become complicated.  This option can ONLY be used with HaploidFrequencies, \
DiploidFrequencies, HaploidIndividuals, or DiploidIndividuals.\
\>", "Text"],

Cell["It is assumed that there is no interference.", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(NetRecombination[{r\_\(1, 2\), 
                r\_\(2, 3\), \[Ellipsis]}]\), \(\(\ \)\(gives\ the\ net\ \
recombination\ rate\ across\ a\ linear\ genetic\ map\)\)}
          }], TraditionalForm]],
  CellTags->"NetRecombination"]], "DefinitionBox",
  CellTags->"NetRecombination"],

Cell["\<\
This function is used to determine the net recombination rate \
across a series of intervals, assuming no interference.  \
\>", "Text"],

Cell[TextData[{
  "This gives the recombination  ",
  Cell[BoxData[
      \(TraditionalForm\`r\_\(1, 3\)\)]],
  " between loci 1 and 3, where the recombination rates in the two component \
intervals are ",
  Cell[BoxData[
      \(TraditionalForm\`r\_\(1, 2\) = 0.1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`r\_\(2, 3\)\)]],
  "=0.2:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NetRecombination[{0.1, 0.2}]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(0.260000000000000008`\)], "Output",
  CellLabel->"Out[64]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(Gametes[Y, Z, 
              Linkage \[Rule] {r\_\(1, 2\), 
                  r\_\(2, 3\), \[Ellipsis]}]\), \(gives\ the\ full\ \
distribution\ of\ \(2\^\(\(n\)\(\ \ \)\)\) 
              offspring\ genotypes\ from\ the\ diploid\ parent\ {Y, \ Z}, \ 
            with\ linkage\ on\ a\ linear\ map\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"Gametes"],

Cell["\<\
With linkage between the heterozygous loci 1 & 2, there are fewer \
recombinant genptypes {0,0,0} and {1,1,0} than parental combinations {0,1,0} \
and {1,0,0}:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gametes[{1, 0, 0}, {0, 1, 0}, 
      Linkage \[Rule] {r\_\(1, 2\), r\_\(2, 3\)}]\)], "Input",
  CellLabel->"In[37]:=  (15:02:53 on 4/23/01)"],

Cell[BoxData[
    \({r\_\(1, 2\)\/2, 0, 1\/2\ \((1 - r\_\(1, 2\))\), 0, 
      1\/2\ \((1 - r\_\(1, 2\))\), 0, r\_\(1, 2\)\/2, 0}\)], "Output",
  CellLabel->"Out[37]=  (15:02:53 on 4/23/01)"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(GameteTable[n, 
              Linkage \[Rule] {r\_\(1, 2\), 
                  r\_\(2, 3\), \[Ellipsis]}]\), \(stores\ a\ matrix\ showing\ \
the\ distribution\ of\ genotypes\ among\ gametes, \ 
            for\ each\ diploid\ genotype, \ \(\(with\)\(\ \)\(linkage\)\(\ \)\
\(on\)\(\ \)\(a\)\(\ \)\(linear\)\(\ \)\(\(map\)\(.\)\)\(\ \)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"GameteTable"],

Cell["\<\
This array list the offspring distributions from all 8\[Times]8 \
diploid genotypes, with linkage:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GameteTable[3, Linkage \[Rule] {0.1, 0.2}]\)], "Input",
  CellLabel->"In[38]:=  (15:04:55 on 4/23/01)"],

Cell[BoxData[
    \({{{1, 0, 0, 0, 0, 0, 0, 0}, {1\/2, 1\/2, 0, 0, 0, 0, 0, 0}, {1\/2, 0, 
          1\/2, 0, 0, 0, 0, 0}, {0.4`, 0.10000000000000003`, 
          0.10000000000000003`, 0.4`, 0, 0, 0, 0}, {1\/2, 0, 0, 0, 1\/2, 0, 
          0, 0}, {0.37`, 0.13`, 0, 0, 0.13`, 0.37`, 0, 0}, {0.45`, 0, 
          0.04999999999999999`, 0, 0.04999999999999999`, 0, 0.45`, 
          0}, {0.36000000000000004`, 0.09000000000000004`, 
          0.010000000000000002`, 0.039999999999999994`, 
          0.039999999999999994`, 0.010000000000000002`, 0.09000000000000004`, 
          0.36000000000000004`}}, {{1\/2, 1\/2, 0, 0, 0, 0, 0, 0}, {0, 1, 0, 
          0, 0, 0, 0, 0}, {0.10000000000000003`, 0.4`, 0.4`, 
          0.10000000000000003`, 0, 0, 0, 0}, {0, 1\/2, 0, 1\/2, 0, 0, 0, 
          0}, {0.13`, 0.37`, 0, 0, 0.37`, 0.13`, 0, 0}, {0, 1\/2, 0, 0, 0, 
          1\/2, 0, 0}, {0.09000000000000004`, 0.36000000000000004`, 
          0.039999999999999994`, 0.010000000000000002`, 
          0.010000000000000002`, 0.039999999999999994`, 0.36000000000000004`, 
          0.09000000000000004`}, {0, 0.45`, 0, 0.04999999999999999`, 0, 
          0.04999999999999999`, 0, 0.45`}}, {{1\/2, 0, 1\/2, 0, 0, 0, 0, 
          0}, {0.10000000000000003`, 0.4`, 0.4`, 0.10000000000000003`, 0, 0, 
          0, 0}, {0, 0, 1, 0, 0, 0, 0, 0}, {0, 0, 1\/2, 1\/2, 0, 0, 0, 
          0}, {0.04999999999999999`, 0, 0.45`, 0, 0.45`, 0, 
          0.04999999999999999`, 0}, {0.010000000000000002`, 
          0.039999999999999994`, 0.36000000000000004`, 0.09000000000000004`, 
          0.09000000000000004`, 0.36000000000000004`, 0.039999999999999994`, 
          0.010000000000000002`}, {0, 0, 1\/2, 0, 0, 0, 1\/2, 0}, {0, 0, 
          0.37`, 0.13`, 0, 0, 0.13`, 0.37`}}, {{0.4`, 0.10000000000000003`, 
          0.10000000000000003`, 0.4`, 0, 0, 0, 0}, {0, 1\/2, 0, 1\/2, 0, 0, 
          0, 0}, {0, 0, 1\/2, 1\/2, 0, 0, 0, 0}, {0, 0, 0, 1, 0, 0, 0, 
          0}, {0.039999999999999994`, 0.010000000000000002`, 
          0.09000000000000004`, 0.36000000000000004`, 0.36000000000000004`, 
          0.09000000000000004`, 0.010000000000000002`, 
          0.039999999999999994`}, {0, 0.04999999999999999`, 0, 0.45`, 0, 
          0.45`, 0, 0.04999999999999999`}, {0, 0, 0.13`, 0.37`, 0, 0, 0.37`, 
          0.13`}, {0, 0, 0, 1\/2, 0, 0, 0, 1\/2}}, {{1\/2, 0, 0, 0, 1\/2, 0, 
          0, 0}, {0.13`, 0.37`, 0, 0, 0.37`, 0.13`, 0, 
          0}, {0.04999999999999999`, 0, 0.45`, 0, 0.45`, 0, 
          0.04999999999999999`, 0}, {0.039999999999999994`, 
          0.010000000000000002`, 0.09000000000000004`, 0.36000000000000004`, 
          0.36000000000000004`, 0.09000000000000004`, 0.010000000000000002`, 
          0.039999999999999994`}, {0, 0, 0, 0, 1, 0, 0, 0}, {0, 0, 0, 0, 
          1\/2, 1\/2, 0, 0}, {0, 0, 0, 0, 1\/2, 0, 1\/2, 0}, {0, 0, 0, 0, 
          0.4`, 0.10000000000000003`, 0.10000000000000003`, 0.4`}}, {{0.37`, 
          0.13`, 0, 0, 0.13`, 0.37`, 0, 0}, {0, 1\/2, 0, 0, 0, 1\/2, 0, 
          0}, {0.010000000000000002`, 0.039999999999999994`, 
          0.36000000000000004`, 0.09000000000000004`, 0.09000000000000004`, 
          0.36000000000000004`, 0.039999999999999994`, 
          0.010000000000000002`}, {0, 0.04999999999999999`, 0, 0.45`, 0, 
          0.45`, 0, 0.04999999999999999`}, {0, 0, 0, 0, 1\/2, 1\/2, 0, 
          0}, {0, 0, 0, 0, 0, 1, 0, 0}, {0, 0, 0, 0, 0.10000000000000003`, 
          0.4`, 0.4`, 0.10000000000000003`}, {0, 0, 0, 0, 0, 1\/2, 0, 
          1\/2}}, {{0.45`, 0, 0.04999999999999999`, 0, 0.04999999999999999`, 
          0, 0.45`, 0}, {0.09000000000000004`, 0.36000000000000004`, 
          0.039999999999999994`, 0.010000000000000002`, 
          0.010000000000000002`, 0.039999999999999994`, 0.36000000000000004`, 
          0.09000000000000004`}, {0, 0, 1\/2, 0, 0, 0, 1\/2, 0}, {0, 0, 
          0.13`, 0.37`, 0, 0, 0.37`, 0.13`}, {0, 0, 0, 0, 1\/2, 0, 1\/2, 
          0}, {0, 0, 0, 0, 0.10000000000000003`, 0.4`, 0.4`, 
          0.10000000000000003`}, {0, 0, 0, 0, 0, 0, 1, 0}, {0, 0, 0, 0, 0, 0, 
          1\/2, 1\/2}}, {{0.36000000000000004`, 0.09000000000000004`, 
          0.010000000000000002`, 0.039999999999999994`, 
          0.039999999999999994`, 0.010000000000000002`, 0.09000000000000004`, 
          0.36000000000000004`}, {0, 0.45`, 0, 0.04999999999999999`, 0, 
          0.04999999999999999`, 0, 0.45`}, {0, 0, 0.37`, 0.13`, 0, 0, 0.13`, 
          0.37`}, {0, 0, 0, 1\/2, 0, 0, 0, 1\/2}, {0, 0, 0, 0, 0.4`, 
          0.10000000000000003`, 0.10000000000000003`, 0.4`}, {0, 0, 0, 0, 0, 
          1\/2, 0, 1\/2}, {0, 0, 0, 0, 0, 0, 1\/2, 1\/2}, {0, 0, 0, 0, 0, 0, 
          0, 1}}}\)], "Output",
  CellLabel->"Out[38]=  (15:04:55 on 4/23/01)"]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(NewGametes[\[Phi], n, 
              Linkage \[Rule] {r\_\(1, 2\), 
                  r\_\(2, 3\), \[Ellipsis]}]\), \(gives\ the\ gametes\ \
produced\ by\ the\ diploid\ matrix\ \[Phi], 
            with\ linkage\ on\ a\ linear\ map; \ 
            n\ is\ the\ new\ deme\ \(\(size\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"NewGametes"],

Cell["\<\
\[Phi] is a diploid population in linkage equilibrium, with allele \
frequencies {0.1, 0.2, 0.3}.  This gives the distribution of gametic \
genotypes in the absence of selection, and with linkage:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Phi] = 
        MakePopulation[3, {0.1, 0.2, 0.3}, 
          NumericalModel -> DiploidFrequencies];\)\), "\n", 
    \(NewGametes[\[Phi], 10, Linkage \[Rule] {0.1, 0.2}]\)}], "Input",
  CellLabel->"In[42]:=  (15:06:55 on 4/23/01)"],

Cell[BoxData[
    \(HaploidFrequencies[{0.5040000000000001`, 0.21600000000000008`, 
        0.12600000000000006`, 0.05400000000000001`, 0.05599999999999997`, 
        0.02399999999999999`, 0.013999999999999995`, 0.005999999999999998`}, 
      10]\)], "Output",
  CellLabel->"Out[43]=  (15:06:55 on 4/23/01)"]
}, Open  ]],

Cell["\<\
This is the same as the distribution with no linkage, because the \
population was in linkage equilibrium:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NewGametes[\[Phi], 10]\)], "Input",
  CellLabel->"In[44]:=  (15:06:58 on 4/23/01)"],

Cell[BoxData[
    \(HaploidFrequencies[{0.504`, 0.21600000000000003`, 0.12600000000000006`, 
        0.054000000000000006`, 0.055999999999999966`, 0.023999999999999994`, 
        0.013999999999999995`, 0.0059999999999999975`}, 10]\)], "Output",
  CellLabel->"Out[44]=  (15:06:58 on 4/23/01)"]
}, Open  ]],

Cell["\<\
Now, set up a population in linkage disequilibrium, by admixture of \
two gametic pools:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Phi]1 = MakePopulation[3, {0.1, 0.2, 0.3}];\)\), "\n", 
    \(\(\[Phi]2 = MakePopulation[3, {0.9, 0.4, 0.7}];\)\), "\n", 
    \(\(\[Psi]D = 
        MakeDiploid[
          HaploidFrequencies[\(\[Phi]1\[LeftDoubleBracket]1\
\[RightDoubleBracket] + \
\[Phi]2\[LeftDoubleBracket]1\[RightDoubleBracket]\)\/2, 10]];\)\), "\n", 
    \(\(DisequilibriumTable[\[Psi]D] // MatrixForm\) // Chop\)}], "Input",
  CellLabel->"In[94]:=  (15:43:03 on 4/23/01)"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.25`", "0.04`", "0.08`"},
            {"0.04`", "0.21000000000000002`", "0.019999999999999983`"},
            {"0.08`", "0.019999999999999983`", "0.25`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[97]//MatrixForm=  (15:43:03 on 4/23/01)"]
}, Open  ]],

Cell["Now, linkage does alter the gametic frequencies:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Psi]L = \(NewGametes[\[Psi]D, 10, 
              Linkage \[Rule] {r\_\(1, 2\), r\_\(2, 3\)}] // Simplify\) // 
          Chop;\)\), "\n", 
    \(\(\[Psi]U = NewGametes[\[Psi]D, 10];\)\), "\n", 
    \({\[Psi]L, \[Psi]U}\)}], "Input",
  CellLabel->"In[99]:=  (15:43:11 on 4/23/01)"],

Cell[BoxData[
    \({HaploidFrequencies[{\(\(0.261`\)\(\[InvisibleSpace]\)\) + 
            r\_\(1, 2\)\ \((\(-0.07600000000000001`\) + 
                  0.112`\ r\_\(2, 3\))\) - 
            0.066`\ r\_\(2, 3\), \(\(0.129`\)\(\[InvisibleSpace]\)\) + 
            r\_\(1, 2\)\ \((\(\(0.036`\)\(\[InvisibleSpace]\)\) - 
                  0.11200000000000002`\ r\_\(2, 3\))\) + 
            0.066`\ r\_\(2, 3\), \(\(0.069`\)\(\[InvisibleSpace]\)\) + 
            r\_\(1, 2\)\ \((\(-0.003999999999999993`\) + 
                  0.048`\ r\_\(2, 3\))\) - 
            0.014000000000000002`\ r\_\(2, 3\), \(\(0.040999999999999995`\)\(\
\[InvisibleSpace]\)\) + 
            r\_\(1, 2\)\ \((\(\(0.04400000000000001`\)\(\[InvisibleSpace]\)\) \
- 0.04800000000000001`\ r\_\(2, 3\))\) + 
            0.014000000000000002`\ r\_\(2, 3\), \(\(0.10900000000000001`\)\(\
\[InvisibleSpace]\)\) + 
            r\_\(1, 2\)\ \((\(\(0.07600000000000001`\)\(\[InvisibleSpace]\)\) \
- 0.11200000000000002`\ r\_\(2, 3\))\) + 
            0.046`\ r\_\(2, 3\), \
\(\(0.20099999999999998`\)\(\[InvisibleSpace]\)\) + 
            r\_\(1, 2\)\ \((\(-0.03599999999999999`\) + 
                  0.112`\ r\_\(2, 3\))\) - 
            0.045999999999999985`\ r\_\(2, 3\), \(\(0.06100000000000001`\)\(\
\[InvisibleSpace]\)\) + 
            r\_\(1, 2\)\ \
\((\(\(0.003999999999999995`\)\(\[InvisibleSpace]\)\) - 
                  0.04800000000000001`\ r\_\(2, 3\))\) + 
            0.034`\ r\_\(2, 3\), \(\(0.129`\)\(\[InvisibleSpace]\)\) + 
            r\_\(1, 2\)\ \((\(-0.044000000000000004`\) + 
                  0.048`\ r\_\(2, 3\))\) - 0.034`\ r\_\(2, 3\)}, 10], 
      HaploidFrequencies[{0.218`, 0.152`, 0.07200000000000001`, 
          0.05800000000000001`, 0.14200000000000002`, 0.188`, 0.068`, 
          0.10200000000000001`}, 10]}\)], "Output",
  CellLabel->"Out[101]=  (15:43:11 on 4/23/01)"]
}, Closed]],

Cell["The linkage disequilibria are reduced by factors (1-r):", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(dt = \(\(DisequilibriumTable[\[Psi]L] // Expand\) // Chop\) // 
        MatrixForm\)], "Input",
  CellLabel->"In[124]:=  (15:48:19 on 4/23/01)"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "0.25`", \(\(\(0.04000000000000001`\)\(\[InvisibleSpace]\)\) - 
                0.04000000000000001`\ r\_\(1, 2\)\), \
\(\(\(0.07999999999999999`\)\(\[InvisibleSpace]\)\) - 0.08`\ r\_\(1, 2\) - 
                0.08000000000000002`\ r\_\(2, 3\) + 
                0.16`\ r\_\(1, 2\)\ r\_\(2, 3\)\)},
            {\(\(\(0.04000000000000001`\)\(\[InvisibleSpace]\)\) - 
                0.04000000000000001`\ r\_\(1, 2\)\), 
              "0.21`", \(\(\(0.01999999999999999`\)\(\[InvisibleSpace]\)\) - 
                0.020000000000000004`\ r\_\(2, 3\)\)},
            {\(\(\(0.07999999999999999`\)\(\[InvisibleSpace]\)\) - 
                0.08`\ r\_\(1, 2\) - 0.08000000000000002`\ r\_\(2, 3\) + 
                0.16`\ r\_\(1, 2\)\ r\_\(2, 3\)\), \(\(\(0.01999999999999999`\
\)\(\[InvisibleSpace]\)\) - 0.020000000000000004`\ r\_\(2, 3\)\), "0.25`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[124]//MatrixForm=  (15:48:20 on 4/23/01)"]
}, Open  ]],

Cell["With no linkage, linkage disequilibria decrease by 1/2:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DisequilibriumTable[\[Psi]U] // Chop\) // MatrixForm\)], "Input",
  CellLabel->"In[103]:=  (15:43:39 on 4/23/01)"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.25000000000000006`", "0.019999999999999997`", "0.04`"},
            {"0.019999999999999997`", "0.21`", "0.010000000000000009`"},
            {"0.04`", "0.010000000000000009`", "0.25000000000000006`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[103]//MatrixForm=  (15:43:39 on 4/23/01)"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{761, 654},
WindowMargins->{{117, Automatic}, {Automatic, 5}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Linkage"->{
    Cell[1775, 53, 427, 9, 70, "DefinitionBox",
      CellTags->"Linkage"]},
  "NetRecombination"->{
    Cell[2577, 73, 343, 7, 38, "DefinitionBox",
      CellTags->"NetRecombination"]},
  "Gametes"->{
    Cell[3644, 112, 437, 9, 50, "DefinitionBox",
      CellTags->"Gametes"]},
  "GameteTable"->{
    Cell[4669, 142, 481, 9, 50, "DefinitionBox",
      CellTags->"GameteTable"]},
  "NewGametes"->{
    Cell[10165, 234, 432, 9, 46, "DefinitionBox",
      CellTags->"NewGametes"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Linkage", 18220, 436},
  {"NetRecombination", 18321, 439},
  {"Gametes", 18422, 442},
  {"GameteTable", 18519, 445},
  {"NewGametes", 18619, 448}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 33, 0, 36, "SubsectionIcon"],
Cell[1775, 53, 427, 9, 70, "DefinitionBox",
  CellTags->"Linkage"],
Cell[2205, 64, 306, 5, 36, "Text"],
Cell[2514, 71, 60, 0, 22, "Text"],
Cell[2577, 73, 343, 7, 38, "DefinitionBox",
  CellTags->"NetRecombination"],
Cell[2923, 82, 145, 3, 22, "Text"],
Cell[3071, 87, 364, 12, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[3460, 103, 86, 2, 27, "Input"],
Cell[3549, 107, 80, 2, 20, "Output"]
}, Open  ]],
Cell[3644, 112, 437, 9, 50, "DefinitionBox",
  CellTags->"Gametes"],
Cell[4084, 123, 190, 4, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[4299, 131, 161, 3, 40, "Input"],
Cell[4463, 136, 191, 3, 48, "Output"]
}, Open  ]],
Cell[4669, 142, 481, 9, 50, "DefinitionBox",
  CellTags->"GameteTable"],
Cell[5153, 153, 129, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5307, 160, 123, 2, 39, "Input"],
Cell[5433, 164, 4717, 67, 556, "Output"]
}, Closed]],
Cell[10165, 234, 432, 9, 46, "DefinitionBox",
  CellTags->"NewGametes"],
Cell[10600, 245, 227, 4, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[10852, 253, 256, 5, 54, "Input"],
Cell[11111, 260, 308, 5, 32, "Output"]
}, Open  ]],
Cell[11434, 268, 137, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[11596, 275, 103, 2, 39, "Input"],
Cell[11702, 279, 292, 4, 32, "Output"]
}, Open  ]],
Cell[12009, 286, 119, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[12153, 293, 470, 9, 98, "Input"],
Cell[12626, 304, 371, 8, 63, "Output"]
}, Open  ]],
Cell[13012, 315, 71, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[13108, 319, 305, 6, 70, "Input"],
Cell[13416, 327, 1874, 33, 76, "Output"]
}, Closed]],
Cell[15305, 363, 78, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[15408, 367, 164, 3, 39, "Input"],
Cell[15575, 372, 1082, 19, 69, "Output"]
}, Open  ]],
Cell[16672, 394, 78, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[16775, 398, 136, 2, 39, "Input"],
Cell[16914, 402, 419, 8, 51, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

