(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     74287,       2161]*)
(*NotebookOutlinePosition[    147036,       4771]*)
(*  CellTagsIndexPosition[    146740,       4758]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Reproduction", "SubsectionIcon"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< NumericalModels`ExactModel`;\)\)], "Input",
  CellLabel->"In[5]:="],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(Gametes[Y, 
              Z]\), \(gives\ the\ full\ distribution\ of\ \(2\^\(\(n\)\(\ \ \
\)\)\) offspring\ genotypes\ from\ the\ diploid\ parent\ {Y, \ Z}\)},
          {\(Gametes[Y, Z, 
              SortByClass \[Rule] True]\), \(orders\ genotypes\ by\ class\)},
          {\(Gametes[Y, Z, W]\), \(is\ just\ multiplied\ by\ W[Y, Z]; \ 
            not\ normalised\)}
          }], TraditionalForm]],
  CellTags->"Gametes"]], "DefinitionBox",
  CellTags->{"Gametes", "Linkage"}],

Cell["\<\
This diploid genotype has two heterozygous loci, and so produces \
equal proportions of {0,0,0}, {0,1,0}, {1,0,0} and {1,1,0} gametes:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gametes[{1, 0, 0}, {0, 1, 0}]\)], "Input",
  CellLabel->"In[23]:=  (14:53:58 on 4/23/01)"],

Cell[BoxData[
    \({1\/4, 0, 1\/4, 0, 1\/4, 0, 1\/4, 0}\)], "Output",
  CellLabel->"Out[23]=  (14:53:58 on 4/23/01)"]
}, Open  ]],

Cell["The genotypes can also be ordered by class:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gametes[{1, 0, 0}, {0, 1, 0}, SortByClass \[Rule] True]\)], "Input",
  CellLabel->"In[6]:=  (7:45:43 on 4/21/01)"],

Cell[BoxData[
    \({1\/4, 0, 1\/4, 1\/4, 0, 0, 1\/4, 0}\)], "Output",
  CellLabel->"Out[6]=  (7:45:43 on 4/21/01)"]
}, Open  ]],

Cell["\<\
This just gives the offspring distribution, weighted by the \
parental fitness W[Y, Z]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gametes[{1, 0, 0}, {0, 1, 0}, W]\)], "Input",
  CellLabel->"In[25]:=  (14:54:10 on 4/23/01)"],

Cell[BoxData[
    \({1\/4\ W[{1, 0, 0}, {0, 1, 0}], 0, 1\/4\ W[{1, 0, 0}, {0, 1, 0}], 0, 
      1\/4\ W[{1, 0, 0}, {0, 1, 0}], 0, 1\/4\ W[{1, 0, 0}, {0, 1, 0}], 
      0}\)], "Output",
  CellLabel->"Out[25]=  (14:54:11 on 4/23/01)"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Related functions:",
    FontWeight->"Bold"],
  " ",
  ButtonBox["GenotypeProbability[o,p]",
    ButtonData:>{"Genotype probabilities", "GenotypeProbability"},
    ButtonStyle->"AddOnsLink"],
  " performs a similar function, but is more general: it allows for multiple \
alleles and segregation distortion."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(GameteTable[
              n]\), \(stores\ a\ matrix\ showing\ the\ distribution\ of\ \
genotypes\ among\ gametes, \ \(\(for\)\(\ \)\(each\)\(\ \)\(diploid\)\(\ \)\(\
\(genotype\)\(.\)\)\(\ \)\)\)},
          {\(GameteTable[n, W]\), \(is\ also\ defined; \ 
            it\ allows\ for\ selection\ W[Y, \ Z]\)},
          {\(GameteTable[n, 
              StoreResults -> False]\), \(does\ not\ store\ results\)}
          }], TraditionalForm]],
  CellTags->"GameteTable"]], "DefinitionBox",
  CellTags->{"StoreResults", "GameteTable"}],

Cell["\<\
This array lists the offspring distributions from all 8\[Times]8 \
diploid genotypes:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GameteTable[3] // MatrixForm\)], "Input",
  CellLabel->"In[26]:=  (14:54:39 on 4/23/01)"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/2\)},
                    {\(1\/2\)},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/2\)},
                    {"0"},
                    {\(1\/2\)},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/2\)},
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {"0"},
                    {"0"},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/2\)},
                    {\(1\/2\)},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {\(1\/2\)},
                    {"0"},
                    {\(1\/2\)},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {"0"},
                    {"0"},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {\(1\/2\)},
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/2\)},
                    {"0"},
                    {\(1\/2\)},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"1"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {\(1\/2\)},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {"0"},
                    {"0"},
                    {\(1\/4\)},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {\(1\/2\)},
                    {"0"},
                    {\(1\/2\)},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {\(1\/2\)},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"1"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {"0"},
                    {"0"},
                    {\(1\/4\)},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/2\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/2\)},
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {"0"},
                    {"0"},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"1"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {\(1\/2\)},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {"0"},
                    {\(1\/2\)},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {"0"},
                    {"0"},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {\(1\/2\)},
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {\(1\/2\)},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"1"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {"0"},
                    {\(1\/2\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {"0"},
                    {"0"},
                    {\(1\/4\)},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {"0"},
                    {\(1\/2\)},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"1"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {\(1\/2\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)},
                    {\(1\/8\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)},
                    {"0"},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {"0"},
                    {"0"},
                    {\(1\/4\)},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/2\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {\(1\/4\)},
                    {\(1\/4\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {"0"},
                    {\(1\/2\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {\(1\/2\)},
                    {\(1\/2\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{1, 0, 0, 0, 0, 0, 0, 0}, {
        Rational[ 1, 2], 
        Rational[ 1, 2], 0, 0, 0, 0, 0, 0}, {
        Rational[ 1, 2], 0, 
        Rational[ 1, 2], 0, 0, 0, 0, 0}, {
        Rational[ 1, 4], 
        Rational[ 1, 4], 
        Rational[ 1, 4], 
        Rational[ 1, 4], 0, 0, 0, 0}, {
        Rational[ 1, 2], 0, 0, 0, 
        Rational[ 1, 2], 0, 0, 0}, {
        Rational[ 1, 4], 
        Rational[ 1, 4], 0, 0, 
        Rational[ 1, 4], 
        Rational[ 1, 4], 0, 0}, {
        Rational[ 1, 4], 0, 
        Rational[ 1, 4], 0, 
        Rational[ 1, 4], 0, 
        Rational[ 1, 4], 0}, {
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8]}}, {{
        Rational[ 1, 2], 
        Rational[ 1, 2], 0, 0, 0, 0, 0, 0}, {0, 1, 0, 0, 0, 0, 0, 0}, {
        Rational[ 1, 4], 
        Rational[ 1, 4], 
        Rational[ 1, 4], 
        Rational[ 1, 4], 0, 0, 0, 0}, {0, 
        Rational[ 1, 2], 0, 
        Rational[ 1, 2], 0, 0, 0, 0}, {
        Rational[ 1, 4], 
        Rational[ 1, 4], 0, 0, 
        Rational[ 1, 4], 
        Rational[ 1, 4], 0, 0}, {0, 
        Rational[ 1, 2], 0, 0, 0, 
        Rational[ 1, 2], 0, 0}, {
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8]}, {0, 
        Rational[ 1, 4], 0, 
        Rational[ 1, 4], 0, 
        Rational[ 1, 4], 0, 
        Rational[ 1, 4]}}, {{
        Rational[ 1, 2], 0, 
        Rational[ 1, 2], 0, 0, 0, 0, 0}, {
        Rational[ 1, 4], 
        Rational[ 1, 4], 
        Rational[ 1, 4], 
        Rational[ 1, 4], 0, 0, 0, 0}, {0, 0, 1, 0, 0, 0, 0, 0}, {0, 0, 
        Rational[ 1, 2], 
        Rational[ 1, 2], 0, 0, 0, 0}, {
        Rational[ 1, 4], 0, 
        Rational[ 1, 4], 0, 
        Rational[ 1, 4], 0, 
        Rational[ 1, 4], 0}, {
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8]}, {0, 0, 
        Rational[ 1, 2], 0, 0, 0, 
        Rational[ 1, 2], 0}, {0, 0, 
        Rational[ 1, 4], 
        Rational[ 1, 4], 0, 0, 
        Rational[ 1, 4], 
        Rational[ 1, 4]}}, {{
        Rational[ 1, 4], 
        Rational[ 1, 4], 
        Rational[ 1, 4], 
        Rational[ 1, 4], 0, 0, 0, 0}, {0, 
        Rational[ 1, 2], 0, 
        Rational[ 1, 2], 0, 0, 0, 0}, {0, 0, 
        Rational[ 1, 2], 
        Rational[ 1, 2], 0, 0, 0, 0}, {0, 0, 0, 1, 0, 0, 0, 0}, {
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8]}, {0, 
        Rational[ 1, 4], 0, 
        Rational[ 1, 4], 0, 
        Rational[ 1, 4], 0, 
        Rational[ 1, 4]}, {0, 0, 
        Rational[ 1, 4], 
        Rational[ 1, 4], 0, 0, 
        Rational[ 1, 4], 
        Rational[ 1, 4]}, {0, 0, 0, 
        Rational[ 1, 2], 0, 0, 0, 
        Rational[ 1, 2]}}, {{
        Rational[ 1, 2], 0, 0, 0, 
        Rational[ 1, 2], 0, 0, 0}, {
        Rational[ 1, 4], 
        Rational[ 1, 4], 0, 0, 
        Rational[ 1, 4], 
        Rational[ 1, 4], 0, 0}, {
        Rational[ 1, 4], 0, 
        Rational[ 1, 4], 0, 
        Rational[ 1, 4], 0, 
        Rational[ 1, 4], 0}, {
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8]}, {0, 0, 0, 0, 1, 0, 0, 0}, {0, 0, 0, 0, 
        Rational[ 1, 2], 
        Rational[ 1, 2], 0, 0}, {0, 0, 0, 0, 
        Rational[ 1, 2], 0, 
        Rational[ 1, 2], 0}, {0, 0, 0, 0, 
        Rational[ 1, 4], 
        Rational[ 1, 4], 
        Rational[ 1, 4], 
        Rational[ 1, 4]}}, {{
        Rational[ 1, 4], 
        Rational[ 1, 4], 0, 0, 
        Rational[ 1, 4], 
        Rational[ 1, 4], 0, 0}, {0, 
        Rational[ 1, 2], 0, 0, 0, 
        Rational[ 1, 2], 0, 0}, {
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8]}, {0, 
        Rational[ 1, 4], 0, 
        Rational[ 1, 4], 0, 
        Rational[ 1, 4], 0, 
        Rational[ 1, 4]}, {0, 0, 0, 0, 
        Rational[ 1, 2], 
        Rational[ 1, 2], 0, 0}, {0, 0, 0, 0, 0, 1, 0, 0}, {0, 0, 0, 0, 
        Rational[ 1, 4], 
        Rational[ 1, 4], 
        Rational[ 1, 4], 
        Rational[ 1, 4]}, {0, 0, 0, 0, 0, 
        Rational[ 1, 2], 0, 
        Rational[ 1, 2]}}, {{
        Rational[ 1, 4], 0, 
        Rational[ 1, 4], 0, 
        Rational[ 1, 4], 0, 
        Rational[ 1, 4], 0}, {
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8]}, {0, 0, 
        Rational[ 1, 2], 0, 0, 0, 
        Rational[ 1, 2], 0}, {0, 0, 
        Rational[ 1, 4], 
        Rational[ 1, 4], 0, 0, 
        Rational[ 1, 4], 
        Rational[ 1, 4]}, {0, 0, 0, 0, 
        Rational[ 1, 2], 0, 
        Rational[ 1, 2], 0}, {0, 0, 0, 0, 
        Rational[ 1, 4], 
        Rational[ 1, 4], 
        Rational[ 1, 4], 
        Rational[ 1, 4]}, {0, 0, 0, 0, 0, 0, 1, 0}, {0, 0, 0, 0, 0, 0, 
        Rational[ 1, 2], 
        Rational[ 1, 2]}}, {{
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8], 
        Rational[ 1, 8]}, {0, 
        Rational[ 1, 4], 0, 
        Rational[ 1, 4], 0, 
        Rational[ 1, 4], 0, 
        Rational[ 1, 4]}, {0, 0, 
        Rational[ 1, 4], 
        Rational[ 1, 4], 0, 0, 
        Rational[ 1, 4], 
        Rational[ 1, 4]}, {0, 0, 0, 
        Rational[ 1, 2], 0, 0, 0, 
        Rational[ 1, 2]}, {0, 0, 0, 0, 
        Rational[ 1, 4], 
        Rational[ 1, 4], 
        Rational[ 1, 4], 
        Rational[ 1, 4]}, {0, 0, 0, 0, 0, 
        Rational[ 1, 2], 0, 
        Rational[ 1, 2]}, {0, 0, 0, 0, 0, 0, 
        Rational[ 1, 2], 
        Rational[ 1, 2]}, {0, 0, 0, 0, 0, 0, 0, 1}}}]]], "Output",
  CellLabel->"Out[26]//MatrixForm=  (14:54:40 on 4/23/01)"]
}, Closed]],

Cell["\<\
This weights each offspring distribution by the fitness of the \
diploid parent, assuming 10% selection against heterozygotes:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gt = GameteTable[3, 0.9\^CountHeterozygotes[#1, #2] &]; 
    gt // MatrixForm\)], "Input",
  CellLabel->"In[12]:=  (19:47:49 on 4/23/01)"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.45`"},
                    {"0.45`"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.45`"},
                    {"0"},
                    {"0.45`"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.45`"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0"},
                    {"0"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.45`"},
                    {"0.45`"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"1"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0.45`"},
                    {"0"},
                    {"0.45`"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0"},
                    {"0"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0.45`"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.45`"},
                    {"0"},
                    {"0.45`"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"1"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0.45`"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0"},
                    {"0"},
                    {"0.2025`"},
                    {"0.2025`"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0.45`"},
                    {"0"},
                    {"0.45`"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0.45`"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"1"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0"},
                    {"0"},
                    {"0.2025`"},
                    {"0.2025`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.45`"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.45`"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0"},
                    {"0"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"1"},
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0.45`"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0"},
                    {"0.45`"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0.2025`"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0"},
                    {"0"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0.45`"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0.45`"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"1"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0.2025`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0"},
                    {"0.45`"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0"},
                    {"0"},
                    {"0.2025`"},
                    {"0.2025`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0"},
                    {"0.45`"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0.2025`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"1"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0.45`"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"},
                    {"0.09112500000000001`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"},
                    {"0"},
                    {"0.2025`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0"},
                    {"0"},
                    {"0.2025`"},
                    {"0.2025`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.45`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0.2025`"},
                    {"0.2025`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0"},
                    {"0.45`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0.45`"},
                    {"0.45`"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"0"},
                    {"1"}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{1, 0, 0, 0, 0, 0, 0, 0}, {0.45000000000000001, 
        0.45000000000000001, 0, 0, 0, 0, 0, 0}, {0.45000000000000001, 0, 
        0.45000000000000001, 0, 0, 0, 0, 0}, {0.20250000000000001, 
        0.20250000000000001, 0.20250000000000001, 0.20250000000000001, 0, 0, 
        0, 0}, {0.45000000000000001, 0, 0, 0, 0.45000000000000001, 0, 0, 0}, {
        0.20250000000000001, 0.20250000000000001, 0, 0, 0.20250000000000001, 
        0.20250000000000001, 0, 0}, {0.20250000000000001, 0, 
        0.20250000000000001, 0, 0.20250000000000001, 0, 0.20250000000000001, 
        0}, {0.091125000000000012, 0.091125000000000012, 0.091125000000000012,
         0.091125000000000012, 0.091125000000000012, 0.091125000000000012, 
        0.091125000000000012, 0.091125000000000012}}, {{0.45000000000000001, 
        0.45000000000000001, 0, 0, 0, 0, 0, 0}, {0, 1, 0, 0, 0, 0, 0, 0}, {
        0.20250000000000001, 0.20250000000000001, 0.20250000000000001, 
        0.20250000000000001, 0, 0, 0, 0}, {0, 0.45000000000000001, 0, 
        0.45000000000000001, 0, 0, 0, 0}, {0.20250000000000001, 
        0.20250000000000001, 0, 0, 0.20250000000000001, 0.20250000000000001, 
        0, 0}, {0, 0.45000000000000001, 0, 0, 0, 0.45000000000000001, 0, 0}, {
        0.091125000000000012, 0.091125000000000012, 0.091125000000000012, 
        0.091125000000000012, 0.091125000000000012, 0.091125000000000012, 
        0.091125000000000012, 0.091125000000000012}, {0, 0.20250000000000001, 
        0, 0.20250000000000001, 0, 0.20250000000000001, 0, 
        0.20250000000000001}}, {{0.45000000000000001, 0, 0.45000000000000001, 
        0, 0, 0, 0, 0}, {0.20250000000000001, 0.20250000000000001, 
        0.20250000000000001, 0.20250000000000001, 0, 0, 0, 0}, {0, 0, 1, 0, 0,
         0, 0, 0}, {0, 0, 0.45000000000000001, 0.45000000000000001, 0, 0, 0, 
        0}, {0.20250000000000001, 0, 0.20250000000000001, 0, 
        0.20250000000000001, 0, 0.20250000000000001, 0}, {
        0.091125000000000012, 0.091125000000000012, 0.091125000000000012, 
        0.091125000000000012, 0.091125000000000012, 0.091125000000000012, 
        0.091125000000000012, 0.091125000000000012}, {0, 0, 
        0.45000000000000001, 0, 0, 0, 0.45000000000000001, 0}, {0, 0, 
        0.20250000000000001, 0.20250000000000001, 0, 0, 0.20250000000000001, 
        0.20250000000000001}}, {{0.20250000000000001, 0.20250000000000001, 
        0.20250000000000001, 0.20250000000000001, 0, 0, 0, 0}, {0, 
        0.45000000000000001, 0, 0.45000000000000001, 0, 0, 0, 0}, {0, 0, 
        0.45000000000000001, 0.45000000000000001, 0, 0, 0, 0}, {0, 0, 0, 1, 0,
         0, 0, 0}, {0.091125000000000012, 0.091125000000000012, 
        0.091125000000000012, 0.091125000000000012, 0.091125000000000012, 
        0.091125000000000012, 0.091125000000000012, 0.091125000000000012}, {0,
         0.20250000000000001, 0, 0.20250000000000001, 0, 0.20250000000000001, 
        0, 0.20250000000000001}, {0, 0, 0.20250000000000001, 
        0.20250000000000001, 0, 0, 0.20250000000000001, 
        0.20250000000000001}, {0, 0, 0, 0.45000000000000001, 0, 0, 0, 
        0.45000000000000001}}, {{0.45000000000000001, 0, 0, 0, 
        0.45000000000000001, 0, 0, 0}, {0.20250000000000001, 
        0.20250000000000001, 0, 0, 0.20250000000000001, 0.20250000000000001, 
        0, 0}, {0.20250000000000001, 0, 0.20250000000000001, 0, 
        0.20250000000000001, 0, 0.20250000000000001, 0}, {
        0.091125000000000012, 0.091125000000000012, 0.091125000000000012, 
        0.091125000000000012, 0.091125000000000012, 0.091125000000000012, 
        0.091125000000000012, 0.091125000000000012}, {0, 0, 0, 0, 1, 0, 0, 
        0}, {0, 0, 0, 0, 0.45000000000000001, 0.45000000000000001, 0, 0}, {0, 
        0, 0, 0, 0.45000000000000001, 0, 0.45000000000000001, 0}, {0, 0, 0, 0,
         0.20250000000000001, 0.20250000000000001, 0.20250000000000001, 
        0.20250000000000001}}, {{0.20250000000000001, 0.20250000000000001, 0, 
        0, 0.20250000000000001, 0.20250000000000001, 0, 0}, {0, 
        0.45000000000000001, 0, 0, 0, 0.45000000000000001, 0, 0}, {
        0.091125000000000012, 0.091125000000000012, 0.091125000000000012, 
        0.091125000000000012, 0.091125000000000012, 0.091125000000000012, 
        0.091125000000000012, 0.091125000000000012}, {0, 0.20250000000000001, 
        0, 0.20250000000000001, 0, 0.20250000000000001, 0, 
        0.20250000000000001}, {0, 0, 0, 0, 0.45000000000000001, 
        0.45000000000000001, 0, 0}, {0, 0, 0, 0, 0, 1, 0, 0}, {0, 0, 0, 0, 
        0.20250000000000001, 0.20250000000000001, 0.20250000000000001, 
        0.20250000000000001}, {0, 0, 0, 0, 0, 0.45000000000000001, 0, 
        0.45000000000000001}}, {{0.20250000000000001, 0, 0.20250000000000001, 
        0, 0.20250000000000001, 0, 0.20250000000000001, 0}, {
        0.091125000000000012, 0.091125000000000012, 0.091125000000000012, 
        0.091125000000000012, 0.091125000000000012, 0.091125000000000012, 
        0.091125000000000012, 0.091125000000000012}, {0, 0, 
        0.45000000000000001, 0, 0, 0, 0.45000000000000001, 0}, {0, 0, 
        0.20250000000000001, 0.20250000000000001, 0, 0, 0.20250000000000001, 
        0.20250000000000001}, {0, 0, 0, 0, 0.45000000000000001, 0, 
        0.45000000000000001, 0}, {0, 0, 0, 0, 0.20250000000000001, 
        0.20250000000000001, 0.20250000000000001, 0.20250000000000001}, {0, 0,
         0, 0, 0, 0, 1, 0}, {0, 0, 0, 0, 0, 0, 0.45000000000000001, 
        0.45000000000000001}}, {{0.091125000000000012, 0.091125000000000012, 
        0.091125000000000012, 0.091125000000000012, 0.091125000000000012, 
        0.091125000000000012, 0.091125000000000012, 0.091125000000000012}, {0,
         0.20250000000000001, 0, 0.20250000000000001, 0, 0.20250000000000001, 
        0, 0.20250000000000001}, {0, 0, 0.20250000000000001, 
        0.20250000000000001, 0, 0, 0.20250000000000001, 
        0.20250000000000001}, {0, 0, 0, 0.45000000000000001, 0, 0, 0, 
        0.45000000000000001}, {0, 0, 0, 0, 0.20250000000000001, 
        0.20250000000000001, 0.20250000000000001, 0.20250000000000001}, {0, 0,
         0, 0, 0, 0.45000000000000001, 0, 0.45000000000000001}, {0, 0, 0, 0, 
        0, 0, 0.45000000000000001, 0.45000000000000001}, {0, 0, 0, 0, 0, 0, 0,
         1}}}]]], "Output",
  CellLabel->"Out[12]//MatrixForm=  (19:47:50 on 4/23/01)"]
}, Closed]],

Cell[TextData[{
  "Multiplying by the distribution of diploid genotype frequencies, \[Phi], \
and summing gives the ",
  StyleBox["unnormalised",
    FontSlant->"Italic"],
  " genotype distribution after selection, new\[Phi]:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Phi] = 
        MakePopulation[3, {0.1, 0.2, 0.3}, 
          NumericalModel -> DiploidFrequencies];\)\), "\n", 
    \(new\[Phi] = 
      Plus @@ \(Plus @@ \((gt\ \[Phi]\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ )\)\)\)}], "Input",
  CellLabel->"In[13]:=  (19:47:53 on 4/23/01)"],

Cell[BoxData[
    \({0.474311376`, 0.19489377600000002`, 0.111317976`, 
      0.045740376000000006`, 0.048442575999999966`, 0.01990497599999999`, 
      0.011369175999999993`, 0.004671575999999998`}\)], "Output",
  CellLabel->"Out[14]=  (19:47:53 on 4/23/01)"]
}, Open  ]],

Cell["\<\
The sum of this unnormalised distribution is just the mean fitness:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Plus @@ new\[Phi], 
      MeanW[\[Phi], 0.9\^CountHeterozygotes[#1, #2] &]}\)], "Input",
  CellLabel->"In[30]:=  (14:55:24 on 4/23/01)"],

Cell[BoxData[
    \({0.910651808`, 0.910651808`}\)], "Output",
  CellLabel->"Out[30]=  (14:55:24 on 4/23/01)"]
}, Open  ]],

Cell["\<\
The normalised distribution of gametes after selection on diploids \
is found by dividing by the mean fitmess; this is the algorithm used by \
NewGametes[]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(new\[Phi]\/Plus @@ new\[Phi]\)], "Input",
  CellLabel->"In[31]:=  (14:55:35 on 4/23/01)"],

Cell[BoxData[
    \({0.5208482230345498`, 0.21401569105543358`, 0.12223988907953719`, 
      0.050228172390560946`, 0.053195497526536475`, 0.02185794375538097`, 
      0.012484657582758562`, 0.005129925575242472`}\)], "Output",
  CellLabel->"Out[31]=  (14:55:35 on 4/23/01)"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Note",
    FontWeight->"Bold"],
  ": by default, GameteTable stores results; this is efficient if fitnesses \
are constant.  However, it can use a great deal of memory if genotypic \
fitnesses are continually changing.  StoreResults->False prevents results \
being stored."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(NewGametes[\[Phi]]\), \(gives\ the\ gametes\ produced\ by\ the\ \
diploid\ representation\ \[Phi]; \ deme\ size\ is\ doubled\)},
          {\(NewGametes[\[Phi], W]\), \(does\ the\ same, \ 
            but\ assuming\ selection\ W[Y, \ Z]\)},
          {\(NewGametes[\[Phi], W, 
              Linkage \[Rule] {r\_\(1, 2\), 
                  r\_\(2, 3\), \[Ellipsis]}]\), \(allows\ for\ linkage\)}
          }], TraditionalForm]],
  CellTags->"NewGametes"]], "DefinitionBox",
  CellTags->{"NewGametes", "Linkage"}],

Cell["\<\
\[Phi] is a diploid population in linkage equilibrium, with allele \
frequencies {0.1, 0.2, 0.3}.  NewGametes[\[Phi]] gives the distribution of \
gametic genotypes in the absence of selection:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NewGametes[\[Phi]]\)], "Input",
  CellLabel->"In[20]:=  (19:50:43 on 4/23/01)"],

Cell[BoxData[
    \(HaploidFrequencies[{0.504`, 0.21600000000000003`, 0.12600000000000006`, 
        0.054000000000000006`, 0.055999999999999966`, 0.023999999999999994`, 
        0.013999999999999995`, 0.0059999999999999975`}, 2]\)], "Output",
  CellLabel->"Out[20]=  (19:50:44 on 4/23/01)"]
}, Open  ]],

Cell["\<\
Deme size is double the default value of 1 that was specified for \
\[Phi].  This convention allows MakeDiploid[] to be used to randomly unite \
pairs of haploid gametes.\
\>", "Text"],

Cell["\<\
This gives the distribution of gametic genotypes with 10% selection \
against heterozygotes at each locus:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NewGametes[\[Phi], 0.9\^CountHeterozygotes[#1, #2] &]\)], "Input",
  CellLabel->"In[21]:=  (19:51:11 on 4/23/01)"],

Cell[BoxData[
    \(HaploidFrequencies[{0.5208482230345498`, 0.21401569105543358`, 
        0.12223988907953719`, 0.050228172390560946`, 0.053195497526536475`, 
        0.02185794375538097`, 0.012484657582758562`, 0.005129925575242472`}, 
      2]\)], "Output",
  CellLabel->"Out[21]=  (19:51:11 on 4/23/01)"]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(NewGametes[\[Phi], 
              Mutation \[Rule] {{\[Mu]\_1, \[Nu]\_1}, {\[Mu]\_2, \[Nu]\_2}, \
\[Ellipsis]}]\), \(allows\ for\ mutation\ at\ \ a\ rate\ \[Mu]\_i\ from\ 0\ \
to\ 1, \ and\ \[Nu]\_i\ from\ 1\ to\ 0\)},
          {\(NewGametes[\[Phi], 
              Mutation \[Rule] {{\[Mu]\_1}, {\[Mu]\_2}, \[Ellipsis]}]\), \
\(allows\ for\ mutation\ at\ \ a\ rate\ \[Mu]\_i\ in\ each\ direction\)},
          {\(NewGametes[\[Phi], 
              Mutation \[Rule] {\[Mu]}]\), \(allows\ for\ mutation\ at\ \ a\ \
rate\ \[Mu]\ in\ each\ direction\ at\ all\ loci\)},
          {\(NewGametes[\[Phi], 
              Mutation \[Rule] {\[Mu], \[Nu]}]\), \(allows\ for\ mutation\ \
at\ \ a\ rate\ \[Mu]\ from\ 0\ to\ 1, \ and\ \[Nu]\ from\ 1\ to\ 0\)}
          }], TraditionalForm]],
  CellTags->"NewGametes"]], "DefinitionBox",
  CellTags->"Mutation"],

Cell["\<\
This specifies a population of individuals, each of genotype \
{{0,0,0},{0,0,0}}:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi]0 = 
      MakePopulation[3, 0, 10, 
        NumericalModel \[Rule] DiploidFrequencies]\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(DiploidFrequencies[{{1, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0, 0, 
          0}, {0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 
          0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0, 0, 
          0}, {0, 0, 0, 0, 0, 0, 0, 0}}, 5]\)], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell["\<\
This specifies that 10% of 0 alleles mutate to 1 alleles at each \
locus:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NewGametes[\[Psi]0, Mutation \[Rule] {0.1, 0}]\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \(HaploidFrequencies[{0.7290000000000001`, 0.08099999999999999`, 
        0.08099999999999999`, 0.008999999999999996`, 0.08099999999999999`, 
        0.008999999999999996`, 0.008999999999999996`, 
        0.0009999999999999994`}, 10]\)], "Output",
  CellLabel->"Out[41]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlleleFrequencyTable[%] // N\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    \({0.09999999999999998`, 0.09999999999999998`, 
      0.09999999999999998`}\)], "Output",
  CellLabel->"Out[42]="]
}, Open  ]],

Cell["This is faster:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NewGametes[\[Psi]0, Mutation \[Rule] {0.1, 0}, 
      Compiled \[Rule] True]\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \(HaploidFrequencies[{0.7290000000000001`, 0.08099999999999999`, 
        0.08099999999999999`, 0.008999999999999996`, 0.08099999999999999`, 
        0.008999999999999996`, 0.008999999999999996`, 
        0.0009999999999999994`}, 10]\)], "Output",
  CellLabel->"Out[43]="]
}, Open  ]],

Cell[TextData[{
  "Mutation is implemented by calculating and storing a matrix which \
describes the chance in genotype frequencies, using ",
  ButtonBox["ConstructMutateMatrix",
    ButtonData:>{"Recursions: mutation", "ConstructMutateMatrix"},
    ButtonStyle->"AddOnsLink"],
  "[].  NewGametes[\[Ellipsis],Mutation\[Rule]\[Ellipsis],Compiled->True] \
compiles this calculation.  "
}], "Text"],

Cell[TextData[{
  "Shorthand forms for the mutation rates are interpreted by ",
  ButtonBox["ConstructMutateList",
    ButtonData:>{"Recursions: mutation", "ConstructMutateList"},
    ButtonStyle->"AddOnsLink"],
  "[]"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(NewGametes[\[Phi], W, 
              DemeSize \[Rule] F]\), \(changes\ deme\ size\ to\ 2 
               F[n, W\&_]\)},
          {\(NewGametes[\[Phi], W, 
              StoreResults -> False]\), \(does\ not\ store\ results\)},
          {\(NewGametes[\[Phi], W, 
              RandomDrift -> 
                True]\), \(samples\ haploid\ gametes\ randomly\ from\ the\ \
diploid\ population, \ after\ selection\)}
          }], TraditionalForm]],
  CellTags->"NewGametes"]], "DefinitionBox",
  CellTags->{"DemeSize", "RandomDrift", "StoreResults"}],

Cell[TextData[{
  "This changes deme size to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(F[n, W\&_]\)\(:\)\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NewGametes[\[Phi], 2\ 0.9\^CountHeterozygotes[#1, #2] &, 
      DemeSize -> \((#1\ Exp[\(-#1\)] #2 &)\)]\)], "Input",
  CellLabel->"In[24]:=  (19:54:05 on 4/23/01)"],

Cell[BoxData[
    \(HaploidFrequencies[{0.5208482230345498`, 0.21401569105543358`, 
        0.12223988907953719`, 0.050228172390560946`, 0.053195497526536475`, 
        0.02185794375538097`, 0.012484657582758562`, 0.005129925575242472`}, 
      1.34]\)], "Output",
  CellLabel->"Out[24]=  (19:54:06 on 4/23/01)",
  CellEditDuplicate->False,
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[TextData[{
  "In this example, the pure function #1 Exp[-#1]#2& represents n ",
  Cell[BoxData[
      \(TraditionalForm\`Exp[\(-n\)] W\&_; \ 
      this\ leads\ to\ an\ equilibrium\ at\ n\_eq = Log[W\&_]\)]],
  ", provided ",
  Cell[BoxData[
      \(TraditionalForm\`W\&_ > 1. \)]],
  "  The same can be achieved using DemeSize->",
  Cell[BoxData[
      StyleBox["ExponentialF",
        FontWeight->"Plain"]], "Input",
    GeneratedCell->True],
  "[1,0,1]"
}], "Text"],

Cell["\<\
This samples 100 haploid gametes from a diploid population, across \
1000 replicates:\
\>", "MathCaption"],

Cell[BoxData[{
    \(\(p0 = {0.1, 0.2, 0.3};\)\), "\[IndentingNewLine]", 
    \(\(\[Phi] = 
        MakePopulation[3, p0, 100, 
          NumericalModel -> DiploidFrequencies];\)\), "\n", 
    \(\(tt = 
        Table[AlleleFrequencyTable[
            NewGametes[\[Phi], RandomDrift -> True]], {1000}];\)\)}], "Input",\

  CellLabel->"In[39]:=  (18:48:35 on 4/28/01)"],

Cell[CellGroupData[{

Cell[BoxData[
    \({p0, Mean[tt], \(p0 \((1 - p0)\)\)\/100, Variance[tt]} // 
      MatrixForm\)], "Input",
  CellLabel->"In[42]:=  (18:48:51 on 4/28/01)"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.1`", "0.2`", "0.3`"},
            {"0.09780999999999979`", "0.19913999999999962`", 
              "0.3000100000000004`"},
            {"0.0009000000000000002`", "0.0016`", "0.0021`"},
            {"0.0008837876876876836`", "0.0017123727727727633`", 
              "0.0021378377377377546`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[42]//MatrixForm=  (18:48:52 on 4/28/01)"]
}, Open  ]],

Cell["\<\
The mean and variance of allele frequency are close to their \
expectation.\
\>", "Text"],

Cell["\<\
This samples 100 haploid gametes from a diploid population, and \
changes the deme size:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NewGametes[\[Phi], RandomDrift -> True, 
      DemeSize -> ExponentialF[1, 0, 0.01]]\)], "Input",
  CellLabel->"In[28]:=  (18:43:20 on 4/28/01)"],

Cell[BoxData[
    \(HaploidFrequencies[{0.43243243243243246`, 0.2702702702702703`, 
        0.10810810810810811`, 0.05405405405405406`, 0.08108108108108109`, 
        0.02702702702702703`, 0, 0.02702702702702703`}, 73.58]\)], "Output",
  CellLabel->"Out[28]=  (18:43:20 on 4/28/01)"]
}, Open  ]],

Cell[TextData[{
  "The deme size is changed to the definite value 2",
  Cell[BoxData[
      \(TraditionalForm\`\(ExponentialF[1, 0, 0.01]\)[n, W\&_], \ 
      which\ here\ is\ 73.58 . \ \ The\ number\ actually\ sampled\ is\ \
rounded\ to\ twice\ the\ nearest\ positive\ \(\(integer\)\(.\)\)\)]]
}], "Text"],

Cell[TextData[{
  "Because population size is very low, only one individual is sampled.  \
However, deme size is still set to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(F[n, W\&_]\)\(:\)\)\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Phi]small = 
        MakePopulation[3, {0.1, 0.2, 0.3}, 0.2, 
          NumericalModel -> DiploidFrequencies];\)\), "\n", 
    \(NewGametes[\[Phi]small, RandomDrift -> True]\)}], "Input",
  CellLabel->"In[21]:=  (18:41:26 on 4/28/01)"],

Cell[BoxData[
    RowBox[{"HaploidFrequencies", "[", 
      RowBox[{\({0, 0, 0, 0, 0, 1.`, 0, 0}\), ",", 
        StyleBox[
          RowBox[{"0.", 
            StyleBox["4",
              CellEditDuplicate->True]}]]}], "]"}]], "Output",
  CellLabel->"Out[22]=  (18:41:26 on 4/28/01)"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{842, 667},
WindowMargins->{{12, Automatic}, {Automatic, 3}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Gametes"->{
    Cell[1924, 59, 543, 11, 74, "DefinitionBox",
      CellTags->{"Gametes", "Linkage"}]},
  "Linkage"->{
    Cell[1924, 59, 543, 11, 74, "DefinitionBox",
      CellTags->{"Gametes", "Linkage"}],
    Cell[63881, 1847, 575, 11, 76, "DefinitionBox",
      CellTags->{"NewGametes", "Linkage"}]},
  "StoreResults"->{
    Cell[4123, 131, 597, 12, 74, "DefinitionBox",
      CellTags->{"StoreResults", "GameteTable"}],
    Cell[69411, 2010, 611, 13, 78, "DefinitionBox",
      CellTags->{"DemeSize", "RandomDrift", "StoreResults"}]},
  "GameteTable"->{
    Cell[4123, 131, 597, 12, 74, "DefinitionBox",
      CellTags->{"StoreResults", "GameteTable"}]},
  "NewGametes"->{
    Cell[63881, 1847, 575, 11, 76, "DefinitionBox",
      CellTags->{"NewGametes", "Linkage"}]},
  "Mutation"->{
    Cell[65935, 1904, 909, 17, 92, "DefinitionBox",
      CellTags->"Mutation"]},
  "DemeSize"->{
    Cell[69411, 2010, 611, 13, 78, "DefinitionBox",
      CellTags->{"DemeSize", "RandomDrift", "StoreResults"}]},
  "RandomDrift"->{
    Cell[69411, 2010, 611, 13, 78, "DefinitionBox",
      CellTags->{"DemeSize", "RandomDrift", "StoreResults"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Gametes", 145589, 4726},
  {"Linkage", 145695, 4729},
  {"StoreResults", 145902, 4734},
  {"GameteTable", 146136, 4739},
  {"NewGametes", 146255, 4742},
  {"Mutation", 146368, 4745},
  {"DemeSize", 146466, 4748},
  {"RandomDrift", 146600, 4751}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 38, 0, 36, "SubsectionIcon"],
Cell[1780, 53, 46, 0, 28, "MathCaption"],
Cell[1829, 55, 92, 2, 27, "Input"],
Cell[1924, 59, 543, 11, 74, "DefinitionBox",
  CellTags->{"Gametes", "Linkage"}],
Cell[2470, 72, 167, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2662, 80, 110, 2, 39, "Input"],
Cell[2775, 84, 118, 2, 48, "Output"]
}, Open  ]],
Cell[2908, 89, 66, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2999, 93, 134, 2, 39, "Input"],
Cell[3136, 97, 116, 2, 48, "Output"]
}, Open  ]],
Cell[3267, 102, 118, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3410, 109, 113, 2, 39, "Input"],
Cell[3526, 113, 232, 4, 48, "Output"]
}, Open  ]],
Cell[3773, 120, 347, 9, 24, "Text"],
Cell[4123, 131, 597, 12, 74, "DefinitionBox",
  CellTags->{"StoreResults", "GameteTable"}],
Cell[4723, 145, 116, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4864, 152, 109, 2, 39, "Input"],
Cell[4976, 156, 27792, 861, 1603, "Output"]
}, Closed]],
Cell[32783, 1020, 159, 4, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[32967, 1028, 158, 3, 42, "Input"],
Cell[33128, 1033, 28543, 740, 1027, "Output"]
}, Closed]],
Cell[61686, 1776, 245, 6, 20, "MathCaption"],

Cell[CellGroupData[{
Cell[61956, 1786, 307, 7, 54, "Input"],
Cell[62266, 1795, 260, 4, 32, "Output"]
}, Open  ]],
Cell[62541, 1802, 100, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[62666, 1809, 157, 3, 42, "Input"],
Cell[62826, 1814, 110, 2, 32, "Output"]
}, Open  ]],
Cell[62951, 1819, 187, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[63163, 1827, 109, 2, 55, "Input"],
Cell[63275, 1831, 275, 4, 32, "Output"]
}, Open  ]],
Cell[63565, 1838, 313, 7, 38, "Text"],
Cell[63881, 1847, 575, 11, 76, "DefinitionBox",
  CellTags->{"NewGametes", "Linkage"}],
Cell[64459, 1860, 223, 4, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[64707, 1868, 99, 2, 38, "Input"],
Cell[64809, 1872, 291, 4, 32, "Output"]
}, Open  ]],
Cell[65115, 1879, 194, 4, 22, "Text"],
Cell[65312, 1885, 137, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[65474, 1892, 134, 2, 42, "Input"],
Cell[65611, 1896, 309, 5, 32, "Output"]
}, Open  ]],
Cell[65935, 1904, 909, 17, 92, "DefinitionBox",
  CellTags->"Mutation"],
Cell[66847, 1923, 112, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[66984, 1930, 151, 4, 26, "Input"],
Cell[67138, 1936, 323, 5, 50, "Output"]
}, Open  ]],
Cell[67476, 1944, 104, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[67605, 1951, 104, 2, 26, "Input"],
Cell[67712, 1955, 290, 5, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[68039, 1965, 86, 2, 26, "Input"],
Cell[68128, 1969, 132, 3, 20, "Output"]
}, Open  ]],
Cell[68275, 1975, 38, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[68338, 1979, 134, 3, 26, "Input"],
Cell[68475, 1984, 290, 5, 20, "Output"]
}, Open  ]],
Cell[68780, 1992, 395, 8, 37, "Text"],
Cell[69178, 2002, 230, 6, 23, "Text"],
Cell[69411, 2010, 611, 13, 78, "DefinitionBox",
  CellTags->{"DemeSize", "RandomDrift", "StoreResults"}],
Cell[70025, 2025, 135, 4, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[70185, 2033, 185, 3, 42, "Input"],
Cell[70373, 2038, 392, 8, 47, "Output"]
}, Open  ]],
Cell[70780, 2049, 473, 14, 38, "Text"],
Cell[71256, 2065, 116, 3, 28, "MathCaption"],
Cell[71375, 2070, 367, 9, 70, "Input"],

Cell[CellGroupData[{
Cell[71767, 2083, 156, 3, 53, "Input"],
Cell[71926, 2088, 508, 11, 79, "Output"]
}, Open  ]],
Cell[72449, 2102, 99, 3, 22, "Text"],
Cell[72551, 2107, 119, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[72695, 2114, 165, 3, 38, "Input"],
Cell[72863, 2119, 283, 4, 32, "Output"]
}, Open  ]],
Cell[73161, 2126, 306, 6, 38, "Text"],
Cell[73470, 2134, 216, 5, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[73711, 2143, 260, 5, 54, "Input"],
Cell[73974, 2150, 285, 7, 32, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

