(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     45456,        957]*)
(*NotebookOutlinePosition[     46386,        987]*)
(*  CellTagsIndexPosition[     46342,        983]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Finding the stability for a cline: a three locus example with \
spatially varying selection\
\>", "SubsectionIcon"],

Cell[TextData[{
  "The algorithms for calculating the stability of a cline also work for \
spatially heterogeneous selection.  The following code stores a three locus \
cline across 20 demes, saving values in \[Psi][t] at t=0,10,\[Ellipsis],100. \
Migration is at its maximum ",
  Cell[BoxData[
      \(TraditionalForm\`\((m\)\)]],
  "=50%).  There is a linear gradient of selection a cross the cline (",
  Cell[BoxData[
      \(TraditionalForm\`W = \((1 - s)\)\^\(\((i + j - ngenes)\) \((x - x\_0)\
\)\)\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  "=1%, ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0 = \((ndemes + 1)\)/2\)]],
  "); this should give a stable set of concordant clines."
}], "Text"],

Cell[BoxData[{
    \(nd = 20; ng = 3;\), "\n", 
    \(\(\(\(grW[s_]\)[x_]\)[i_, 
          j_, _] := \((1 + s)\)\^\(\((i + j - ng)\) \((x - \((nd + 1)\)\/2)\)\
\);\)\), "\n", 
    \(\(\[Psi]0 = 
        MakeCline[nd, ng, 1, 
          NumericalModel \[Rule] 
            SymmetricHaploidFrequencies];\)\), "\[IndentingNewLine]", 
    \(\(StoreExact[\[Psi], \[Psi]0, grW[0.01], 0.5, {100, 10}, 
        Compiled \[Rule] True];\)\)}], "Input",
  CellLabel->"In[76]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi][100] // MatrixForm\)], "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(SymmetricHaploidFrequencies[{0.9734381864235827`, 
                  0.026298279620950746`, 0.00026253717594440816`, 
                  9.96779522191639`*^-7}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.963042504921839`, 
                  0.03638213622595457`, 0.0005715676414583467`, 
                  3.79121074806961`*^-6}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.9399774703536825`, 
                  0.05840713579098788`, 0.0015966559296295595`, 
                  0.00001873792570010641`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.8994855684695245`, 
                  0.09590515457238367`, 0.004518666662863022`, 
                  0.00009061029522874896`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.8354195197799681`, 
                  0.1521048499725552`, 0.012072872069108793`, 
                  0.0004027581783678564`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.7424344215596652`, 
                  0.22638063685299054`, 0.029579202356656505`, 
                  0.0016057392306874695`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.619727342687542`, 
                  0.309453406602105`, 0.0651690978510926`, 
                  0.005650152859260403`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.475240479966805`, 
                  0.3805858326224407`, 0.1268689807712375`, 
                  0.017304706639516755`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.32691285015054883`, 
                  0.4127253823642398`, 0.2147683275160759`, 
                  0.0455934399691355`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.19724786085378873`, 
                  0.38786272562695207`, 0.31228699734055665`, 
                  0.10260241617870276`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.1026024161787028`, 
                  0.3122869973405567`, 0.38786272562695195`, 
                  0.19724786085378868`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.04559343996913553`, 
                  0.21476832751607597`, 0.4127253823642398`, 
                  0.3269128501505488`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.017304706639516762`, 
                  0.12686898077123754`, 0.3805858326224407`, 
                  0.47524047996680485`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.005650152859260406`, 
                  0.06516909785109262`, 0.3094534066021051`, 
                  0.6197273426875418`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.0016057392306874712`, 
                  0.02957920235665653`, 0.22638063685299056`, 
                  0.7424344215596653`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.00040275817836785653`, 
                  0.012072872069108795`, 0.1521048499725552`, 
                  0.8354195197799682`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.0000906102952287489`, 
                  0.004518666662863017`, 0.09590515457238358`, 
                  0.8994855684695245`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{0.000018737925700106386`, 
                  0.0015966559296295576`, 0.058407135790987844`, 
                  0.9399774703536825`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{3.7912107480696065`*^-6, 
                  0.0005715676414583461`, 0.036382136225954556`, 
                  0.9630425049218391`}, 1.`]\)},
            {\(SymmetricHaploidFrequencies[{9.967795221916376`*^-7, 
                  0.0002625371759444078`, 0.02629827962095073`, 
                  0.9734381864235826`}, 1.`]\)}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        SymmetricHaploidFrequencies[ {0.97343818642358271, 
          0.026298279620950746, 0.00026253717594440816, 
          9.9677952219163906*^-07}, 1.0], 
        SymmetricHaploidFrequencies[ {0.96304250492183896, 
          0.03638213622595457, 0.00057156764145834666, 
          3.7912107480696098*^-06}, 1.0], 
        SymmetricHaploidFrequencies[ {0.93997747035368251, 
          0.058407135790987878, 0.0015966559296295595, 
          1.873792570010641*^-05}, 1.0], 
        SymmetricHaploidFrequencies[ {0.89948556846952454, 
          0.095905154572383675, 0.0045186666628630216, 
          9.0610295228748961*^-05}, 1.0], 
        SymmetricHaploidFrequencies[ {0.83541951977996809, 
          0.15210484997255519, 0.012072872069108793, 0.00040275817836785642}, 
          1.0], 
        SymmetricHaploidFrequencies[ {0.74243442155966521, 
          0.22638063685299054, 0.029579202356656505, 0.0016057392306874695}, 
          1.0], 
        SymmetricHaploidFrequencies[ {0.61972734268754204, 
          0.30945340660210502, 0.065169097851092594, 0.0056501528592604027}, 
          1.0], 
        SymmetricHaploidFrequencies[ {0.47524047996680502, 
          0.38058583262244072, 0.12686898077123751, 0.017304706639516755}, 
          1.0], 
        SymmetricHaploidFrequencies[ {0.32691285015054883, 
          0.41272538236423978, 0.21476832751607591, 0.045593439969135501}, 
          1.0], 
        SymmetricHaploidFrequencies[ {0.19724786085378873, 
          0.38786272562695207, 0.31228699734055665, 0.10260241617870276}, 
          1.0], 
        SymmetricHaploidFrequencies[ {0.1026024161787028, 0.3122869973405567, 
          0.38786272562695195, 0.19724786085378868}, 1.0], 
        SymmetricHaploidFrequencies[ {0.045593439969135528, 
          0.21476832751607597, 0.41272538236423978, 0.32691285015054877}, 
          1.0], 
        SymmetricHaploidFrequencies[ {0.017304706639516762, 
          0.12686898077123754, 0.38058583262244072, 0.47524047996680485}, 
          1.0], 
        SymmetricHaploidFrequencies[ {0.0056501528592604062, 
          0.065169097851092622, 0.30945340660210507, 0.61972734268754182}, 
          1.0], 
        SymmetricHaploidFrequencies[ {0.0016057392306874712, 
          0.02957920235665653, 0.22638063685299056, 0.74243442155966533}, 
          1.0], 
        SymmetricHaploidFrequencies[ {0.00040275817836785653, 
          0.012072872069108795, 0.15210484997255519, 0.8354195197799682}, 
          1.0], 
        SymmetricHaploidFrequencies[ {9.0610295228748906*^-05, 
          0.0045186666628630173, 0.095905154572383577, 0.89948556846952454}, 
          1.0], 
        SymmetricHaploidFrequencies[ {1.8737925700106386*^-05, 
          0.0015966559296295576, 0.058407135790987844, 0.93997747035368251}, 
          1.0], 
        SymmetricHaploidFrequencies[ {3.7912107480696065*^-06, 
          0.00057156764145834611, 0.036382136225954556, 0.96304250492183907}, 
          1.0], 
        SymmetricHaploidFrequencies[ {9.9677952219163757*^-07, 
          0.00026253717594440778, 0.026298279620950729, 0.9734381864235826}, 
          1.0]}]]], "Output",
  CellLabel->"Out[80]//MatrixForm="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[AlleleFrequencyMean[\[Psi][100]], 
        PlotJoined \[Rule] True];\)\)], "Input",
  CellLabel->"In[81]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0147151 0.593915 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .1335 -18 -4.5 ]
[.01131 .1335 0 4.5 ]
[.01131 .25228 -18 -4.5 ]
[.01131 .25228 0 4.5 ]
[.01131 .37106 -18 -4.5 ]
[.01131 .37106 0 4.5 ]
[.01131 .48985 -18 -4.5 ]
[.01131 .48985 0 4.5 ]
[.01131 .60863 -6 -4.5 ]
[.01131 .60863 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(10)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(15)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(20)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .1335 m
.03006 .1335 L
s
[(0.2)] .01131 .1335 1 0 Mshowa
.02381 .25228 m
.03006 .25228 L
s
[(0.4)] .01131 .25228 1 0 Mshowa
.02381 .37106 m
.03006 .37106 L
s
[(0.6)] .01131 .37106 1 0 Mshowa
.02381 .48985 m
.03006 .48985 L
s
[(0.8)] .01131 .48985 1 0 Mshowa
.02381 .60863 m
.03006 .60863 L
s
[(1)] .01131 .60863 1 0 Mshowa
.125 Mabswid
.02381 .04441 m
.02756 .04441 L
s
.02381 .07411 m
.02756 .07411 L
s
.02381 .1038 m
.02756 .1038 L
s
.02381 .16319 m
.02756 .16319 L
s
.02381 .19289 m
.02756 .19289 L
s
.02381 .22259 m
.02756 .22259 L
s
.02381 .28198 m
.02756 .28198 L
s
.02381 .31167 m
.02756 .31167 L
s
.02381 .34137 m
.02756 .34137 L
s
.02381 .40076 m
.02756 .40076 L
s
.02381 .43046 m
.02756 .43046 L
s
.02381 .46015 m
.02756 .46015 L
s
.02381 .51954 m
.02756 .51954 L
s
.02381 .54924 m
.02756 .54924 L
s
.02381 .57893 m
.02756 .57893 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.07143 .02003 m
.11905 .02215 L
.16667 .02692 L
.21429 .03554 L
.2619 .04985 L
.30952 .0722 L
.35714 .10514 L
.40476 .15057 L
.45238 .20854 L
.5 .27609 L
.54762 .34726 L
.59524 .41481 L
.64286 .47277 L
.69048 .51821 L
.7381 .55115 L
.78571 .5735 L
.83333 .5878 L
.88095 .59642 L
.92857 .6012 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[81]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00E03oool3000003X0oooo0`0000040?ooo`800000>03oool3000000<0oooo0`00000f0?oo
o`D000000`3oool2000000D0oooo001C0?ooo`050000003oool0oooo0?ooo`000000>P3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000003P0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo03@0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000040?ooo`00E`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000>03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`00E`3oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000>03oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo03H0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0080oooo001C0?ooo`@00000>`3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000003P0oooo00@000000?ooo`3oool0oooo1000000f0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`00D`3oool00`000000oooo
0?ooo`0k0?ooo`800000103oool010000000oooo0?ooo`00000g0?ooo`8000000`3oool00`000000
oooo0?ooo`0g0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000004
0?ooo`00D`3oool5000003X0oooo00<000000?ooo`3oool00`3oool2000003T0oooo00@000000?oo
o`3oool0oooo1@00000f0?ooo`<00000103oool2000000D0oooo000F0?ooo`030000003oool0oooo
0?l0oooo203oool001H0oooo00<000000?ooo`3oool0o`3oool80?ooo`005P3oool00`000000oooo
0?ooo`3o0?ooo`P0oooo000F0?ooo`030000003oool0oooo0?l0oooo203oool00100ooooo`00000?
00000080oooo000F0?ooo`030000003oool0oooo00X0oooo200000050?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00H0oooo000F0?ooo`030000003oool0oooo0180oooo3@00000N0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00H0
oooo000F0?ooo`030000003oool0oooo01l0oooo2000003P0?ooo`005P3oool00`000000oooo0?oo
o`0W0?ooo`@00000g03oool001H0oooo00<000000?ooo`3oool0:`3oool400000=P0oooo000F0?oo
o`030000003oool0oooo02l0oooo1000003D0?ooo`005P3oool00`000000oooo0?ooo`0c0?ooo`D0
0000c`3oool001H0oooo0P00000i0?ooo`@00000b`3oool001H0oooo00<000000?ooo`3oool0?03o
ool300000<P0oooo000F0?ooo`030000003oool0oooo03l0oooo0P0000360?ooo`005P3oool00`00
0000oooo0?ooo`110?ooo`800000a03oool001H0oooo00<000000?ooo`3oool0@`3oool300000<40
oooo000F0?ooo`030000003oool0oooo04H0oooo0P00002o0?ooo`005P3oool00`000000oooo0?oo
o`180?ooo`800000_@3oool001H0oooo00<000000?ooo`3oool0BP3oool200000;/0oooo000F0?oo
o`800000C@3oool00`000000oooo0?ooo`2h0?ooo`005P3oool00`000000oooo0?ooo`1=0?ooo`80
0000^03oool001H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`2e0?ooo`005P3o
ool00`000000oooo0?ooo`1@0?ooo`800000]@3oool001H0oooo00<000000?ooo`3oool0DP3oool0
0`000000oooo0?ooo`2b0?ooo`005P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
0;40oooo000F0?ooo`030000003oool0oooo05@0oooo0P00002a0?ooo`005P3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0:h0oooo000F0?ooo`800000F03oool00`000000oooo0?oo
o`2]0?ooo`005P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0:`0oooo000F0?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0Z`3oool001H0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`2Z0?ooo`005P3oool00`000000oooo0?ooo`1K0?ooo`030000
003oool0oooo0:T0oooo00030?ooo`800000103oool010000000oooo0?ooo`3oool5000000@0oooo
00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`2X0?ooo`000P3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0G@3oool00`000000
oooo0?ooo`2W0?ooo`000P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`2V0?ooo`000P3oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo0`00001O0?ooo`030000003oool0oooo0:D0
oooo00020?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool0Y03oool00080oooo00@000000?ooo`3o
ool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0H@3oool0
0`000000oooo0?ooo`2S0?ooo`000`3oool2000000T0oooo0`0000050?ooo`030000003oool0oooo
0680oooo00<000000?ooo`3oool0XP3oool001H0oooo00<000000?ooo`3oool0H`3oool00`000000
oooo0?ooo`2Q0?ooo`005P3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0:00oooo
000F0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0X03oool001H0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`2O0?ooo`005P3oool2000006L0oooo00<000000?oo
o`3oool0WP3oool001H0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`2M0?ooo`00
5P3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo09`0oooo000F0?ooo`030000003o
ool0oooo06T0oooo00<000000?ooo`3oool0V`3oool001H0oooo00<000000?ooo`3oool0JP3oool0
0`000000oooo0?ooo`2J0?ooo`005P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo
09T0oooo000F0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0V@3oool001H0oooo
00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`2H0?ooo`005P3oool2000006h0oooo00<0
00000?ooo`3oool0U`3oool001H0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`2F
0?ooo`005P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo09D0oooo000F0?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool0U03oool001H0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`2C0?ooo`005P3oool00`000000oooo0?ooo`1a0?ooo`030000003o
ool0oooo09<0oooo000F0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0TP3oool0
01H0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`2A0?ooo`005P3oool2000007@0
oooo00<000000?ooo`3oool0T@3oool001H0oooo00<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`2@0?ooo`005P3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo08l0oooo000F
0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0S`3oool001H0oooo00<000000?oo
o`3oool0MP3oool00`000000oooo0?ooo`2>0?ooo`000`3oool2000000@0oooo00<000000?ooo`3o
ool00`3oool3000000@0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2=0?ooo`00
0P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`2=0?ooo`000P3oool010000000oooo0?ooo`0000070?ooo`D0
0000103oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo08`0oooo00020?ooo`040000
003oool0oooo000000L0oooo00@000000?ooo`3oool000001@3oool3000007T0oooo00<000000?oo
o`3oool0R`3oool00080oooo00@000000?ooo`3oool00000203oool00`000000oooo000000050?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool0R`3oool00080oooo00@000000?ooo`3o
ool000002@3oool2000000D0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2:0?oo
o`000`3oool2000000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1k0?ooo`03
0000003oool0oooo08T0oooo000F0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0
R@3oool001H0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`280?ooo`005P3oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo08L0oooo000F0?ooo`030000003oool0oooo
07d0oooo00<000000?ooo`3oool0Q`3oool001H0oooo0P00001o0?ooo`030000003oool0oooo08H0
oooo000F0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0Q@3oool001H0oooo00<0
00000?ooo`3oool0O`3oool00`000000oooo0?ooo`250?ooo`005P3oool00`000000oooo0?ooo`20
0?ooo`030000003oool0oooo08@0oooo000F0?ooo`030000003oool0oooo0840oooo00<000000?oo
o`3oool0P`3oool001H0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`230?ooo`00
5P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0880oooo000F0?ooo`030000003o
ool0oooo08<0oooo00<000000?ooo`3oool0P@3oool001H0oooo0P0000240?ooo`030000003oool0
oooo0840oooo000F0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0P03oool001H0
oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`200?ooo`005P3oool00`000000oooo
0?ooo`250?ooo`030000003oool0oooo07l0oooo000F0?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool0OP3oool001H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1n
0?ooo`005P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo07d0oooo000F0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0O03oool001H0oooo0P0000290?ooo`030000
003oool0oooo07`0oooo000F0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0N`3o
ool001H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`1j0?ooo`005P3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo07X0oooo000F0?ooo`030000003oool0oooo08/0
oooo00<000000?ooo`3oool0N@3oool000<0oooo0P0000040?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0N03oool00080oooo00@0
00000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`1g0?ooo`000P3oool010000000oooo0?ooo`0000070?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
07L0oooo00020?ooo`040000003oool0oooo000000L0oooo100000050?ooo`<00000SP3oool00`00
0000oooo0?ooo`1f0?ooo`000P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`1e0?ooo`000P3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`1e0?ooo`000`3oool2000000X0oooo0P0000050?ooo`030000003oool0oooo0900
oooo00<000000?ooo`3oool0M03oool001H0oooo00<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`1c0?ooo`005P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0780oooo000F
0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0LP3oool001H0oooo00<000000?oo
o`3oool0T`3oool00`000000oooo0?ooo`1a0?ooo`005P3oool2000009D0oooo00<000000?ooo`3o
ool0L03oool001H0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1`0?ooo`005P3o
ool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo06l0oooo000F0?ooo`030000003oool0
oooo09H0oooo00<000000?ooo`3oool0KP3oool001H0oooo00<000000?ooo`3oool0U`3oool00`00
0000oooo0?ooo`1]0?ooo`005P3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo06d0
oooo000F0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0K03oool001H0oooo00<0
00000?ooo`3oool0V@3oool00`000000oooo0?ooo`1[0?ooo`005P3oool2000009/0oooo00<00000
0?ooo`3oool0JP3oool001H0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`1Y0?oo
o`005P3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo06P0oooo000F0?ooo`030000
003oool0oooo09d0oooo00<000000?ooo`3oool0I`3oool001H0oooo00<000000?ooo`3oool0WP3o
ool00`000000oooo0?ooo`1V0?ooo`005P3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0
oooo06H0oooo000F0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0I@3oool001H0
oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`1T0?ooo`005P3oool200000:80oooo
00<000000?ooo`3oool0H`3oool001H0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?oo
o`1R0?ooo`005P3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo0640oooo000F0?oo
o`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0H03oool001H0oooo00<000000?ooo`3o
ool0Y@3oool00`000000oooo0?ooo`1O0?ooo`000`3oool2000000@0oooo00<000000?ooo`3oool0
0P3oool3000000D0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`1N0?ooo`000P3o
ool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`2W0?ooo`030000003oool0oooo05d0oooo00020?ooo`040000003oool0oooo000000L0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0:P0oooo00<000000?oo
o`3oool0G03oool00080oooo00@000000?ooo`3oool00000203oool3000000D0oooo0`00002Y0?oo
o`030000003oool0oooo05/0oooo00020?ooo`040000003oool0oooo000000L0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0FP3oool0
0080oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1I0?ooo`000`3oool2000000T0oooo0`000005
0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0F03oool001H0oooo00<000000?oo
o`3oool0[@3oool00`000000oooo0?ooo`1G0?ooo`005P3oool00`000000oooo0?ooo`2^0?ooo`03
0000003oool0oooo05H0oooo000F0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0
E@3oool001H0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`1D0?ooo`005P3oool2
00000;80oooo0P00001D0?ooo`005P3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo
0540oooo000F0?ooo`030000003oool0oooo0;@0oooo0P00001A0?ooo`005P3oool00`000000oooo
0?ooo`2f0?ooo`030000003oool0oooo04h0oooo000F0?ooo`030000003oool0oooo0;L0oooo0P00
001>0?ooo`005P3oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo04/0oooo000F0?oo
o`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0BP3oool001H0oooo00<000000?ooo`3o
ool0^`3oool2000004X0oooo000F0?ooo`800000_P3oool00`000000oooo0?ooo`170?ooo`005P3o
ool00`000000oooo0?ooo`2n0?ooo`800000A`3oool001H0oooo00<000000?ooo`3oool0`03oool2
000004D0oooo000F0?ooo`030000003oool0oooo0<80oooo0P0000130?ooo`005P3oool00`000000
oooo0?ooo`340?ooo`800000@@3oool001H0oooo00<000000?ooo`3oool0aP3oool2000003l0oooo
000F0?ooo`030000003oool0oooo0<P0oooo0P00000m0?ooo`005P3oool00`000000oooo0?ooo`3:
0?ooo`<00000>P3oool001H0oooo0P00003>0?ooo`D00000=@3oool001H0oooo00<000000?ooo`3o
ool0dP3oool400000340oooo000F0?ooo`030000003oool0oooo0=H0oooo1000000]0?ooo`005P3o
ool00`000000oooo0?ooo`3J0?ooo`D00000:03oool001H0oooo00<000000?ooo`3oool0g`3oool4
000002@0oooo000>0?ooo`<000001@3oool00`000000oooo0?ooo`3S0?ooo`T000006`3oool000l0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3/0?ooo`d000003P3oool000l0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3i0?ooo`H00000203oool000l0oooo00<0
00000?ooo`3oool0103oool300000?l0oooo203oool000l0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?ooo`P0oooo000>0?ooo`8000001P3oool00`000000oooo0?ooo`3o0?oo
o`P0oooo000?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3oool80?ooo`00
o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.76375, -0.0772696, \
0.0779182, 0.00624733}}]
}, Open  ]],

Cell["The eigenvalues are now given by:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExactEigenvalues[StabilityK[#1, #2, #3, \[Psi][100], grW[0.01], 0.5] &, 
        3] // TableForm\)], "Input",
  CellLabel->"In[82]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"0.9760974256407225`", "0.9440547559939396`", "0.920914201244217`",
             "0.8978474242449934`", "0.8633745930000438`", 
            "0.8167556286907809`", "0.7609069043406459`", 
            "0.6978492795121074`", "0.6293350648943635`", 
            "0.5571285562663306`", "0.4830418902758721`", 
            "0.4805157941287003`", "0.45479604697959825`", 
            "0.4350775935549213`", 
            "0.4205660105257303`", \(\(\(0.4074917702487594`\)\(\
\[InvisibleSpace]\)\) + 
              0.00017871413144618113`\ \[ImaginaryI]\), \
\(\(\(0.4074917702487594`\)\(\[InvisibleSpace]\)\) - 
              0.00017871413144618113`\ \[ImaginaryI]\), "0.3858345222112757`",
             "0.359888629875418`", "0.3375791081675474`", 
            "0.3289603950712511`", "0.2976041105938886`", 
            "0.2670256180973892`", "0.2628506884717647`", 
            "0.2390597407750463`", "0.2274991356822231`", 
            "0.22225847245455357`", "0.20887277371296947`", 
            "0.20072327214838592`", "0.19859643186548112`", 
            "0.1946802769303292`", "0.19079437050375617`", 
            "0.18218090817889437`", "0.17083403996502616`", 
            "0.15734752604135532`", \(\(\(0.1518920132393634`\)\(\
\[InvisibleSpace]\)\) + 
              0.005508997370525025`\ \[ImaginaryI]\), \
\(\(\(0.1518920132393634`\)\(\[InvisibleSpace]\)\) - 
              0.005508997370525025`\ \[ImaginaryI]\), "0.14166032040535986`", 
            "0.12511835618193468`", "0.11963340218344332`", 
            "0.10835074957323322`", 
            "0.10267973506322087`", \(\(\(0.09035975432914634`\)\(\
\[InvisibleSpace]\)\) + 
              0.0023324341829352724`\ \[ImaginaryI]\), \
\(\(\(0.09035975432914634`\)\(\[InvisibleSpace]\)\) - 
              0.0023324341829352724`\ \[ImaginaryI]\), "0.07325943199490564`",
             "0.06367536543842547`", "0.06337966049742942`", 
            "0.05738673176290541`", "0.04248605350716294`", 
            "0.039874678743946644`", "0.03514296299231305`", 
            "0.02871776688154596`", "0.022080726469933778`", 
            "0.017161674359038752`", "0.01573211544464612`", 
            "0.010732414261603852`", "0.006910196256825479`", 
            "0.005057633234612108`", "0.0029679495958582023`", 
            "0.0017940743722290868`", 
            "6.390627289947947`*^-15", \(-1.4858146851670698`*^-15\), \
\(4.669245584706862`*^-16 + 
              2.3245878854949015`*^-16\ \[ImaginaryI]\), \
\(4.669245584706862`*^-16 - 
              2.3245878854949015`*^-16\ \[ImaginaryI]\), \
\(\(-2.5970995953993976`*^-16\) + 
              1.7900616107509753`*^-16\ \[ImaginaryI]\), \
\(\(-2.5970995953993976`*^-16\) - 1.7900616107509753`*^-16\ \[ImaginaryI]\), 
            "1.0853111070685861`*^-16", \(-1.0121277429309222`*^-16\), \
\(\(-2.321373978651733`*^-18\) + 
              8.65330737650708`*^-17\ \[ImaginaryI]\), \
\(\(-2.321373978651733`*^-18\) - 8.65330737650708`*^-17\ \[ImaginaryI]\), 
            "7.304038768080469`*^-17", 
            "6.531499029877225`*^-17", \(-5.71775629535624`*^-17\), \
\(-5.664912401610988`*^-17\), "5.1986505620975117`*^-17", 
            "2.6642638036621912`*^-17", \(-1.5096529620112236`*^-17\), \
\(-4.715813320363495`*^-18\), "3.4347902217310044`*^-18", 
            "1.284463363628279`*^-18"},
          {"0.9778434791385667`", "0.9436861598973805`", 
            "0.9203361839641789`", "0.8972930563506599`", 
            "0.8626691897972322`", "0.8157604072328544`", 
            "0.7595412867743817`", "0.6960527314868995`", 
            "0.6270647424754953`", "0.5543589843486807`", 
            "0.48342678585757975`", "0.47976601816681874`", 
            "0.4565674032941064`", "0.43615172611682923`", 
            "0.4212945214275978`", "0.406496846318227`", 
            "0.40550696600738945`", "0.3869365793112361`", 
            "0.36113249563219074`", "0.3333346734943266`", 
            "0.33021439608720526`", "0.29848277640385085`", 
            "0.2637295300968668`", "0.2629747857077195`", 
            "0.22808005244656823`", "0.19815650825723918`", 
            "0.19331058526171088`", "0.1564946715575453`", 
            "0.14315936356497966`", "0.12349842206933154`", 
            "0.09446353308824186`", "0.09275881262144617`", 
            "0.06515311292397238`", "0.05590951372978941`", 
            "0.041132351957174386`", "0.02869035426178875`", 
            "0.02069044958124567`", "0.012363808655071829`", 
            "0.0059913836851032114`", 
            "0.0033645142103285062`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\
\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\
\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\
\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\
\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{0.97609742564072255, 0.94405475599393962, 
        0.92091420124421697, 0.89784742424499342, 0.86337459300004382, 
        0.81675562869078089, 0.7609069043406459, 0.6978492795121074, 
        0.62933506489436353, 0.55712855626633062, 0.48304189027587208, 
        0.48051579412870032, 0.45479604697959825, 0.43507759355492132, 
        0.42056601052573028, 
        Complex[ 0.40749177024875938, 0.00017871413144618113], 
        Complex[ 0.40749177024875938, -0.00017871413144618113], 
        0.38583452221127568, 0.35988862987541798, 0.33757910816754738, 
        0.32896039507125108, 0.29760411059388858, 0.26702561809738917, 
        0.26285068847176468, 0.2390597407750463, 0.2274991356822231, 
        0.22225847245455357, 0.20887277371296947, 0.20072327214838592, 
        0.19859643186548112, 0.19468027693032919, 0.19079437050375617, 
        0.18218090817889437, 0.17083403996502616, 0.15734752604135532, 
        Complex[ 0.15189201323936341, 0.0055089973705250246], 
        Complex[ 0.15189201323936341, -0.0055089973705250246], 
        0.14166032040535986, 0.12511835618193468, 0.11963340218344332, 
        0.10835074957323322, 0.10267973506322087, 
        Complex[ 0.090359754329146336, 0.0023324341829352724], 
        Complex[ 0.090359754329146336, -0.0023324341829352724], 
        0.073259431994905644, 0.063675365438425474, 0.063379660497429421, 
        0.057386731762905409, 0.042486053507162939, 0.039874678743946644, 
        0.035142962992313051, 0.02871776688154596, 0.022080726469933778, 
        0.017161674359038752, 0.01573211544464612, 0.010732414261603852, 
        0.0069101962568254788, 0.0050576332346121081, 0.0029679495958582023, 
        0.0017940743722290868, 
        6.390627289947947*^-15, -1.4858146851670698*^-15, 
        Complex[ 4.6692455847068621*^-16, 2.3245878854949015*^-16], 
        Complex[ 4.6692455847068621*^-16, -2.3245878854949015*^-16], 
        Complex[ -2.5970995953993976*^-16, 1.7900616107509753*^-16], 
        Complex[ -2.5970995953993976*^-16, -1.7900616107509753*^-16], 
        1.0853111070685861*^-16, -1.0121277429309222*^-16, 
        Complex[ -2.3213739786517331*^-18, 8.6533073765070805*^-17], 
        Complex[ -2.3213739786517331*^-18, -8.6533073765070805*^-17], 
        7.3040387680804692*^-17, 
        6.5314990298772251*^-17, -5.71775629535624*^-17, \
-5.6649124016109879*^-17, 5.1986505620975117*^-17, 
        2.6642638036621912*^-17, -1.5096529620112236*^-17, \
-4.7158133203634947*^-18, 3.4347902217310044*^-18, 1.284463363628279*^-18}, {
        0.97784347913856673, 0.94368615989738047, 0.92033618396417893, 
        0.89729305635065992, 0.86266918979723217, 0.81576040723285437, 
        0.75954128677438171, 0.6960527314868995, 0.62706474247549526, 
        0.55435898434868069, 0.48342678585757975, 0.47976601816681874, 
        0.45656740329410639, 0.43615172611682923, 0.42129452142759782, 
        0.40649684631822702, 0.40550696600738945, 0.3869365793112361, 
        0.36113249563219074, 0.33333467349432661, 0.33021439608720526, 
        0.29848277640385085, 0.26372953009686678, 0.26297478570771948, 
        0.22808005244656823, 0.19815650825723918, 0.19331058526171088, 
        0.15649467155754529, 0.14315936356497966, 0.12349842206933154, 
        0.094463533088241861, 0.092758812621446168, 0.065153112923972384, 
        0.05590951372978941, 0.041132351957174386, 0.028690354261788752, 
        0.020690449581245669, 0.012363808655071829, 0.0059913836851032114, 
        0.0033645142103285062}}]]], "Output",
  CellLabel->"Out[82]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "The rows give eigenvalues for ",
  Cell[BoxData[
      \(TraditionalForm\`p = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`p = 1\)]],
  "."
}], "Text"],

Cell["\<\
The eigenvalues can be found more quickly using \
StabilityKTable[]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(wt = 
        Table[\(\(grW[0.01]\)[d]\)[i, j, h], {d, 20}, {i, 0, ng}, {j, 0, 
            ng}, {h, 0, ng}];\)\), "\[IndentingNewLine]", 
    \(ExactEigenvalues[StabilityKTable[#1, #2, #3, \[Psi][100], wt, 0.5] &, 
        3] // TableForm\)}], "Input",
  CellLabel->"In[83]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"0.9760974256407225`", "0.9440547559939396`", "0.920914201244217`",
             "0.8978474242449934`", "0.8633745930000438`", 
            "0.8167556286907809`", "0.7609069043406459`", 
            "0.6978492795121074`", "0.6293350648943635`", 
            "0.5571285562663306`", "0.4830418902758721`", 
            "0.4805157941287003`", "0.45479604697959825`", 
            "0.4350775935549213`", 
            "0.4205660105257303`", \(\(\(0.4074917702487594`\)\(\
\[InvisibleSpace]\)\) + 
              0.00017871413144618113`\ \[ImaginaryI]\), \
\(\(\(0.4074917702487594`\)\(\[InvisibleSpace]\)\) - 
              0.00017871413144618113`\ \[ImaginaryI]\), "0.3858345222112757`",
             "0.359888629875418`", "0.3375791081675474`", 
            "0.3289603950712511`", "0.2976041105938886`", 
            "0.2670256180973892`", "0.2628506884717647`", 
            "0.2390597407750463`", "0.2274991356822231`", 
            "0.22225847245455357`", "0.20887277371296947`", 
            "0.20072327214838592`", "0.19859643186548112`", 
            "0.1946802769303292`", "0.19079437050375617`", 
            "0.18218090817889437`", "0.17083403996502616`", 
            "0.15734752604135532`", \(\(\(0.1518920132393634`\)\(\
\[InvisibleSpace]\)\) + 
              0.005508997370525025`\ \[ImaginaryI]\), \
\(\(\(0.1518920132393634`\)\(\[InvisibleSpace]\)\) - 
              0.005508997370525025`\ \[ImaginaryI]\), "0.14166032040535986`", 
            "0.12511835618193468`", "0.11963340218344332`", 
            "0.10835074957323322`", 
            "0.10267973506322087`", \(\(\(0.09035975432914634`\)\(\
\[InvisibleSpace]\)\) + 
              0.0023324341829352724`\ \[ImaginaryI]\), \
\(\(\(0.09035975432914634`\)\(\[InvisibleSpace]\)\) - 
              0.0023324341829352724`\ \[ImaginaryI]\), "0.07325943199490564`",
             "0.06367536543842547`", "0.06337966049742942`", 
            "0.05738673176290541`", "0.04248605350716294`", 
            "0.039874678743946644`", "0.03514296299231305`", 
            "0.02871776688154596`", "0.022080726469933778`", 
            "0.017161674359038752`", "0.01573211544464612`", 
            "0.010732414261603852`", "0.006910196256825479`", 
            "0.005057633234612108`", "0.0029679495958582023`", 
            "0.0017940743722290868`", 
            "6.390627289947947`*^-15", \(-1.4858146851670698`*^-15\), \
\(4.669245584706862`*^-16 + 
              2.3245878854949015`*^-16\ \[ImaginaryI]\), \
\(4.669245584706862`*^-16 - 
              2.3245878854949015`*^-16\ \[ImaginaryI]\), \
\(\(-2.5970995953993976`*^-16\) + 
              1.7900616107509753`*^-16\ \[ImaginaryI]\), \
\(\(-2.5970995953993976`*^-16\) - 1.7900616107509753`*^-16\ \[ImaginaryI]\), 
            "1.0853111070685861`*^-16", \(-1.0121277429309222`*^-16\), \
\(\(-2.321373978651733`*^-18\) + 
              8.65330737650708`*^-17\ \[ImaginaryI]\), \
\(\(-2.321373978651733`*^-18\) - 8.65330737650708`*^-17\ \[ImaginaryI]\), 
            "7.304038768080469`*^-17", 
            "6.531499029877225`*^-17", \(-5.71775629535624`*^-17\), \
\(-5.664912401610988`*^-17\), "5.1986505620975117`*^-17", 
            "2.6642638036621912`*^-17", \(-1.5096529620112236`*^-17\), \
\(-4.715813320363495`*^-18\), "3.4347902217310044`*^-18", 
            "1.284463363628279`*^-18"},
          {"0.9778434791385667`", "0.9436861598973805`", 
            "0.9203361839641789`", "0.8972930563506599`", 
            "0.8626691897972322`", "0.8157604072328544`", 
            "0.7595412867743817`", "0.6960527314868995`", 
            "0.6270647424754953`", "0.5543589843486807`", 
            "0.48342678585757975`", "0.47976601816681874`", 
            "0.4565674032941064`", "0.43615172611682923`", 
            "0.4212945214275978`", "0.406496846318227`", 
            "0.40550696600738945`", "0.3869365793112361`", 
            "0.36113249563219074`", "0.3333346734943266`", 
            "0.33021439608720526`", "0.29848277640385085`", 
            "0.2637295300968668`", "0.2629747857077195`", 
            "0.22808005244656823`", "0.19815650825723918`", 
            "0.19331058526171088`", "0.1564946715575453`", 
            "0.14315936356497966`", "0.12349842206933154`", 
            "0.09446353308824186`", "0.09275881262144617`", 
            "0.06515311292397238`", "0.05590951372978941`", 
            "0.041132351957174386`", "0.02869035426178875`", 
            "0.02069044958124567`", "0.012363808655071829`", 
            "0.0059913836851032114`", 
            "0.0033645142103285062`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\
\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\
\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\
\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", "\<\"\
\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{0.97609742564072255, 0.94405475599393962, 
        0.92091420124421697, 0.89784742424499342, 0.86337459300004382, 
        0.81675562869078089, 0.7609069043406459, 0.6978492795121074, 
        0.62933506489436353, 0.55712855626633062, 0.48304189027587208, 
        0.48051579412870032, 0.45479604697959825, 0.43507759355492132, 
        0.42056601052573028, 
        Complex[ 0.40749177024875938, 0.00017871413144618113], 
        Complex[ 0.40749177024875938, -0.00017871413144618113], 
        0.38583452221127568, 0.35988862987541798, 0.33757910816754738, 
        0.32896039507125108, 0.29760411059388858, 0.26702561809738917, 
        0.26285068847176468, 0.2390597407750463, 0.2274991356822231, 
        0.22225847245455357, 0.20887277371296947, 0.20072327214838592, 
        0.19859643186548112, 0.19468027693032919, 0.19079437050375617, 
        0.18218090817889437, 0.17083403996502616, 0.15734752604135532, 
        Complex[ 0.15189201323936341, 0.0055089973705250246], 
        Complex[ 0.15189201323936341, -0.0055089973705250246], 
        0.14166032040535986, 0.12511835618193468, 0.11963340218344332, 
        0.10835074957323322, 0.10267973506322087, 
        Complex[ 0.090359754329146336, 0.0023324341829352724], 
        Complex[ 0.090359754329146336, -0.0023324341829352724], 
        0.073259431994905644, 0.063675365438425474, 0.063379660497429421, 
        0.057386731762905409, 0.042486053507162939, 0.039874678743946644, 
        0.035142962992313051, 0.02871776688154596, 0.022080726469933778, 
        0.017161674359038752, 0.01573211544464612, 0.010732414261603852, 
        0.0069101962568254788, 0.0050576332346121081, 0.0029679495958582023, 
        0.0017940743722290868, 
        6.390627289947947*^-15, -1.4858146851670698*^-15, 
        Complex[ 4.6692455847068621*^-16, 2.3245878854949015*^-16], 
        Complex[ 4.6692455847068621*^-16, -2.3245878854949015*^-16], 
        Complex[ -2.5970995953993976*^-16, 1.7900616107509753*^-16], 
        Complex[ -2.5970995953993976*^-16, -1.7900616107509753*^-16], 
        1.0853111070685861*^-16, -1.0121277429309222*^-16, 
        Complex[ -2.3213739786517331*^-18, 8.6533073765070805*^-17], 
        Complex[ -2.3213739786517331*^-18, -8.6533073765070805*^-17], 
        7.3040387680804692*^-17, 
        6.5314990298772251*^-17, -5.71775629535624*^-17, \
-5.6649124016109879*^-17, 5.1986505620975117*^-17, 
        2.6642638036621912*^-17, -1.5096529620112236*^-17, \
-4.7158133203634947*^-18, 3.4347902217310044*^-18, 1.284463363628279*^-18}, {
        0.97784347913856673, 0.94368615989738047, 0.92033618396417893, 
        0.89729305635065992, 0.86266918979723217, 0.81576040723285437, 
        0.75954128677438171, 0.6960527314868995, 0.62706474247549526, 
        0.55435898434868069, 0.48342678585757975, 0.47976601816681874, 
        0.45656740329410639, 0.43615172611682923, 0.42129452142759782, 
        0.40649684631822702, 0.40550696600738945, 0.3869365793112361, 
        0.36113249563219074, 0.33333467349432661, 0.33021439608720526, 
        0.29848277640385085, 0.26372953009686678, 0.26297478570771948, 
        0.22808005244656823, 0.19815650825723918, 0.19331058526171088, 
        0.15649467155754529, 0.14315936356497966, 0.12349842206933154, 
        0.094463533088241861, 0.092758812621446168, 0.065153112923972384, 
        0.05590951372978941, 0.041132351957174386, 0.028690354261788752, 
        0.020690449581245669, 0.012363808655071829, 0.0059913836851032114, 
        0.0033645142103285062}}]]], "Output",
  CellLabel->"Out[84]//TableForm="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{1082, 708},
WindowMargins->{{Automatic, 23}, {Automatic, -3}},
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 125, 3, 36, "SubsectionIcon"],
Cell[1867, 56, 724, 18, 37, "Text"],
Cell[2594, 76, 466, 11, 85, "Input"],

Cell[CellGroupData[{
Cell[3085, 91, 83, 2, 26, "Input"],
Cell[3171, 95, 6910, 124, 347, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[10118, 224, 139, 3, 22, "Input"],
Cell[10260, 229, 16742, 392, 184, 3087, 218, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[27017, 624, 56, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[27098, 628, 154, 3, 26, "Input"],
Cell[27255, 633, 8773, 146, 49, "Output"]
}, Open  ]],
Cell[36043, 782, 181, 8, 22, "Text"],
Cell[36227, 792, 99, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[36351, 799, 301, 6, 42, "Input"],
Cell[36655, 807, 8773, 146, 49, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

