(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5732,        145]*)
(*NotebookOutlinePosition[      6807,        181]*)
(*  CellTagsIndexPosition[      6727,        175]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Generating a stability matrix", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(StabilityMatrix[a, 
              n]\), \(constructs\ the\ stability\ matrix\ for\ n\ loci, \ 
            with\ elements\ a[i, \ j, \ h]\  . \ 
                Stores\ \(\(results\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"StabilityMatrix"],

Cell[TextData[{
  "This shows the form of the full ",
  Cell[BoxData[
      \(TraditionalForm\`2\^3\ \[Times]2\^3\)]],
  "stability matrix for 3 loci; the haplotypes are ordered by class (i.e. \
{{0,0,0},{0,0,1},{0,1,0},{0,1,1},{1,0,0},{1,0,1},{1,1,0},{1,1,1}}).  For \
example, consider the partial derivatives involving haplotypes with a single \
'1' allele (i.e. ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(1, 1, #\)\)]],
  ", highlighted in ",
  StyleBox["red",
    FontColor->RGBColor[1, 0, 0]],
  "). Derivatives such as ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_\(g[{0, 0, 1}]\)\(g\^*\)[{0, 0, 
            1}]\)]],
  " appear in the diagonal of the sub-matrix; since they are heterozygous at \
no loci, they involve coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(1, 1, 0\)\)]],
  ".  The remaining derivatives involve pairs of genotypes that are \
'heterozygous' at two loci, and therefore give coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(1, 1, 2\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StabilityMatrix[a, 3] /. a[z__] \[RuleDelayed] a\_z // 
      MatrixForm\)], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\(a\_\(0, 0, 0\)\), \(a\_\(0, 1, 1\)\), \(a\_\(0, 1, 1\)\), 
              \(a\_\(0, 1, 1\)\), \(a\_\(0, 2, 2\)\), \(a\_\(0, 2, 2\)\), 
              \(a\_\(0, 2, 2\)\), \(a\_\(0, 3, 3\)\)},
            {\(a\_\(1, 0, 1\)\), 
              StyleBox[\(a\_\(1, 1, 0\)\),
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[\(a\_\(1, 1, 2\)\),
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[\(a\_\(1, 1, 2\)\),
                FontColor->RGBColor[1, 0, 0]], \(a\_\(1, 2, 1\)\), 
              \(a\_\(1, 2, 1\)\), \(a\_\(1, 2, 3\)\), \(a\_\(1, 3, 2\)\)},
            {\(a\_\(1, 0, 1\)\), 
              StyleBox[\(a\_\(1, 1, 2\)\),
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[\(a\_\(1, 1, 0\)\),
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[\(a\_\(1, 1, 2\)\),
                FontColor->RGBColor[1, 0, 0]], \(a\_\(1, 2, 1\)\), 
              \(a\_\(1, 2, 3\)\), \(a\_\(1, 2, 1\)\), \(a\_\(1, 3, 2\)\)},
            {\(a\_\(1, 0, 1\)\), 
              StyleBox[\(a\_\(1, 1, 2\)\),
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[\(a\_\(1, 1, 2\)\),
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[\(a\_\(1, 1, 0\)\),
                FontColor->RGBColor[1, 0, 0]], \(a\_\(1, 2, 3\)\), 
              \(a\_\(1, 2, 1\)\), \(a\_\(1, 2, 1\)\), \(a\_\(1, 3, 2\)\)},
            {\(a\_\(2, 0, 2\)\), \(a\_\(2, 1, 1\)\), \(a\_\(2, 1, 1\)\), 
              \(a\_\(2, 1, 3\)\), \(a\_\(2, 2, 0\)\), \(a\_\(2, 2, 2\)\), 
              \(a\_\(2, 2, 2\)\), \(a\_\(2, 3, 1\)\)},
            {\(a\_\(2, 0, 2\)\), \(a\_\(2, 1, 1\)\), \(a\_\(2, 1, 3\)\), 
              \(a\_\(2, 1, 1\)\), \(a\_\(2, 2, 2\)\), \(a\_\(2, 2, 0\)\), 
              \(a\_\(2, 2, 2\)\), \(a\_\(2, 3, 1\)\)},
            {\(a\_\(2, 0, 2\)\), \(a\_\(2, 1, 3\)\), \(a\_\(2, 1, 1\)\), 
              \(a\_\(2, 1, 1\)\), \(a\_\(2, 2, 2\)\), \(a\_\(2, 2, 2\)\), 
              \(a\_\(2, 2, 0\)\), \(a\_\(2, 3, 1\)\)},
            {\(a\_\(3, 0, 3\)\), \(a\_\(3, 1, 2\)\), \(a\_\(3, 1, 2\)\), 
              \(a\_\(3, 1, 2\)\), \(a\_\(3, 2, 1\)\), \(a\_\(3, 2, 1\)\), 
              \(a\_\(3, 2, 1\)\), \(a\_\(3, 3, 0\)\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[72]//MatrixForm="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{1019, 572},
WindowMargins->{{Automatic, 58}, {Automatic, 4}},
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "StabilityMatrix"->{
    Cell[1797, 53, 338, 7, 37, "DefinitionBox",
      CellTags->"StabilityMatrix"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"StabilityMatrix", 6617, 168}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 55, 0, 36, "SubsectionIcon"],
Cell[1797, 53, 338, 7, 37, "DefinitionBox",
  CellTags->"StabilityMatrix"],
Cell[2138, 62, 1032, 26, 51, "Text"],

Cell[CellGroupData[{
Cell[3195, 92, 130, 3, 26, "Input"],
Cell[3328, 97, 2376, 44, 159, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

