(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     17477,        564]*)
(*NotebookOutlinePosition[     19086,        615]*)
(*  CellTagsIndexPosition[     18873,        605]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Immigration from a source  population", "SubsectionIcon",
  CellTags->"Immigration"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MigrateExact[\[Phi], \[Phi]\_s, 
              m]\), \(gives\ class\ frequencies\ and\ deme\ sizes\ after\ \
migration\ from\ a\ source\ population\ \[Phi]\_s\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"MigrateExact"],

Cell["\<\
This gives the allele frequencies after a proportion m of \
individuals migrate:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(hp = 
        MakePopulation[3, 0.3, 10, 
          NumericalModel \[Rule] 
            SymmetricHaploidFrequencies];\)\), "\[IndentingNewLine]", 
    \(\(hps = 
        MakePopulation[3, 1, 10, 
          NumericalModel \[Rule] SymmetricHaploidFrequencies];\)\), "\n", 
    \(hp1 = MigrateExact[hp, hps, m]; 
    AlleleFrequencyTable[hp1] // Simplify\)}], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \({\(\(0.29999999999999993`\)\(\[InvisibleSpace]\)\) + 
        0.7`\ m, \(\(0.29999999999999993`\)\(\[InvisibleSpace]\)\) + 
        0.7`\ m, \(\(0.29999999999999993`\)\(\[InvisibleSpace]\)\) + 
        0.7`\ m}\)], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell["The deme size also remains constant:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DemeSize[hp1] // Simplify\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \(10\)], "Output",
  CellLabel->"Out[34]="]
}, Open  ]],

Cell["\<\
Immigration from a larger population has a greater effect on allele \
frequency:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(hps2 = 
        MakePopulation[3, 1, 100, 
          NumericalModel \[Rule] SymmetricHaploidFrequencies];\)\), "\n", 
    \(\(hp2 = MigrateExact[hp, hps2, m];\)\), "\[IndentingNewLine]", 
    \(AlleleFrequencyTable[hp2] // Simplify\)}], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \({\(\(\(2.9999999999999996`\)\(\[InvisibleSpace]\)\) + 97.`\ m\)\/\(10 + \
90\ m\), \(\(\(2.9999999999999996`\)\(\[InvisibleSpace]\)\) + 97.`\ m\)\/\(10 \
+ 90\ m\), \(\(\(2.9999999999999996`\)\(\[InvisibleSpace]\)\) + 97.`\ \
m\)\/\(10 + 90\ m\)}\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell["The deme size also increases:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DemeSize[hp2]\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \(10\ \((1 - m)\) + 100\ m\)], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell[TextData[{
  "In general, the new deme size is ",
  Cell[BoxData[
      \(TraditionalForm\`n(1 - m) + \(n\_s\) 
          m, \ \(\(and\)\(\ \)\(the\)\(\ \)\(new\)\(\ \)\(allele\)\(\ \
\)\(frequency\)\(\ \)\(is\)\(\ \)\)\)]],
  Cell[BoxData[
      FormBox[
        FractionBox[
          FormBox[\(n\ \(p(1 - m)\) + \(n\_s\) \(p\_s\) m\),
            "TraditionalForm"], \(n(1 - m) + \(n\_s\) m\)], 
        TraditionalForm]]],
  "; thus, m is the ",
  StyleBox["forward",
    FontSlant->"Italic"],
  " migration rate. "
}], "Text"],

Cell[TextData[{
  "The ",
  StyleBox["backwards",
    FontSlant->"Italic"],
  " migration rate (the proportion of the new population that are \
immigrants), is ",
  Cell[BoxData[
      \(TraditionalForm\`m\_b\)]],
  " ",
  Cell[BoxData[
      FormBox[
        FractionBox[
          FormBox[\(\(n\_s\) m\),
            "TraditionalForm"], \(n(1 - m) + \(n\_s\) m\)], 
        TraditionalForm]]]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Nearest-neighbour migration", "SubsectionIcon",
  CellTags->"Nearest-neighbour migration"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MigrateExact[{\[Phi]\_1, \[Ellipsis], \[Phi]\_n}, 
              m]\), \(gives\ the\ array\ of\ class\ frequencies\ after\ \
nearest - neighbour\ migration\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["\<\
This sets up a stepped cline across 6 demes, with 3 loci and deme \
size 10:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(hp = 
      MakeCline[6, 3, 10, 
        NumericalModel \[Rule] SymmetricHaploidFrequencies]\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \({SymmetricHaploidFrequencies[{1, 0, 0, 0}, 10], 
      SymmetricHaploidFrequencies[{1, 0, 0, 0}, 10], 
      SymmetricHaploidFrequencies[{1, 0, 0, 0}, 10], 
      SymmetricHaploidFrequencies[{0, 0, 0, 1}, 10], 
      SymmetricHaploidFrequencies[{0, 0, 0, 1}, 10], 
      SymmetricHaploidFrequencies[{0, 0, 0, 1}, 10]}\)], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell["\<\
Nearest-neighbour migration only affects the central demes in this \
example:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(hp1 = MigrateExact[hp, m] // Simplify\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \({SymmetricHaploidFrequencies[{1, 0, 0, 0}, 10], 
      SymmetricHaploidFrequencies[{1, 0, 0, 0}, 10], 
      SymmetricHaploidFrequencies[{1 - m\/2, 0, 0, m\/2}, 10], 
      SymmetricHaploidFrequencies[{m\/2, 0, 0, 1 - m\/2}, 10], 
      SymmetricHaploidFrequencies[{0, 0, 0, 1}, 10], 
      SymmetricHaploidFrequencies[{0, 0, 0, 1}, 10]}\)], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell["\<\
MigrateExact[] can also act on an array of diploid class \
frequencies:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dp = 
        MakeCline[6, 3, 10, 
          NumericalModel \[Rule] 
            SymmetricDiploidFrequencies];\)\), "\[IndentingNewLine]", 
    \(\(dp1 = MigrateExact[dp, m] // Simplify;\)\), "\[IndentingNewLine]", 
    \(AlleleFrequencyTable[dp1] // MatrixForm\)}], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "0"},
            {"0", "0", "0"},
            {\(m\/2\), \(m\/2\), \(m\/2\)},
            {\(\(2 - m\)\/2\), \(\(2 - m\)\/2\), \(\(2 - m\)\/2\)},
            {"1", "1", "1"},
            {"1", "1", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[43]//MatrixForm="]
}, Open  ]],

Cell["Migration generates linkage disequilibrium:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DisequilibriumTable[dp1] // Simplify\) // MatrixForm\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(\(-\(1\/4\)\)\ \((\(-2\) + m)\)\ m\)},
                    {\(\(-\(1\/4\)\)\ \((\(-2\) + m)\)\ m\)},
                    {\(\(-\(1\/4\)\)\ \((\(-2\) + m)\)\ m\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(\(-\(1\/4\)\)\ \((\(-2\) + m)\)\ m\)},
                    {\(\(-\(1\/4\)\)\ \((\(-2\) + m)\)\ m\)},
                    {\(\(-\(1\/4\)\)\ \((\(-2\) + m)\)\ m\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(\(-\(1\/4\)\)\ \((\(-2\) + m)\)\ m\)},
                    {\(\(-\(1\/4\)\)\ \((\(-2\) + m)\)\ m\)},
                    {\(\(-\(1\/4\)\)\ \((\(-2\) + m)\)\ m\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(\(-\(1\/4\)\)\ \((\(-2\) + m)\)\ m\)},
                    {\(\(-\(1\/4\)\)\ \((\(-2\) + m)\)\ m\)},
                    {\(\(-\(1\/4\)\)\ \((\(-2\) + m)\)\ m\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(\(-\(1\/4\)\)\ \((\(-2\) + m)\)\ m\)},
                    {\(\(-\(1\/4\)\)\ \((\(-2\) + m)\)\ m\)},
                    {\(\(-\(1\/4\)\)\ \((\(-2\) + m)\)\ m\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(\(-\(1\/4\)\)\ \((\(-2\) + m)\)\ m\)},
                    {\(\(-\(1\/4\)\)\ \((\(-2\) + m)\)\ m\)},
                    {\(\(-\(1\/4\)\)\ \((\(-2\) + m)\)\ m\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"0"},
                    {"0"},
                    {"0"}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 0}, {
        0, 0, 0}}, {{
        Times[ 
          Rational[ -1, 4], 
          Plus[ -2, m], m], 
        Times[ 
          Rational[ -1, 4], 
          Plus[ -2, m], m], 
        Times[ 
          Rational[ -1, 4], 
          Plus[ -2, m], m]}, {
        Times[ 
          Rational[ -1, 4], 
          Plus[ -2, m], m], 
        Times[ 
          Rational[ -1, 4], 
          Plus[ -2, m], m], 
        Times[ 
          Rational[ -1, 4], 
          Plus[ -2, m], m]}, {
        Times[ 
          Rational[ -1, 4], 
          Plus[ -2, m], m], 
        Times[ 
          Rational[ -1, 4], 
          Plus[ -2, m], m], 
        Times[ 
          Rational[ -1, 4], 
          Plus[ -2, m], m]}}, {{
        Times[ 
          Rational[ -1, 4], 
          Plus[ -2, m], m], 
        Times[ 
          Rational[ -1, 4], 
          Plus[ -2, m], m], 
        Times[ 
          Rational[ -1, 4], 
          Plus[ -2, m], m]}, {
        Times[ 
          Rational[ -1, 4], 
          Plus[ -2, m], m], 
        Times[ 
          Rational[ -1, 4], 
          Plus[ -2, m], m], 
        Times[ 
          Rational[ -1, 4], 
          Plus[ -2, m], m]}, {
        Times[ 
          Rational[ -1, 4], 
          Plus[ -2, m], m], 
        Times[ 
          Rational[ -1, 4], 
          Plus[ -2, m], m], 
        Times[ 
          Rational[ -1, 4], 
          Plus[ -2, m], m]}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {
        0, 0, 0}, {0, 0, 0}}}]]], "Output",
  CellLabel->"Out[44]//MatrixForm="]
}, Closed]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MigrateExact[{\[Phi]\_1, \[Ellipsis], \[Phi]\_n}, m, 
              FixedEnds \[Rule] {\[Phi]\_0, \[Phi]\_\(n + 1\)}]\), 
            
            RowBox[{\(sets\ fixed\ endpoints\), ",", " ", \(\[Phi]\_0\), ",", 
              
              RowBox[{\(\[Phi]\_\(n + 1\)\), " ", 
                StyleBox["outside",
                  FontSlant->"Italic"], " ", "the", " ", "iterated", " ", 
                "demes"}]}]}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"FixedEnds"],

Cell["\<\
Using FixedEnds sets up hypothetical demes with fixed genotype \
frequencies (here, 0.1 and 0.9) outside the ends of the iterated cline:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi]0 = 
      MakePopulation[3, 0.1, 10, 
        NumericalModel \[Rule] SymmetricHaploidFrequencies]; \[Psi]1 = 
      MakePopulation[3, 0.9, 10, 
        NumericalModel \[Rule] 
          SymmetricHaploidFrequencies];\), "\[IndentingNewLine]", 
    \({\[Psi]0, \[Psi]1}\)}], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \({SymmetricHaploidFrequencies[{0.7290000000000001`, 
          0.24300000000000005`, 0.02700000000000001`, 
          0.0010000000000000002`}, 10], 
      SymmetricHaploidFrequencies[{0.0009999999999999994`, 
          0.02699999999999999`, 0.24299999999999997`, 0.7290000000000001`}, 
        10]}\)], "Output",
  CellLabel->"Out[46]="]
}, Open  ]],

Cell["\<\
Immigration from these source populations introduces \
polymorphism:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(hp2 = MigrateExact[hp, 0.5, FixedEnds \[Rule] {\[Psi]0, \[Psi]1}]; 
    AlleleFrequencyMean[hp2]\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \({0.02500000000000001`, 0, 0.25`, 0.75`, 1.`, 0.975`}\)], "Output",
  CellLabel->"Out[47]="]
}, Open  ]],

Cell["\<\
FixedEnds can also be used to set different kinds of boundary \
condition at either end: \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(hp3 = MigrateExact[hp, 0.5, FixedEnds \[Rule] {{}, \[Psi]1}]; 
    AlleleFrequencyMean[hp3]\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \({0, 0, 0.25`, 0.75`, 1.`, 0.975`}\)], "Output",
  CellLabel->"Out[48]="]
}, Open  ]],

Cell["\<\
The default {} or {{}} indicates that there should be no flow \
across the boundary.\
\>", "Text"],

Cell[TextData[{
  "If FixedEnds is used with diploid genotype frequencies, then the end \
frequencies ",
  StyleBox["must",
    FontWeight->"Bold"],
  " also give diploid frequencies:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Psi]1 = 
        MakePopulation[3, 0.9, 10, 
          NumericalModel \[Rule] 
            SymmetricDiploidFrequencies];\)\), "\[IndentingNewLine]", 
    \(dp3 = MigrateExact[dp, 0.5, FixedEnds \[Rule] {{}, \[Psi]1}]; 
    AlleleFrequencyMean[dp3]\)}], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \({0, 0, 0.25`, 0.75`, 1.`, 0.9750000000000001`}\)], "Output",
  CellLabel->"Out[50]="]
}, Open  ]],

Cell["Deme sizes may change as a result of migration:", "MathCaption",
  CellTags->"DemeSize"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Psi]1 = 
        MakePopulation[3, 0.9, 100, 
          NumericalModel \[Rule] 
            SymmetricHaploidFrequencies];\)\), "\[IndentingNewLine]", 
    \(hp4 = 
      MigrateExact[hp, 0.5, 
        FixedEnds \[Rule] {{}, \[Psi]1}]; {AlleleFrequencyMean[hp4], 
      DemeSize[hp4]}\)}], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \({{0, 0, 0.25`, 0.75`, 1.`, 0.923076923076923`}, {10.`, 10.`, 10.`, 
        10.`, 10.`, 32.5`}}\)], "Output",
  CellLabel->"Out[52]="]
}, Open  ]],

Cell[TextData[{
  "m is the ",
  StyleBox["forward",
    FontSlant->"Italic"],
  " migration rate (see above); immigration from the larger source population \
increases deme size."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{681, 691},
WindowMargins->{{39, Automatic}, {Automatic, -2}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Immigration"->{
    Cell[1739, 51, 90, 1, 36, "SubsectionIcon",
      CellTags->"Immigration"]},
  "MigrateExact"->{
    Cell[1832, 54, 304, 6, 52, "DefinitionBox",
      CellTags->"MigrateExact"]},
  "Nearest-neighbour migration"->{
    Cell[5204, 176, 96, 1, 36, "SubsectionIcon",
      CellTags->"Nearest-neighbour migration"]},
  "FixedEnds"->{
    Cell[13583, 428, 559, 12, 48, "DefinitionBox",
      CellTags->"FixedEnds"]},
  "DemeSize"->{
    Cell[16631, 533, 94, 1, 28, "MathCaption",
      CellTags->"DemeSize"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Immigration", 18340, 586},
  {"MigrateExact", 18441, 589},
  {"Nearest-neighbour migration", 18558, 592},
  {"FixedEnds", 18673, 595},
  {"DemeSize", 18771, 598}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 90, 1, 36, "SubsectionIcon",
  CellTags->"Immigration"],
Cell[1832, 54, 304, 6, 52, "DefinitionBox",
  CellTags->"MigrateExact"],
Cell[2139, 62, 111, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2275, 69, 413, 10, 90, "Input"],
Cell[2691, 81, 269, 5, 20, "Output"]
}, Open  ]],
Cell[2975, 89, 59, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3059, 93, 83, 2, 26, "Input"],
Cell[3145, 97, 61, 2, 20, "Output"]
}, Open  ]],
Cell[3221, 102, 111, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3357, 109, 293, 6, 74, "Input"],
Cell[3653, 117, 305, 5, 36, "Output"]
}, Open  ]],
Cell[3973, 125, 52, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4050, 129, 71, 2, 26, "Input"],
Cell[4124, 133, 83, 2, 20, "Output"]
}, Open  ]],
Cell[4222, 138, 536, 16, 30, "Text"],
Cell[4761, 156, 406, 15, 29, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5204, 176, 96, 1, 36, "SubsectionIcon",
  CellTags->"Nearest-neighbour migration"],
Cell[5303, 179, 273, 5, 37, "DefinitionBox"],
Cell[5579, 186, 107, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5711, 193, 150, 4, 26, "Input"],
Cell[5864, 199, 376, 7, 95, "Output"]
}, Open  ]],
Cell[6255, 209, 108, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6388, 216, 95, 2, 26, "Input"],
Cell[6486, 220, 396, 7, 145, "Output"]
}, Open  ]],
Cell[6897, 230, 102, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7024, 237, 323, 7, 58, "Input"],
Cell[7350, 246, 406, 11, 127, "Output"]
}, Open  ]],
Cell[7771, 260, 66, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[7862, 264, 112, 2, 26, "Input"],
Cell[7977, 268, 5591, 157, 357, "Output"]
}, Closed]],
Cell[13583, 428, 559, 12, 48, "DefinitionBox",
  CellTags->"FixedEnds"],
Cell[14145, 442, 169, 4, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[14339, 450, 334, 8, 74, "Input"],
Cell[14676, 460, 356, 7, 35, "Output"]
}, Open  ]],
Cell[15047, 470, 99, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[15171, 477, 154, 3, 26, "Input"],
Cell[15328, 482, 111, 2, 20, "Output"]
}, Open  ]],
Cell[15454, 487, 120, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[15599, 494, 149, 3, 26, "Input"],
Cell[15751, 499, 92, 2, 20, "Output"]
}, Open  ]],
Cell[15858, 504, 108, 3, 22, "Text"],
Cell[15969, 509, 203, 6, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[16197, 519, 311, 7, 58, "Input"],
Cell[16511, 528, 105, 2, 20, "Output"]
}, Open  ]],
Cell[16631, 533, 94, 1, 28, "MathCaption",
  CellTags->"DemeSize"],

Cell[CellGroupData[{
Cell[16750, 538, 347, 9, 74, "Input"],
Cell[17100, 549, 154, 3, 20, "Output"]
}, Open  ]],
Cell[17269, 555, 192, 6, 24, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

