(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     40613,        969]*)
(*NotebookOutlinePosition[    112456,       3557]*)
(*  CellTagsIndexPosition[    112307,       3549]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Finding the stability for a single deme: a four locus example\
\>", \
"SubsectionIcon"],

Cell["This loads the package, as well as the graphics package:", "MathCaption"],

Cell[BoxData[
    \(<< NumericalModels`ExactModel`; << Graphics`;\)], "Input",
  CellLabel->"In[19]:="],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(StabilityK[k, i, h, \[Psi], 
              W]\), \(calculates\ the\ elements\ of\ the\ stability\ matrix\ \
for\ the\ given\ fitness\ scheme . \ 
                Omits\ the\ factor\ \(2\/\(\(W\&_\)\(.\)\)\) . \ \ \[Psi]\ \
must\ have\ the\ form\ SymmetricHaploidFrequencies[{\[Phi]\_0, \[Ellipsis]}, 
                n\_d]\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"StabilityK"],

Cell[TextData[{
  "Initially, a population ",
  Cell[BoxData[
      \(TraditionalForm\`\((g0\)\)]],
  ") is fixed for genotypes with 2 '0' alleles and 2 '1' alleles; all such \
genotypes are  equally frequent. Stabilising selection of strength s towards \
optimum ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0\)]],
  " is defined by ",
  Cell[BoxData[
      \(TraditionalForm\`stabW[s, z\_0]\)]],
  ". This fitness function is passed to IterateExact[], which is applied over \
10 generations using Nest[].  Since selection is strong (s=1), the result ",
  Cell[BoxData[
      \(TraditionalForm\`\((gt\)\)]],
  ") is very close to equilibrium.  Mean fitness is 0.651."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g0 = SymmetricHaploidFrequencies[{0, 0, 1, 0, 0}, 1];\)\), "\n", 
    \(\(\(stabW[s_, z0_]\)[i_, j_, 
          h_] := \[ExponentialE]\^\(\(-s\) \(\(\((i + j - \
z0)\)\^2\)\(/\)\(2\)\(\ \)\)\);\)\), "\n", 
    \(\(gt = Nest[IterateExact[#, stabW[1, 4. ], 0] &, g0, 10];\)\), "\n", 
    \(wb = MeanW[MakeDiploid[gt], stabW[1, 4. ]]\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(0.6513987336049852`\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell["\<\
This histogram shows the equilibrium under stabilising selection:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BarChart[gt\[LeftDoubleBracket]1\[RightDoubleBracket], 
        BarLabels \[Rule] {0, 1, 2, 3, 4}, 
        PlotRange \[Rule] {{1, 5}, {0, 0.5}}];\)\)], "Input",
  CellLabel->"In[89]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.25 0.25 0 1.23607 [
[0 -0.0125 -3 -9 ]
[0 -0.0125 3 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.1625 .12361 -18 -4.5 ]
[-0.1625 .12361 0 4.5 ]
[-0.1625 .24721 -18 -4.5 ]
[-0.1625 .24721 0 4.5 ]
[-0.1625 .37082 -18 -4.5 ]
[-0.1625 .37082 0 4.5 ]
[-0.1625 .49443 -18 -4.5 ]
[-0.1625 .49443 0 4.5 ]
[-0.1625 .61803 -18 -4.5 ]
[-0.1625 .61803 0 4.5 ]
[ -0.15 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(0)] 0 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
-0.15 .12361 m
-0.14375 .12361 L
s
[(0.1)] -0.1625 .12361 1 0 Mshowa
-0.15 .24721 m
-0.14375 .24721 L
s
[(0.2)] -0.1625 .24721 1 0 Mshowa
-0.15 .37082 m
-0.14375 .37082 L
s
[(0.3)] -0.1625 .37082 1 0 Mshowa
-0.15 .49443 m
-0.14375 .49443 L
s
[(0.4)] -0.1625 .49443 1 0 Mshowa
-0.15 .61803 m
-0.14375 .61803 L
s
[(0.5)] -0.1625 .61803 1 0 Mshowa
.125 Mabswid
-0.15 .02472 m
-0.14625 .02472 L
s
-0.15 .04944 m
-0.14625 .04944 L
s
-0.15 .07416 m
-0.14625 .07416 L
s
-0.15 .09889 m
-0.14625 .09889 L
s
-0.15 .14833 m
-0.14625 .14833 L
s
-0.15 .17305 m
-0.14625 .17305 L
s
-0.15 .19777 m
-0.14625 .19777 L
s
-0.15 .22249 m
-0.14625 .22249 L
s
-0.15 .27193 m
-0.14625 .27193 L
s
-0.15 .29666 m
-0.14625 .29666 L
s
-0.15 .32138 m
-0.14625 .32138 L
s
-0.15 .3461 m
-0.14625 .3461 L
s
-0.15 .39554 m
-0.14625 .39554 L
s
-0.15 .42026 m
-0.14625 .42026 L
s
-0.15 .44498 m
-0.14625 .44498 L
s
-0.15 .46971 m
-0.14625 .46971 L
s
-0.15 .51915 m
-0.14625 .51915 L
s
-0.15 .54387 m
-0.14625 .54387 L
s
-0.15 .56859 m
-0.14625 .56859 L
s
-0.15 .59331 m
-0.14625 .59331 L
s
.25 Mabswid
-0.15 0 m
-0.15 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
-0.1 0 m
-0.1 .03023 L
.1 .03023 L
.1 0 L
F
0 g
.5 Mabswid
0 .03023 m
.1 .03023 L
.1 0 L
s
1 0 0 r
.15 0 m
.15 .2928 L
.35 .2928 L
.35 0 L
F
0 g
.15 0 m
.15 .2928 L
.35 .2928 L
.35 0 L
.15 0 L
s
1 0 0 r
.4 0 m
.4 .59 L
.6 .59 L
.6 0 L
F
0 g
.4 0 m
.4 .59 L
.6 .59 L
.6 0 L
.4 0 L
s
1 0 0 r
.65 0 m
.65 .2928 L
.85 .2928 L
.85 0 L
F
0 g
.65 0 m
.65 .2928 L
.85 .2928 L
.85 0 L
.65 0 L
s
1 0 0 r
.9 0 m
.9 .03023 L
1.1 .03023 L
1.1 0 L
F
0 g
.9 0 m
.9 .03023 L
s
.9 .03023 m
1 .03023 L
s
.9 0 m
0 0 rlineto s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[89]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00=P3oool2
000003H0oooo0`00000e0?ooo`D00000=@3oool3000003P0oooo0`0000020?ooo`00=@3oool01000
0000oooo0?ooo`00000f0?ooo`030000003oool0oooo03D0oooo00@000000?ooo`3oool00000=03o
ool01@000000oooo0?ooo`3oool0000003P0oooo00<000000?ooo`3oool00@3oool003D0oooo00@0
00000?ooo`3oool00000=P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0<`3oool500000080oooo000e0?ooo`040000003oool0oooo000003H0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0e0?ooo`800000=P3oool010000000oooo
0?ooo`0000030?ooo`00=@3oool010000000oooo0?ooo`00000f0?ooo`030000003oool0oooo03@0
oooo00D000000?ooo`3oool0oooo0000000h0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`0000000`3oool003D0oooo00@000000?ooo`3oool00000=@3oool2000003H0oooo00D000000?oo
o`3oool0oooo0000000d0?ooo`050000003oool0oooo0?ooo`000000=`3oool2000000<0oooo000f
0?ooo`800000=`3oool00`000000oooo0?ooo`0e0?ooo`<00000=P3oool3000003T0oooo00<00000
0?ooo`3oool00@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool001@0oooo00<000000?ooo`3oool0803ooooV000000<0oooo000D0?ooo`030000003oool0oooo
00T0oooo;P3o00000`000000oooo0?ooo`080?ooo`030000003o0000o`0002/0o`0000<000000?oo
o`3oool0203oool00`000000o`000?l0000[0?l000030000003oool0oooo00P0oooo00<000000?l0
003o0000:`3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0001P0o`00000D0?ooo`03
0000003oool0oooo00T0oooo;P3o00000`000000oooo0?ooo`080?ooo`030000003o0000o`0002/0
o`0000<000000?ooo`3oool0203oool00`000000o`000?l0000[0?l000030000003oool0oooo00P0
oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`090?ooo`030000003o0000o`0001P0
o`00000D0?ooo`030000003oool0oooo00T0oooo;P3o00000`000000oooo0?ooo`080?ooo`030000
003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`000000o`000?l0000[0?l000030000
003oool0oooo00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`090?ooo`030000
003o0000o`0001P0o`00000D0?ooo`030000003oool0oooo00T0oooo;P3o00000`000000oooo0?oo
o`080?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`000000o`000?l0
000[0?l000030000003oool0oooo00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?oo
o`090?ooo`030000003o0000o`0001P0o`00000D0?ooo`030000003oool0oooo00T0oooo;P3o0000
0`000000oooo0?ooo`080?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0203oool0
0`000000o`000?l0000[0?l000030000003oool0oooo00P0oooo00<000000?l0003o0000:`3o0000
0`000000oooo0?ooo`090?ooo`030000003o0000o`0001P0o`00000D0?ooo`8000002P3oool^0?l0
00030000003oool0oooo00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`080?oo
o`030000003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`000000o`000?l0000[0?l0
00030000003oool0oooo00T0oooo00<000000?l0003o0000603o000001@0oooo00<000000?ooo`3o
ool02@3ooolG0?l001P000002P3oool00`000000o`000?l0000[0?l000030000003oool0oooo00P0
oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`080?ooo`030000003o0000o`0002/0
o`0000<000000?ooo`3oool02@3ooolH000000<0o`00000D0?ooo`030000003oool0oooo0480oooo
00<000000?l0003o0000:`3o00000`000000oooo0?ooo`080?ooo`030000003o0000o`0002/0o`00
00<000000?ooo`3oool0203oool00`000000o`000?l0000[0?l000030000003oool0oooo02@0oooo
000D0?ooo`030000003oool0oooo0480oooo00<000000?l0003o0000:`3o00000`000000oooo0?oo
o`080?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`000000o`000?l0
000[0?l000030000003oool0oooo02@0oooo000D0?ooo`030000003oool0oooo0480oooo00<00000
0?l0003o0000:`3o00000`000000oooo0?ooo`080?ooo`030000003o0000o`0002/0o`0000<00000
0?ooo`3oool0203oool00`000000o`000?l0000[0?l000030000003oool0oooo02@0oooo000D0?oo
o`800000@`3oool00`000000o`000?l0000[0?l000030000003oool0oooo00P0oooo00<000000?l0
003o0000:`3o00000`000000oooo0?ooo`080?ooo`030000003o0000o`0002/0o`0000<000000?oo
o`3oool0903oool001@0oooo00<000000?ooo`3oool0@P3oool00`000000o`000?l0000[0?l00003
0000003oool0oooo00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`080?ooo`03
0000003o0000o`0002/0o`0000<000000?ooo`3oool0903oool001@0oooo00<000000?ooo`3oool0
@P3oool00`000000o`000?l0000[0?l000030000003oool0oooo00P0oooo00<000000?l0003o0000
:`3o00000`000000oooo0?ooo`080?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0
903oool001@0oooo00<000000?ooo`3oool0@P3oool00`000000o`000?l0000[0?l000030000003o
ool0oooo00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`080?ooo`030000003o
0000o`0002/0o`0000<000000?ooo`3oool0903oool001@0oooo00<000000?ooo`3oool0@P3oool0
0`000000o`000?l0000[0?l000030000003oool0oooo00P0oooo00<000000?l0003o0000:`3o0000
0`000000oooo0?ooo`080?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0903oool0
01@0oooo00<000000?ooo`3oool0@P3oool00`000000o`000?l0000[0?l000030000003oool0oooo
00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`080?ooo`030000003o0000o`00
02/0o`0000<000000?ooo`3oool0903oool001@0oooo0P0000130?ooo`030000003o0000o`0002/0
o`0000<000000?ooo`3oool0203oool00`000000o`000?l0000[0?l000030000003oool0oooo00P0
oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`0T0?ooo`00503oool00`000000oooo
0?ooo`120?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`000000o`00
0?l0000[0?l000030000003oool0oooo00P0oooo00<000000?l0003o0000:`3o00000`000000oooo
0?ooo`0T0?ooo`00503oool00`000000oooo0?ooo`120?ooo`030000003o0000o`0002/0o`0000<0
00000?ooo`3oool0203oool00`000000o`000?l0000[0?l000030000003oool0oooo00P0oooo00<0
00000?l0003o0000:`3o00000`000000oooo0?ooo`0T0?ooo`00503oool00`000000oooo0?ooo`12
0?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`000000o`000?l0000[
0?l000030000003oool0oooo00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`0T
0?ooo`00503oool00`000000oooo0?ooo`120?ooo`030000003o0000o`0002/0o`0000<000000?oo
o`3oool0203oool00`000000o`000?l0000[0?l000030000003oool0oooo00P0oooo00<000000?l0
003o0000:`3o00000`000000oooo0?ooo`0T0?ooo`00503oool00`000000oooo0?ooo`120?ooo`03
0000003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`000000o`000?l0000[0?l00003
0000003oool0oooo00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`0T0?ooo`00
503oool2000004<0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`080?ooo`030000
003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`000000o`000?l0000[0?l000030000
003oool0oooo02@0oooo000D0?ooo`030000003oool0oooo0480oooo00<000000?l0003o0000:`3o
00000`000000oooo0?ooo`080?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0203o
ool00`000000o`000?l0000[0?l000030000003oool0oooo02@0oooo000D0?ooo`030000003oool0
oooo0480oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`080?ooo`030000003o0000
o`0002/0o`0000<000000?ooo`3oool0203oool00`000000o`000?l0000[0?l000030000003oool0
oooo02@0oooo00020?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<00000103oool00`00
0000oooo0?ooo`120?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`00
0000o`000?l0000[0?l000030000003oool0oooo00P0oooo00<000000?l0003o0000:`3o00000`00
0000oooo0?ooo`0T0?ooo`0000D0oooo0000003oool0oooo000000090?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0@P3oool00`000000o`000?l0000[0?l000030000003oool0oooo
00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`080?ooo`030000003o0000o`00
02/0o`0000<000000?ooo`3oool0903oool000050?ooo`000000oooo0?ooo`0000002@3oool00`00
0000oooo0?ooo`030?ooo`<00000@P3oool00`000000o`000?l0000[0?l000030000003oool0oooo
00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`080?ooo`030000003o0000o`00
02/0o`0000<000000?ooo`3oool0903oool000050?ooo`000000oooo0?ooo`0000002@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0480oooo00<000000?l0003o0000:`3o00000`00
0000oooo0?ooo`080?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`00
0000o`000?l0000[0?l000030000003oool0oooo02@0oooo00001@3oool000000?ooo`3oool00000
00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`120?ooo`030000003o0000o`00
02/0o`0000<000000?ooo`3oool0203oool00`000000o`000?l0000[0?l000030000003oool0oooo
00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`0T0?ooo`0000D0oooo0000003o
ool0oooo000000080?ooo`8000001@3oool00`000000oooo0?ooo`120?ooo`030000003o0000o`00
02/0o`0000<000000?ooo`3oool0203oool00`000000o`000?l0000[0?l000030000003oool0oooo
00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`0T0?ooo`000P3oool2000000X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`120?ooo`030000003o0000o`0002/0
o`0000<000000?ooo`3oool0203oool00`000000o`000?l0000[0?l000030000003oool0oooo00P0
oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`0T0?ooo`00503oool00`000000oooo
0?ooo`120?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`000000o`00
0?l0000[0?l000030000003oool0oooo00P0oooo00<000000?l0003o0000:`3o00000`000000oooo
0?ooo`0T0?ooo`00503oool2000004<0oooo00<000000?l0003o0000:`3o00000`000000oooo0?oo
o`080?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`000000o`000?l0
000[0?l000030000003oool0oooo02@0oooo000D0?ooo`030000003oool0oooo0480oooo00<00000
0?l0003o0000:`3o00000`000000oooo0?ooo`080?ooo`030000003o0000o`0002/0o`0000<00000
0?ooo`3oool0203oool00`000000o`000?l0000[0?l000030000003oool0oooo02@0oooo000D0?oo
o`030000003oool0oooo0480oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`080?oo
o`030000003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`000000o`000?l0000[0?l0
00030000003oool0oooo02@0oooo000D0?ooo`030000003oool0oooo0480oooo00<000000?l0003o
0000:`3o00000`000000oooo0?ooo`080?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3o
ool0203oool00`000000o`000?l0000[0?l000030000003oool0oooo02@0oooo000D0?ooo`030000
003oool0oooo0480oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`080?ooo`030000
003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`000000o`000?l0000[0?l000030000
003oool0oooo02@0oooo000D0?ooo`030000003oool0oooo0480oooo00<000000?l0003o0000:`3o
00000`000000oooo0?ooo`080?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0203o
ool00`000000o`000?l0000[0?l000030000003oool0oooo02@0oooo000D0?ooo`800000@`3oool0
0`000000o`000?l0000[0?l000030000003oool0oooo00P0oooo00<000000?l0003o0000:`3o0000
0`000000oooo0?ooo`080?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0903oool0
01@0oooo00<000000?ooo`3oool0@P3oool00`000000o`000?l0000[0?l000030000003oool0oooo
00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`080?ooo`030000003o0000o`00
02/0o`0000<000000?ooo`3oool0903oool001@0oooo00<000000?ooo`3oool0@P3oool00`000000
o`000?l0000[0?l000030000003oool0oooo00P0oooo00<000000?l0003o0000:`3o00000`000000
oooo0?ooo`080?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0903oool001@0oooo
00<000000?ooo`3oool0@P3oool00`000000o`000?l0000[0?l000030000003oool0oooo00P0oooo
00<000000?l0003o0000:`3o00000`000000oooo0?ooo`080?ooo`030000003o0000o`0002/0o`00
00<000000?ooo`3oool0903oool001@0oooo00<000000?ooo`3oool0@P3oool00`000000o`000?l0
000[0?l000030000003oool0oooo00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?oo
o`080?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0903oool001@0oooo0P000013
0?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`000000o`000?l0000[
0?l000030000003oool0oooo00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`0T
0?ooo`00503oool00`000000oooo0?ooo`120?ooo`030000003o0000o`0002/0o`0000<000000?oo
o`3oool0203oool00`000000o`000?l0000[0?l000030000003oool0oooo00P0oooo00<000000?l0
003o0000:`3o00000`000000oooo0?ooo`0T0?ooo`00503oool00`000000oooo0?ooo`120?ooo`03
0000003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`000000o`000?l0000[0?l00003
0000003oool0oooo00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`0T0?ooo`00
503oool00`000000oooo0?ooo`120?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0
203oool00`000000o`000?l0000[0?l000030000003oool0oooo00P0oooo00<000000?l0003o0000
:`3o00000`000000oooo0?ooo`0T0?ooo`00503oool00`000000oooo0?ooo`120?ooo`030000003o
0000o`0002/0o`0000<000000?ooo`3oool0203oool00`000000o`000?l0000[0?l000030000003o
ool0oooo00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`0T0?ooo`00503oool0
0`000000oooo0?ooo`120?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0203oool0
0`000000o`000?l0000[0?l000030000003oool0oooo00P0oooo00<000000?l0003o0000:`3o0000
0`000000oooo0?ooo`0T0?ooo`00503oool2000004<0oooo00<000000?l0003o0000:`3o00000`00
0000oooo0?ooo`080?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`00
0000o`000?l0000[0?l000030000003oool0oooo02@0oooo000D0?ooo`030000003oool0oooo0480
oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`080?ooo`030000003o0000o`0002/0
o`0000<000000?ooo`3oool0203oool00`000000o`000?l0000[0?l000030000003oool0oooo02@0
oooo000D0?ooo`030000003oool0oooo0480oooo00<000000?l0003o0000:`3o00000`000000oooo
0?ooo`080?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`000000o`00
0?l0000[0?l000030000003oool0oooo02@0oooo00020?ooo`800000103oool010000000oooo0?oo
o`3oool5000000<0oooo00<000000?ooo`3oool0@P3oool00`000000o`000?l0000[0?l000030000
003oool0oooo00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`080?ooo`030000
003o0000o`0002/0o`0000<000000?ooo`3oool0903oool000050?ooo`000000oooo0?ooo`000000
203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0480oooo00<000000?l0003o
0000:`3o00000`000000oooo0?ooo`080?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3o
ool0203oool00`000000o`000?l0000[0?l000030000003oool0oooo02@0oooo00001@3oool00000
0?ooo`3oool0000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`120?ooo`03
0000003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`000000o`000?l0000[0?l00003
0000003oool0oooo00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`0T0?ooo`00
00D0oooo0000003oool0oooo0000000:0?ooo`030000003oool0oooo0080oooo0`0000120?ooo`03
0000003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`000000o`000?l0000[0?l00003
0000003oool0oooo00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`0T0?ooo`00
00D0oooo0000003oool0oooo000000070?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`120?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`00
0000o`000?l0000[0?l000030000003oool0oooo00P0oooo00<000000?l0003o0000:`3o00000`00
0000oooo0?ooo`0T0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`120?ooo`030000003o0000o`0002/0o`0000<00000
0?ooo`3oool0203oool00`000000o`000?l0000[0?l000030000003oool0oooo00P0oooo00<00000
0?l0003o0000:`3o00000`000000oooo0?ooo`0T0?ooo`000P3oool2000000T0oooo0`0000040?oo
o`030000003oool0oooo0480oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`080?oo
o`030000003o0000o`0002/0o`0000<000000?ooo`3oool0203oool00`000000o`000?l0000[0?l0
00030000003oool0oooo02@0oooo000D0?ooo`030000003oool0oooo0480oooo00<000000?l0003o
0000:`3o00000`000000oooo0?ooo`080?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3o
ool0203oool00`000000o`000?l0000[0?l000030000003oool0oooo02@0oooo000D0?ooo`800000
@`3oool00`000000o`000?l0000[0?l000030000003oool0oooo00P0oooo00<000000?l0003o0000
:`3o00000`000000oooo0?ooo`080?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0
903oool001@0oooo00<000000?ooo`3oool0@P3oool00`000000o`000?l0000[0?l000030000003o
ool0oooo00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`080?ooo`030000003o
0000o`0002/0o`0000<000000?ooo`3oool0903oool001@0oooo00<000000?ooo`3oool0@P3oool0
0`000000o`000?l0000[0?l000030000003oool0oooo00P0oooo00<000000?l0003o0000:`3o0000
0`000000oooo0?ooo`080?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0903oool0
01@0oooo00<000000?ooo`3oool0@P3oool00`000000o`000?l0000[0?l000030000003oool0oooo
00P0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`080?ooo`030000003o0000o`00
02/0o`0000<000000?ooo`3oool0903oool001@0oooo00<000000?ooo`3oool0@P3oool00`000000
o`000?l0000[0?l000030000003oool0oooo00P0oooo00<000000?l0003o0000:`3o00000`000000
oooo0?ooo`080?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0903oool001@0oooo
00<000000?ooo`3oool0@P3oool_000000X0oooo00<000000?l0003o0000:`3o00000`000000oooo
0?ooo`080?ooobl000009P3oool001@0oooo0P00001l0?ooo`030000003o0000o`0002/0o`0000<0
00000?ooo`3oool0G@3oool001@0oooo00<000000?ooo`3oool0N`3oool00`000000o`000?l0000[
0?l000030000003oool0oooo05d0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?l0
003o0000:`3o00000`000000oooo0?ooo`1M0?ooo`00503oool00`000000oooo0?ooo`1k0?ooo`03
0000003o0000o`0002/0o`0000<000000?ooo`3oool0G@3oool001@0oooo00<000000?ooo`3oool0
N`3oool00`000000o`000?l0000[0?l000030000003oool0oooo05d0oooo000D0?ooo`030000003o
ool0oooo07/0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`1M0?ooo`00503oool2
000007`0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`1M0?ooo`00503oool00`00
0000oooo0?ooo`1k0?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0G@3oool001@0
oooo00<000000?ooo`3oool0N`3oool00`000000o`000?l0000[0?l000030000003oool0oooo05d0
oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?l0003o0000:`3o00000`000000oooo
0?ooo`1M0?ooo`00503oool00`000000oooo0?ooo`1k0?ooo`030000003o0000o`0002/0o`0000<0
00000?ooo`3oool0G@3oool001@0oooo0P00001l0?ooo`030000003o0000o`0002/0o`0000<00000
0?ooo`3oool0G@3oool001@0oooo00<000000?ooo`3oool0N`3oool00`000000o`000?l0000[0?l0
00030000003oool0oooo05d0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?l0003o
0000:`3o00000`000000oooo0?ooo`1M0?ooo`000P3oool2000000@0oooo00<000000?ooo`3oool0
0P3oool3000000@0oooo00<000000?ooo`3oool0N`3oool00`000000o`000?l0000[0?l000030000
003oool0oooo05d0oooo00001@3oool000000?ooo`3oool0000000L0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo07/0oooo00<000000?l0003o0000:`3o00000`000000
oooo0?ooo`1M0?ooo`0000D0oooo0000003oool0oooo0000000;0?ooo`050000003oool0oooo0?oo
o`000000O@3oool00`000000o`000?l0000[0?l000030000003oool0oooo05d0oooo00001@3oool0
00000?ooo`3oool0000000T0oooo0P0000040?ooo`<00000N`3oool00`000000o`000?l0000[0?l0
00030000003oool0oooo05d0oooo00001@3oool000000?ooo`3oool0000000/0oooo00D000000?oo
o`3oool0oooo0000001m0?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0G@3oool0
00050?ooo`000000oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool0N`3oool00`000000o`000?l0000[0?l000030000003oool0oooo05d0oooo0002
0?ooo`8000002@3oool3000000@0oooo00<000000?ooo`3oool0N`3oool00`000000o`000?l0000[
0?l000030000003oool0oooo05d0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?l0
003o0000:`3o00000`000000oooo0?ooo`1M0?ooo`00503oool00`000000oooo0?ooo`1k0?ooo`03
0000003o0000o`0002/0o`0000<000000?ooo`3oool0G@3oool001@0oooo0P00001l0?ooo`030000
003o0000o`0002/0o`0000<000000?ooo`3oool0G@3oool001@0oooo00<000000?ooo`3oool0N`3o
ool00`000000o`000?l0000[0?l000030000003oool0oooo05d0oooo000D0?ooo`030000003oool0
oooo07/0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`1M0?ooo`00503oool00`00
0000oooo0?ooo`1k0?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0G@3oool001@0
oooo00<000000?ooo`3oool0N`3oool00`000000o`000?l0000[0?l000030000003oool0oooo05d0
oooo000D0?ooo`800000O03oool00`000000o`000?l0000[0?l000030000003oool0oooo05d0oooo
000D0?ooo`030000003oool0oooo07/0oooo00<000000?l0003o0000:`3o00000`000000oooo0?oo
o`1M0?ooo`00503oool00`000000oooo0?ooo`1k0?ooo`030000003o0000o`0002/0o`0000<00000
0?ooo`3oool0G@3oool001@0oooo00<000000?ooo`3oool0N`3oool00`000000o`000?l0000[0?l0
00030000003oool0oooo05d0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?l0003o
0000:`3o00000`000000oooo0?ooo`1M0?ooo`00503oool00`000000oooo0?ooo`1k0?ooo`030000
003o0000o`0002/0o`0000<000000?ooo`3oool0G@3oool001@0oooo0P00001l0?ooo`030000003o
0000o`0002/0o`0000<000000?ooo`3oool0G@3oool001@0oooo00<000000?ooo`3oool0N`3oool0
0`000000o`000?l0000[0?l000030000003oool0oooo05d0oooo000D0?ooo`030000003oool0oooo
07/0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`1M0?ooo`00503oool00`000000
oooo0?ooo`1k0?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0G@3oool001@0oooo
00<000000?ooo`3oool0N`3oool00`000000o`000?l0000[0?l000030000003oool0oooo05d0oooo
000D0?ooo`800000O03oool00`000000o`000?l0000[0?l000030000003oool0oooo05d0oooo000D
0?ooo`030000003oool0oooo07/0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`1M
0?ooo`00503oool00`000000oooo0?ooo`1k0?ooo`030000003o0000o`0002/0o`0000<000000?oo
o`3oool0G@3oool001@0oooo00<000000?ooo`3oool0N`3oool00`000000o`000?l0000[0?l00003
0000003oool0oooo05d0oooo00020?ooo`800000103oool00`000000oooo0?ooo`030?ooo`<00000
0`3oool00`000000oooo0?ooo`1k0?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0
G@3oool000050?ooo`000000oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo07/0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`1M0?ooo`0000D0
oooo0000003oool0oooo000000070?ooo`D000000`3oool3000007/0oooo00<000000?l0003o0000
:`3o00000`000000oooo0?ooo`1M0?ooo`0000D0oooo0000003oool0oooo000000070?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0N`3oool00`000000o`000?l0000[0?l00003
0000003oool0oooo05d0oooo00001@3oool000000?ooo`3oool0000000P0oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`1k0?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3o
ool0G@3oool000050?ooo`000000oooo0?ooo`0000002@3oool2000000@0oooo00<000000?ooo`3o
ool0N`3oool00`000000o`000?l0000[0?l000030000003oool0oooo05d0oooo00020?ooo`800000
2`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07/0oooo00<000000?l0003o0000
:`3o00000`000000oooo0?ooo`1M0?ooo`00503oool00`000000oooo0?ooo`1k0?ooo`030000003o
0000o`0002/0o`0000<000000?ooo`3oool0G@3oool001@0oooo0P00001l0?ooo`030000003o0000
o`0002/0o`0000<000000?ooo`3oool0G@3oool001@0oooo00<000000?ooo`3oool0N`3oool00`00
0000o`000?l0000[0?l000030000003oool0oooo05d0oooo000D0?ooo`030000003oool0oooo07/0
oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`1M0?ooo`00503oool00`000000oooo
0?ooo`1k0?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0G@3oool001@0oooo00<0
00000?ooo`3oool0N`3oool00`000000o`000?l0000[0?l000030000003oool0oooo05d0oooo000D
0?ooo`800000O03oool00`000000o`000?l0000[0?l000030000003oool0oooo05d0oooo000D0?oo
o`030000003oool0oooo07/0oooo00<000000?l0003o0000:`3o00000`000000oooo0?ooo`1M0?oo
o`00503oool00`000000oooo0?ooo`1k0?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3o
ool0G@3oool001@0oooo00<000000?ooo`3oool0N`3oool00`000000o`000?l0000[0?l000030000
003oool0oooo05d0oooo000D0?ooo`030000003oool0oooo07/0oooo00<000000?l0003o0000:`3o
00000`000000oooo0?ooo`1M0?ooo`00503oool00`000000oooo0?ooo`1k0?ooo`030000003o0000
o`0002/0o`0000<000000?ooo`3oool0G@3oool001@0oooo0P00001l0?ooo`030000003o0000o`00
02/0o`0000<000000?ooo`3oool0G@3oool001@0oooo00<000000?ooo`3oool0N`3oool00`000000
o`000?l0000[0?l000030000003oool0oooo05d0oooo000D0?ooo`030000003oool0oooo07/0oooo
00<000000?l0003o0000:`3o00000`000000oooo0?ooo`1M0?ooo`00503oool00`000000oooo0?oo
o`1k0?ooo`030000003o0000o`0002/0o`0000<000000?ooo`3oool0G@3oool001@0oooo00<00000
0?ooo`3oool0N`3oool00`000000o`000?l0000[0?l000030000003oool0oooo05d0oooo000D0?oo
o`030000003oool0oooo07/0oooo;`00001O0?ooo`00503oool200000?l0oooo2`3oool001@0oooo
00<000000?ooo`3oool0o`3oool:0?ooo`00503oool00`000000oooo0?ooo`3o0?ooo`X0oooo0002
0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<00000103oool00`000000oooo0?ooo`3o
0?ooo`X0oooo00001@3oool000000?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo0?l0oooo2P3oool000050?ooo`000000oooo0?ooo`0000002`3o
ool010000000oooo0?ooo`3oool300000?l0oooo2P3oool000050?ooo`000000oooo0?ooo`000000
2`3oool00`000000oooo0?ooo`3o0?ooo`h0oooo00001@3oool000000?ooo`3oool0000000L0oooo
1000003o0?oooa40oooo00001@3oool000000?ooo`3oool0000000L0oooo00<000000?ooo`3oool0
o`3ooolB0?ooo`000P3oool2000000P0oooo1@00003o0?oooa00oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.0353119, -0.0758106, \
0.0174814, 0.00353568}}]
}, Open  ]],

Cell[TextData[{
  "This is ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_\(g[Y]\)\(g\^*\)[X]\)]],
  ", where |X|=|Y|=1, and {X,Y} has no heterozygous loci.  Note that the \
factor ",
  Cell[BoxData[
      \(TraditionalForm\`2\/W\&_\)]],
  "must be included: it is not used in StabilityK[] because it is the same \
for all the matrix elements, and so only needs to be calculated once."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(2\/wb\) StabilityK[1, 1, 0, gt, stabW[1, 4. ]]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(0.3703959202986421`\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell[TextData[{
  "This generates the full ",
  Cell[BoxData[
      \(TraditionalForm\`2\^4\[Times]2\^4\)]],
  " stability matrix, and finds the eigenvalues:  "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(sm = \(2\/wb\) 
          StabilityMatrix[StabilityK[#1, #2, #3, gt, stabW[1, 4. ]] &, 
            4];\)\), "\n", 
    \(Eigenvalues[sm] // Chop\)}], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \({1.0556668664874813`, 1.055666866487481`, 1.0556668664874804`, 
      0.5920288171653224`, 0.5920288171653221`, 0.42962041585539545`, 
      0.3504629451062373`, 0.3504629451062369`, 0.35046294510623666`, 
      0.20342982678420038`, 0.20342982678420027`, 0.20342982678420013`, 
      0.17088948114256608`, 0.06305217544529636`, 0.055521474721357135`, 
      0}\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell["This would not be feasible for more than a few loci.", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"SigmaMatrix", "[", 
              RowBox[{"a", ",", "i", ",", "j", ",", "p", ",", 
                StyleBox["nloci",
                  FontSlant->"Italic"]}], 
              "]"}], \(\(\ \)\(gives\ the\ elements\ of\ the\ \ matrix\ for\ \
eigenvectors\ in\ class\ p\)\)},
          {\(SigmaMatrix[a, p, 
              n]\), \(\(stores\)\(\ \)\(the\)\(\ \)\(p\)\(\ \)\(matrix\)\(\ \
\)\(\(itself\)\(.\)\)\(\ \ \)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"SigmaMatrix"],

Cell["\<\
A more efficient method is to break the full matrix down into \
smaller matrices with the same eigenvalues, using SigmaMatrix[]. \
\>", "Text"],

Cell[TextData[{
  "For example, concordant perturbations are described by SigmaMatrix[] with \
",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  "=0:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(s0 = \(2\/wb\) 
          SigmaMatrix[StabilityK[#1, #2, #3, gt, stabW[1, 4. ]] &, 0, 
            4];\)\), "\n", 
    \(s0 // MatrixForm\)}], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.0958102410540731`", 
              "0.1708971493125482`", \(-0.07523114121474715`\), \
\(-0.10404299927682158`\), \(-0.012980800612325184`\)},
            {"0.02905457425849259`", 
              "0.22119039014037944`", \(-0.04500392827809502`\), \
\(-0.16269115949391372`\), \(-0.024318394007946`\)},
            {\(-0.016962360240655706`\), \(-0.050141845436931884`\), 
              "0.08508228477570924`", \(-0.050141845436931974`\), \
\(-0.016962360240655706`\)},
            {\(-0.024318394007945995`\), \(-0.16269115949391372`\), \
\(-0.04500392827809502`\), "0.22119039014037953`", "0.029054574258492574`"},
            {\(-0.012980800612325179`\), \(-0.10404299927682158`\), \
\(-0.07523114121474718`\), "0.1708971493125482`", "0.09581024105407308`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[11]//MatrixForm="]
}, Open  ]],

Cell["\<\
The eigenvalues are all less than 1 in magnitude, showing that the \
system is stable towards concordant fluctuations.  There is a single \
eigenvalue of zero, corresponding to the constraint that frequencies sum to \
1.  Note that each of these concordant eigenvalues appears once in the set \
derived from the full StabilityMatrix[].\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvalues[s0] // Chop\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \({0.42962041585539557`, 0.170889481142566`, 0.06305217544529645`, 
      0.05552147472135718`, 0}\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(ExactEigenvalues[a, n]\), 
            RowBox[{
            "finds", " ", "all", " ", "the", " ", "eigenvalues", " ", "for", 
              " ", "the", " ", "stability", " ", \(matrix . \ a[i, j, h]\), 
              " ", "must", " ", "be", " ", "a", " ", "function", " ", "which",
               " ", "gives", " ", 
              StyleBox["numerical",
                FontWeight->"Bold"], " ", "values", " ", "for", " ", "the", 
              " ", \(\(derivatives\)\(.\)\)}]}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"ExactEigenvalues"],

Cell[TextData[{
  "The full set of eigenvalues is generated using SigmaMatrix[] for ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  "=0, 1, 2; this is done by ExactEigenvalues[].  The first row gives \
eigenvalues for p=0, which appear once each in the full set; the second row \
eigenvalues for p=0, which appear three times each in the full set; and the \
last row gives the single eigenvalue for p=2, which appears twice in the full \
set.  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ExactEigenvalues[\(2\/wb\) 
              StabilityK[#1, #2, #3, gt, stabW[1, 4. ]] &, 4]\  // Chop\) // 
      TableForm\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"0.42962041585539557`", "0.1708894811425658`", 
            "0.06305217544529645`", "0.05552147472135712`", "0"},
          {"1.0556668664874804`", "0.3504629451062372`", 
            "0.20342982678420035`", "\<\"\"\>", "\<\"\"\>"},
          {
            "0.5920288171653223`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>", \
"\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{0.42962041585539557, 0.1708894811425658, 
        0.063052175445296454, 0.055521474721357121, 0}, {1.0556668664874804, 
        0.35046294510623721, 0.20342982678420035}, {
        0.5920288171653223}}]]], "Output",
  CellLabel->"Out[13]//TableForm="]
}, Open  ]],

Cell["\<\
There is a single eigenvalue greater than 1, showing a discordant \
instability.  The eigenvector can be found using SigmaMatrix[]:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(es = 
      Eigensystem[
        SigmaMatrix[\(2\/wb\) StabilityK[#1, #2, #3, gt, stabW[1, 4. ]] &, 1, 
          4]]; es\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \({1.0556668664874804`, 0.3504629451062372`, 
      0.20342982678420035`}\)], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(es\[LeftDoubleBracket]2, 1\[RightDoubleBracket]\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \({\(-0.5088954941042179`\), \(-0.694298748494369`\), \
\(-0.5088954941042184`\)}\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell[TextData[{
  "Written out in full, the class of eigenvectors ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  "=1 has the structure ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\({0, e\_1\),
            "TraditionalForm"], ",", "0", ",", "0", ",", 
          RowBox[{"-", 
            FormBox[\(e\_1\),
              "TraditionalForm"]}], ",", \(e\_2\)}], TraditionalForm]]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`e\_2\)]],
  ",0,0,-",
  Cell[BoxData[
      \(TraditionalForm\`e\_2\)]],
  ",-",
  Cell[BoxData[
      \(TraditionalForm\`e\_2\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`e\_3\)]],
  ",0,0,-",
  Cell[BoxData[
      \(TraditionalForm\`e\_3\)]],
  ",0}, where in this case ",
  Cell[BoxData[
      \(TraditionalForm\`{e\_1\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`e\_2\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`e\_3\)]],
  "}={-0.509,-0.694,-0.509}.  Here, the ",
  Cell[BoxData[
      \(TraditionalForm\`2\^4\)]],
  " genotypes are written in order \
{{0,0,0,0},{0,0,0,1},\[Ellipsis],{1,1,1,0},{1,1,1,1}}. This can be checked \
using the full stability matrix.  However, a complication is that the \
eigenvectors of that matrix may appear as any linear combination of the \
degenerate eigenvectors, and so their structure will not be clear:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Eigenvectors[sm]\)\[LeftDoubleBracket]1\[RightDoubleBracket] // 
      Chop\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \({0, \(-0.25070931715474165`\), \(-0.1542601083992296`\), 
      0.25766290188543894`, 0.1473065236685318`, \(-0.5525098347265462`\), 
      0.009486948169134962`, 
      0.14107499661530645`, \(-0.14107499661530584`\), \
\(-0.009486948169135364`\), 
      0.5525098347265461`, \(-0.14730652366853206`\), \(-0.25766290188543917`\
\), 0.1542601083992295`, 0.25070931715474176`, 0}\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell["\<\
Nevertheless, the simpler version derived from SigmaMatrix[] is an \
eigenvector of the full matrix:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ev = {0, e\_1, 0, 0, \(-e\_1\), e\_2, e\_2, 0, 0, \(-e\_2\), \(-e\_2\), 
          e\_3, 0, 0, \(-e\_3\), 0} /. 
        e\_i_ \[RuleDelayed] 
          es\[LeftDoubleBracket]2, 1, i\[RightDoubleBracket]\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \({0, \(-0.5088954941042179`\), 0, 0, 
      0.5088954941042179`, \(-0.694298748494369`\), \(-0.694298748494369`\), 
      0, 0, 0.694298748494369`, 0.694298748494369`, \(-0.5088954941042184`\), 
      0, 0, 0.5088954941042184`, 0}\)], "Output",
  CellLabel->"Out[17]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sm . ev\/es\[LeftDoubleBracket]1, 1\[RightDoubleBracket] // 
      Chop\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \({0, \(-0.5088954941042181`\), 0, 0, 
      0.5088954941042182`, \(-0.6942987484943689`\), \
\(-0.6942987484943689`\), 0, 0, 0.6942987484943689`, 
      0.6942987484943689`, \(-0.5088954941042184`\), 0, 0, 
      0.5088954941042184`, 0}\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{978, 600},
WindowMargins->{{Automatic, 73}, {Automatic, 2}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\[Placeholder]", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", 
                BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->Utilities`Notation`Private`DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "StabilityK"->{
    Cell[2027, 62, 466, 9, 62, "DefinitionBox",
      CellTags->"StabilityK"]},
  "SigmaMatrix"->{
    Cell[31775, 700, 576, 13, 56, "DefinitionBox",
      CellTags->"SigmaMatrix"]},
  "ExactEigenvalues"->{
    Cell[34516, 778, 623, 12, 52, "DefinitionBox",
      CellTags->"ExactEigenvalues"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"StabilityK", 111986, 3536},
  {"SigmaMatrix", 112085, 3539},
  {"ExactEigenvalues", 112193, 3542}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 97, 3, 36, "SubsectionIcon"],
Cell[1839, 56, 79, 0, 28, "MathCaption"],
Cell[1921, 58, 103, 2, 26, "Input"],
Cell[2027, 62, 466, 9, 62, "DefinitionBox",
  CellTags->"StabilityK"],
Cell[2496, 73, 682, 17, 50, "Text"],

Cell[CellGroupData[{
Cell[3203, 94, 391, 7, 80, "Input"],
Cell[3597, 103, 77, 2, 20, "Output"]
}, Open  ]],
Cell[3689, 108, 98, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3812, 115, 208, 4, 26, "Input"],
Cell[4023, 121, 26187, 525, 184, 2929, 233, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[30225, 649, 407, 10, 43, "Text"],

Cell[CellGroupData[{
Cell[30657, 663, 105, 2, 41, "Input"],
Cell[30765, 667, 77, 2, 20, "Output"]
}, Open  ]],
Cell[30857, 672, 179, 5, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[31061, 681, 206, 5, 59, "Input"],
Cell[31270, 688, 419, 7, 35, "Output"]
}, Open  ]],
Cell[31704, 698, 68, 0, 22, "Text"],
Cell[31775, 700, 576, 13, 56, "DefinitionBox",
  CellTags->"SigmaMatrix"],
Cell[32354, 715, 153, 3, 22, "Text"],
Cell[32510, 720, 172, 6, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[32707, 730, 199, 5, 59, "Input"],
Cell[32909, 737, 954, 18, 95, "Output"]
}, Open  ]],
Cell[33878, 758, 359, 6, 36, "Text"],

Cell[CellGroupData[{
Cell[34262, 768, 81, 2, 26, "Input"],
Cell[34346, 772, 155, 3, 20, "Output"]
}, Open  ]],
Cell[34516, 778, 623, 12, 52, "DefinitionBox",
  CellTags->"ExactEigenvalues"],
Cell[35142, 792, 462, 9, 36, "Text"],

Cell[CellGroupData[{
Cell[35629, 805, 181, 4, 41, "Input"],
Cell[35813, 811, 789, 18, 63, "Output"]
}, Open  ]],
Cell[36617, 832, 164, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[36806, 840, 221, 5, 41, "Input"],
Cell[37030, 847, 130, 3, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37197, 855, 105, 2, 26, "Input"],
Cell[37305, 859, 138, 3, 20, "Output"]
}, Open  ]],
Cell[37458, 865, 1341, 45, 51, "Text"],

Cell[CellGroupData[{
Cell[38824, 914, 135, 3, 26, "Input"],
Cell[38962, 919, 437, 8, 35, "Output"]
}, Open  ]],
Cell[39414, 930, 131, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[39570, 937, 261, 5, 27, "Input"],
Cell[39834, 944, 288, 5, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40159, 954, 129, 3, 41, "Input"],
Cell[40291, 959, 294, 6, 20, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

