(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4378,        128]*)
(*NotebookOutlinePosition[      5306,        158]*)
(*  CellTagsIndexPosition[      5262,        154]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Outline", "SubsectionIcon"],

Cell[TextData[{
  "Suppose that we have a symmetrical solution, in which all genotypes within \
a given class are equally frequent.  Is this stable to asymmetric \
fluctuations?  The full stability matrix is ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\[Times]2\^n\)]],
  ", which is extremely large for even a few loci.  However, this matrix can \
be reduced to a set of smaller matrices, allowing all the eigenvalues and \
eigenvectors to be calculated using matrices no larger than ",
  Cell[BoxData[
      \(TraditionalForm\`n\[Times]n\)]],
  ".  This is done in two steps. First, the partial derivatives ",
  Cell[BoxData[
      \(TraditionalForm\`a[i, j, h] = \[PartialD]\_\(g[Y]\)\(g\^*\)[X]\)]],
  " are calculated (where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(X\)\(|\)\) = i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(Y\)\(|\)\) = j\)]],
  ", and the number of heterozygous loci in the (hypothetical) genotype {X,Y} \
is ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  ").  Second, the eigenvalues and eigenvectors of the stability matrix are \
calculated in terms of the ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "'s.  The eigenvectors fall into families which are picked out by choosing \
(arbitrarily) ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " pairs of loci."
}], "Text"],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "'s are defined for selection within a single deme; selection and \
immigration into a single deme; and for a linear stepping-stone model with ",
  Cell[BoxData[
      \(TraditionalForm\`n\_d\)]],
  " demes.  In the latter case, each ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " becomes a matrix of dimension ",
  Cell[BoxData[
      \(TraditionalForm\`n\_d\[Times]n\_d\)]],
  "; however, the algorithm is otherwise essentially the same."
}], "Text"],

Cell[TextData[{
  "For further details, see Barton and Shpak, ",
  ButtonBox["2000.",
    ButtonData:>{"Symmetric model: references", "Barton & Shpak 2000"},
    ButtonStyle->"AddOnsLink"]
}], "Text"],

Cell[TextData[{
  StyleBox["NOTE",
    FontWeight->"Bold"],
  ": The stability algorithms used here assume that deme size is fixed; they \
do not follow the joint evolution of deme size with allele frequencies.  That \
would require calculation of derivatives of allele frequencies with respect \
to deme size, and vice versa."
}], "Text"],

Cell[TextData[{
  StyleBox["BEWARE",
    FontWeight->"Bold"],
  ": StabilityK[] cannot be used with the option SymmetricCline\[Rule]True."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{840, 453},
WindowMargins->{{Automatic, 54}, {Automatic, 4}},
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 33, 0, 36, "SubsectionIcon"],
Cell[1775, 53, 1350, 33, 78, "Text"],
Cell[3128, 88, 536, 15, 36, "Text"],
Cell[3667, 105, 200, 5, 23, "Text"],
Cell[3870, 112, 339, 7, 38, "Text"],
Cell[4212, 121, 150, 4, 24, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

