(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11984,        329]*)
(*NotebookOutlinePosition[     14454,        394]*)
(*  CellTagsIndexPosition[     14113,        382]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Setting up a cline", "SubsectionIcon",
  CellTags->"Making a cline"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< NumericalModels`ExactModel`;\)\)], "Input",
  CellLabel->"In[39]:=  (19:05:28 on 4/20/01)"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MakeCline[n\_d, n\_g, n\_inds, 
              NumericalModel \[Rule] 
                SymmetricHaploidFrequencies]\), \(sets\ up\ a\ stepped\ cline\
\ with\ n\_d\ haploid\ demes, \ \(n\_\(\(g\)\(\ \)\)\) genes, \ 
            and\ n\_inds\ individuals\ in\ each\ deme\)},
          {\(MakeCline[n\_d, n\_g, n\_inds, \[CapitalDelta]p, 
              NumericalModel \[Rule] 
                SymmetricHaploidFrequencies]\), \(sets\ up\ a\ linear\ \
gradient, \ spanning\ \[CapitalDelta]p\)},
          {\(\(ClineWidth[\[Psi]]\)\(\ \)\), \(gives\ the\ cline\ widths\ at\ \
each\ locus\)}
          }], TraditionalForm]],
  CellTags->{"InitialiseDemes", "ClineWidth"}]], "DefinitionBox",
  CellTags->{"ClineWidth", "MakeCline", "SymmetricHaploidFrequencies"}],

Cell["This gives a stepped cline of 10 demes:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi] = 
      MakeCline[10, 3, 10, 
        NumericalModel \[Rule] SymmetricHaploidFrequencies]\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \({SymmetricHaploidFrequencies[{1, 0, 0, 0}, 10], 
      SymmetricHaploidFrequencies[{1, 0, 0, 0}, 10], 
      SymmetricHaploidFrequencies[{1, 0, 0, 0}, 10], 
      SymmetricHaploidFrequencies[{1, 0, 0, 0}, 10], 
      SymmetricHaploidFrequencies[{1, 0, 0, 0}, 10], 
      SymmetricHaploidFrequencies[{0, 0, 0, 1}, 10], 
      SymmetricHaploidFrequencies[{0, 0, 0, 1}, 10], 
      SymmetricHaploidFrequencies[{0, 0, 0, 1}, 10], 
      SymmetricHaploidFrequencies[{0, 0, 0, 1}, 10], 
      SymmetricHaploidFrequencies[{0, 0, 0, 1}, 10]}\)], "Output",
  CellLabel->"Out[17]="]
}, Closed]],

Cell["This gives the allele frequencies:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlleleFrequencyMean[\[Psi]]\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 1, 1, 1, 1, 1}\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell["\<\
This gives the cline widths for each of the three loci \
involved:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ClineWidth[\[Psi]]\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \({1, 1, 1}\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell["Cline width is defined as the maximum gradient.", "Text"],

Cell["\<\
This gives a linear gradient spanning \[CapitalDelta]p=1:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi] = 
      MakeCline[10, 3, 10, 1, 
        NumericalModel \[Rule] SymmetricHaploidFrequencies]\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({SymmetricHaploidFrequencies[{1, 0, 0, 0}, 10], 
      SymmetricHaploidFrequencies[{512\/729, 64\/243, 8\/243, 1\/729}, 10], 
      SymmetricHaploidFrequencies[{343\/729, 98\/243, 28\/243, 8\/729}, 10], 
      SymmetricHaploidFrequencies[{8\/27, 4\/9, 2\/9, 1\/27}, 10], 
      SymmetricHaploidFrequencies[{125\/729, 100\/243, 80\/243, 64\/729}, 
        10], SymmetricHaploidFrequencies[{64\/729, 80\/243, 100\/243, 
          125\/729}, 10], 
      SymmetricHaploidFrequencies[{1\/27, 2\/9, 4\/9, 8\/27}, 10], 
      SymmetricHaploidFrequencies[{8\/729, 28\/243, 98\/243, 343\/729}, 10], 
      SymmetricHaploidFrequencies[{1\/729, 8\/243, 64\/243, 512\/729}, 10], 
      SymmetricHaploidFrequencies[{0, 0, 0, 1}, 10]}\)], "Output",
  CellLabel->"Out[20]="]
}, Closed]],

Cell["This gives the allele frequencies:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlleleFrequencyMean[\[Psi]]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \({0, 1\/9, 2\/9, 1\/3, 4\/9, 5\/9, 2\/3, 7\/9, 8\/9, 1}\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell["This gives the cline width at each locus:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ClineWidth[\[Psi]]\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \({9, 9, 9}\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MakeCline[n\_d, n\_g, n\_inds, 
              NumericalModel \[Rule] 
                SymmetricDiploidFrequencies]\), \(specifies\ diploid\ \
populations, under\ the\ symmetric\ \(\(model\)\(.\)\(\n\)\)\)},
          {\(MakeCline[n\_d, n\_g, n\_inds, 
              NumericalModel \[Rule] 
                SymmetricNeutralHaploidFrequencies]\), \(specifies\ haploid\ \
populations\ with\ a\ neutral\ marker\)},
          {\(MakeCline[n\_d, n\_g, n\_inds, 
              NumericalModel \[Rule] 
                SymmetricNeutralDiploidFrequencies]\), \(\(specifies\)\(\ \
\)\(diploid\)\(\ \)\(populations\)\(\ \)\(with\)\(\ \)\(a\)\(\ \
\)\(neutral\)\(\ \)\(marker\)\(\n\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{
  "SymmetricDiploidFrequencies", "SymmetricNeutralDiploidFrequencies", 
    "SymmetricNeutralHaploidFrequencies"}],

Cell["This is a set of diploid demes:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi] = 
      MakeCline[10, 3, 10, 1, 
        NumericalModel \[Rule] SymmetricDiploidFrequencies]\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \({SymmetricDiploidFrequencies[{{1, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
            0}, {0, 0, 0, 0}}, 10], 
      SymmetricDiploidFrequencies[{{262144\/531441, 32768\/177147, 
            4096\/177147, 512\/531441}, {32768\/177147, 4096\/59049, 
            512\/59049, 64\/177147}, {4096\/177147, 512\/59049, 64\/59049, 
            8\/177147}, {512\/531441, 64\/177147, 8\/177147, 1\/531441}}, 
        10], SymmetricDiploidFrequencies[{{117649\/531441, 33614\/177147, 
            9604\/177147, 2744\/531441}, {33614\/177147, 9604\/59049, 
            2744\/59049, 784\/177147}, {9604\/177147, 2744\/59049, 
            784\/59049, 224\/177147}, {2744\/531441, 784\/177147, 
            224\/177147, 64\/531441}}, 10], 
      SymmetricDiploidFrequencies[{{64\/729, 32\/243, 16\/243, 
            8\/729}, {32\/243, 16\/81, 8\/81, 4\/243}, {16\/243, 8\/81, 
            4\/81, 2\/243}, {8\/729, 4\/243, 2\/243, 1\/729}}, 10], 
      SymmetricDiploidFrequencies[{{15625\/531441, 12500\/177147, 
            10000\/177147, 8000\/531441}, {12500\/177147, 10000\/59049, 
            8000\/59049, 6400\/177147}, {10000\/177147, 8000\/59049, 
            6400\/59049, 5120\/177147}, {8000\/531441, 6400\/177147, 
            5120\/177147, 4096\/531441}}, 10], 
      SymmetricDiploidFrequencies[{{4096\/531441, 5120\/177147, 6400\/177147, 
            8000\/531441}, {5120\/177147, 6400\/59049, 8000\/59049, 
            10000\/177147}, {6400\/177147, 8000\/59049, 10000\/59049, 
            12500\/177147}, {8000\/531441, 10000\/177147, 12500\/177147, 
            15625\/531441}}, 10], 
      SymmetricDiploidFrequencies[{{1\/729, 2\/243, 4\/243, 8\/729}, {2\/243, 
            4\/81, 8\/81, 16\/243}, {4\/243, 8\/81, 16\/81, 
            32\/243}, {8\/729, 16\/243, 32\/243, 64\/729}}, 10], 
      SymmetricDiploidFrequencies[{{64\/531441, 224\/177147, 784\/177147, 
            2744\/531441}, {224\/177147, 784\/59049, 2744\/59049, 
            9604\/177147}, {784\/177147, 2744\/59049, 9604\/59049, 
            33614\/177147}, {2744\/531441, 9604\/177147, 33614\/177147, 
            117649\/531441}}, 10], 
      SymmetricDiploidFrequencies[{{1\/531441, 8\/177147, 64\/177147, 
            512\/531441}, {8\/177147, 64\/59049, 512\/59049, 
            4096\/177147}, {64\/177147, 512\/59049, 4096\/59049, 
            32768\/177147}, {512\/531441, 4096\/177147, 32768\/177147, 
            262144\/531441}}, 10], 
      SymmetricDiploidFrequencies[{{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
            0}, {0, 0, 0, 1}}, 10]}\)], "Output",
  CellLabel->"Out[23]="]
}, Closed]],

Cell["This gives the allele frequencies:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlleleFrequencyMean[\[Psi]]\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \({0, 1\/9, 2\/9, 1\/3, 4\/9, 5\/9, 2\/3, 7\/9, 8\/9, 1}\)], "Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell["\<\
This includes a neutral marker, which is at the same frequency as \
the selected alelles, and in linkage equilibrium with them:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi] = 
      MakeCline[10, 3, 10, 1, 
        NumericalModel \[Rule] SymmetricNeutralHaploidFrequencies]\)], "Input",\

  CellLabel->"In[26]:="],

Cell[BoxData[
    \({SymmetricNeutralHaploidFrequencies[{{1, 0, 0, 0}, {0, 0, 0, 0}}, 10], 
      SymmetricNeutralHaploidFrequencies[{{512\/729, 64\/243, 8\/243, 
            1\/729}, {1\/9, 1\/9, 1\/9, 1\/9}}, 10], 
      SymmetricNeutralHaploidFrequencies[{{343\/729, 98\/243, 28\/243, 
            8\/729}, {2\/9, 2\/9, 2\/9, 2\/9}}, 10], 
      SymmetricNeutralHaploidFrequencies[{{8\/27, 4\/9, 2\/9, 1\/27}, {1\/3, 
            1\/3, 1\/3, 1\/3}}, 10], 
      SymmetricNeutralHaploidFrequencies[{{125\/729, 100\/243, 80\/243, 
            64\/729}, {4\/9, 4\/9, 4\/9, 4\/9}}, 10], 
      SymmetricNeutralHaploidFrequencies[{{64\/729, 80\/243, 100\/243, 
            125\/729}, {5\/9, 5\/9, 5\/9, 5\/9}}, 10], 
      SymmetricNeutralHaploidFrequencies[{{1\/27, 2\/9, 4\/9, 8\/27}, {2\/3, 
            2\/3, 2\/3, 2\/3}}, 10], 
      SymmetricNeutralHaploidFrequencies[{{8\/729, 28\/243, 98\/243, 
            343\/729}, {7\/9, 7\/9, 7\/9, 7\/9}}, 10], 
      SymmetricNeutralHaploidFrequencies[{{1\/729, 8\/243, 64\/243, 
            512\/729}, {8\/9, 8\/9, 8\/9, 8\/9}}, 10], 
      SymmetricNeutralHaploidFrequencies[{{0, 0, 0, 1}, {1, 1, 1, 1}}, 
        10]}\)], "Output",
  CellLabel->"Out[26]="]
}, Closed]],

Cell["\<\
This gives the allele frequencies at the selected loci, and of the \
neutral marker:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlleleFrequencyMean[\[Psi]]\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \({{0, 0}, {1\/9, 1\/9}, {2\/9, 2\/9}, {1\/3, 1\/3}, {4\/9, 4\/9}, {5\/9, 
        5\/9}, {2\/3, 2\/3}, {7\/9, 7\/9}, {8\/9, 8\/9}, {1, 1}}\)], "Output",\

  CellLabel->"Out[27]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{816, 703},
WindowMargins->{{9, Automatic}, {Automatic, -1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Making a cline"->{
    Cell[1739, 51, 74, 1, 36, "SubsectionIcon",
      CellTags->"Making a cline"]},
  "ClineWidth"->{
    Cell[1984, 60, 817, 15, 110, "DefinitionBox",
      CellTags->{"ClineWidth", "MakeCline", "SymmetricHaploidFrequencies"}]},
  "MakeCline"->{
    Cell[1984, 60, 817, 15, 110, "DefinitionBox",
      CellTags->{"ClineWidth", "MakeCline", "SymmetricHaploidFrequencies"}]},
  "SymmetricHaploidFrequencies"->{
    Cell[1984, 60, 817, 15, 110, "DefinitionBox",
      CellTags->{"ClineWidth", "MakeCline", "SymmetricHaploidFrequencies"}]},
  "SymmetricDiploidFrequencies"->{
    Cell[5899, 186, 917, 18, 128, "DefinitionBox",
      CellTags->{
      "SymmetricDiploidFrequencies", "SymmetricNeutralDiploidFrequencies", 
        "SymmetricNeutralHaploidFrequencies"}]},
  "SymmetricNeutralDiploidFrequencies"->{
    Cell[5899, 186, 917, 18, 128, "DefinitionBox",
      CellTags->{
      "SymmetricDiploidFrequencies", "SymmetricNeutralDiploidFrequencies", 
        "SymmetricNeutralHaploidFrequencies"}]},
  "SymmetricNeutralHaploidFrequencies"->{
    Cell[5899, 186, 917, 18, 128, "DefinitionBox",
      CellTags->{
      "SymmetricDiploidFrequencies", "SymmetricNeutralDiploidFrequencies", 
        "SymmetricNeutralHaploidFrequencies"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Making a cline", 12849, 351},
  {"ClineWidth", 12951, 354},
  {"MakeCline", 13096, 357},
  {"SymmetricHaploidFrequencies", 13259, 360},
  {"SymmetricDiploidFrequencies", 13422, 363},
  {"SymmetricNeutralDiploidFrequencies", 13658, 368},
  {"SymmetricNeutralHaploidFrequencies", 13894, 373}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 74, 1, 36, "SubsectionIcon",
  CellTags->"Making a cline"],
Cell[1816, 54, 46, 0, 28, "MathCaption"],
Cell[1865, 56, 116, 2, 38, "Input"],
Cell[1984, 60, 817, 15, 110, "DefinitionBox",
  CellTags->{"ClineWidth", "MakeCline", "SymmetricHaploidFrequencies"}],
Cell[2804, 77, 62, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2891, 81, 155, 4, 26, "Input"],
Cell[3049, 87, 592, 11, 80, "Output"]
}, Closed]],
Cell[3656, 101, 57, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[3738, 105, 85, 2, 26, "Input"],
Cell[3826, 109, 89, 2, 20, "Output"]
}, Open  ]],
Cell[3930, 114, 97, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4052, 121, 76, 2, 26, "Input"],
Cell[4131, 125, 68, 2, 20, "Output"]
}, Open  ]],
Cell[4214, 130, 63, 0, 22, "Text"],
Cell[4280, 132, 90, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4395, 139, 158, 4, 26, "Input"],
Cell[4556, 145, 779, 12, 274, "Output"]
}, Closed]],
Cell[5350, 160, 57, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[5432, 164, 85, 2, 26, "Input"],
Cell[5520, 168, 113, 2, 36, "Output"]
}, Open  ]],
Cell[5648, 173, 64, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5737, 177, 76, 2, 26, "Input"],
Cell[5816, 181, 68, 2, 20, "Output"]
}, Open  ]],
Cell[5899, 186, 917, 18, 128, "DefinitionBox",
  CellTags->{
  "SymmetricDiploidFrequencies", "SymmetricNeutralDiploidFrequencies", 
    "SymmetricNeutralHaploidFrequencies"}],
Cell[6819, 206, 54, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6898, 210, 158, 4, 26, "Input"],
Cell[7059, 216, 2583, 40, 596, "Output"]
}, Closed]],
Cell[9657, 259, 57, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[9739, 263, 85, 2, 26, "Input"],
Cell[9827, 267, 113, 2, 36, "Output"]
}, Open  ]],
Cell[9955, 272, 160, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[10140, 280, 167, 5, 26, "Input"],
Cell[10310, 287, 1205, 20, 324, "Output"]
}, Closed]],
Cell[11530, 310, 115, 3, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[11670, 317, 85, 2, 26, "Input"],
Cell[11758, 321, 198, 4, 36, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

