(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     33643,       1068]*)
(*NotebookOutlinePosition[     34977,       1111]*)
(*  CellTagsIndexPosition[     34839,       1103]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Storing a cline", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{"StoreExact", "[", 
                RowBox[{
                "\[Psi]", ",", \(W[]\), ",", "m", ",", \({t, dt}\), ",", 
                  RowBox[{"{", 
                    RowBox[{
                      StyleBox["ndemes",
                        FontSlant->"Italic"], ",", 
                      StyleBox["ngenes",
                        FontSlant->"Italic"]}], "}"}]}], "]"}], 
              " "}], \(stores\ a\ cline\ shape\ at\ intervals\ dt\ in\ \[Psi][
                t], \ starting\ with\ a\ \(\(step\)\(.\)\)\)},
          {
            RowBox[{"StoreExact", "[", 
              RowBox[{
              "\[Psi]", ",", \(W[]\), ",", "m", ",", \({t, dt}\), ",", 
                RowBox[{"{", 
                  RowBox[{
                    StyleBox["ndemes",
                      FontSlant->"Italic"], ",", 
                    StyleBox["ngenes",
                      FontSlant->"Italic"], ",", "\[CapitalDelta]p"}], 
                  "}"}]}], 
              "]"}], \(\(starts\)\(\ \)\(with\)\(\ \)\(a\)\(\ \
\)\(gradient\)\(\ \)\(spanning\)\(\ \)\(\(\[CapitalDelta]p\)\(.\)\)\(\ \)\)},
          {
            RowBox[{"StoreExact", "[", 
              RowBox[{
              "\[Psi]", ",", \(W[]\), ",", "m", ",", \({t, dt}\), ",", 
                RowBox[{"{", 
                  RowBox[{
                    StyleBox["ndemes",
                      FontSlant->"Italic"], ",", 
                    StyleBox["ngenes",
                      FontSlant->"Italic"]}], "}"}], 
                ",", \(Compiled \[Rule] True\)}], 
              "]"}], \(uses\ compiled\ \(\(code\)\(.\)\)\)},
          {
            RowBox[{"StoreExact", "[", 
              RowBox[{
              "\[Psi]", ",", \(W[]\), ",", "m", ",", \({t, dt}\), ",", 
                RowBox[{"{", 
                  RowBox[{
                    StyleBox["ndemes",
                      FontSlant->"Italic"], ",", 
                    StyleBox["ngenes",
                      FontSlant->"Italic"]}], "}"}], 
                ",", \(MigrationOrder \[Rule] MUS\)}], 
              "]"}], \(uses\ the\ order\ \ migration \[Rule] \(random\ union \
\[Rule] \(selection \[Rule] meiosis\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->{"StoreExact", "Cline"}],

Cell["\<\
This stores clines for 2% selection against heterozygotes at t = 0, \
10,\[Ellipsis],100 in \[Psi][0], \[Psi][10],\[Ellipsis],\[Psi][100]:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(hetW[s_]\)[_]\)[_, _, h_] := \((1 - s)\)\^h; \n
    Timing[StoreExact[\[Psi], hetW[0.1], 0.5, {100, 10}, {30, 3}, 
        Compiled \[Rule] True]; ]\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \({1.96666666666533274`\ Second, Null}\)], "Output",
  CellLabel->"Out[39]="]
}, Closed]],

Cell["\<\
The function \[Psi][t] evaluated at t=100:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi][100]\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \({{0.999740906137318319`, 0.000259068058509299925`, 
        2.58031362971041566`*^-8, 1.0361958491458536`*^-12}, {
        0.999624122336241782`, 0.000375813804975276255`, 
        6.38537616713602496`*^-8, 5.02117995664603533`*^-12}, {
        0.999338489915905903`, 0.00066129430055892735`, 
        2.15750015358772317`*^-7, 3.35198352522653131`*^-11}, {
        0.998756859921298634`, 0.00124235654327257272`, 
        7.83299135866763052`*^-7, 2.36292956123575237`*^-10}, {
        0.997621016493305035`, 0.00237609074446473034`, 
        2.89107647540382117`*^-6, 1.68575467356584347`*^-9}, {
        0.995428992219730446`, 0.00456029399768910614`, 
        0.0000107017270409706299`, 1.2055539309575276`*^-8}, {
        0.991219846408801608`, 0.00874050515826211871`, 
        0.0000395622419757943042`, 8.6190960369997267`*^-8}, {
        0.983175837073935454`, 0.0166778914318437943`, 
        0.000145656562395966471`, 6.14931824752341427`*^-7}, {
        0.967921537512203222`, 0.0315423374383491328`, 
        0.000531762690748631072`, 4.36235869898185057`*^-6}, {
        0.939406480825830492`, 0.0586543683975514973`, 
        0.00190863523368759189`, 0.0000305155429304557346`}, {
        0.887530681010948185`, 0.105640751503093022`, 
        0.00662185426599603577`, 0.000206713219962731997`}, {
        0.797817456809753622`, 0.179360128892000725`, 0.0215138477934545102`, 
        0.00130856650479130065`}, {0.65620651945854167`, 
        0.274442836862113415`, 0.0620701094515562079`, 
        0.00728053422778859271`}, {0.464825746198717748`, 
        0.354711727811136734`, 0.147766856603613199`, 
        0.0326956693865322556`}, {0.262050431818806739`, 
        0.359401011048278107`, 0.269314250085258377`, 
        0.109234307047656686`}, {0.109234307047656574`, 
        0.269314250085258288`, 0.359401011048278196`, 0.26205043181880705`}, {
        0.032695669386532189`, 0.147766856603613021`, 0.354711727811136734`, 
        0.464825746198718015`}, {0.00728053422778858383`, 
        0.0620701094515561813`, 0.274442836862113415`, 
        0.656206519458541936`}, {0.00130856650479129732`, 
        0.0215138477934544747`, 0.179360128892000609`, 
        0.797817456809753711`}, {0.000206713219962731553`, 
        0.00662185426599602333`, 0.105640751503092911`, 
        0.887530681010948185`}, {0.0000305155429304556413`, 
        0.00190863523368758674`, 0.0586543683975514262`, 
        0.939406480825830492`}, {4.36235869898183459`*^-6, 
        0.000531762690748629562`, 0.0315423374383490884`, 
        0.967921537512203222`}, {6.1493182475233894`*^-7, 
        0.000145656562395966027`, 0.016677891431843772`, 
        0.983175837073935454`}, {8.6190960369996965`*^-8, 
        0.0000395622419757942278`, 0.00874050515826210983`, 
        0.991219846408801608`}, {1.20555393095752472`*^-8, 
        0.0000107017270409706144`, 0.00456029399768910526`, 
        0.995428992219730623`}, {1.68575467356584107`*^-9, 
        2.89107647540381798`*^-6, 0.00237609074446472945`, 
        0.997621016493305035`}, {2.3629295612357497`*^-10, 
        7.83299135866762696`*^-7, 0.00124235654327257205`, 
        0.998756859921298634`}, {3.35198352522652909`*^-11, 
        2.1575001535877214`*^-7, 0.000661294300558926906`, 
        0.999338489915905725`}, {5.02117995664603178`*^-12, 
        6.3853761671360214`*^-8, 0.000375813804975276166`, 
        0.999624122336241782`}, {1.03619584914585294`*^-12, 
        2.58031362971041344`*^-8, 0.000259068058509299747`, 
        0.999740906137318141`}}\)], "Output",
  CellLabel->"Out[40]="]
}, Closed]],

Cell[TextData[
"It may be convenient to label the results as (say) \[Psi][0.1]; this avoids \
the danger of overwriting previous simulations."], "Text"],

Cell["\<\
Plots of allele frequency and linkage disequilibrium for this \
example, at t=100:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      GraphicsArray[\n
        \t\t{ListPlot[MeanP[\(\[Psi][0.02]\)[500]], PlotJoined -> True], \n\t
          ListPlot[MeanD[\(\[Psi][0.02]\)[500]], PlotJoined -> True]}]]; 
    \)\)], "Input",
  CellLabel->"In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0147151 0.605495 [
[.18254 .00222 -3 -9 ]
[.18254 .00222 3 0 ]
[.34127 .00222 -6 -9 ]
[.34127 .00222 6 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.65873 .00222 -6 -9 ]
[.65873 .00222 6 0 ]
[.81746 .00222 -6 -9 ]
[.81746 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .13581 -18 -4.5 ]
[.01131 .13581 0 4.5 ]
[.01131 .25691 -18 -4.5 ]
[.01131 .25691 0 4.5 ]
[.01131 .37801 -18 -4.5 ]
[.01131 .37801 0 4.5 ]
[.01131 .49911 -18 -4.5 ]
[.01131 .49911 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(10)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(15)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(20)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(25)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(30)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13581 m
.03006 .13581 L
s
[(0.2)] .01131 .13581 1 0 Mshowa
.02381 .25691 m
.03006 .25691 L
s
[(0.4)] .01131 .25691 1 0 Mshowa
.02381 .37801 m
.03006 .37801 L
s
[(0.6)] .01131 .37801 1 0 Mshowa
.02381 .49911 m
.03006 .49911 L
s
[(0.8)] .01131 .49911 1 0 Mshowa
.125 Mabswid
.02381 .04499 m
.02756 .04499 L
s
.02381 .07526 m
.02756 .07526 L
s
.02381 .10554 m
.02756 .10554 L
s
.02381 .16609 m
.02756 .16609 L
s
.02381 .19636 m
.02756 .19636 L
s
.02381 .22664 m
.02756 .22664 L
s
.02381 .28719 m
.02756 .28719 L
s
.02381 .31746 m
.02756 .31746 L
s
.02381 .34774 m
.02756 .34774 L
s
.02381 .40829 m
.02756 .40829 L
s
.02381 .43856 m
.02756 .43856 L
s
.02381 .46884 m
.02756 .46884 L
s
.02381 .52939 m
.02756 .52939 L
s
.02381 .55966 m
.02756 .55966 L
s
.02381 .58994 m
.02756 .58994 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.05556 .03161 m
.0873 .03287 L
.11905 .03549 L
.15079 .03964 L
.18254 .0456 L
.21429 .05371 L
.24603 .06445 L
.27778 .07835 L
.30952 .09599 L
.34127 .11793 L
.37302 .14461 L
.40476 .1762 L
.43651 .21249 L
.46825 .25271 L
.5 .29557 L
.53175 .33936 L
.56349 .38222 L
.59524 .42244 L
.62698 .45872 L
.65873 .49032 L
.69048 .517 L
.72222 .53894 L
.75397 .55658 L
.78571 .57048 L
.81746 .58121 L
.84921 .58933 L
.88095 .59528 L
.9127 .59943 L
.94444 .60205 L
.97619 .60332 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0147151 112.74 [
[.18254 .00222 -3 -9 ]
[.18254 .00222 3 0 ]
[.34127 .00222 -6 -9 ]
[.34127 .00222 6 0 ]
[.5 .00222 -6 -9 ]
[.5 .00222 6 0 ]
[.65873 .00222 -6 -9 ]
[.65873 .00222 6 0 ]
[.81746 .00222 -6 -9 ]
[.81746 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .12746 -30 -4.5 ]
[.01131 .12746 0 4.5 ]
[.01131 .24019 -30 -4.5 ]
[.01131 .24019 0 4.5 ]
[.01131 .35293 -30 -4.5 ]
[.01131 .35293 0 4.5 ]
[.01131 .46567 -30 -4.5 ]
[.01131 .46567 0 4.5 ]
[.01131 .57841 -30 -4.5 ]
[.01131 .57841 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(10)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(15)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(20)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(25)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(30)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .12746 m
.03006 .12746 L
s
[(0.001)] .01131 .12746 1 0 Mshowa
.02381 .24019 m
.03006 .24019 L
s
[(0.002)] .01131 .24019 1 0 Mshowa
.02381 .35293 m
.03006 .35293 L
s
[(0.003)] .01131 .35293 1 0 Mshowa
.02381 .46567 m
.03006 .46567 L
s
[(0.004)] .01131 .46567 1 0 Mshowa
.02381 .57841 m
.03006 .57841 L
s
[(0.005)] .01131 .57841 1 0 Mshowa
.125 Mabswid
.02381 .03726 m
.02756 .03726 L
s
.02381 .05981 m
.02756 .05981 L
s
.02381 .08236 m
.02756 .08236 L
s
.02381 .10491 m
.02756 .10491 L
s
.02381 .15 m
.02756 .15 L
s
.02381 .17255 m
.02756 .17255 L
s
.02381 .1951 m
.02756 .1951 L
s
.02381 .21765 m
.02756 .21765 L
s
.02381 .26274 m
.02756 .26274 L
s
.02381 .28529 m
.02756 .28529 L
s
.02381 .30784 m
.02756 .30784 L
s
.02381 .33039 m
.02756 .33039 L
s
.02381 .37548 m
.02756 .37548 L
s
.02381 .39803 m
.02756 .39803 L
s
.02381 .42058 m
.02756 .42058 L
s
.02381 .44313 m
.02756 .44313 L
s
.02381 .48822 m
.02756 .48822 L
s
.02381 .51077 m
.02756 .51077 L
s
.02381 .53332 m
.02756 .53332 L
s
.02381 .55587 m
.02756 .55587 L
s
.02381 .60096 m
.02756 .60096 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.05556 .01513 m
.0873 .01618 L
.11905 .01857 L
.15079 .02294 L
.18254 .0304 L
.21429 .04268 L
.24603 .0623 L
.27778 .09257 L
.30952 .13727 L
.34127 .19967 L
.37302 .28053 L
.40476 .37555 L
.43651 .47326 L
.46825 .55566 L
.5 .60332 L
.53175 .60332 L
.56349 .55566 L
.59524 .47326 L
.62698 .37555 L
.65873 .28053 L
.69048 .19967 L
.72222 .13727 L
.75397 .09257 L
.78571 .0623 L
.81746 .04268 L
.84921 .0304 L
.88095 .02294 L
.9127 .01857 L
.94444 .01618 L
.97619 .01513 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 84.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000E1000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00:Woo0`002goo0`0017oo0P002Goo0`00
0goo0`0027oo10000goo0P0027oo10000Woo0`002Goo0`0017oo0P00VGoo000]Ool00`00Oomoo`09
Ool00`00Oomoo`02Ool01000Oomoo`002Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol0
0Woo00@007ooOol000Qoo`03001oogoo00Eoo`03001oogoo00Uoo`04001oogoo0002Ool00`00Oomo
o`2FOol002eoo`03001oogoo00Uoo`03001oogoo009oo`04001oogoo0009Ool00`00Oomoo`05Ool0
0`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol01goo00<007ooOol017oo00<007ooOol0
2Goo00@007ooOol0009oo`03001oogoo09Ioo`00:Woo0`0037oo00<007ooOol00Woo00@007ooOol0
00Uoo`03001oogoo009oo`<000]oo`04001oogoo0002Ool00`00Oomoo`08Ool00`00Oomoo`03000:
Ool20003Ool01000Oomoo`00>Woo0`002Goo0`0017oo0P001goo0`000goo0`001Woo10000goo0P00
1Woo10000Woo0`001goo0`0017oo0P002goo000ZOol00`00Oomoo`0<Ool00`00Oomoo`02Ool01000
Oomoo`002Goo00<007ooOol00Woo00<007ooOol027oo00@007ooOol0009oo`04001oogoo0007Ool0
1000Oomoo`000Woo00<007ooOol037oo00@007ooOol0009oo`03001oogoo03]oo`03001oogoo00Mo
o`03001oogoo009oo`04001oogoo0007Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool01000Oomoo`001Woo00<007ooOol01Goo00<007ooOol01goo00@007ooOol0009oo`03001oogoo
00Qoo`00:Woo10002Woo0P001Goo0P002Goo0P0017oo100027oo0P0017oo0P002Goo0P000goo1000
27oo0`0017oo0P00?Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol000Moo`03001oogoo
00Eoo`03001oogoo00Eoo`05001oogooOol00002Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`07Ool01000Oomoo`000Woo00<007ooOol027oo000KOol00`00Oomoo`2TOol3000:Ool00`00
Oomoo`02Ool01000Oomoo`001goo00<007ooOol00Woo0`002Goo00@007ooOol0009oo`03001oogoo
00Ioo`03001oogoo00<000Qoo`8000=oo`04001oogoo000:Ool001]oo`03001oogoo0:Aoo`03001o
ogoo00Yoo`03001oogoo009oo`04001oogoo0007Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01000
Oomoo`000Woo00@007ooOol000Eoo`04001oogoo0002Ool00`00Oomoo`0:Ool01000Oomoo`000Woo
00<007ooOol027oo000HOom^000lOol40008Ool20005Ool20007Ool20004Ool40006Ool20004Ool2
0007Ool20003Ool40006Ool30004Ool2000;Ool001]oo`03001oogoo00ioo`03001oogoo00ioo`03
001oogoo00moo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00moo`03001oogoo09Yoo`00
6goo00<007ooOol02P00SGoo00<007ooOol0J7oo000KOol00`00Oomoo`0:Ool70023OomR000<Ool0
01]oo`03001oogoo015oo`@0089oo`04001oogoo0002Ool00`00Oomoo`070002Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo
00<007oo00001@0000=oo`00Ool00Woo00<007ooOol037oo000KOol00`00Oomoo`0EOol20020Ool0
0`00Oomoo`0<Ool3000lOol3000JOol001]oo`03001oogoo01Moo`03001oogoo07eoo`03001oogoo
00moo`8003Moo`<001eoo`006goo00<007ooOol067oo0P00OGoo00<007ooOol04Goo00<007ooOol0
<goo00<007ooOol07Woo000KOol00`00Oomoo`0JOol2001kOol00`00Oomoo`0BOol00`00Oomoo`0a
Ool00`00Oomoo`0OOol001]oo`03001oogoo01aoo`8007Uoo`03001oogoo01=oo`03001oogoo02mo
o`03001oogoo021oo`006goo00<007ooOol07Woo00<007ooOol0MWoo00<007ooOol057oo00<007oo
Ool0;Goo00<007ooOol08Goo0009Ool20004Ool20003Ool40003Ool00`00Oomoo`0OOol2001fOol0
0`00Oomoo`0EOol00`00Oomoo`0[Ool00`00Oomoo`0ROol000Qoo`04001oogoo0003Ool20004Ool0
0`00Oomoo`03Ool00`00Oomoo`0QOol00`00Oomoo`1EOol20004Ool20004Ool20004Ool20003Ool3
0004Ool00`00Oomoo`0EOol00`00Oomoo`0[Ool00`00Oomoo`0ROol000Qoo`04001oogoo000:Ool0
0`00Oomoo`02Ool00`00Oomoo`0ROol00`00Oomoo`1COol01000Oomoo`000goo0P000goo00@007oo
Ool0009oo`04001oogoo0003Ool00`00Oomoo`03Ool00`00Oomoo`0FOol00`00Oomoo`0YOol00`00
Oomoo`0SOol000Qoo`04001oogoo000;Ool01@00Oomoogoo00009Goo00<007ooOol0DWoo00@007oo
Ool000Qoo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol00goo00<007ooOol05goo00<0
07ooOol09goo00<007ooOol097oo0008Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
02=oo`03001oogoo059oo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
ogoo00=oo`03001oogoo01Qoo`03001oogoo02Eoo`03001oogoo02Eoo`002Goo0P002Woo0P0017oo
00<007ooOol097oo00<007ooOol0DGoo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`00
0goo00<007ooOol00goo00<007ooOol067oo00<007ooOol09Goo00<007ooOol09Goo000KOol00`00
Oomoo`0UOol00`00Oomoo`1AOol2000:Ool20004Ool20003Ool20005Ool00`00Oomoo`0IOol00`00
Oomoo`0SOol00`00Oomoo`0VOol001]oo`03001oogoo02Ioo`03001oogoo06ioo`03001oogoo01Uo
o`03001oogoo02=oo`03001oogoo02Ioo`006goo00<007ooOol09goo00<007ooOol0KGoo00<007oo
Ool06Woo00<007ooOol08Goo00<007ooOol09goo000KOol00`00Oomoo`0XOol00`00Oomoo`1/Ool0
0`00Oomoo`0JOol00`00Oomoo`0QOol00`00Oomoo`0WOol001]oo`03001oogoo02Uoo`03001oogoo
06]oo`03001oogoo01]oo`03001oogoo01moo`03001oogoo02Qoo`006goo00<007ooOol0:Woo00<0
07ooOol0JWoo00<007ooOol06goo00<007ooOol07goo00<007ooOol0:7oo000KOol00`00Oomoo`0Z
Ool00`00Oomoo`1<Ool20004Ool20004Ool20004Ool20003Ool40003Ool00`00Oomoo`0LOol00`00
Oomoo`0MOol00`00Oomoo`0YOol000Uoo`8000Aoo`8000Aoo`<000=oo`03001oogoo02]oo`03001o
ogoo04Yoo`04001oogoo0003Ool20003Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo
00=oo`03001oogoo01aoo`03001oogoo01eoo`03001oogoo02Uoo`0027oo00@007ooOol000=oo`80
00Eoo`03001oogoo009oo`03001oogoo02aoo`03001oogoo04Uoo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo01aoo`03001oogoo01eoo`03001o
ogoo02Uoo`0027oo00@007ooOol000Qoo`@000=oo`03001oogoo02eoo`03001oogoo04Qoo`04001o
ogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol0000OOol00`00Oomoo`0K
Ool00`00Oomoo`0ZOol000Qoo`04001oogoo0008Ool00`00Ool00004Ool00`00Oomoo`0]Ool00`00
Oomoo`18Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo
00<007ooOol07Goo00<007ooOol06goo00<007ooOol0:Woo0008Ool01000Oomoo`0027oo00<007oo
000017oo00<007ooOol0;Woo00<007ooOol0B7oo0P002Woo0P0017oo0P0017oo0P0017oo00<007oo
Ool07Goo00<007ooOol06goo00<007ooOol0:Woo0009Ool2000:Ool20004Ool00`00Oomoo`0_Ool0
0`00Oomoo`1UOol00`00Oomoo`0NOol00`00Oomoo`0IOol00`00Oomoo`0[Ool001]oo`03001oogoo
031oo`03001oogoo06Aoo`03001oogoo01ioo`03001oogoo01Uoo`03001oogoo02]oo`006goo00<0
07ooOol0<Goo00<007ooOol0Hgoo00<007ooOol07goo00<007ooOol05goo00<007ooOol0;7oo000K
Ool00`00Oomoo`0aOol00`00Oomoo`1SOol00`00Oomoo`0OOol00`00Oomoo`0GOol00`00Oomoo`0/
Ool001]oo`03001oogoo039oo`03001oogoo069oo`03001oogoo01moo`03001oogoo01Moo`03001o
ogoo02aoo`006goo00<007ooOol0<goo00<007ooOol0@goo0P0017oo0P0017oo0P0017oo0P000goo
0`0017oo00<007ooOol087oo00<007ooOol05Goo00<007ooOol0;Goo000KOol00`00Oomoo`0dOol0
0`00Oomoo`11Ool01000Oomoo`000goo0P000goo00@007ooOol0009oo`04001oogoo0005Ool01@00
Oomoogoo00008Woo00<007ooOol05Goo00<007ooOol0;Goo000KOol00`00Oomoo`0dOol00`00Oomo
o`11Ool01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomoogoo00008Woo
00<007ooOol05Goo00<007ooOol0;Goo000KOol00`00Oomoo`0eOol00`00Oomoo`10Ool01000Oomo
o`0027oo00@007ooOol0009oo`04001oogoo0003Ool20004Ool00`00Oomoo`0QOol00`00Oomoo`0C
Ool00`00Oomoo`0^Ool000Uoo`8000Aoo`8000Aoo`8000Aoo`03001oogoo03Ioo`03001oogoo03mo
o`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Eoo`05001oogooOol0000SOol00`00
Oomoo`0COol00`00Oomoo`0^Ool000Qoo`04001oogoo0003Ool20003Ool01000Oomoo`000goo00<0
07ooOol0=goo00<007ooOol0?goo0P002Woo0P0017oo0P000goo0`0017oo00<007ooOol08Goo00<0
07ooOol04goo00<007ooOol0;Woo0008Ool01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo
03Qoo`03001oogoo05aoo`03001oogoo025oo`03001oogoo01=oo`03001oogoo02ioo`0027oo00@0
07ooOol000Qoo`<000Aoo`03001oogoo03Qoo`03001oogoo05aoo`03001oogoo029oo`03001oogoo
015oo`03001oogoo02moo`0027oo00@007ooOol000Qoo`03001oogoo00Aoo`03001oogoo03Uoo`03
001oogoo05]oo`03001oogoo029oo`03001oogoo015oo`03001oogoo02moo`002Goo0P002Woo0`00
0goo00<007ooOol0>Woo00<007ooOol0FWoo00<007ooOol08Woo00<007ooOol04Goo00<007ooOol0
;goo000KOol00`00Oomoo`0kOol00`00Oomoo`1IOol00`00Oomoo`0SOol00`00Oomoo`0?Ool00`00
Oomoo`0`Ool001]oo`03001oogoo03]oo`03001oogoo03]oo`8000Aoo`8000Aoo`8000Aoo`8000Ao
o`<000=oo`03001oogoo02=oo`03001oogoo00moo`03001oogoo031oo`006goo00<007ooOol0?7oo
00<007ooOol0>Goo00@007ooOol000=oo`8000=oo`04001oogoo0002Ool01000Oomoo`0017oo00<0
07ooOol00Woo00<007ooOol08goo00<007ooOol03goo00<007ooOol0<7oo000KOol00`00Oomoo`0m
Ool00`00Oomoo`0hOol01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool40003Ool0
0`00Oomoo`0TOol00`00Oomoo`0=Ool00`00Oomoo`0aOol001]oo`03001oogoo03ioo`03001oogoo
03Moo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oo`0000Aoo`03001o
ogoo02Aoo`03001oogoo00eoo`03001oogoo035oo`006goo00<007ooOol0?goo00<007ooOol0=Woo
00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo00<007oo000017oo00<007ooOol0
97oo00<007ooOol03Goo00<007ooOol0<Goo000KOol00`00Oomoo`10Ool00`00Oomoo`0fOol2000:
Ool20004Ool20004Ool20004Ool00`00Oomoo`0UOol00`00Oomoo`0;Ool00`00Oomoo`0bOol000Uo
o`8000Aoo`8000Aoo`8000Aoo`03001oogoo045oo`03001oogoo05=oo`03001oogoo02Eoo`03001o
ogoo00]oo`03001oogoo039oo`0027oo00@007ooOol000=oo`8000=oo`04001oogoo0003Ool00`00
Oomoo`12Ool00`00Oomoo`1BOol00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`0cOol000Qo
o`04001oogoo0008Ool01000Oomoo`000goo00<007ooOol0@goo00<007ooOol0DGoo00<007ooOol0
9goo00<007ooOol027oo00<007ooOol0<goo0008Ool01000Oomoo`002Goo0P0017oo00<007ooOol0
A7oo00<007ooOol0D7oo00<007ooOol09goo00<007ooOol027oo00<007ooOol0<goo0008Ool01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo04Eoo`80051oo`03001oogoo02Qoo`03001oogoo
00Ioo`03001oogoo03Aoo`002Goo0P002Woo0P0017oo00<007ooOol0Agoo0P00<7oo0P0017oo0P00
17oo0P0017oo0P000goo0`0017oo00<007ooOol0:7oo00<007ooOol01Woo00<007ooOol0=7oo000K
Ool00`00Oomoo`19Ool2000]Ool01000Oomoo`000goo0P000goo00@007ooOol0009oo`04001oogoo
0005Ool01@00Oomoogoo0000:goo00<007ooOol017oo00<007ooOol0=Goo000KOol00`00Oomoo`1;
Ool00`00Oomoo`0ZOol01000Oomoo`0027oo00@007ooOol0009oo`04001oogoo0005Ool01@00Oomo
ogoo0000;7oo00<007ooOol00Woo00<007ooOol0=Woo000KOol00`00Oomoo`1<Ool2000ZOol01000
Oomoo`0027oo00@007ooOol0009oo`04001oogoo0002Ool30004Ool00`00Oomoo`0ZOol00`00Oomo
o`02Ool00`00Oomoo`0fOol001]oo`03001oogoo04ioo`8002Qoo`04001oogoo0008Ool01000Oomo
o`000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001oogoo02]oo`@003Uoo`006goo00<007oo
Ool0D7oo0`009Woo0P002Woo0P0017oo0P000goo10000goo00<007ooOol0J7oo000KOol00`00Oomo
o`1COol30011Ool00`00Oomoo`1XOol001]oo`03001oogoo05Ioo`L00:Eoo`006goo00<007ooOol0
GGoo2@00W7oo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`00ogoo8Goo003o
OolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {83.75, 0}} -> {-0.0589635, -0.0147182, 
  0.00737954, 0.00737954}, {{7.9375, 137}, {81.75, 
  1.9375}} -> {-7.89748, -0.215994, 0.289295, 0.0151677}, {{149.938, 279}, {
  81.75, 1.9375}} -> {-59.1612, -0.00161629, 0.326598, 9.19655*^-5}}]
}, Closed]],

Cell[TextData[{
  "If evaluation is slow, it may be useful to store results using Save[",
  StyleBox["filename",
    FontSlant->"Italic"],
  ",",
  StyleBox["symbol",
    FontSlant->"Italic"],
  "]:"
}], "MathCaption"],

Cell[BoxData[
    \(Save["\<temp\>", \ \[Psi]]\)], "Input",
  CellLabel->"In[61]:="],

Cell["\<\
This retrieves the definitions of \[Psi] from the file \
\"temp\":\
\>", "MathCaption"],

Cell[BoxData[
    \(<< temp\)], "Input",
  CellLabel->"In[63]:="],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              RowBox[{"StoreExact", "[", 
                RowBox[{
                "\[Psi]", ",", \(W[]\), ",", "m", ",", \({t, dt}\), ",", 
                  RowBox[{"{", 
                    RowBox[{
                      StyleBox["ndemes",
                        FontSlant->"Italic"], ",", 
                      StyleBox["ngenes",
                        FontSlant->"Italic"]}], "}"}], 
                  ",", \(SymmetricCline \[Rule] True\)}], "]"}], 
              " "}], \(stores\ a\ symmetric\ cline\ at\ intervals\ dt\ in\ \
\[Psi][t], \ starting\ with\ a\ step; \ twice\ as\ \(\(efficient\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"SymmetricCline"],

Cell[TextData[{
  "This stores clines for 10% selection against heterozygotes at t = 0, 10,\
\[Ellipsis],100 in \[Psi][0.1][0], \
\[Psi][0.1][10],\[Ellipsis],\[Psi][0.1][100].  The cline is assumed \
symmetric, and so only half the cline needs to be simulated; the other half \
is then regenerated.  Surprisingly, this is considerably ",
  StyleBox["slower",
    FontSlant->"Italic"],
  ", presumably because the compiled iteration is fast, and the overhead \
involved in halving & doubling the cline rather slow.  This option may be \
more efficient, however, when simulating a symmetric ecotone, since then, a \
homogeneous selection regime can be assumed on the left half.  "
}], "Text"],

Cell["\<\
To gain speed, StoreExact needs to be compiled:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      StoreExact[\[Psi]S, hetW[0.1], 0.5, {100, 10}, {30, 3}, 
        Compiled \[Rule] True, SymmetricCline \[Rule] True]; ]\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    \({57.2499999999999964`\ Second, Null}\)], "Output",
  CellLabel->"Out[42]="]
}, Closed]],

Cell["\<\
The function \[Psi][t] evaluated at t=100:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi]S[100]\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \({{0.999740906137318319`, 0.000259068058509299925`, 
        2.58031362971041566`*^-8, 1.0361958491458536`*^-12}, {
        0.999624122336241782`, 0.000375813804975276255`, 
        6.38537616713602496`*^-8, 5.02117995664603533`*^-12}, {
        0.999338489915905903`, 0.00066129430055892735`, 
        2.15750015358772317`*^-7, 3.35198352522653131`*^-11}, {
        0.998756859921298634`, 0.00124235654327257272`, 
        7.83299135866763052`*^-7, 2.36292956123575192`*^-10}, {
        0.997621016493305035`, 0.00237609074446473034`, 
        2.89107647540381975`*^-6, 1.68575467356584258`*^-9}, {
        0.995428992219730446`, 0.00456029399768910614`, 
        0.0000107017270409706277`, 1.20555393095752649`*^-8}, {
        0.991219846408801608`, 0.00874050515826211871`, 
        0.0000395622419757942633`, 8.61909603699970894`*^-8}, {
        0.983175837073935454`, 0.0166778914318437827`, 
        0.000145656562395966249`, 6.14931824752340361`*^-7}, {
        0.967921537512203222`, 0.0315423374383491061`, 
        0.000531762690748630362`, 4.36235869898184258`*^-6}, {
        0.939406480825830492`, 0.0586543683975514618`, 
        0.00190863523368759011`, 0.0000305155429304557035`}, {
        0.887530681010948363`, 0.105640751503092955`, 
        0.00662185426599602955`, 0.00020671321996273182`}, {
        0.797817456809753622`, 0.17936012889200068`, 0.0215138477934544969`, 
        0.00130856650479129932`}, {0.656206519458541848`, 
        0.274442836862113415`, 0.0620701094515562079`, 
        0.00728053422778859093`}, {0.464825746198717837`, 
        0.354711727811136734`, 0.147766856603613199`, 
        0.0326956693865322378`}, {0.262050431818806828`, 
        0.359401011048278196`, 0.269314250085258377`, 
        0.109234307047656663`}, {0.109234307047656663`, 
        0.269314250085258377`, 0.359401011048278196`, 
        0.262050431818806828`}, {0.0326956693865322378`, 
        0.147766856603613199`, 0.354711727811136734`, 
        0.464825746198717837`}, {0.00728053422778859093`, 
        0.0620701094515562079`, 0.274442836862113415`, 
        0.656206519458541848`}, {0.00130856650479129932`, 
        0.0215138477934544969`, 0.17936012889200068`, 
        0.797817456809753622`}, {0.00020671321996273182`, 
        0.00662185426599602955`, 0.105640751503092955`, 
        0.887530681010948363`}, {0.0000305155429304557035`, 
        0.00190863523368759011`, 0.0586543683975514618`, 
        0.939406480825830492`}, {4.36235869898184258`*^-6, 
        0.000531762690748630362`, 0.0315423374383491061`, 
        0.967921537512203222`}, {6.14931824752340361`*^-7, 
        0.000145656562395966249`, 0.0166778914318437827`, 
        0.983175837073935454`}, {8.61909603699970894`*^-8, 
        0.0000395622419757942633`, 0.00874050515826211871`, 
        0.991219846408801608`}, {1.20555393095752649`*^-8, 
        0.0000107017270409706277`, 0.00456029399768910614`, 
        0.995428992219730446`}, {1.68575467356584258`*^-9, 
        2.89107647540381975`*^-6, 0.00237609074446473034`, 
        0.997621016493305035`}, {2.36292956123575192`*^-10, 
        7.83299135866763052`*^-7, 0.00124235654327257272`, 
        0.998756859921298634`}, {3.35198352522653131`*^-11, 
        2.15750015358772317`*^-7, 0.00066129430055892735`, 
        0.999338489915905903`}, {5.02117995664603533`*^-12, 
        6.38537616713602496`*^-8, 0.000375813804975276255`, 
        0.999624122336241782`}, {1.0361958491458536`*^-12, 
        2.58031362971041566`*^-8, 0.000259068058509299925`, 
        0.999740906137318319`}}\)], "Output",
  CellLabel->"Out[45]="]
}, Closed]],

Cell[TextData[{
  StyleBox["Note",
    FontWeight->"Bold"],
  ": This option does not work for MigrationOrder\[Rule]USM, because the \
endpoint of the half-cline is then fixed at the appropriate value before \
selection, rather than after.  This problem could be fixed rather easily."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{526, 699},
WindowMargins->{{Automatic, -5}, {Automatic, 0}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "StoreExact"->{
    Cell[1783, 53, 2350, 54, 166, "DefinitionBox",
      CellTags->{"StoreExact", "Cline"}]},
  "Cline"->{
    Cell[1783, 53, 2350, 54, 166, "DefinitionBox",
      CellTags->{"StoreExact", "Cline"}]},
  "SymmetricCline"->{
    Cell[27668, 935, 776, 17, 64, "DefinitionBox",
      CellTags->"SymmetricCline"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"StoreExact", 34504, 1090},
  {"Cline", 34611, 1093},
  {"SymmetricCline", 34727, 1096}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 41, 0, 36, "SubsectionIcon"],
Cell[1783, 53, 2350, 54, 166, "DefinitionBox",
  CellTags->{"StoreExact", "Cline"}],
Cell[4136, 109, 171, 4, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[4332, 117, 210, 4, 43, "Input"],
Cell[4545, 123, 95, 2, 20, "Output"]
}, Closed]],
Cell[4655, 128, 73, 2, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[4753, 134, 69, 2, 27, "Input"],
Cell[4825, 138, 3584, 60, 401, "Output"]
}, Closed]],
Cell[8424, 201, 152, 2, 32, "Text"],
Cell[8579, 205, 113, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[8717, 212, 247, 6, 57, "Input"],
Cell[8967, 220, 18210, 689, 91, 7863, 556, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[27192, 912, 218, 8, 20, "MathCaption"],
Cell[27413, 922, 84, 2, 27, "Input"],
Cell[27500, 926, 97, 3, 28, "MathCaption"],
Cell[27600, 931, 65, 2, 27, "Input"],
Cell[27668, 935, 776, 17, 64, "DefinitionBox",
  CellTags->"SymmetricCline"],
Cell[28447, 954, 690, 12, 94, "Text"],
Cell[29140, 968, 78, 2, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[29243, 974, 191, 4, 42, "Input"],
Cell[29437, 980, 95, 2, 20, "Output"]
}, Closed]],
Cell[29547, 985, 73, 2, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[29645, 991, 70, 2, 27, "Input"],
Cell[29718, 995, 3598, 61, 401, "Output"]
}, Closed]],
Cell[33331, 1059, 296, 6, 48, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

