(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    225350,       5143]*)
(*NotebookOutlinePosition[    264217,       6451]*)
(*  CellTagsIndexPosition[    264173,       6447]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(\(BeginPackage["\<NumericalModels`ExactModel`\>", \
{"\<LinearAlgebra`MatrixManipulation`\>", "\<Multilocus`DataManipulation`\>", \
"\<Statistics`DiscreteDistributions`\>", "\<Utilities`Matrices`\>", \
"\<Utilities`RandomNumbers`\>", "\<Utilities`SetManipulation`\>", \
"\<Utilities`Miscellaneous`\>"}];\)\)], "Input",
  PageWidth->PaperWidth,
  InitializationCell->True,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[" Usage statements", "Section",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->False],

Cell[BoxData[
    \(\(Off[General::spell1, General::spell];\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Describing genotype frequencies", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox["MakePopulation",
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["MakePopulation",
            FontFamily->"Times"], "::", "usage"}], "=", 
        "\"\<MakePopulation[nloci,p] gives a haploid population at linkage \
equilibrium, with allele frequency p; this is represented as \
HaploidFrequencies[{\!\(\[Psi]\_000\)\[Ellipsis]}]. The option NumericalModel \
can be used to give other representations.  For example, \
MakePopulation[nloci,{p,u},NumericalModel->SymmetricNeutralHaploidFrequencies \
gives a haploid population at LE, with selected loci at frequency p, and a \
single neutral marker at frequency u. \
MakePopulation[nloci,p,NumericalModel->HaploidIndividuals] gives a single \
haploid individual, drawn at random. MakePopulation[nloci,p,ndeme,opts] \
allows deme size to be specified; the default is 1.  \>\""}], ";"}]], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MakeDiploid", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(MakeDiploid::usage = "\<MakeDiploid[HaploidFrequencies[\[Ellipsis]]] \
gives the matrix of diploid genotype frequencies after random mating. Deme \
size is halved. Applies to vectors of class, genotype and allele frequencies; \
 MakeDiploid[HaploidIndividuals[\[Ellipsis]]] generates a population of \
diploids by sampling with replacement from the haploid population; not \
particularly useful, and added for completeness only.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MakeHaploid", "Subsubsection"],

Cell[BoxData[
    \(\(MakeHaploid::usage = "\<MakeHaploid[DiploidFrequencies[\[Ellipsis]]] \
gives the haploid genotype frequencies, averaged over maternal and paternal \
genomes.  Deme size is doubled.  Applies to vectors of class, genotype and \
allele frequencies.  Deme size is left unaltered, except for \
MakeHaploid[DiploidIndividuals[\[Ellipsis]]], for which deme size is doubled. \
 This just flattens the list: there is no sampling.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MakeIndividuals", "Subsubsection"],

Cell[BoxData[
    \(\(MakeIndividuals::usage = \*"\"\<MakeIndividuals[\[Psi],n] generates n \
random individuals from the population \[Psi].  If \[Psi] represents a \
diploid population, the representation DiploidIndividuals[] is returned; \
similarly for haploids.  MakeIndividuals[AlleleFrequencies[p,n0],n] returns n \
haploid individuals, drawn from a population at linkage equilibrium. \
MakeIndividuals[SymmetricNeutralHaploidFrequencies[{\[Psi],u},n0],n] adds a \
neutral marker locus at the last position of the genotype.  MakeIndividuals[{\
\!\(\[Psi]\_1\)\[Ellipsis]},{\!\(n\_1\),\[Ellipsis]}] generates individuals \
across a cline.  MakeIndividuals[j,n] returns a haplotype of n genes, wih j \
randomly assigned to 1.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MakeOptionsHaploid", "Subsubsection"],

Cell[BoxData[
    \(\(MakeOptionsHaploid::usage = "\<MakeOptionsHaploid is a rule which \
converts options such as NumericalModel->DiploidFrequencies to their haploid \
version\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`NumericalModel\)], "Subsubsection"],

Cell[BoxData[
    \(\(NumericalModel::usage = "\<NumericalModel is an option which \
determines how a population is represented.  Possible values are any \
PopulationRepresentations\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`HaploidFrequencies\)], "Subsubsection"],

Cell[BoxData[
    \(\(HaploidFrequencies::usage = \
\*"\"\<HaploidFrequencies[{\!\(\[Psi]\_000\),\[Ellipsis]},n] represents \
haploid genotype frequencies, and deme size n.  \
HaploidFrequencies[{\!\(\[Psi]\_000\),\[Ellipsis]}] is shorthand for \
HaploidFrequencies[{\!\(\[Psi]\_000\),\[Ellipsis]},1]\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`DiploidFrequencies\)], "Subsubsection"],

Cell[BoxData[
    \(\(DiploidFrequencies::usage = \
\*"\"\<DiploidFrequencies[{{\!\(\[Psi]\_\(000, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\
\ \)\(000\)\)\)\),\[Ellipsis]},\[Ellipsis]},n] represents diploid genotype \
frequencies, and deme size n.  DiploidFrequencies[{{\!\(\[Psi]\_\(000, \\\\\\\
\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(000\)\)\)\),\[Ellipsis]},\[Ellipsis]}] is \
shorthand for DiploidFrequencies[{{\!\(\[Psi]\_\(000, \\\\\\\ \
\(\(\\\\\\\\\)\(\\\\\\\ \
\)\(000\)\)\)\),\[Ellipsis]},\[Ellipsis]},1]\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`AlleleFrequencies\)], "Subsubsection"],

Cell[BoxData[
    \(\(AlleleFrequencies::usage = \*"\"\<AlleleFrequencies[{\!\(p\_1\),\!\(p\
\_2\),\[Ellipsis]},n] represents allele frequencies, and deme size n.  \
AlleleFrequencies[{\!\(p\_1\),\!\(p\_2\),\[Ellipsis]}] is shorthand for \
AlleleFrequencies[{\!\(p\_1\),\!\(p\_2\),\[Ellipsis]},1]\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`SymmetricHaploidFrequencies\)], "Subsubsection"],

Cell[BoxData[
    \(\(SymmetricHaploidFrequencies::usage = \
\*"\"\<SymmetricHaploidFrequencies[{\!\(\[Psi]\_0\),\[Ellipsis]},n] \
represents a haploid population in which genotypes with the same # of '1' \
alleles are equally frequent.  This allows a haploid population to be \
repesented by n+1 variables, rather than \!\(2\^n\). \
SymmetricHaploidFrequencies[{\!\(\[Psi]\_0\),\[Ellipsis]}] is shorthand for \
SymmetricHaploidFrequencies[{\!\(\[Psi]\_0\),\[Ellipsis]},1]\>\"";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`SymmetricDiploidFrequencies\)], "Subsubsection"],

Cell[BoxData[
    \(\(SymmetricDiploidFrequencies::usage = \
\*"\"\<SymmetricDiploidFrequencies[{{\!\(\[Psi]\_\(0, \\\\\\\ \
\(\(\\\\\\\\\)\(\\\\\\\ \)\(0\)\)\)\),\[Ellipsis]},\[Ellipsis]},n] represents \
a diploid population in which haplotypes with the same # of '1' alleles are \
equally frequent.  This allows a diploid population to be repesented by \
(n+1\!\(\()\^2\)\) variables, rather than \!\(2\^\(2\\\\\\\\\\\\\\\ \
\\\\\\\\\\\\\\\ n\)\). SymmetricDiploidFrequencies[{{\!\(\[Psi]\_\(0, \\\\\\\ \
\(\(\\\\\\\\\)\(\\\\\\\ \)\(0\)\)\)\),\[Ellipsis]},\[Ellipsis]}] is shorthand \
for SymmetricDiploidFrequencies[{{\!\(\[Psi]\_\(0, \\\\\\\ \(\(\\\\\\\\\)\(\\\
\\\\\ \)\(0\)\)\)\),\[Ellipsis]},\[Ellipsis]},1]\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`HaploidIndividuals\)], "Subsubsection"],

Cell[BoxData[
    \(\(HaploidIndividuals::usage = \
"\<HaploidIndividuals[{{0,0,1\[Ellipsis]},\[Ellipsis]},n] represents a \
population of n haploid individuals; n must match the length of the list, and \
is added automatically if \
HaploidIndividuals[{{0,0,1\[Ellipsis]},\[Ellipsis]}] is specified.\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`DiploidIndividuals\)], "Subsubsection"],

Cell[BoxData[
    \(\(DiploidIndividuals::usage = \
"\<DiploidIndividuals[{{{0,0,1\[Ellipsis]},{0,1,1},\[Ellipsis]}},\[Ellipsis]},\
n] represents a population of n diploid individuals; n must match the length \
of the list, and is added automatically if DiploidIndividuals[{{{0,0,1\
\[Ellipsis]},{0,1,1},\[Ellipsis]}},\[Ellipsis]}] is specified.\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SymmetricNeutralHaploidFrequencies", "Subsubsection"],

Cell[BoxData[
    \(\(SymmetricNeutralHaploidFrequencies::usage = \
\*"\"\<SymmetricNeutralHaploidFrequencies[{{\!\(\[Psi]\_0\),\[Ellipsis]},{\!\(\
u\_0\),\[Ellipsis]}},n] represents a population by the frequency of each \
genotypic class, \!\(\[Psi]\_i\), and the frequency of a neutral marker \
within that class, \!\(u\_i\).  SymmetricNeutralHaploidFrequencies[{{\!\(\
\[Psi]\_0\),\[Ellipsis]},{\!\(u\_0\),\[Ellipsis]}}] is shorthand for \
SymmetricNeutralHaploidFrequencies[{{\!\(\[Psi]\_0\),\[Ellipsis]},{\!\(u\_0\),\
\[Ellipsis]}},1].\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SymmetricNeutralDiploidFrequencies", "Subsubsection"],

Cell[BoxData[
    \(\(SymmetricNeutralDiploidFrequencies::usage = \
\*"\"\<SymmetricNeutralDiploidFrequencies[{{{\!\(\[Psi]\_\(0, \\\\\\\ \
\(\(\\\\\\\\\)\(\\\\\\\ \)\(0\)\)\)\),\[Ellipsis]},\[Ellipsis]},{{\!\(u\_\(0, \
\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(0\)\)\)\),\[Ellipsis]},\[Ellipsis]}},n] \
represents a diploid population by the frequency of each genotypic class, \
\!\(\[Psi]\_\(i, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(j\)\)\)\), and the \
frequency of a neutral marker within that class, \!\(u\_\(i, \\\\\\\ \(\(\\\\\
\\\\\)\(\\\\\\\ \)\(j\)\)\)\).  SymmetricNeutralDiploidFrequencies[{{{\!\(\
\[Psi]\_\(0, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(0\)\)\)\),\[Ellipsis]},\
\[Ellipsis]},{{\!\(u\_\(0, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(0\)\)\)\),\
\[Ellipsis]},\[Ellipsis]}}] is shorthand for \
SymmetricNeutralDiploidFrequencies[{{{\!\(\[Psi]\_\(0, \\\\\\\ \(\(\\\\\\\\\)\
\(\\\\\\\ \)\(0\)\)\)\),\[Ellipsis]},\[Ellipsis]},{{\!\(u\_\(0, \\\\\\\ \
\(\(\\\\\\\\\)\(\\\\\\\ \
\)\(0\)\)\)\),\[Ellipsis]},\[Ellipsis]}},1].\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PopulationRepresentations", "Subsubsection"],

Cell[BoxData[
    \(\(PopulationRepresentations::usage = "\<PopulationRepresentations is a \
pattern which matches any valid representation of a population.\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["FrequencyRepresentations", "Subsubsection"],

Cell[BoxData[
    \(\(FrequencyRepresentations::usage = "\<FrequencyRepresentations is a \
pattern which matches any valid representation of a population by allele, \
class or genotype frequencies.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["IndividualRepresentations", "Subsubsection"],

Cell[BoxData[
    \(\(IndividualRepresentations::usage = "\<IndividualRepresentations is a \
pattern which matches any valid representation of a population as a list of \
individuals.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["HaploidRepresentations", "Subsubsection"],

Cell[BoxData[
    \(\(HaploidRepresentations::usage = "\<HaploidRepresentations is a \
pattern which matches any valid representation of a haploid population.\>";\)\
\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["DiploidRepresentations", "Subsubsection"],

Cell[BoxData[
    \(\(DiploidRepresentations::usage = "\<DiploidRepresentations is a \
pattern which matches any valid representation of a diploid population.\>";\)\
\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NeutralRepresentations", "Subsubsection"],

Cell[BoxData[
    \(\(NeutralRepresentations::usage = "\<NeutralRepresentations is a \
pattern which matches \
SymmetricNeutralHaploidFrequencies|SymmetricNeutralDiploidFrequencies.\>";\)\)\
], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NonNeutralRepresentations", "Subsubsection"],

Cell[BoxData[
    \(\(NonNeutralRepresentations::usage = "\<NonNeutralRepresentations is a \
pattern which matches any valid representation except NeutralRepresentations.\
\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SymmetricRepresentations", "Subsubsection"],

Cell[BoxData[
    \(\(SymmetricRepresentations::usage = "\<SymmetricRepresentations is a \
pattern which matches any symmetric representation.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NonSymmetricRepresentations", "Subsubsection"],

Cell[BoxData[
    \(\(NonSymmetricRepresentations::usage = "\<NonSymmetricRepresentations \
is a pattern which matches any valid representation except \
SymmetricRepresentations or AlleleFrequencies.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["DiploidPhenotype", "Subsubsection"],

Cell[BoxData[
    \(\(DiploidPhenotype::usage = "\<DiploidPhenotype[z,\[Psi]] gives the \
frequency of the diploid phenotype z, given the population representation \
\[Psi].  DiploidPhenotype[\[Psi]] lists the whole distribution.  \>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`NumberOfGenes\)], "Subsubsection"],

Cell[BoxData[
    \(\(NumberOfGenes::usage = 
        NumberOfGenes::usage <> "\<  NumberOfGenes[\[Psi]] gives the number \
of genes, where \[Psi] represents a population.  Also applies to a list of \
\[Psi]'s, representing a cline.  \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`AlleleFrequencyMean\)], "Subsubsection"],

Cell[BoxData[
    \(\(AlleleFrequencyMean::usage = 
        AlleleFrequencyMean::usage <> \*"\"\<  AlleleFrequencyMean[\[Psi]] \
gives the average frequency of 1 alleles for the population representation \
\[Psi].  Also applies to a list of \[Psi]'s, representing a cline.  For \
representations SymmetricNeutralHaploidFrequencies or \
SymmetricNeutralDiploidFrequencies, returns {p,\!\(u\&_\)}, where \!\(u\&_\) \
is the average neutral allele frequency. \>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`AlleleFrequencyTable\)], "Subsubsection"],

Cell[BoxData[
    \(\(AlleleFrequencyTable::usage = 
        AlleleFrequencyTable::usage <> \*"\"\<  AlleleFrequencyTable[\[Psi]] \
gives the frequency of 1 alleles for each locus.  Also applies to a list of \
\[Psi]'s, representing a cline. For representations \
SymmetricNeutralHaploidFrequencies or SymmetricNeutralDiploidFrequencies, \
returns {{p,p,\[Ellipsis]},\!\(u\&_\)}, where \!\(u\&_\) is the average \
neutral allele frequency.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["DisequilibriumMean", "Subsubsection"],

Cell[BoxData[
    \(\(DisequilibriumMean::usage = "\<DisequilibriumMean[\[Psi]] gives the \
mean pairwise linkage disequilibrium for the population representation \
\[Psi].  Also applies to a list of \[Psi]'s, representing a cline.  For \
representations SymmetricNeutralHaploidFrequencies or \
SymmetricNeutralDiploidFrequencies, returns the mean D between selected loci, \
and the mean D between the neutral and selected loci.  \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["DisequilibriumTable", "Subsubsection"],

Cell[BoxData[
    \(\(DisequilibriumTable::usage = "\<DisequilibriumTable[\[Psi]] gives a \
matrix of pairwise linkage disequilibrium for the population representation \
\[Psi].  Also applies to a list of \[Psi]'s, representing a cline.  For \
representations SymmetricNeutralHaploidFrequencies or \
SymmetricNeutralDiploidFrequencies, returns the D between selected loci, and \
the D between the neutral and selected loci.   \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["DemeSize", "Subsubsection"],

Cell[BoxData[
    \(\(DemeSize::usage = "\<DemeSize[\[Psi]] gives the deme size associated \
with the population representation \[Psi]; also applies to a cline.\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ClineWidth", "Subsubsection"],

Cell[BoxData[
    \(\(ClineWidth::usage = \*"\"\<ClineWidth[{\!\(p\_0\),\[Ellipsis]}] gives \
the cline width, defined as the maximum gradient  in allele frequencies, \
\!\(p\_i\).  ClineWidth[\[Psi]], where \[Psi] is a list of population \
representations, lists the cline widths for each locus. For representations \
SymmetricNeutralHaploidFrequencies or SymmetricNeutralDiploidFrequencies, \
ClineWidth[\[Psi]] returns the widths of the selected and the neutral clines.\
\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`ClineGradient\)], "Subsubsection"],

Cell[BoxData[
    \(\(ClineGradient::usage = \*"\"\<ClineGradient[p] gives the gradient (\!\
\(p\_i\)-\!\(p\_\(i\\\\\\\\\\\\\\\ \\\\\\\ \(-\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \
\)\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) 1\)\)\)\)\)) of the list of \
allele frequencies \!\(p\_1\)\!\(\[Ellipsis]p\_n\); returns the list \
{\!\(p\_1\)-\!\(p\_0\), \!\(\[Ellipsis]p\_\(n, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\
\ \)\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) 1\)\)\)\)-\!\(p\_n\)}.  \
The default is to assume that \!\(p\_0\)=\!\(p\_1\), \!\(p\_\(n, \\\\\\\ \(\(\
\\\\\\\\\)\(\\\\\\\ \)\(1\)\)\)\)=\!\(p\_n\).  FixedEnds\[Rule]{\!\(p\_0\),\!\
\(p\_\(n, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\
\(\\\\\\\ \)\) 1\)\)\)\)} sets the outer demes to have allele frequencies \
\!\(p\_0\),\!\(p\_\(n, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(\\\\\\\\\\\\\\\\ \
\(\(\\\\\\\\\)\(\\\\\\\ \)\) 1\)\)\)\)  instead.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`BarrierStrength\)], "Subsubsection"],

Cell[BoxData[
    \(\(BarrierStrength::usage = \*"\"\<BarrierStrength[u] gives the barrier \
strengths \
{\[CapitalDelta]u/\!\(\[PartialD]\_x\)\!\(\(u\_-\)\),\[CapitalDelta]u/\!\(\
\[PartialD]\_x\)\!\(\(u\_+\)\)}, based on the list of allele frequencies \
\!\(u\_1\)\!\(\[Ellipsis]u\_n\).  The default is to assume that \!\(u\_0\)=\!\
\(u\_1\), \!\(u\_\(n, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(\\\\\\\\\\\\\\\\ \(\
\(\\\\\\\\\)\(\\\\\\\ \)\) \\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) \
1\)\)\)\)=\!\(u\_n\).  FixedEnds\[Rule]{\!\(u\_0\),\!\(u\_\(n, \\\\\\\ \(\(\\\
\\\\\\\)\(\\\\\\\ \)\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) \
\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) 1\)\)\)\)} sets the outer demes \
to have allele frequencies \!\(u\_0\),\!\(u\_\(n, \\\\\\\ \
\(\(\\\\\\\\\)\(\\\\\\\ \)\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) \
\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) 1\)\)\)\)  instead; sensible \
results are only obtained with this option set, since otherwise the gradients \
at the edges are zero. Also works with pairs {p,u}, as derived under \
SymmetricNeutralHaploidFrequencies or SymmetricNeutralDiploidFrequencies. \
\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MakeCline", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(MakeCline::usage = "\<MakeCline[ndemes,nloci,ninds] sets up a stepped \
cline, with ninds individuals per deme.  MakeCline[ndemes,nloci,ninds,dp] \
sets up a linear gradient, with net change dp<1.  NumericalModel specifies \
which representation is to be used. SymmetricNeutralModel allows for the \
presence of a neutral locus under the symmetric model; this is initially \
either in a step, or a gradient spanning dp.  \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["CountHeterozygotes", "Subsubsection"],

Cell[BoxData[
    \(\(CountHeterozygotes::usage = \
"\<CountHeterozygotes[{0,1,\[Ellipsis]},{0,0,\[Ellipsis]}] returns the number \
of heterozygotes.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["DoubleCline", "Subsubsection"],

Cell[BoxData[
    \(\(DoubleCline::usage = "\<DoubleCline[\[Psi],EvenQ[ndemes]] takes the \
cline \[Psi] to represent the left half of a symmetric cline, and adds the \
right half.  If the total number of demes is even, then the second argument \
is set True, and the extra demes are a mirror image of \[Psi].  If the total \
number of demes is odd, the second argument is set False, and Last[\[Psi]] is \
assumed to be the central deme; it must contain a symmetrical set of genotype \
frequencies. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`MeanW\)], "Subsubsection"],

Cell[BoxData[
    \(\(MeanW::usage = \*"\"\<MeanW[\[Psi],W] gives the mean fitness of \
population \[Psi]; W is the fitness function. MeanW[\[Psi],{{{\!\(W\_\(0, \
\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \
\)\) \\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) 0\)\), \\\\\\\ \
\(\(\\\\\\\\\)\(\\\\\\\ \)\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) \
\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) 0\)\)\)\),\[Ellipsis]}}}] gives \
the mean fitness, based on an appropriate table of fitnesses.\>\"";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SymmetricMeanW", "Subsubsection"],

Cell[BoxData[
    \(\(SymmetricMeanW::usage = \*"\"\<SymmetricMeanW[i,j,n,W] gives the mean \
fitness of the diploid combination {i,j}, averaging over heterozygosities; \
there are n genes.  Fitness is W[i,j,h].  SymmetricMeanW[n,W] gives a table \
of diploid fitnesses.  SymmetricMeanW[n,{{{\!\(W\_\(0, \\\\\\\ \(\(\\\\\\\\\)\
\(\\\\\\\ \)\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) \\\\\\\\\\\\\\\\ \
\(\(\\\\\\\\\)\(\\\\\\\ \)\) 0\)\), \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \
\)\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) 0\)\)\)\),\[Ellipsis]}\
\[Ellipsis]}\[Ellipsis]}] gives the mean fitness of the diploid combination \
{i,j}, averaging over heterozygosities; there are n genes.  Fitness is \
tabulated in {{{\!\(W\_\(0, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \
\)\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) \\\\\\\\\\\\\\\\ \(\(\\\\\\\
\\\)\(\\\\\\\ \)\) 0\)\), \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \
\)\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) 0\)\)\)\),\[Ellipsis]}\
\[Ellipsis]}\[Ellipsis]}.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`MarginalW\)], "Subsubsection"],

Cell[BoxData[
    \(\(MarginalW::usage = \*"\"\<MarginalW[\[Psi],W] lists the marginal \
fitness of each haplotype or class, in terms of the representation \[Psi], \
and the fitness function W. MarginalW[\[Psi],{{{\!\(W\_\(0, \\\\\\\ \
\(\(\\\\\\\\\)\(\\\\\\\ \)\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) \
\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) 0\)\), \\\\\\\ \(\(\\\\\\\\\)\(\
\\\\\\\ \)\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) 0\)\)\)\),\
\[Ellipsis]}}}] uses a table of fitnesses, which can be much faster.\>\""\ \ \
;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`FitnessTable\)], "Subsubsection"],

Cell[BoxData[
    \(\(FitnessTable::usage = "\<FitnessTable[W,n] gives a table of all \
possible fitnesses, using the fitness function W, for n loci.  NumericalModel \
specifies which representation is used.  Useful for tabulating fitness in \
order to speed up functions such as MeanW.  Note that fitnesses cannot be \
tabulated if AlleleFrequencies are used.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Recursions", "Subsection"],

Cell[CellGroupData[{

Cell["StoreResults", "Subsubsection"],

Cell[BoxData[
    \(\(StoreResults::usage = "\<StoreResults\[Rule]False is an option for \
GameteTable[] which prevents results being stored.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`GameteTable\)], "Subsubsection"],

Cell[BoxData[
    \(\(GameteTable::usage = \*"\"\<GameteTable[n] gives the full \
distribution of \!\(2\^n\)  offspring genotypes. Linkage\[Rule]{\!\(r\_\(1, \
\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \
\)\) \\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) 2\)\)\)\),\!\(r\_\(2, \\\\\
\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) \
\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) 3\)\)\)\),\[Ellipsis]} \
specifies a linear genetic map. \
GameteTable[n,NumericalModel\[Rule]SymmetricHaploidFrequencies] stores a \
matrix showing the distribution of genotypes among gametes, for each diploid \
genotype, under the symmetric model. GameteTable[n,W] is also defined; it \
allows for a fitness function W.   Results are stored, which greatly speeds \
calculations.  However, if fitnesses continually change, the option \
StoreResults\[Rule]False must be used.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`Gametes\)], "Subsubsection"],

Cell[BoxData[
    \(\(Gametes::usage = \*"\"\<Gametes[Y,Z] gives the full distribution of \
\!\(2\^n\)offspring genotypes. Linkage\[Rule]{\!\(r\_\(1, \\\\\\\ \
\(\(\\\\\\\\\)\(\\\\\\\ \)\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) \
\(\\\\\\\\\\\\\\\\  \\\\\\\\\\\\\\\\\\\\\\\ \(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\
\(\\\\\\\ \)\)\)\\\\\\\ \\\\\\\\\\\\\\\\  \\\\\\\\\\\\\\\\\\\\\\\ \
\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\)\)\\\\\\\ \\\\\\\\\\\\\\\\  \\\
\\\\\\\\\\\\\\\\\\\\\ \(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\)\)\\\\\\\
\ 2\)\)\)\)\),\!\(r\_\(2, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \
\)\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) 3\)\)\)\),\[Ellipsis]} \
specifies a linear genetic map. Gametes[X,Y,Z] is also defined, and gives the \
probability of a specific gamete X from diploid parent {Y,Z}. \
Gametes[i,j,n,NumericalModel\[Rule]SymmetricHaploidFrequencies] gives the \
distribution of genotypes among gametes from a parent of genotype {i,j}. \
Gametes[i,j,n,W,NumericalModel\[Rule]SymmetricHaploidFrequencies] gives the \
same, for fitness W[i,j,h]. NOT normalised by MeanW[], however.\>\"";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["HeterozygoteB", "Subsubsection"],

Cell[BoxData[
    \(\(HeterozygoteB::usage = "\<HeterozygoteB[i,j,n] gives the distribution \
of the # of heterozygous loci among gametes from a parent of genotype {i,j}, \
under the symmetric model.  HeterozygoteB[n] stores a table of \
HeterozygoteB[i,j,n] for i=0\[Ellipsis]n, j=0\[Ellipsis]n.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`NewGametes\)], "Subsubsection"],

Cell[BoxData[
    \(\(NewGametes::usage = \*"\"\<NewGametes[\[Psi]] gives the haploid \
population after meiosis; \[Psi] must represent a diploid population, or a \
list of diploid populations.  By default, deme size is doubled.  NewGametes[\
\[Psi],W] does the same, but assuming fitness function W.  DemeSize-> \
f[n,\!\(W\&_\)] allows for changes in deme size, to 2f[n,\!\(W\&_\)].  \
Linkage\[Rule]{\!\(r\_\(1, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(\\\\\\\\\\\\\\\
\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) 2\)\)\)\),\!\(r\_\(2, \\\\\\\ \
\(\(\\\\\\\\\)\(\\\\\\\ \)\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) 3\)\
\)\)\),\[Ellipsis]} can be used to specify a linear genetic map, where \
appropriate. RandomDrift->True samples haploid gametes from the diploid \
population; does not apply to symmetric or individual representations. \
TruncationSelection->True applies with individual representations, and takes \
the f[n,\!\(W\&_\)] individuals with highest W as parents.  Gametes are then \
sampled randomly from these parents, so not all the chosen parents may \
actually reproduce.  Mutation->{{\[Mu],\[Nu]},\[Ellipsis]} allows for \
mutation at rate \[Mu] from allele 0 to 1, and \[Nu] from 1 to 0.\>\"";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Mutate", "Subsubsection"],

Cell[BoxData[
    \(\(Mutate::usage = "\<Mutate[\[Psi],{{\[Mu],\[Nu]},\[Ellipsis]}] mutates \
with probability \[Mu] from 0 to 1, and \[Nu] from 1 to 0.  Compiled->True is \
much faster. When applied to FrequencyRepresentations, uses MutationMatrix[] \
to store the transformation matrix. For the symmetric \
model,Mutate[SymmetricHaploidFrequencies[],{\[Mu],\[Nu]}] should be used, \
because mutation rates must be the same across loci.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MutateCompiled", "Subsubsection"],

Cell[BoxData[
    \(\(MutateCompiled::usage = \*"\"\<MutateCompiled[HaploidFrequencies][{\!\
\(p\_{0, \\\\\\\ \\\\\\\ \[Ellipsis]}\),\[Ellipsis]},{{\[Mu],\[Nu]},\
\[Ellipsis]}] alters haploid genotype frequencies to allow for mutation.  \
MutateCompiled[SymmetricHaploidFrequencies][{\!\(p\_0\),\[Ellipsis]},{\[Mu],\
\[Nu]}] applies to the symmetric model; similarly for \
SymmetricNeutralFrequencies. These versions use ConstructMutateMatrix[] to \
store a large matrix.  MutateCompiled[AlleleFrequencies][{\!\(p\_1\),\
\[Ellipsis]},{{\[Mu],\[Nu]},\[Ellipsis]}] applies to allele frequencies.  \
MutateCompiled[HaploidIndividuals][{0,1,\[Ellipsis]},{{\[Mu],\[Nu]},\
\[Ellipsis]}] mutates a genotype {0,1,\[Ellipsis]} with probability \[Mu] \
from 0 to 1, and \[Nu] from 1 to 0.  For short genomes, MutateCompiled[] is \
faster than using Mutate[\[Ellipsis],Compiled->True], because there is no \
need to check options.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ConstructMutateList", "Subsubsection"],

Cell[BoxData[
    \(\(ConstructMutateList::usage = "\<ConstructMutateList[{{\[Mu]}}] \
converts shorthand versions of a list of mutation rates into the full form, \
{{\[Mu],\[Mu]},\[Ellipsis]}\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ConstructMutateMatrix", "Subsubsection"],

Cell[BoxData[
    \(\(ConstructMutateMatrix::usage = \
"\<ConstructMutateMatrix[{{\[Mu],\[Nu]},\[Ellipsis]},ngenes,NumericalModel->\
HaploidFrequencies] generates the matrix which determines the effects of \
mutation on haploid genotype frequencies. \
NumericalModel->SymmetricFrequencies or SymmetricNeutralFrequencies can be \
used.  Compiled->True is faster for numerical values.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ConstructMutateMatrixCompiled", "Subsubsection"],

Cell[BoxData[
    \(\(ConstructMutateMatrixCompiled::usage = \
"\<ConstructMutateMatrixCompiled[HaploidFrequencies][{{\[Mu],\[Nu]},\
\[Ellipsis]},{{0,\[Ellipsis]},\[Ellipsis]}] gives the mutation matrix; called \
by ConstructMutateMatrix[\[Ellipsis],Compiled->True].  \
ConstructMutateMatrixCompiled[SymmetricHaploidFrequencies][{\[Mu],\[Nu]},\
ngenes] is also defined, as is \
ConstructMutateMatrixCompiled[SymmetricHaploidFrequencies][{\[Mu],\[Nu]},\
ngenes].\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Mutation", "Subsubsection"],

Cell[BoxData[
    \(\(Mutation::usage = "\<Mutation->{{\[Mu],\[Nu]},\[Ellipsis]} is an \
option for NewGametes which specifies mutation at rate \[Mu] from 0 to 1, and \
\[Nu] from 1 to 0.  Mutation->{{\[Mu]},\[Ellipsis]} is shorthand for a rate \
\[Mu] in each direction.  Mutation->{\[Mu],\[Nu]} or {\[Mu]} specifies the \
same rates at all loci.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SelectionExact", "Subsubsection"],

Cell[BoxData[
    \(\(SelectionExact::usage = \*"\"\<SelectionExact[\[Psi],W] gives the \
population after selection, assuming a fitness function W[\[Ellipsis]].  By \
default, deme size stays the same. SelectionExact[\[Psi],W,f] specifies that \
deme size becomes f[n,\!\(W\&_\)]. SelectionExact[\[Psi],{{W\[Ellipsis]}\
\[Ellipsis]},f] specifies fitness as a list.  If HaploidIndividuals or \
DiploidIndividuals are specified, then the fitnesses give the probability of \
survival, and the new deme size is a consequence of this viability: f has no \
effect.  When individuals are specified, TruncationSelection->True preserves \
the f[n,\!\(W\&_\)] individuals with highest W; \
f[n,\!\(W\&_\)]\[LessEqual]n\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["TruncationSelection", "Subsubsection"],

Cell[BoxData[
    \(\(TruncationSelection::usage = \*"\"\<TruncationSelection->True is an \
option for SelectionExact and NewGametes which applies when individuals are \
selected.  Those individuals with highest 'fitness', W, survive; if f[n,\!\(W\
\&_\)] is larger than deme size, or if no f[] is specified, then all \
individuals survive.  If TruncationSelection->False (the default), then \
survival or reproduction occurs independently with probability W.\>\"";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RandomDrift", "Subsubsection"],

Cell[BoxData[
    \(\(RandomDrift::usage = "\<RandomDrift[\[Psi],n] gives the random \
frequencies generated by sampling n individuals from the genotype or allele \
frequencies \[Psi].  Compiled->True uses compiled code. Deme size is changed \
to n.  RandomDrift[\[Psi],\[Infinity]] makes no change. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`IterateExact\)], "Subsubsection"],

Cell[BoxData[
    \(\(IterateExact::usage = \*"\"\<IterateExact[\[Psi],W,0] gives gamete \
frequencies after one generation of selection; \[Psi] may represent a single \
deme, or an array of demes, but must represent a haploid population. \
IterateExact[\[Psi],W,m] allows for migration.  If \[Psi] contains only a \
single population, then it iterates that deme, with immigration from a source \
of the same size, fixed for {1,1\[Ellipsis]}; FixedEnds->{\!\(\[Psi]\_s\)} \
specifies an arbitrary source population.  The fitness is represented by a \
function W[i,j,h] in the symmetrical model, W[X,Y] if all \!\(2\^n\) \
genotypes are iterated, or W[p]={\!\(W\&_\),{\!\(s\_1\),\[Ellipsis]}} if only \
AlleleFrequencies are supplied.  If \[Psi] consists of a list of demes, \
migration is at a rate m/2 to each neighbour.  The fitness is then \
represented by a function W[deme][i,j,h] in the symmetrical model, or \
W[deme][X,Y] if all \!\(2\^n\) genotypes are iterated. Compiled->True uses \
compiled code. The default order is random \
union\[Rule]migration\[Rule]selection\[Rule]meiosis, which is represented by \
MigrationOrder\[Rule]UMS. MigrationOrder\[Rule]MUS represents \
migration\[Rule]random union\[Rule]selection\[Rule]meiosis.  MigrationOrder\
\[Rule]USM represents random \
union\[Rule]selection\[Rule]migration\[Rule]meiosis.  For a cline, FixedEnds\
\[Rule]{\[Psi]0,\[Psi]1} fixes genotype frequencies at \[Psi]0, \[Psi]1 at \
either end. For SymmetricNeutralHaploidFrequencies, \
IterateExact[{\[Psi],u},W,{m,\!\(\(u\^*\)\)}] includes the frequency of the \
neutral marker after one generation of selection followed by immigration from \
a source population with frequency \!\(\(u\^*\)\).  DemeSize->F allows deme \
size to change to some function F[n,\!\(W\&_\)], where n is the number before \
selection.  Compiled code can only use a limited set of F: either \
\!\(\(n\^*\)\)&, where \!\(\(n\^*\)\) is a fixed number; or ExponentialF[r,\
\[Beta],\[Lambda]], which represents \
r\[VeryThinSpace]n\[VeryThinSpace]\!\(W\&_\^\[Beta]\)Exp[-\[Lambda]\
\[VeryThinSpace]n]; or PowerF[r,\[Beta],\[Gamma]], which represents r\
\[VeryThinSpace]\!\(n\^\(1  \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\ \
\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\ \\\\\\\\\\\\\\\ \(-\(\(\\\\\\\\\)\(\\\\\\\ \)\
\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) \\\\\\\\\\\\\\\\ \(\(\\\\\\\\\
\)\(\\\\\\\ \)\) \[Gamma]\)\)\)\)\)\[VeryThinSpace]\!\(W\&_\^\[Beta]\). \
RandomDrift->True includes random sampling of a number of haploid gametes \
equal to the deme size after selection.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExponentialF", "Subsubsection"],

Cell[BoxData[
    \(\(ExponentialF::usage = \
\*"\"\<ExponentialF[r,\[Beta],\[Lambda]][n,\!\(W\&_\)] is the function r\
\[VeryThinSpace]n\[VeryThinSpace]\!\(W\&_\^\[Beta]\)Exp[-\[Lambda]\
\[VeryThinSpace]n]. DemeSize->ExponentialF[r,\[Beta],\[Lambda]] can be passed \
to compiled versions of IterateExact and StoreExact. ExponentialF[r,\[Beta],\
\[Gamma],\[Lambda]][n,\!\(W\&_\)] represents the generalised form r\
\[VeryThinSpace]\!\(n\^\(1  \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\ \
\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\ \\\\\\\\\\\\\\\ \(-\(\(\\\\\\\\\)\(\\\\\\\ \)\
\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) \\\\\\\\\\\\\\\\ \(\(\\\\\\\\\
\)\(\\\\\\\ \)\) \[Gamma]\)\)\)\)\)\[VeryThinSpace]\!\(W\&_\^\[Beta]\)Exp[-\
\[Lambda]\[VeryThinSpace]n].  ExponentialF[r\[Ellipsis]][j][n,\!\(W\&_\)] is \
the same as ExponentialF[r\[Ellipsis]][n,\!\(W\&_\)].\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PowerF", "Subsubsection"],

Cell[BoxData[
    \(\(PowerF::usage = \*"\"\<PowerF[r,\[Beta],\[Gamma]][n,\!\(W\&_\)] is \
the function r\[VeryThinSpace]\!\(n\^\(1  \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\ \
\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\ \\\\\\\\\\\\\\\ \(-\(\(\\\\\\\\\)\(\\\\\\\ \)\
\(\\\\\\\\\\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\) \\\\\\\\\\\\\\\\ \(\(\\\\\\\\\
\)\(\\\\\\\ \)\) \[Gamma]\)\)\)\)\)\[VeryThinSpace]\!\(W\&_\^\[Beta]\). \
DemeSize->PowerF[r,\[Beta],\[Gamma]] can be passed to compiled versions of \
IterateExact and StoreExact.  PowerF[\!\(\(n\^*\)\),0,1][n,\!\(W\&_\)] \
represents a fixed number \!\(\(n\^*\)\).  \
PowerF[r,\[Beta],\[Gamma],\[Lambda]][n,\!\(W\&_\)] represents the generalised \
form r\[VeryThinSpace]\!\(n\^\(1  \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\ \
\\\\\\\\\\\\\\\ \(-\(\(\\\\\\\\\)\(\\\\\\\ \)\(\\\\\\\\\\\\\\\\ \
\(\(\\\\\\\\\)\(\\\\\\\ \)\) \[Gamma]\)\)\)\)\)\[VeryThinSpace]\!\(W\&_\^\
\[Beta]\)Exp[-\[Lambda]\[VeryThinSpace]n].  \
PowerF[r\[Ellipsis]][j][n,\!\(W\&_\)] is the same as \
PowerF[r\[Ellipsis]][n,\!\(W\&_\)].\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MigrationOrder", "Subsubsection"],

Cell[BoxData[
    \(\(MigrationOrder::usage = "\<MigrationOrder is a option for \
IterateExact which determines the order of the life cycle.  Can take values \
UMS, MUS, or USM,\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["UMS", "Subsubsection"],

Cell[BoxData[
    \(\(UMS::usage = "\<UMS is a setting for MigrationOrder, which represents \
the order random union\[Rule]migration\[Rule]selection\[Rule]meiosis in \
IterateExact.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MUS", "Subsubsection"],

Cell[BoxData[
    \(\(MUS::usage = "\<MUS is a setting for MigrationOrder, which represents \
the order migration\[Rule]random union\[Rule]selection\[Rule]meiosis in \
IterateExact.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["USM", "Subsubsection"],

Cell[BoxData[
    \(\(USM::usage = "\<USM is a setting for MigrationOrder, which represents \
the order random union\[Rule]selection\[Rule]migration\[Rule]meiosis in \
IterateExact.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SymmetricCline", "Subsubsection"],

Cell[BoxData[
    \(\(SymmetricCline::usage = "\<SymmetricCline is an option for \
StoreExact[] which allows a symmetrical cline to be simulated more \
efficiently.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MigrateExact", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(MigrateExact::usage = \*"\"\<MigrateExact[\[Psi],\!\(\[Psi]\_s\),m] \
implements migration from a source population \!\(\[Psi]\_s\); \[Psi] can be \
any valid representation of a population.  MigrateExact[{\!\(\[Psi]\_1\),\
\[Ellipsis]},m] implements migration along a linear cline. The option \
FixedEnds\[Rule]{\[Psi]0, \[Psi]1} allows fixed endpoints.  Where individuals \
are involved, each has an independent probability of migrating; for a single \
population, the parameter m is now the number of individuals immigrating from \
the source population, and must be an integer no greater than the population \
size.  FixedEnds must now specify a source with given HaploidFrequencies[] or \
DiploidFrequencies[].\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["StoreExact", "Subsubsection"],

Cell[BoxData[
    \(\(StoreExact::usage = "\<StoreExact[\[Psi],\[Psi]0,W,m,{t,dt}] stores \
results at intervals dt in \[Psi][t], starting with \[Psi]0.  \[Psi]0 can \
represent a single population or a cline.  The options Compiled, FixedEnds, \
DemeSize, RandomDrift and MigrationOrder can be used, as for IterateExact. \
NumericalModel specifies the representation. SymmetricCline\[Rule]True \
simulates a symmetric cline more efficiently.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`MidParent\)], "Subsubsection"],

Cell[BoxData[
    \(\(MidParent::usage = \*"\"\<MidParent[u] gives the matrix of \
mid-parental frequencies, (\!\(u\_i\)+\!\(u\_j\))/2\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["FixedEnds", "Subsubsection"],

Cell[BoxData[
    \(\(FixedEnds::usage = "\<FixedEnds is an option for MigrateExact and \
related functions which specifies that endpoints should be fixed.  FixedEnds\
\[Rule]{\[Psi]} specifies a source population that provides migrants into a \
single deme.  FixedEnds\[Rule]{\[Psi]0,\[Psi]1} fixes genotype frequencies at \
\[Psi]0, \[Psi]1 at either end of a cline.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`ClassToGenotypes\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(ClassToGenotypes::usage = \
\*"\"\<ClassToGenotypes[SymmetricHaploidFrequencies[\[Psi],n]] converts class \
frequencies to genotype frequencies, of the form HaploidFrequencies[\!\(\(\
\[Psi]\^*\)\),n].  Defined in a similar way for SymmetricDiploidFrequencies; \
does nopt apply when a neutral marker is included.  Also applies to a \
cline.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["GenotypePosition", "Subsubsection"],

Cell[BoxData[
    \(\(GenotypePosition::usage = "\<GenotypePosition[X] gives the position \
of genotype X in the list of haplotypes.  The option SortByClass can be used \
to define the ordering; default is SortByClass\[Rule]False.\>";\)\)], "Input",\

  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Stability", "Subsection"],

Cell[CellGroupData[{

Cell["StabilityMatrix", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(StabilityMatrix::usage = "\<StabilityMatrix[a,n] constructs the \
stability matrix for n loci, with elements a[i,j,h]. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`StabilityK\)], "Subsubsection"],

Cell[BoxData[
    \(\(StabilityK::usage = \*"\"\<StabilityK[k,i,h,g,W] calculates the \
elements of the stability matrix for the given fitness scheme. Omits the \
factor \!\(2\/W\&_\). StabilityK[k,i,h,g,g',W] gives the more general element \
for demic models.  StabilityK[k,i,h,g,W,m] generates an \
\!\(n\_d\)\[Times]\!\(n\_d\) matrix which gives the stability for a stepping \
stone model.  g must now be an array \!\(n\_d\)\[Times](\!\(n\_g\)+1).  \
Includes the factor \!\(2\/W\&_\), since this now varies across demes.  \
Assumes equilibrium and uniform W.   \>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`StabilityKTable\)], "Subsubsection"],

Cell[BoxData[
    \(\(StabilityKTable::usage = \
\*"\"\<StabilityKTable[k,i,h,g,{{{\!\(W\_\(0, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \
\)\(0\)\), \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(0\)\)\)\),\[Ellipsis]},\
\[Ellipsis]}}] calculates the elements of the stability matrix, using a table \
of fitnesses, \!\(W\_\(i, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(j\)\), \\\\\\\ \
\(\(\\\\\\\\\)\(\\\\\\\ \)\(h\)\)\)\). Omits the factor \!\(2\/W\&_\). \
StabilityKTable[k,i,h,g,g',{{{\!\(W\_\(0, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \
\)\(0\)\), \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(0\)\)\)\),\[Ellipsis]},\
\[Ellipsis]}}] gives the more general element for demic models.  \
StabilityK[k,i,h,g,{{{\!\(W\_\(0, \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(0\)\), \
\\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(0\)\)\)\),\[Ellipsis]},\[Ellipsis]}},m] \
generates an \!\(n\_d\)\[Times]\!\(n\_d\) matrix which gives the stability \
for a stepping stone model.  g must now be an array \
\!\(n\_d\)\[Times](\!\(n\_g\)+1).  Includes the factor \!\(2\/W\&_\), since \
this now varies across demes.  Assumes equilibrium and uniform W.  This is \
much faster than StabilityK[], since the fitness values are only calculated \
once. \>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SigmaMatrix", "Subsubsection"],

Cell[BoxData[
    \(\(SigmaMatrix::usage = "\<SigmaMatrix[a,i,j,p,n] gives the elements of \
the p matrix for n loci. SigmaMatrix[a,p,n] stores the p matrix itself.  \
BlockMatrix[] must be applied for a structured population.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExactEigenvalues", "Subsubsection"],

Cell[BoxData[
    \(\(ExactEigenvalues::usage = "\<ExactEigenvalues[a,n] finds all the \
eigenvalues for the stability matrix. a[i,j,h] must be a function which gives \
numerical values for the derivatives.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`StabilityDirect\)], "Subsubsection"],

Cell[BoxData[
    \(\(StabilityDirect::usage = \*"\"\<StabilityDirect[\[Psi],W,m] gives a \
stability matrix, which is the derivative of the new variables with respect \
to the original variables; this is obtained by direct differentiation of an \
expression derived from IterateExact[].  The variables are either haploid \
genotype frequencies or allele frequencies, plus deme size.  Can take all the \
options of IterateExact[], except Compiled\[Rule]True and RandomDrift->True.  \
Does NOT apply to the symmetric model or individual representations.  For  a \
stepping-stone model, each element is an array \
\!\(n\_d\)\[Times]\!\(n\_d\).\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises", "Subsection"],

Cell[CellGroupData[{

Cell["logLikNm", "Subsubsection"],

Cell[BoxData[
    \(\(logLikNm::usage = \
\*"\"\<logLikNm[{\!\(p\_1\),\!\(\[Ellipsis]p\_n\)},{\!\(k\_1\),\[Ellipsis]},\
Nm] gives the log likelihood of Nm, given allele frequencies sampled from n \
demes, with \!\(k\_1\)\[Ellipsis] genes sampled.  logLikNm[p,k,\!\(p\&_\),Nm] \
gives the log likelihood for a single deme.  logLikNm[{\!\(p\_1\),\!\(\
\[Ellipsis]p\_n\)},k,Nm] assumes the same sample size throughout. \
\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NmMLE", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(NmMLE::usage = \*"\"\<NmMLE[{\!\(p\_1\),\!\(\[Ellipsis]p\_n\)},{\!\(k\
\_1\),\[Ellipsis]},Nm] gives the MLE of Nm, given allele frequencies sampled \
from n demes, with \!\(k\_1\)\[Ellipsis] genes sampled.  NmMLE[{\!\(p\_1\),\!\
\(\[Ellipsis]p\_n\)},k,Nm] assumes the same sample size throughout. \
\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Private parts", "Section"],

Cell[BoxData[
    \(\(Begin["\<NumericalModels`ExactModel`Private`\>"];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
These packages should not need to be reloaded; but perhaps there \
was a bug at some stage....\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(<< Statistics`ContinuousDistributions`;\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Describing genotype frequencies", "Subsection"],

Cell[CellGroupData[{

Cell["NumericalModel", "Subsubsection"],

Cell[BoxData[
    \(\(NumericalModel::badSetting = "\<Invalid setting `1` for \
NumericalModel\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`HaploidFrequencies\)], "Subsubsection"],

Cell[BoxData[
    \(\(HaploidFrequencies[\[Psi]_List] \
:= \[IndentingNewLine]HaploidFrequencies[\[Psi], 1];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`DiploidFrequencies\)], "Subsubsection"],

Cell[BoxData[
    \(\(DiploidFrequencies[\[Psi]_List] \
:= \[IndentingNewLine]DiploidFrequencies[\[Psi], 1];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`AlleleFrequencies\)], "Subsubsection"],

Cell[BoxData[
    \(\(AlleleFrequencies[\[Psi]_List] := 
        AlleleFrequencies[\[Psi], 1];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`SymmetricHaploidFrequencies\)], "Subsubsection"],

Cell[BoxData[
    \(\(SymmetricHaploidFrequencies[\[Psi]_List] := 
        SymmetricHaploidFrequencies[\[Psi], 1];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`SymmetricDiploidFrequencies\)], "Subsubsection"],

Cell[BoxData[
    \(\(SymmetricDiploidFrequencies[\[Psi]_List] := 
        SymmetricDiploidFrequencies[\[Psi], 1];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SymmetricNeutralHaploidFrequencies", "Subsubsection"],

Cell[BoxData[
    \(\(SymmetricNeutralHaploidFrequencies[\[Psi]_List] := 
        SymmetricNeutralHaploidFrequencies[\[Psi], 1];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SymmetricNeutralDiploidFrequencies", "Subsubsection"],

Cell[BoxData[
    \(\(SymmetricNeutralDiploidFrequencies[\[Psi]_List] := 
        SymmetricNeutralDiploidFrequencies[\[Psi], 1];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`HaploidIndividuals\)], "Subsubsection"],

Cell[BoxData[
    \(\(HaploidIndividuals[\[Psi]_List] := 
        HaploidIndividuals[\[Psi], Length[\[Psi]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`DiploidIndividuals\)], "Subsubsection"],

Cell[BoxData[
    \(\(DiploidIndividuals[\[Psi]_List] := 
        DiploidIndividuals[\[Psi], Length[\[Psi]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PopulationRepresentations", "Subsubsection"],

Cell[BoxData[
    \(\(PopulationRepresentations = 
        HaploidFrequencies | DiploidFrequencies | AlleleFrequencies | 
          SymmetricHaploidFrequencies | SymmetricDiploidFrequencies | 
          SymmetricNeutralHaploidFrequencies | 
          SymmetricNeutralDiploidFrequencies | HaploidIndividuals | 
          DiploidIndividuals;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["FrequencyRepresentations", "Subsubsection"],

Cell[BoxData[
    \(\(FrequencyRepresentations = 
        HaploidFrequencies | DiploidFrequencies | AlleleFrequencies | 
          SymmetricHaploidFrequencies | SymmetricDiploidFrequencies | 
          SymmetricNeutralHaploidFrequencies | 
          SymmetricNeutralDiploidFrequencies;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["IndividualRepresentations", "Subsubsection"],

Cell[BoxData[
    \(\(IndividualRepresentations = 
        HaploidIndividuals | DiploidIndividuals;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["HaploidRepresentations", "Subsubsection"],

Cell[BoxData[
    \(\(HaploidRepresentations = 
        HaploidFrequencies | AlleleFrequencies | 
          SymmetricHaploidFrequencies | SymmetricNeutralHaploidFrequencies | 
          HaploidIndividuals;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["DiploidRepresentations", "Subsubsection"],

Cell[BoxData[
    \(\(DiploidRepresentations = 
        DiploidFrequencies | AlleleFrequencies | 
          SymmetricDiploidFrequencies | SymmetricNeutralDiploidFrequencies | 
          DiploidIndividuals;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NeutralRepresentations", "Subsubsection"],

Cell[BoxData[
    \(\(NeutralRepresentations = 
        SymmetricNeutralHaploidFrequencies | 
          SymmetricNeutralDiploidFrequencies;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NonNeutralRepresentations", "Subsubsection"],

Cell[BoxData[
    \(\(NonNeutralRepresentations = 
        HaploidFrequencies | DiploidFrequencies | AlleleFrequencies | 
          SymmetricHaploidFrequencies | SymmetricDiploidFrequencies | 
          HaploidIndividuals | DiploidIndividuals;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SymmetricRepresentations", "Subsubsection"],

Cell[BoxData[
    \(\(SymmetricRepresentations = 
        SymmetricHaploidFrequencies | SymmetricDiploidFrequencies | 
          SymmetricNeutralHaploidFrequencies | 
          SymmetricNeutralDiploidFrequencies;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["NonSymmetricRepresentations", "Subsubsection"],

Cell[BoxData[
    \(\(NonSymmetricRepresentations = 
        HaploidFrequencies | DiploidFrequencies | HaploidIndividuals | 
          DiploidIndividuals;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox["MakePopulation",
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(Options[MakePopulation] = {NumericalModel \[Rule] HaploidFrequencies, 
          SortByClass \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MakePopulation[nloci_Integer, p_, 
          opts___Rule] := \[IndentingNewLine]MakePopulation[nloci, p, 1, 
          opts];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MakePopulation[n_Integer, p_, ninds_, 
          opts___Rule] := \[IndentingNewLine]Module[{i, 
            nm = \(NumericalModel /. {opts}\) /. 
                Options[MakePopulation]}, \[IndentingNewLine]Switch[
            nm, \[IndentingNewLine]HaploidRepresentations, \
\[IndentingNewLine]\ \ Switch[nm, \[IndentingNewLine]\ 
              HaploidFrequencies, \[IndentingNewLine]\ \ \ \ \
HaploidFrequencies[\[IndentingNewLine]\ \ \ \ HaploidTypes[n, 
                    opts] /. {{a___Integer} :> 
                      Times @@ \(({a} \((2  p - 1)\) + 1 - p)\)}, 
                ninds], \[IndentingNewLine]\ 
              SymmetricHaploidFrequencies, \[IndentingNewLine]\ \ \ \
SymmetricHaploidFrequencies[\[IndentingNewLine]\ \ \ If[
                  p == 0, \[IndentingNewLine]\ \ \ \ ReplacePart[
                    Array[0 &, n + 1], 1, 
                    1], \n\t\ \ \ \ \ \ \ \ \ \ \ \ \ If[
                    p == 1, \[IndentingNewLine]\ \ ReplacePart[
                      Array[0 &, n + 1], 
                      1, \(-1\)], \n\t\t\ \ \ \ \ \ \ \ Table[
                      Binomial[n, i] \(p\^i\) \((1 - p)\)\^\(n - i\), {i, 0, 
                        n}]]], 
                ninds], \
\[IndentingNewLine]SymmetricNeutralHaploidFrequencies, \[IndentingNewLine]\ \ \
SymmetricNeutralHaploidFrequencies[\[IndentingNewLine]\ \ \ {\(MakePopulation[
                      n, p\[LeftDoubleBracket]1\[RightDoubleBracket], 
                      NumericalModel \[Rule] 
                        SymmetricHaploidFrequencies]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket], 
                  Array[p\[LeftDoubleBracket]2\[RightDoubleBracket] &, 
                    n + 1]}, 
                ninds], \[IndentingNewLine]AlleleFrequencies, \
\[IndentingNewLine]\ \ \ \ AlleleFrequencies[Array[1 &, n] p, 
                ninds], \[IndentingNewLine]HaploidIndividuals, \
\[IndentingNewLine]\ \ MakeIndividuals[\ 
                AlleleFrequencies[Array[1 &, n] p, 1], 
                ninds]], \[IndentingNewLine]DiploidRepresentations, \
\[IndentingNewLine]\ \ \ \ Switch[
              nm, \[IndentingNewLine]DiploidIndividuals, \[IndentingNewLine]\ \
\ DiploidIndividuals[
                Transpose[{\[IndentingNewLine]\(MakePopulation[n, p, ninds, 
                        NumericalModel \[Rule] 
                          HaploidIndividuals]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket], \(MakePopulation[n, p, ninds, 
                        NumericalModel \[Rule] 
                          HaploidIndividuals]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]}], 
                ninds], \[IndentingNewLine]\ \ _, \[IndentingNewLine]\ \ \ \ \
\ \ MakeDiploid[\(MakePopulation[n, p, ninds, ##] &\) @@ \(({opts} /. 
                      MakeOptionsHaploid)\)]], \[IndentingNewLine]_, \
\[IndentingNewLine]\((Message[NumericalModel::badSetting, 
                nm]; {})\)]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MakeOptionsHaploid", "Subsubsection"],

Cell[BoxData[
    \(\(MakeOptionsHaploid = {\((NumericalModel \[Rule] 
                DiploidFrequencies)\) -> \((NumericalModel \[Rule] 
                HaploidFrequencies)\), \[IndentingNewLine]\((NumericalModel \
\[Rule] SymmetricDiploidFrequencies)\) -> \((NumericalModel \[Rule] 
                SymmetricHaploidFrequencies)\), \
\[IndentingNewLine]\((NumericalModel \[Rule] 
                SymmetricNeutralDiploidFrequencies)\) -> \((NumericalModel \
\[Rule] SymmetricNeutralHaploidFrequencies)\), \
\[IndentingNewLine]\((NumericalModel \[Rule] 
                DiploidIndividuals)\) -> \((NumericalModel \[Rule] 
                HaploidIndividuals)\)};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MakeDiploid", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(MakeDiploid::odd = "\<MakeDiploid[HaploidIndividuals[\[Psi],n] only \
applies when n is even.  Deme size `1` has been reduced by 1.\>";\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(MakeDiploid[\[Psi] : {PopulationRepresentations[_, _] ... }] := 
        MakeDiploid /@ \[Psi];\)\), "\[IndentingNewLine]", 
    \(\(MakeDiploid[\[Psi] : 
            DiploidRepresentations[_, _]] := \[Psi];\)\), \
"\[IndentingNewLine]", 
    \(\(MakeDiploid[HaploidFrequencies[\[Psi]_, n_]] := 
        DiploidFrequencies[Outer[Times, \[Psi], \[Psi]], 
          n/2];\)\), "\[IndentingNewLine]", 
    \(\(MakeDiploid[SymmetricHaploidFrequencies[\[Psi]_, n_]] := 
        SymmetricDiploidFrequencies[Outer[Times, \[Psi], \[Psi]], 
          n/2];\)\), "\[IndentingNewLine]", 
    \(\(MakeDiploid[SymmetricNeutralHaploidFrequencies[{\[Psi]_, u_}, n_]] := 
        SymmetricNeutralDiploidFrequencies[{Outer[Times, \[Psi], \[Psi]], 
            MidParent[u]}, n/2];\)\), "\[IndentingNewLine]", 
    \(MakeDiploid[
        HaploidIndividuals[\[Psi]_, 
          n_?OddQ]] := \[IndentingNewLine]\((Message[MakeDiploid::odd, n]; 
        DiploidIndividuals[
          Partition[Drop[\[Psi], \(-1\)], 2], \((n - 1)\)/2])\); 
    MakeDiploid[HaploidIndividuals[\[Psi]_, n_?EvenQ]] := 
      DiploidIndividuals[Partition[\[Psi], 2], n/2];\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MakeHaploid", "Subsubsection"],

Cell[BoxData[{
    \(\(MakeHaploid[\[Psi] : {DiploidRepresentations[_, _] ... }] := 
        MakeHaploid /@ \[Psi];\)\), "\[IndentingNewLine]", 
    \(\(MakeHaploid[
          DiploidFrequencies[\[Psi]_, 
            n_]] := \[IndentingNewLine]HaploidFrequencies[\((Plus @@ \[Psi] + 
                Plus @@ Transpose[\[Psi]])\)/2, 
          2  n];\)\), "\[IndentingNewLine]", 
    \(\(MakeHaploid[AlleleFrequencies[p_, n_]] := 
        AlleleFrequencies[p, 2  n];\)\), "\[IndentingNewLine]", 
    \(\(MakeHaploid[SymmetricDiploidFrequencies[\[Psi]_, n_]] := 
        SymmetricHaploidFrequencies[\((Plus @@ \[Psi] + 
                Plus @@ Transpose[\[Psi]])\)/2, 
          2  n];\)\), "\[IndentingNewLine]", 
    \(\(MakeHaploid[SymmetricNeutralDiploidFrequencies[{\[Psi]_, u_}, n_]] := 
        Module[{\[Psi]m = \((Plus @@ \[Psi] + Plus @@ Transpose[\[Psi]])\)/
                2, \[Psi]u = \[Psi]*
                u}, \[IndentingNewLine]SymmetricNeutralHaploidFrequencies[{\
\[Psi]m, \((Plus @@ \[Psi]u + 
                    Plus @@ Transpose[\[Psi]u])\)/\((2  \[Psi]m)\)}, 
            2  n]];\)\), "\[IndentingNewLine]", 
    \(\(MakeHaploid[DiploidIndividuals[\[Psi]_, n_]] := 
        HaploidIndividuals[Flatten[\[Psi], 1], 2  n];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MakeIndividuals", "Subsubsection"],

Cell[BoxData[
    \(\(MakeIndividuals[\[Psi] : {FrequencyRepresentations[_, _] ... }, 
          n_List, opts___Rule] := \[IndentingNewLine]MapThread[
          MakeIndividuals[#1, #2, opts] &, {\[Psi], n}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(MakeIndividuals[AlleleFrequencies[p_, _], n_, 
          opts___Rule] := \[IndentingNewLine]HaploidIndividuals[
          Table[\(If[Random[] < #, 1, 0] &\) /@ p, {n}], 
          n];\)\), "\[IndentingNewLine]", 
    \(\(MakeIndividuals[HaploidFrequencies[\[Psi]_, _], n_, 
          opts___Rule] := \[IndentingNewLine]HaploidIndividuals[
          RandomList[n, \[Psi], HaploidTypes[Log[2, Length[\[Psi]]], opts]], 
          n];\)\), "\[IndentingNewLine]", 
    \(\(MakeIndividuals[DiploidFrequencies[\[Psi]_, _], n_, 
          opts___Rule] := \[IndentingNewLine]Module[{ht = 
              HaploidTypes[Log[2, Length[\[Psi]]], 
                opts]}, \[IndentingNewLine]DiploidIndividuals[
            RandomList[n, Flatten[\[Psi]], 
              Flatten[Outer[List, ht, ht, 1], 1]], 
            n]];\)\), "\[IndentingNewLine]", 
    \(\(MakeIndividuals[SymmetricHaploidFrequencies[\[Psi]_, _], n_, 
          opts___Rule] := \[IndentingNewLine]Module[{ng = 
              Length[\[Psi]] - 
                1}, \[IndentingNewLine]HaploidIndividuals[\(MakeIndividuals[#,\
 ng] &\) /@ RandomList[n, \[Psi], Range[0, ng]], 
            n]];\)\), "\[IndentingNewLine]", 
    \(\(MakeIndividuals[SymmetricDiploidFrequencies[\[Psi]_, _], n_, 
          opts___Rule] := \[IndentingNewLine]Module[{ng = 
              Length[\[Psi]] - 1}, \[IndentingNewLine]DiploidIndividuals[
            Map[MakeIndividuals[#, 
                  ng] &, \({Quotient[# - 1, ng + 1], Mod[# - 1, ng + 1]} &\) /@ 
                RandomList[n, Flatten[\[Psi]]], {2}], 
            n]];\)\), "\[IndentingNewLine]", 
    \(\(MakeIndividuals[
          SymmetricNeutralHaploidFrequencies[{\[Psi]_, u_}, n0_], n_, 
          opts___Rule] := \[IndentingNewLine]Module[{ng = 
              Length[\[Psi]] - 
                1}, \[IndentingNewLine]HaploidIndividuals[\(Append[
                  MakeIndividuals[#, ng], \ 
                  If[Random[] < 
                      u\[LeftDoubleBracket]# + 1\[RightDoubleBracket], 1, 
                    0]] &\) /@ RandomList[n, \[Psi], Range[0, ng]], 
            n]];\)\), "\[IndentingNewLine]", 
    \(\(MakeIndividuals[
          SymmetricNeutralDiploidFrequencies[{\[Psi]_, u_}, n0_], n_, 
          opts___Rule] := \[IndentingNewLine]Module[{ng = Length[\[Psi]] - 1, 
            fu = Flatten[
                u]}, \[IndentingNewLine]DiploidIndividuals[\({\
\[IndentingNewLine]Append[
                    MakeIndividuals[#\[LeftDoubleBracket]1\
\[RightDoubleBracket], ng], \ 
                    If[Random[] < 
                        fu\[LeftDoubleBracket]#\[LeftDoubleBracket]3\
\[RightDoubleBracket]\[RightDoubleBracket], 1, 0]], 
                  Append[MakeIndividuals[#\[LeftDoubleBracket]2\
\[RightDoubleBracket], ng], \ 
                    If[Random[] < 
                        fu\[LeftDoubleBracket]#\[LeftDoubleBracket]3\
\[RightDoubleBracket]\[RightDoubleBracket], 1, 
                      0]]} &\) /@ \((\({Quotient[# - 1, ng + 1], 
                      Mod[# - 1, ng + 1], 
                      fu\[LeftDoubleBracket]#\[RightDoubleBracket]} &\) /@ 
                  RandomList[n, Flatten[\[Psi]]])\), n]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(\ \)\(MakeIndividuals[j_Integer, n_Integer] := 
        Muddle[Join[Array[1 &, j], Array[0 &, n - j]]];\)\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["DiploidPhenotype", "Subsubsection"],

Cell[BoxData[
    \(\(DiploidPhenotype[z_, g_] := 
        Module[{i, 
            n = Length[g] - 
                1}, \[Sum]\+\(i = Max[0, z - n]\)\%\(Min[z, n]\)g\
\[LeftDoubleBracket]i + 1\[RightDoubleBracket] 
              g\[LeftDoubleBracket]z - i + 
                  1\[RightDoubleBracket]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DiploidPhenotype[
          g_] := \[IndentingNewLine]Module[{z, n = Length[g] - 1}, 
          Table[DiploidPhenotype[z, g], {z, 0, 2  n}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`NumberOfGenes\)], "Subsubsection"],

Cell[BoxData[
    \(\(NumberOfGenes::noIndividuals = "\<No individuals in this \
population\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NumberOfGenes[{\((pr : PopulationRepresentations)\)[\[Psi]_, 
              n_], ___}] := NumberOfGenes[pr[\[Psi], n]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NumberOfGenes[\((pr : 
                PopulationRepresentations)\)[\[Psi]_, _]] \
:= \[IndentingNewLine]Switch[
          pr, \[IndentingNewLine]HaploidFrequencies | 
            DiploidFrequencies, \[IndentingNewLine]Log[2, 
            Length[\[Psi]]], \[IndentingNewLine]AlleleFrequencies, \
\[IndentingNewLine]Length[\[Psi]], \
\[IndentingNewLine]SymmetricHaploidFrequencies | 
            SymmetricDiploidFrequencies, \[IndentingNewLine]Length[\[Psi]] - 
            1, \[IndentingNewLine]SymmetricNeutralHaploidFrequencies | 
            SymmetricNeutralDiploidFrequencies, \[IndentingNewLine]Length[\
\[Psi]\[LeftDoubleBracket]1\[RightDoubleBracket]] - 
            1, \[IndentingNewLine]HaploidIndividuals, \[IndentingNewLine]If[\
\[Psi] \[Equal] {}, Message[NumberOfGenes::noIndividuals], 
            Length[\[Psi]\[LeftDoubleBracket]1\[RightDoubleBracket]]], \
\[IndentingNewLine]DiploidIndividuals, \[IndentingNewLine]If[\[Psi] \[Equal] \
{}, Message[NumberOfGenes::noIndividuals], 
            Length[\[Psi]\[LeftDoubleBracket]1, 
                1\[RightDoubleBracket]]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`AlleleFrequencyMean\)], "Subsubsection"],

Cell[BoxData[{
    \(\(AlleleFrequencyMean[\[Psi] : {PopulationRepresentations[_, _] ... }, 
          opts___Rule] := \[IndentingNewLine]\(AlleleFrequencyMean[#, 
              opts] &\) /@ \[Psi];\)\), "\[IndentingNewLine]", 
    \(\(AlleleFrequencyMean[z : PopulationRepresentations[_, _], 
          opts___Rule] := 
        AlleleFrequencyTable[z, 
            opts] /. {{x_List, y_} \[RuleDelayed] {Mean[x], y}, 
            x_List \[RuleDelayed] Mean[x]};\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`AlleleFrequencyTable\)], "Subsubsection"],

Cell[BoxData[{
    \(\(AlleleFrequencyTable[\[Psi] : {PopulationRepresentations[_, _] ... }, 
          opts___Rule] := \[IndentingNewLine]\(AlleleFrequencyTable[#, 
              opts] &\) /@ \[Psi];\)\), "\[IndentingNewLine]", 
    \(\(AlleleFrequencyTable[AlleleFrequencies[p_, _], ___Rule] := 
        p;\)\), "\[IndentingNewLine]", 
    \(\(AlleleFrequencyTable[\[Psi] : DiploidRepresentations[_, _], 
          opts___Rule] := \[IndentingNewLine]AlleleFrequencyTable[
          MakeHaploid[\[Psi]], opts];\)\), "\[IndentingNewLine]", 
    \(\(AlleleFrequencyTable[HaploidFrequencies[\[Psi]_, _], 
          opts___Rule] := \[IndentingNewLine]Plus @@ \((HaploidTypes[
                Log[2, Length[\[Psi]]], 
                opts] \[Psi])\);\)\), "\[IndentingNewLine]", 
    \(\(AlleleFrequencyTable[SymmetricHaploidFrequencies[\[Psi]_, _], 
          opts___Rule] := \[IndentingNewLine]Module[{n = Length[\[Psi]] - 1, 
            p}, \[IndentingNewLine]If[n \[Equal] 0, Indeterminate, 
            p = \[Psi] . Range[0, 1, 1/n]; 
            Table[p, {n}]]];\)\), "\[IndentingNewLine]", 
    \(AlleleFrequencyTable[
        SymmetricNeutralHaploidFrequencies[{\[Psi]_, u_}, _], 
        opts___Rule] := \[IndentingNewLine]Module[{n = Length[\[Psi]] - 1, 
          pb, ub}, \[IndentingNewLine]If[
          n == 0, {Indeterminate, 
            Indeterminate}, \[IndentingNewLine]pb = \[Psi] . 
              Range[0, 1, 1/n]; ub = \[Psi] . u; {Table[pb, {n}], ub}]]; 
    AlleleFrequencyTable[HaploidIndividuals[\[Psi]_, n_], 
        opts___Rule] := \[IndentingNewLine]\((Plus @@ \[Psi])\)/
        n;\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["DisequilibriumMean", "Subsubsection"],

Cell[BoxData[{
    \(\(DisequilibriumMean[\[Psi] : {PopulationRepresentations[_, _] ... }, 
          opts___Rule] := \[IndentingNewLine]\(DisequilibriumMean[#, 
              opts] &\) /@ \[Psi];\)\), "\[IndentingNewLine]", 
    \(DisequilibriumMean[pr : NonNeutralRepresentations[_, _], 
        opts___Rule] := \[IndentingNewLine]Module[{n, 
          dt = DisequilibriumTable[pr, opts]}, \[IndentingNewLine]n = 
          Length[dt]; \[IndentingNewLine]Plus @@ \(Plus @@ \((\((Array[
                        1 &, {n, n}] - IdentityMatrix[n])\) dt)\)\) 
          1\/\(n \((n - 1)\)\)]; 
    DisequilibriumMean[pr : NeutralRepresentations[_, _], 
        opts___Rule] := \[IndentingNewLine]Module[{n, 
          dt = DisequilibriumTable[pr, opts]}, \[IndentingNewLine]n = 
          Length[dt\[LeftDoubleBracket]1\[RightDoubleBracket]]; \
\[IndentingNewLine]{Plus @@ \(Plus @@ \((\((Array[1 &, {n, n}] - 
                        IdentityMatrix[n])\) 
                    dt\[LeftDoubleBracket]1\[RightDoubleBracket])\)\) 
            1\/\(n \((n - 1)\)\), 
          Mean[dt\[LeftDoubleBracket]2\[RightDoubleBracket]]}];\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["DisequilibriumTable", "Subsubsection"],

Cell[BoxData[{
    \(\(DisequilibriumTable[\[Psi] : {PopulationRepresentations[_, _] ... }, 
          opts___Rule] := \[IndentingNewLine]\(DisequilibriumTable[#, 
              opts] &\) /@ \[Psi];\)\), "\[IndentingNewLine]", 
    \(\(DisequilibriumTable[
          AlleleFrequencies[
            p_, _], ___Rule] := \[IndentingNewLine]DiagonalMatrix[
          p \((1 - p)\)];\)\), "\[IndentingNewLine]", 
    \(\(DisequilibriumTable[\[Psi] : DiploidRepresentations[_, _], 
          opts___Rule] := \[IndentingNewLine]DisequilibriumTable[
          MakeHaploid[\[Psi]], opts];\)\), "\[IndentingNewLine]", 
    \(\(DisequilibriumTable[HaploidFrequencies[\[Psi]_, _], 
          opts___Rule] := \[IndentingNewLine]Module[{n = 
              Log[2, Length[\[Psi]]], 
            p = AlleleFrequencyTable[HaploidFrequencies[\[Psi]], opts], 
            dk}, \n\tdk = \(\((# - p)\) &\) /@ 
              HaploidTypes[n, 
                opts]; \n\t\[Psi] . \((\(Outer[Times, #, #] &\) /@ 
                dk)\)];\)\), "\[IndentingNewLine]", 
    \(\(DisequilibriumTable[SymmetricHaploidFrequencies[\[Psi]_, nd_], 
          opts___Rule] := \[IndentingNewLine]Module[{n = Length[\[Psi]] - 1, 
            p = AlleleFrequencyMean[SymmetricHaploidFrequencies[\[Psi], nd], 
                opts], d, 
            du}, \[IndentingNewLine]d = \(\[Psi] . \((Range[0, n] - n\ \
p)\)\^2 - n\ p \((1 - p)\)\)\/\(n \((n - 1)\)\); \
\[IndentingNewLine]IdentityMatrix[n] \((p \((1 - p)\) - d)\) + 
            Array[d &, {n, n}]];\)\), "\[IndentingNewLine]", 
    \(\(DisequilibriumTable[
          SymmetricNeutralHaploidFrequencies[{\[Psi]_, u_}, nd_], 
          opts___Rule] := \[IndentingNewLine]Module[{n = Length[\[Psi]] - 1, 
            pu = AlleleFrequencyTable[
                SymmetricNeutralHaploidFrequencies[{\[Psi], u}, nd], opts], 
            p, ub, d, du}, \[IndentingNewLine]p = 
            pu\[LeftDoubleBracket]1, 1\[RightDoubleBracket]; 
          ub = pu\[LeftDoubleBracket]2\[RightDoubleBracket]; \
\[IndentingNewLine]d = \(n\ \[Psi] . \((Range[0, 1, 1\/n] - \ p)\)\^2 - \ p \
\((1 - p)\)\)\/\((n - 1)\); \[IndentingNewLine]du = \((\((Range[0, 1, 
                        1\/n] - \ p)\) \[Psi])\) . \((u - 
                  ub)\); {IdentityMatrix[n] \((p \((1 - p)\) - d)\) + 
              Array[d &, {n, n}], \[IndentingNewLine]Array[
              du &, {n}]}];\)\), "\[IndentingNewLine]", 
    \(\(DisequilibriumTable[HaploidIndividuals[\[Psi]_, nd_], 
          opts___Rule] := \[IndentingNewLine]Module[{nl = 
              Length[\[Psi]\[LeftDoubleBracket]1\[RightDoubleBracket]], 
            p = AlleleFrequencyTable[HaploidIndividuals[\[Psi], nd]]}, \n\t
          If[nd < 2, Array[Indeterminate &, {nl, nl}], 
            Plus @@ \((\(Outer[Times, # - p, # - p] &\) /@ \[Psi])\)/\((nd - 
                  1)\)]];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["DemeSize", "Subsubsection"],

Cell[BoxData[{
    \(\(DemeSize[PopulationRepresentations[_, n_]] := 
        n;\)\), "\[IndentingNewLine]", 
    \(\(DemeSize[\[Psi] : {PopulationRepresentations[_, _] ... }] := 
        DemeSize /@ \[Psi];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ClineWidth", "Subsubsection"],

Cell[BoxData[
    \(\(ClineWidth::badDepth = "\<The cline `1` does not have an appropriate \
structure.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(ClineWidthRaw[p_List] := 
        1/Max[Drop[p - RotateRight[p], 1]];\)\), "\n", 
    \(\(ClineWidth[\[Psi] : {PopulationRepresentations[_, _] ... }, 
          opts___] := \[IndentingNewLine]Module[{p = 
              AlleleFrequencyTable[\[Psi], opts]}, \n\ \ \ \ \ \ If[
            Length[p] < 2, 
            Indeterminate, \[IndentingNewLine]Switch[
              TensorRank[p], \[IndentingNewLine]2, 
              ClineWidthRaw /@ 
                Transpose[p], \[IndentingNewLine]\ \ \ 3, {ClineWidthRaw /@ 
                  Transpose[First /@ p], 
                ClineWidthRaw /@ 
                  Transpose[Last /@ p]}, \[IndentingNewLine]\ \ \ \ _, 
              Message[ClineWidth::badDepth, \[Psi]]; 
              Indeterminate]]];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`ClineGradient\)], "Subsubsection"],

Cell[BoxData[
    \(\(Options[ClineGradient] = {FixedEnds \[Rule] {{}, {}}};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ClineGradient[p_, 
          opts___] := \[IndentingNewLine]Module[{pp, 
            fe = \(FixedEnds /. {opts}\) /. 
                Options[ClineGradient]}, \n\t\tpp = 
            If[\((\(fe // Flatten\) // Length)\) == 0, \n\t\t\t\tPrepend[
                Append[p, Last[p]], First[p]], \n\t\t\t\tPrepend[
                Append[p, Last[fe]], First[fe]]]; \n\t\tDrop[
            RotateLeft[pp] - pp, \(-1\)]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`BarrierStrength\)], "Subsubsection"],

Cell[BoxData[
    \(\(Options[BarrierStrength] = {FixedEnds \[Rule] {{}, {}}};\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(BarrierStrength[u_, opts___] := \n\t
        Module[{uu = u, gr = ClineGradient[u, opts], du, ps}, \n\t
          If[TensorRank[gr] == 2, \n\t\t\tuu = 
              Transpose[uu] // Last; \n\t\t\tgr = Transpose[gr] // Last]; \n
          ps = \(Position[gr, Max[gr]]\)\[LeftDoubleBracket]1, 
                1\[RightDoubleBracket] - 0.5; \n
          du = \((Last[uu] - 
                  Last[gr] \((Length[uu] - ps)\))\) - \((First[uu] + 
                  First[gr] \((ps - 1)\))\); \n
          du/{First[gr], Last[gr]}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MakeCline", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[
          MakeCline] = {NumericalModel \[Rule] 
            HaploidFrequencies};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MakeCline[nd_, ng_, ni_, opts___Rule] := \n\ 
        Module[{nm = \(NumericalModel /. {opts}\) /. Options[MakeCline], 
            pp = Array[\(1\/2\) \((1 + Sign[# - \(nd + 1\)\/2])\) &, 
                nd]}, \[IndentingNewLine]\ \(MakePopulation[ng, #, ni, 
                opts] &\) /@ \[IndentingNewLine]Switch[
              nm, \[IndentingNewLine]NonNeutralRepresentations, 
              pp, \[IndentingNewLine]NeutralRepresentations, 
              Transpose[{pp, pp}], \[IndentingNewLine]_, 
              Message[NumericalModel::badSetting, nm]; {}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MakeCline[nd_, ng_, ni_, dp_, opts___Rule] := \n\ 
        Module[{nm = \(NumericalModel /. {opts}\) /. 
                Options[MakeCline], \[IndentingNewLine]pp = 
              Range[\(1 - dp\)\/2, \(1 + dp\)\/2, 
                dp\/\(nd - 1\)]}, \[IndentingNewLine]\ \(MakePopulation[
                ng, #, ni, opts] &\) /@ \[IndentingNewLine]Switch[
              nm, \[IndentingNewLine]NonNeutralRepresentations, 
              pp, \[IndentingNewLine]NeutralRepresentations, 
              Transpose[{pp, pp}], \[IndentingNewLine]_, 
              Message[NumericalModel::badSetting, nm]; {}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["CountHeterozygotes", "Subsubsection"],

Cell[BoxData[
    \(\(CountHeterozygotes[x_List, y_List] := \((Plus @@ \((x + y)\))\) - 
          2 \((Plus @@ \((x\ y)\))\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["DoubleCline", "Subsubsection"],

Cell[BoxData[
    \(\(DoubleCline[\[Psi] : {\((IndividualRepresentations | 
                      AlleleFrequencies)\)[_, _] ... }, eQ_] := 
        Join[\[Psi], 
          Reverse[If[eQ, \[Psi], 
                Drop[\[Psi], \(-1\)]] /. \((pr : PopulationRepresentations)\)[
                  f_, n_] :> pr[1 - f, n]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DoubleCline[\[Psi] : {\((HaploidFrequencies | DiploidFrequencies | 
                      SymmetricHaploidFrequencies | 
                      SymmetricDiploidFrequencies)\)[_, _] ... }, eQ_] := 
        Join[\[Psi], 
          Reverse[If[eQ, \[Psi], 
                Drop[\[Psi], \(-1\)]] /. \((pr : PopulationRepresentations)\)[
                  f_, n_] :> pr[Reverse[f], n]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DoubleCline[\[Psi] : {NeutralRepresentations[_, _] ... }, eQ_] := 
        Join[\[Psi], 
          Reverse[If[eQ, \[Psi], 
                Drop[\[Psi], \(-1\)]] /. \((pr : 
                      NeutralRepresentations)\)[{f_, u_}, n_] :> 
                pr[{Reverse[f], 1 - Reverse[u]}, n]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MeanW", "Subsubsection"],

Cell[BoxData[
    \(\(AlleleFrequencies::badW = \*"\"\<W[p]=`1` does not have the form \
{\!\(W\&_\),{\!\(s\_1\)\[Ellipsis]}}\>\"";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(MeanW[\[Psi] : {PopulationRepresentations[_, _] ... }, 
          W_?\((Not[ListQ[#]] &)\), 
          opts___Rule] := \[IndentingNewLine]MapIndexed[
          MeanW[#1, W[First[#2]], 
              opts] &, \[Psi]];\)\), "\[IndentingNewLine]", 
    \(\(MeanW[\[Psi] : {PopulationRepresentations[_, _] ... }, W_List, 
          opts___Rule] := \[IndentingNewLine]MapIndexed[
          MeanW[#1, W\[LeftDoubleBracket]First[#2]\[RightDoubleBracket], 
              opts] &, \[Psi]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(MeanW[SymmetricNeutralHaploidFrequencies[{\[Psi]_, u_}, n_], W_, 
          opts___Rule] := \[IndentingNewLine]MeanW[
          SymmetricHaploidFrequencies[\[Psi], n], W, 
          opts];\)\), "\[IndentingNewLine]", 
    \(\(MeanW[SymmetricNeutralDiploidFrequencies[{\[Psi]_, u_}, _], W_, 
          opts___Rule] := \[IndentingNewLine]MeanW[
          SymmetricDiploidFrequencies[\[Psi], n], W, opts];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(MeanW[AlleleFrequencies[p_, _], W_?\((Not[ListQ[#]] &)\), 
          opts___Rule] := \[IndentingNewLine]Module[{wl = 
              W[p]}, \[IndentingNewLine]If[
            MatchQ[wl, {_, _List}], \[IndentingNewLine]First[
              wl], \[IndentingNewLine]Message[AlleleFrequencies::badW, wl]; 
            Indeterminate]];\)\), "\n", 
    \(\(MeanW[\((fr : FrequencyRepresentations)\)[\[Psi]_, _], 
          W_?\((Not[ListQ[#]] &)\), 
          opts___Rule] := \[IndentingNewLine]Module[{n = 
              Switch[fr, \[IndentingNewLine]SymmetricRepresentations, 
                Length[\[Psi]] - 1, \[IndentingNewLine]_, 
                Log[2, Length[\[Psi]]]]}, \[IndentingNewLine]Plus @@ \(Plus @@ \
\((\[Psi]*FitnessTable[W, n, NumericalModel \[Rule] fr, 
                    opts])\)\)];\)\), "\n", 
    \(\(MeanW[HaploidIndividuals[\[Psi]_, _], W_?\((Not[ListQ[#]] &)\), 
          opts___Rule] := \[IndentingNewLine]Mean[W /@ \[Psi]];\)\), "\n", 
    \(\(MeanW[DiploidIndividuals[\[Psi]_, _], W_?\((Not[ListQ[#]] &)\), 
          opts___Rule] := \[IndentingNewLine]Mean[\(W @@ # &\) /@ \
\[Psi]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(MeanW[AlleleFrequencies[p_, _], W_List, 
          opts___Rule] := \[IndentingNewLine]\((Message[
            FitnessTable::badOption]; 1)\);\)\), "\[IndentingNewLine]", 
    \(\(MeanW[FrequencyRepresentations[\[Psi]_, _], W_List, 
          opts___Rule] := \[IndentingNewLine]Plus @@ \(Plus @@ \((\[Psi]*
                W)\)\);\)\), "\[IndentingNewLine]", 
    \(\(MeanW[HaploidIndividuals[\[Psi]_, _], W_List, 
          opts___Rule] := \[IndentingNewLine]Module[{ht}, \
\[IndentingNewLine]If[
            Length[\[Psi]] == 
              0, \[IndentingNewLine]Indeterminate, \[IndentingNewLine]ht = 
              HaploidTypes[Length[First[\[Psi]]], 
                opts]; \[IndentingNewLine]Mean[\(Extract[
                    W, #] &\) /@ \((\(First[
                        Position[
                          ht, #]] &\) /@ \[Psi])\)]]];\)\), "\
\[IndentingNewLine]", 
    \(\(MeanW[DiploidIndividuals[\[Psi]_, _], W_List, 
          opts___Rule] := \[IndentingNewLine]Module[{ht}, \
\[IndentingNewLine]If[
            Length[\[Psi]] == 
              0, \[IndentingNewLine]Indeterminate, \[IndentingNewLine]ht = 
              HaploidTypes[
                Length[\[Psi]\[LeftDoubleBracket]1, 1\[RightDoubleBracket]], 
                opts]; \[IndentingNewLine]Mean[\(Extract[
                    W, #] &\) /@ \((\(Flatten[{Position[
                            ht, #\[LeftDoubleBracket]1\[RightDoubleBracket]], 
                          Position[
                            ht, #\[LeftDoubleBracket]2\[RightDoubleBracket]]}]\
 &\) /@ \[Psi])\)]]];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`MarginalW\)], "Subsubsection"],

Cell[BoxData[
    \(\(MarginalW::badOption = "\<Marginal fitnesses cannot be calculated for \
a set of individuals.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(hreps = 
        HaploidFrequencies | 
          SymmetricHaploidFrequencies;\)\), "\[IndentingNewLine]", 
    \(\(dreps = 
        DiploidFrequencies | 
          SymmetricDiploidFrequencies;\)\), "\[IndentingNewLine]", 
    \(\(freps = 
        HaploidFrequencies | SymmetricHaploidFrequencies | 
          DiploidFrequencies | SymmetricDiploidFrequencies;\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(MarginalW[\[Psi] : {PopulationRepresentations[_, _] ... }, 
          W_?\((Not[ListQ[#]] &)\), 
          opts___Rule] := \[IndentingNewLine]MapIndexed[
          MarginalW[#1, W[First[#2]], 
              opts] &, \[Psi]];\)\), "\[IndentingNewLine]", 
    \(\(MarginalW[\[Psi] : {PopulationRepresentations[_, _] ... }, W_List, 
          opts___Rule] := \[IndentingNewLine]MapIndexed[
          MarginalW[#1, W\[LeftDoubleBracket]First[#2]\[RightDoubleBracket], 
              opts] &, \[Psi]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(MarginalW[AlleleFrequencies[p_, _], W_List, 
          opts___Rule] := \[IndentingNewLine]\((Message[
            FitnessTable::badOption]; 
          Indeterminate)\);\)\), "\[IndentingNewLine]", 
    \(\(MarginalW[AlleleFrequencies[p_, _], W_?\((Not[ListQ[#]] &)\), 
          opts___Rule] := Last[W[p]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(MarginalW[hreps[\[Psi]_, _], W_List, opts___Rule] := W;\)\), "\n", 
    \(\(MarginalW[dreps[\[Psi]_, n_], W_List, opts___Rule] := 
        Plus @@ \((\[Psi]*W)\)\/Plus @@ \[Psi];\)\), "\n", 
    \(\(MarginalW[\((pr : freps)\)[\[Psi]_, n_], W_?\((Not[ListQ[#]] &)\), 
          opts___Rule] := \[IndentingNewLine]MarginalW[pr[\[Psi], n], 
          FitnessTable[W, NumberOfGenes[pr[\[Psi], n]], 
            NumericalModel \[Rule] pr, opts]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(MarginalW[SymmetricNeutralHaploidFrequencies[{\[Psi]_, u_}, nd_], W_, 
          opts___Rule] := \[IndentingNewLine]MarginalW[
          SymmetricHaploidFrequencies[\[Psi], nd], W, 
          opts];\)\), "\[IndentingNewLine]", 
    \(\(MarginalW[SymmetricNeutralDiploidFrequencies[{\[Psi]_, u_}, _], W_, 
          opts___Rule] := \[IndentingNewLine]MarginalW[
          SymmetricDiploidFrequencies[\[Psi], nd], W, 
          opts];\)\), "\[IndentingNewLine]", 
    \(\(MarginalW[IndividualRepresentations[\[Psi]_, _], W_, 
          opts___Rule] := \[IndentingNewLine]\((Message[
            MarginalW::badOption]; {})\);\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SymmetricMeanW", "Subsubsection"],

Cell[BoxData[
    \(SymmetricMeanW[n_Integer, wt_List] := 
      Apply[Plus, wt*HeterozygoteB[n], {2}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SymmetricMeanW[i_Integer, j_Integer, n_Integer, wt_List] := \n\t
        HeterozygoteB[i, j, n] . 
          wt\[LeftDoubleBracket]i + 1, 
            j + 1\[RightDoubleBracket];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SymmetricMeanW[i_Integer, j_Integer, n_Integer, 
          W_?\((Not[ListQ[#]] &)\)] := 
        Module[{l, hh = HeterozygoteB[i, j, n]}, \n\t\t\tSum[
            hh\[LeftDoubleBracket]i + j - 2  l + 1\[RightDoubleBracket] 
              W[i, j, i + j - 2  l], {l, Max[0, i + j - n], 
              Min[i, j]}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(SymmetricMeanW[n_Integer, W_?\((Not[ListQ[#]] &)\), 
        opts___Rule] := \[IndentingNewLine]Module[{i, j}, 
        Table[SymmetricMeanW[i, j, n, W], {i, 0, n}, {j, 0, n}]]\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`FitnessTable\)], "Subsubsection"],

Cell[BoxData[
    \(\(Options[
          FitnessTable] = {NumericalModel \[Rule] 
            HaploidFrequencies};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FitnessTable::badOption = "\<Fitness cannot be tabulated for \
AlleleFrequencies.  A function which supplies the mean fitness and the \
selection coefficients as a function of allele frequencies must be \
used.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FitnessTable[W_, n_Integer, 
          opts___Rule] := \[IndentingNewLine]Module[{i, j, h, ht, 
            nm = \(NumericalModel /. {opts}\) /. 
                Options[FitnessTable]}, \n\t\tSwitch[
            nm, \[IndentingNewLine]HaploidFrequencies | 
              HaploidIndividuals, \[IndentingNewLine]\ \ \ \ W /@ 
              HaploidTypes[n, opts], \[IndentingNewLine]DiploidFrequencies | 
              DiploidIndividuals, \[IndentingNewLine]\ \ \ \ ht = 
              HaploidTypes[n, opts]; 
            Outer[W, ht, ht, 
              1], \[IndentingNewLine]SymmetricHaploidFrequencies | 
              SymmetricNeutralHaploidFrequencies, \[IndentingNewLine]\ \ \ \ \
Table[W[i], {i, 0, n}], \[IndentingNewLine]SymmetricDiploidFrequencies | 
              SymmetricNeutralDiploidFrequencies, \[IndentingNewLine]\ \ \ \ \
Table[SymmetricMeanW[i, j, n, W], {i, 0, n}, {j, 0, 
                n}], \[IndentingNewLine]AlleleFrequencies, \
\[IndentingNewLine]\ \ \ Message[
              FitnessTable::badOption]; {}, \[IndentingNewLine]_, \
\[IndentingNewLine]\ \ \ \ Message[NumericalModel::badSetting, 
              nm]; {}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Recursions", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`GameteTable\)], "Subsubsection"],

Cell[BoxData[
    \(\(Options[GameteTable] = {Linkage \[Rule] False, 
          StoreResults \[Rule] True, 
          NumericalModel \[Rule] HaploidFrequencies};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GameteTable::badOpts = "\<`1` is not a valid option for \
GameteTable\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GameteTable[n_Integer, opts___Rule] := 
        GameteTable[n, 1 &, opts];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GameteTable[n_Integer, ww_, 
          opts___Rule] := \[IndentingNewLine]Module[\[IndentingNewLine]{i, j, 
            ht, \n\tnm = \(NumericalModel /. {opts}\) /. 
                Options[GameteTable], \n\t
            srQ = \(StoreResults /. {opts}\) /. 
                Options[GameteTable]}, \n\ \ \ \ \ \ \ \ If[
            srQ, \n\t\tGameteTable[n, ww, opts] = 
              GameteTable[n, ww, StoreResults \[Rule] False, opts], \n\t
            Switch[nm, \[IndentingNewLine]SymmetricRepresentations, \
\[IndentingNewLine]Table[
                Gametes[i, j, n, ww], {i, 0, n}, {j, 0, 
                  n}], \[IndentingNewLine]NonSymmetricRepresentations, \
\[IndentingNewLine]ht = HaploidTypes[n, opts]; \n\t\t\ \ Outer[
                Gametes[#1, #2, ww, opts] &, ht, ht, 
                1], \[IndentingNewLine]_, \[IndentingNewLine]Message[
                GameteTable::badOpts, nm]]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`Gametes\)], "Subsubsection"],

Cell[BoxData[
    \(\(Options[Gametes] = {Linkage \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Gametes[i_Integer, j_Integer, n_Integer] := 
        Gametes[i, j, n, 1 &];\)\), "\[IndentingNewLine]", 
    \(\(Gametes[Y_List, Z_List, opts___Rule] := 
        Gametes[Y, Z, 1 &, opts];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Gametes[i_Integer, j_Integer, n_Integer, 
          W_] := \[IndentingNewLine]Module[{l, 
            k}, \n\t\(2\^\(-\((i + j)\)\)\/Binomial[n, j]\) 
            Sum[\(2\^\(2  l\)\) 
                Table[Binomial[i + j - 2  l, k - l], {k, 0, n}] 
                Binomial[i, l] Binomial[n - i, j - l] 
                W[i, j, i + j - 2  l], {l, Max[0, i + j - n], 
                Min[i, j]}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Gametes[Y_List, Z_List, W_, 
          opts___Rule] := \((\(GametesRaw[#, Y, Z, opts] &\) /@ 
              HaploidTypes[Length[Z], opts])\) W[Y, Z];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(GametesRaw[X_List, Y_List, Z_List, opts___Rule] := \n\t
        Module[{ph, rr, 
            rQ, \n\t\t\tr = \(Linkage /. {opts}\) /. 
                Options[Gametes], \n\t\t\th = 
              Y + Z - 2  Y\ Z,  (*heterozygous\ loci*) \n\t\t\tp = \((1 - X - 
                  Y + 2  X\ Y)\)}, \t (*Is\ the\ offspring\ in\ the\ smae\ \
state\ as\ parent\ \(\(Y\)\(?\)\)*) \n\t\ \ \ \ \ ph = 
            Flatten[Position[h, 1]];  (*\ 
            positions\ of\ heterozygous\ loci*) \n\ \ \ \ \ \ \ If[
            Times @@ \((h + \((1 - h)\) p)\) == 0, \n\t\t\t\ \ 0,  (*\ 
              an\ impossible\ offspring*) \n\t\t\ \ \tIf[\((r === False)\) || 
                ph == {}, \n\t\t\ \ \ \ \ \ \tTimes @@ \((1 - h/2)\),  (*\ 
                no\ linkage*) \n\t\t\ \ \ \ \ \ \ rr = 
                Prepend[
                  NetRecombination /@  (*\ 
                      recombination\ rate\ with\ previous\ heterozygous\ \
locus*) \n\t\t\t\ \t\t\t\((\(Take[r, #] &\) /@ 
                        Drop[Transpose[{ph, RotateLeft[ph - 1]}], \(-1\)])\), 
                  1/2]; \n\t\t\ \ \ \ \ \ \ rQ = \(p\[LeftDoubleBracket]#\
\[RightDoubleBracket] &\) /@ ph; \n\t\t\t\t\ \ \ rQ = 
                Abs[rQ - RotateRight[rQ]];  (*\ 
                Is\ each\ heterozygous\ loci\ cis\ or\ trans\ wrt\ the\ \
\(\(last\)\(?\)\)\ *) \n\t\t\ \ \ \ \ \ \ \ Times @@ \((\((1 - rr)\) + 
                    rQ \((2  rr - 1)\))\)]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["HeterozygoteB", "Subsubsection"],

Cell[BoxData[
    \(\(HeterozygoteB[i_, j_, 
          n_] := \(HeterozygoteB[i, j, 
            n] = \[IndentingNewLine]Module[{l, 
              pp = Array[0 &, n + 1]}, \n\t\t\tDo[
              pp\[LeftDoubleBracket]i + j - 2  l + 1\[RightDoubleBracket] = 
                Binomial[i, l] Binomial[n - i, j - l\ ], {l, 
                Max[0, i + j - n], Min[i, j]}]; 
            pp/Binomial[n, j]]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(HeterozygoteB[
          n_] := \(HeterozygoteB[n] = \n\t\tModule[{i, j}, 
            Table[HeterozygoteB[i, j, n], {i, 0, n}, {j, 0, 
                n}]]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`NewGametes\)], "Subsubsection"],

Cell[BoxData[
    \(\(Options[NewGametes] = {Linkage \[Rule] False, Mutation \[Rule] None, 
          DemeSize \[Rule] \((#1 &)\), RandomDrift \[Rule] False, 
          TruncationSelection \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NewGametes::badN = "\<New deme size `1` is greater than original size \
`2`\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(NewGametes[AlleleFrequencies[p_, n_], 
          opts___Rule] := \[IndentingNewLine]NewGametes[
          AlleleFrequencies[p, n], {1, Array[0 &, Length[p]]} &, 
          opts];\)\), "\[IndentingNewLine]", 
    \(\(NewGametes[\((pr : DiploidRepresentations)\)[\[Psi]_, n_], 
          opts___Rule] := NewGametes[pr[\[Psi], n], 1 &, opts];\)\)}], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(NewGametes[AlleleFrequencies[p_, n_], W_, 
          opts___Rule] := \[IndentingNewLine]Module[{f = \(DemeSize /. {opts}\
\) /. Options[NewGametes], ww = W[p], 
            rd = \(RandomDrift /. {opts}\) /. Options[NewGametes], 
            pn, \[IndentingNewLine]mut = \(Mutation /. {opts}\) /. 
                Options[NewGametes]}, \[IndentingNewLine]f = 
            f /. {r_, \[Beta]_, \[Gamma]_, \[Lambda]_} \[Rule] 
                ExponentialF[
                  r, \[Beta], \[Gamma], \[Lambda]]; \[IndentingNewLine]pn = 
            AlleleFrequencies[
              p \((1 + \((1 - 
                          p)\) \(\(\ \)\(ww\[LeftDoubleBracket]2\
\[RightDoubleBracket]\)\)\/ww\[LeftDoubleBracket]1\[RightDoubleBracket])\), 
              2  f[n, ww\[LeftDoubleBracket]1\[RightDoubleBracket]]]; \
\[IndentingNewLine]If[rd, 
            pn = RandomDrift[pn, 
                pn\[LeftDoubleBracket]2\[RightDoubleBracket]]]; \
\[IndentingNewLine]If[
            mut === None, \[IndentingNewLine]pn, \[IndentingNewLine]Mutate[
              pn, ConstructMutateList[mut, Length[pn]], opts]]];\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(NewGametes[DiploidFrequencies[\[Phi]_, n_], W_, 
          opts___Rule] := \[IndentingNewLine]Module[{f = \(DemeSize /. {opts}\
\) /. Options[NewGametes], \[IndentingNewLine]wb = 
              MeanW[DiploidFrequencies[\[Phi], n], W, 
                opts], \[IndentingNewLine]rd = \(RandomDrift /. {opts}\) /. 
                Options[NewGametes], 
            hn, \[IndentingNewLine]mut = \(Mutation /. {opts}\) /. 
                Options[NewGametes]}, \[IndentingNewLine]f = 
            f /. {r_, \[Beta]_, \[Gamma]_, \[Lambda]_} \[Rule] 
                ExponentialF[
                  r, \[Beta], \[Gamma], \[Lambda]]; \[IndentingNewLine]hn = 
            HaploidFrequencies[
              If[Length[\[Phi]] == 
                  0, {}, \[IndentingNewLine]If[\[Phi]\[LeftDoubleBracket]1\
\[RightDoubleBracket] === {}, \[IndentingNewLine]{}, \[IndentingNewLine]Plus @@ \
\(Plus @@ \((GameteTable[Log[2, Length[\[Phi]]], W, opts]*\[Phi])\)\)/\ 
                    wb]], \[IndentingNewLine]2 
                 f[n, wb]]; \[IndentingNewLine]If[rd, 
            hn = RandomDrift[hn, 
                hn\[LeftDoubleBracket]2\[RightDoubleBracket]]]; \
\[IndentingNewLine]If[
            mut === None, \[IndentingNewLine]hn, \[IndentingNewLine]Mutate[
              hn, ConstructMutateList[mut, Log[2, Length[\[Phi]]]], 
              opts]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NewGametes[SymmetricDiploidFrequencies[\[Phi]_, n_], W_, 
          opts___Rule] := \[IndentingNewLine]Module[{f = \(DemeSize /. {opts}\
\) /. Options[NewGametes], \[IndentingNewLine]wb = 
              MeanW[SymmetricDiploidFrequencies[\[Phi], n], W, opts], 
            mut = \(Mutation /. {opts}\) /. 
                Options[NewGametes], \[IndentingNewLine]ng, 
            nn}, \[IndentingNewLine]f = 
            f /. {r_, \[Beta]_, \[Gamma]_, \[Lambda]_} \[Rule] 
                ExponentialF[
                  r, \[Beta], \[Gamma], \[Lambda]]; \[IndentingNewLine]nn = 
            2  f[n, wb]; \[IndentingNewLine]If[
            Length[\[Phi]] == 
              0, \[IndentingNewLine]SymmetricHaploidFrequencies[{}, 
              nn], \[IndentingNewLine]If[\[Phi]\[LeftDoubleBracket]1\
\[RightDoubleBracket] === {}, \
\[IndentingNewLine]SymmetricHaploidFrequencies[{}, 
                nn], \[IndentingNewLine]ng = 
                SymmetricHaploidFrequencies[
                  Plus @@ \(Plus @@ \((GameteTable[Length[\[Phi]] - 1, W, 
                              NumericalModel \[Rule] 
                                SymmetricDiploidFrequencies]*\[Phi])\)\)/wb, 
                  nn]; \[IndentingNewLine]If[
                mut === 
                  None, \[IndentingNewLine]ng, \[IndentingNewLine]Mutate[ng, 
                  mut /. {\[Mu]_} \[Rule] {\[Mu], \[Mu]}, 
                  opts]]]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NewGametes[SymmetricNeutralDiploidFrequencies[{\[Phi]_, u_}, n_], W_, 
          opts___Rule] := \[IndentingNewLine]Module[{f = \(DemeSize /. {opts}\
\) /. Options[NewGametes], \[IndentingNewLine]wb = 
              MeanW[SymmetricNeutralDiploidFrequencies[\[Phi], n], W, 
                opts], \[IndentingNewLine]gt, n\[Psi], 
            n\[Psi]u}, \[IndentingNewLine]f = 
            f /. {r_, \[Beta]_, \[Gamma]_, \[Lambda]_} \[Rule] 
                ExponentialF[
                  r, \[Beta], \[Gamma], \[Lambda]]; \
\[IndentingNewLine]SymmetricNeutralHaploidFrequencies[
            If[Length[\[Phi]] == 
                0, {}, \[IndentingNewLine]If[\[Phi]\[LeftDoubleBracket]1\
\[RightDoubleBracket] === {}, \[IndentingNewLine]{}, \[IndentingNewLine]gt = 
                  GameteTable[Length[\[Phi]] - 1, W, 
                    NumericalModel \[Rule] 
                      SymmetricNeutralDiploidFrequencies]; \
\[IndentingNewLine]n\[Psi] = 
                  Plus @@ \(Plus @@ \((gt*\[Phi])\)\); \[IndentingNewLine]n\
\[Psi]u = Plus @@ \(Plus @@ \((gt*\[Phi]*
                          u)\)\); \[IndentingNewLine]{n\[Psi]\/wb, 
                  DivideZero[n\[Psi]u, n\[Psi]]}]], \[IndentingNewLine]2 
               f[n, wb]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NewGametes[\[Phi] : DiploidIndividuals[\[Psi]_, n_], W_, 
          opts___Rule] := \[IndentingNewLine]Module[{f = \(DemeSize /. {opts}\
\) /. Options[NewGametes], \[IndentingNewLine]wb = MeanW[\[Phi], W, opts], 
            wl, newN, rl, ht, tp, np, 
            ss, \[IndentingNewLine]ts = \(TruncationSelection /. {opts}\) /. 
                Options[
                  NewGametes], \[IndentingNewLine]mut = \(Mutation /. \
{opts}\) /. Options[NewGametes]}, \[IndentingNewLine]wl = 
            If[ListQ[W], \[IndentingNewLine]ht = 
                HaploidTypes[
                  Length[\[Psi]\[LeftDoubleBracket]1, 
                      1\[RightDoubleBracket]], 
                  opts]; \[IndentingNewLine]\((\(Extract[
                      W, #] &\) /@ \((\(Flatten[{Position[
                              ht, #\[LeftDoubleBracket]1\[RightDoubleBracket]]\
, Position[
                              ht, #\[LeftDoubleBracket]2\[RightDoubleBracket]]\
}] &\) /@ \[Psi])\))\), \[IndentingNewLine]\(W @@ # &\) /@ \[Psi]]; \
\[IndentingNewLine]f = 
            f /. {r_, \[Beta]_, \[Gamma]_, \[Lambda]_} \[Rule] 
                ExponentialF[
                  r, \[Beta], \[Gamma], \[Lambda]]; \[IndentingNewLine]newN = 
            2  Round[f[n, wb]]; \[IndentingNewLine]rl = 
            If[ts, \[IndentingNewLine]If[
                newN > n, \[IndentingNewLine]Message[NewGametes::badN, newN, 
                  n]; newN = n]; \[IndentingNewLine]ss = 
                Transpose[{wl, Range[n]}]; \[IndentingNewLine]tp = \(Sort[
                    wl]\)\[LeftDoubleBracket]\(-newN\)\[RightDoubleBracket]; 
              np = Select[
                  ss, \((#\[LeftDoubleBracket]1\[RightDoubleBracket] > 
                        tp)\) &]; \[IndentingNewLine]np = 
                Join[np, 
                  RandomSet[newN - Length[np], 
                    Select[ss, \((#\[LeftDoubleBracket]1\[RightDoubleBracket] \
== tp)\) &]]]; \[IndentingNewLine]Muddle[
                Last /@ np], \[IndentingNewLine]RandomList[newN, 
                wl\/Plus @@ wl]]; \[IndentingNewLine]If[
            mut === None, \
\[IndentingNewLine]HaploidIndividuals[\(RandomFamily[\[Psi]\
\[LeftDoubleBracket]#\[RightDoubleBracket], opts] &\) /@ rl, 
              newN], \[IndentingNewLine]HaploidIndividuals[\(\(MutateCompiled[
                      HaploidIndividuals]\)[
                    RandomFamily[\[Psi]\[LeftDoubleBracket]#\
\[RightDoubleBracket], opts], 
                    ConstructMutateList[mut, 
                      Length[\[Psi]\[LeftDoubleBracket]1, 
                          1\[RightDoubleBracket]]]] &\) /@ rl, 
              newN]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ConstructMutateList", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(ConstructMutateList[ml_, n_Integer]\), ":=", 
        RowBox[{"Module", "[", 
          RowBox[{\({mut}\), ",", "\[IndentingNewLine]", 
            
            RowBox[{\(mut = 
                ml /. {\[Mu]_?\((Not[ListQ[#]] &)\)} \[Rule] {\[Mu], \[Mu]}\),
               
              StyleBox[";",
                FontWeight->"Plain"], 
              "\[IndentingNewLine]", \(If[Depth[mut] \[Equal] 2, 
                Array[mut &, n], mut]\)}]}], "]"}]}], ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Mutate", "Subsubsection"],

Cell[BoxData[
    \(\(Options[Mutate] = {Compiled \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Mutate[g_List, mr_List, 
          opts___Rule] := \[IndentingNewLine]If[\(Compiled /. {opts}\) /. 
            Options[Mutate], \[IndentingNewLine]\(MutateCompiled[
              HaploidIndividuals]\)[g, mr], \[IndentingNewLine]MapThread[
            If[Random[] < #2\[LeftDoubleBracket]#1 + 1\[RightDoubleBracket], 
                1 - #1, #1] &, {g, mr}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Mutate[HaploidIndividuals[\[Psi]_, n_], mr_List, 
          opts___Rule] := \[IndentingNewLine]HaploidIndividuals[\(Mutate[#, 
                mr, opts] &\) /@ \[Psi], n];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Mutate[AlleleFrequencies[p_, n_], mr_List, 
          opts___Rule] := \[IndentingNewLine]AlleleFrequencies[\
\[IndentingNewLine]If[\(Compiled /. {opts}\) /. 
              Options[Mutate], \[IndentingNewLine]\(MutateCompiled[
                AlleleFrequencies]\)[p, 
              mr], \[IndentingNewLine]Module[{tmr = 
                  Transpose[
                    mr]}, \[IndentingNewLine]p \((1 - 
                      tmr\[LeftDoubleBracket]1\[RightDoubleBracket] - 
                      tmr\[LeftDoubleBracket]2\[RightDoubleBracket])\) + 
                tmr\[LeftDoubleBracket]1\[RightDoubleBracket]]], 
          n];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Mutate[HaploidFrequencies[\[Psi]_, n_], mr_List, 
          opts___Rule] := \[IndentingNewLine]HaploidFrequencies[
          ConstructMutateMatrix[mr, Log[2, Length[\[Psi]]], opts] . \[Psi], 
          n];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Mutate[SymmetricHaploidFrequencies[\[Psi]_, n_], mr_List, 
          opts___Rule] := \[IndentingNewLine]SymmetricHaploidFrequencies[
          ConstructMutateMatrix[mr, Length[\[Psi]] - 1, opts, 
              NumericalModel \[Rule] SymmetricHaploidFrequencies] . \[Psi], 
          n];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Mutate[SymmetricNeutralHaploidFrequencies[\[Psi]_, n_], mr_List, 
          opts___Rule] := 0;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ConstructMutateMatrix", "Subsubsection"],

Cell[BoxData[
    \(\(Options[ConstructMutateMatrix] = {Compiled \[Rule] False, 
          NumericalModel \[Rule] HaploidFrequencies};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ConstructMutateMatrix::badModel = "\<`1` is not a valid setting for \
NumericalModel in ConstructMutateMatrix\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ConstructMutateMatrix[mr_List, n_Integer, 
          opts___Rule] := \(ConstructMutateMatrix[mr, n, 
            opts] = \[IndentingNewLine]Module[{nm = \(NumericalModel /. \
{opts}\) /. Options[
                    ConstructMutateMatrix], \[IndentingNewLine]tmr, \[Mu], \
\[Nu], ht, i, j, 
              a}, \[IndentingNewLine]If[\(Compiled /. {opts}\) /. 
                Options[ConstructMutateMatrix], \[IndentingNewLine]Switch[
                nm, \[IndentingNewLine]HaploidFrequencies, \
\[IndentingNewLine]\(ConstructMutateMatrixCompiled[nm]\)[mr, 
                  HaploidTypes[n, 
                    opts]], \[IndentingNewLine]SymmetricHaploidFrequencies | 
                  SymmetricNeutralHaploidFrequencies, \
\[IndentingNewLine]\(ConstructMutateMatrixCompiled[nm]\)[mr, 
                  n], \[IndentingNewLine]_, \[IndentingNewLine]\(Message[
                    ConstructMutateMatrix::badModel, 
                    nm];\)], \[IndentingNewLine]Switch[
                nm, \[IndentingNewLine]HaploidFrequencies, \
\[IndentingNewLine]tmr = Transpose[mr]; 
                ht = HaploidTypes[n, opts]; \[IndentingNewLine]\[Mu] = 
                  tmr\[LeftDoubleBracket]1\[RightDoubleBracket]; \[Nu] = 
                  tmr\[LeftDoubleBracket]2\[RightDoubleBracket]; \
\[IndentingNewLine]Outer[
                  Times @@ \((\((1 - \[Mu])\) - #1 \((1 - 
                                2  \[Mu])\) - #2 \((1 - 
                                2  #1)\) \((1 - \[Mu] - \[Nu])\))\) &, ht, 
                  ht, 1], \[IndentingNewLine]SymmetricHaploidFrequencies, \
\[IndentingNewLine]\[Mu] = 
                  mr\[LeftDoubleBracket]1\[RightDoubleBracket]; \[Nu] = 
                  mr\[LeftDoubleBracket]2\[RightDoubleBracket]; 
                a = \((\(\[Mu]\/\(1 - \[Mu]\)\) \[Nu]\/\(1 - \[Nu]\))\); \
\[IndentingNewLine]Table[
                  If[i > j, \[IndentingNewLine]\(\[Mu]\^\(i - 
                            j\)\) \(\((1 - \[Mu])\)\^\(n - 
                            i\)\) \(\((1 - \[Nu])\)\^j\) 
                      Binomial[n - j, n - i]\ Hypergeometric2F1[\(-j\), 
                        i - n, 1 + i - j, a], \[IndentingNewLine]If[
                      i \[Equal] 
                        j, \[IndentingNewLine]\(\((1 - \[Mu])\)\^\(n - 
                              j\)\) \((1 - \[Nu])\)\^j\ \
Hypergeometric2F1[\(-j\), j - n, 1, 
                          a], \[IndentingNewLine]\(\((1 - \[Mu])\)\^\(n - 
                              j\)\) \(\((1 - \[Nu])\)\^i\) \(\[Nu]\^\(j - 
                              i\)\) Binomial[j, i]\ Hypergeometric2F1[\(-i\), 
                          j - n, 1 - i + j, a]]], \[IndentingNewLine]{i, 0, 
                    n}, {j, 0, 
                    n}], \[IndentingNewLine]\
SymmetricNeutralHaploidFrequencies, \[IndentingNewLine]0, \
\[IndentingNewLine]_, \[IndentingNewLine]\(Message[
                    ConstructMutateMatrix::badModel, 
                    nm];\)]]]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Working for ConstructMutateMatrix", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Sum[\(a\^x\) \(n!\)\/\(\(x!\) \(\((n - j - x)\)!\) \(\((i - x)\)!\) \(\
\((j - i + x)\)!\)\), {x, 0, n - j}], 
      Sum[\(a\^x\) \(n!\)\/\(\(x!\) \(\((n - j - x)\)!\) \(\((i - x)\)!\) \
\(\((j - i + x)\)!\)\), {x, i - j, n - j}]}\)], "Input"],

Cell[BoxData[
    \({\(\(n!\)\ Hypergeometric2F1[\(-i\), j - n, 1 - i + j, a]\)\/\(Gamma[1 \
+ i]\ Gamma[1 - i + j]\ Gamma[1 - j + n]\), \(a\^\(i - j\)\ \(n!\)\ \
Hypergeometric2F1[\(-j\), i - n, 1 + i - j, a]\)\/\(Gamma[1 + i - j]\ Gamma[1 \
+ j]\ Gamma[1 - i + n]\)}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(If[i > 
        j, \[IndentingNewLine]\(a\^\(i - 
              j\)\) \(\(n!\)\ Hypergeometric2F1[\(-j\), i - n, 1 + i - j, \
a]\)\/\(\(j!\)\ \(\((i - j)\)!\)\ \(\((n - i)\)!\)\), \
\[IndentingNewLine]\(\(n!\)\ Hypergeometric2F1[\(-i\), j - n, 1 - i + j, a]\)\
\/\(\(i!\)\ \(\((j - i)\)!\)\ \(\((n - j)\)!\)\)]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(rl = {n \[Rule] 10, i \[Rule] 5, 
          j \[Rule] 7};\)\), "\[IndentingNewLine]", 
    \({Sum[\(a\^x\) \(n!\)\/\(\(x!\) \(\((n - j - x)\)!\) \(\((i - x)\)!\) \(\
\((j - i + x)\)!\)\), {x, 0, n - j}] /. rl, 
      Sum[\(a\^x\) \(n!\)\/\(\(x!\) \(\((n - j - x)\)!\) \(\((i - x)\)!\) \
\(\((j - i + x)\)!\)\), {x, 0, i}] /. 
        rl, \(\(n!\)\ Hypergeometric2F1[\(-i\), j - n, 1 - i + j, \
a]\)\/\(\(i!\)\ \(\((j - i)\)!\)\ \(\((n - j)\)!\)\) /. rl}\)}], "Input"],

Cell[BoxData[
    \({2520\ \((1 + 5\ a + 5\ a\^2 + a\^3)\), 
      2520\ \((1 + 5\ a + 5\ a\^2 + a\^3)\), 
      2520\ \((1 + 5\ a + 5\ a\^2 + a\^3)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(rl = {n \[Rule] 10, i \[Rule] 5, 
          j \[Rule] 3};\)\), "\[IndentingNewLine]", 
    \({Sum[\(a\^x\) \(n!\)\/\(\(x!\) \(\((n - j - x)\)!\) \(\((i - x)\)!\) \(\
\((j - i + x)\)!\)\), {x, i - j, n - j}] /. rl, 
      Sum[\(a\^x\) \(n!\)\/\(\(x!\) \(\((n - j - x)\)!\) \(\((i - x)\)!\) \
\(\((j - i + x)\)!\)\), {x, i - j, i}] /. 
        rl, \(a\^\(i - 
                j\)\) \(\(n!\)\ Hypergeometric2F1[\(-j\), i - n, 1 + i - j, \
a]\)\/\(\(j!\)\ \(\((i - j)\)!\)\ \(\((n - i)\)!\)\) /. rl}\)}], "Input"],

Cell[BoxData[
    \({2520\ a\^2\ \((1 + 5\ a + 5\ a\^2 + a\^3)\), 
      2520\ a\^2\ \((1 + 5\ a + 5\ a\^2 + a\^3)\), 
      2520\ a\^2\ \((1 + 5\ a + 5\ a\^2 + a\^3)\)}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["ConstructMutateMatrixCompiled", "Subsubsection"],

Cell[BoxData[
    \(\(ConstructMutateMatrixCompiled[HaploidFrequencies] = 
        Compile[{{mr, _Real, 2}, {ht, _Integer, 
              2}}, \[IndentingNewLine]Module[{tmr = Transpose[mr], j, 
              k}, \[IndentingNewLine]Table[
              Times @@ \((\((1 - 
                        tmr\[LeftDoubleBracket]1\[RightDoubleBracket])\) - 
                    ht\[LeftDoubleBracket]j\[RightDoubleBracket] \((1 - 
                          2  tmr\[LeftDoubleBracket]1\[RightDoubleBracket])\) \
- ht\[LeftDoubleBracket]k\[RightDoubleBracket] \((1 - 
                          2  ht\[LeftDoubleBracket]
                              j\[RightDoubleBracket])\) \((1 - 
                          tmr\[LeftDoubleBracket]1\[RightDoubleBracket] - 
                          tmr\[LeftDoubleBracket]2\[RightDoubleBracket])\))\),\
 {j, Length[ht]}, {k, Length[ht]}]], \[IndentingNewLine]{{tmr, _Real, 
              2}, {j, _Integer}, {k, _Integer}}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ConstructMutateMatrixCompiled[SymmetricHaploidFrequencies] = 
        Compile[{{mr, _Real, 
              1}, {n, _Integer}}, \[IndentingNewLine]Module[{i, j, 
              a, \[Mu], \[Nu]}, \[IndentingNewLine]\[Mu] = 
              mr\[LeftDoubleBracket]1\[RightDoubleBracket]; \[Nu] = 
              mr\[LeftDoubleBracket]2\[RightDoubleBracket]; 
            a = \((\(\[Mu]\/\(1 - \[Mu]\)\) \[Nu]\/\(1 - \[Nu]\))\); \
\[IndentingNewLine]Table[
              If[i > j, \[IndentingNewLine]\(\[Mu]\^\(i - 
                        j\)\) \(\((1 - \[Mu])\)\^\(n - 
                        i\)\) \(\((1 - \[Nu])\)\^j\) 
                  Binomial[n - j, n - i]\ Hypergeometric2F1[\(-j\), i - n, 
                    1 + i - j, a], \[IndentingNewLine]If[
                  j \[Equal] 
                    i, \[IndentingNewLine]\(\((1 - \[Mu])\)\^\(n - 
                          j\)\) \((1 - \[Nu])\)\^j\ Hypergeometric2F1[\(-j\), 
                      j - n, 1, a], \[IndentingNewLine]Binomial[j, 
                      i] \(\((1 - \[Mu])\)\^\(n - 
                          j\)\) \(\((1 - \[Nu])\)\^i\) \[Nu]\^\(j - i\)\ \
Hypergeometric2F1[\(-i\), j - n, 1 - i + j, a]]], \[IndentingNewLine]{i, 0, 
                n}, {j, 0, 
                n}]], \[IndentingNewLine]{{a, _Real}, {\[Mu], _Real}, {\[Nu], \
_Real}, {i, _Integer}, {j, _Integer}, {Binomial[_, _], _Real}}];\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MutateCompiled", "Subsubsection"],

Cell[BoxData[
    \(\(MutateCompiled[HaploidIndividuals] = 
        Compile[{{g, _Integer, 1}, {mr, _Real, 
              2}}, \[IndentingNewLine]Module[{j}, \[IndentingNewLine]Table[
              If[Random[] < 
                  mr\[LeftDoubleBracket]j, 
                    g\[LeftDoubleBracket]j\[RightDoubleBracket] + 
                      1\[RightDoubleBracket], 
                1 - g\[LeftDoubleBracket]j\[RightDoubleBracket], 
                g\[LeftDoubleBracket]j\[RightDoubleBracket]], {j, 
                Length[g]}]], \[IndentingNewLine]{{j, _Integer}}];\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MutateCompiled[AlleleFrequencies] = 
        Compile[{{p, _Real, 1}, {mr, _Real, 
              2}}, \[IndentingNewLine]Module[{tmr = 
                Transpose[
                  mr]}, \[IndentingNewLine]p \((1 - 
                    tmr\[LeftDoubleBracket]1\[RightDoubleBracket] - 
                    tmr\[LeftDoubleBracket]2\[RightDoubleBracket])\) + 
              tmr\[LeftDoubleBracket]1\[RightDoubleBracket]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(MutateCompiled[HaploidFrequencies]\)[\[Psi]_, mr_, 
          opts___Rule] := \[IndentingNewLine]ConstructMutateMatrix[mr, 
            Log[2, Length[\[Psi]]], opts, 
            Compiled \[Rule] True] . \[Psi];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(MutateCompiled[SymmetricHaploidFrequencies]\)[\[Psi]_, 
          mr_] := \[IndentingNewLine]ConstructMutateMatrix[mr, 
            Length[\[Psi]] - 1, Compiled \[Rule] True, 
            NumericalModel \[Rule] 
              SymmetricHaploidFrequencies] . \[Psi];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["MigrateExact", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[MigrateExact] = {FixedEnds \[Rule] {{}, {}}};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(MigrateExact[\((pr : NeutralRepresentations)\)[{\[Psi]_, u_}, 
            n_], \((pr : NeutralRepresentations)\)[{\[Psi]s_, us_}, ns_], m_, 
          opts___Rule] := \[IndentingNewLine]pr[{DivideZero[\((1 - 
                      m)\) \((n\ \[Psi])\) + 
                m\ \((ns\ \[Psi]s)\), \((1 - m)\) n + m\ ns], 
            DivideZero[\((1 - m)\) \((n\ u\ \[Psi])\) + 
                m\ \((ns\ us\ \[Psi]s)\), \((1 - m)\) \((n\ \[Psi])\) + 
                m\ \((ns\ \[Psi]s)\)]}, \((1 - m)\) n + 
            m\ ns];\)\), "\[IndentingNewLine]", 
    \(\(MigrateExact[\((pr : FrequencyRepresentations)\)[\[Psi]_, 
            n_], \((pr : PopulationRepresentations)\)[\[Psi]s_, ns_], m_, 
          opts___Rule] := \[IndentingNewLine]pr[
          DivideZero[\((1 - m)\) \((n\ \[Psi])\) + 
              m \((ns\ \ \[Psi]s)\), \((1 - m)\) n + m\ ns], \((1 - m)\) n + 
            m\ ns];\)\), "\[IndentingNewLine]", 
    \(\(MigrateExact[\((ir : IndividualRepresentations)\)[\[Psi]_, 
            n_], \((fr : FrequencyRepresentations)\)[\[Psi]s_, ns_], 
          Nm_Integer, 
          opts___Rule] := \[IndentingNewLine]Module[{nStay = 
              Random[BinomialDistribution[n, \((1 - Nm\/n)\)]], 
            np}, \[IndentingNewLine]np = 
            ir[Muddle[
                Join[\(MakeIndividuals[fr[\[Psi]s, ns], 
                      Nm]\)\ \[LeftDoubleBracket]1\[RightDoubleBracket], 
                  RandomSet[nStay, \[Psi]]]], 
              nStay + Nm]; \[IndentingNewLine]If[
            MatchQ[ir, HaploidIndividuals] \[And] 
              OddQ[nStay + Nm], \[IndentingNewLine]HaploidIndividuals[
              Drop[np\[LeftDoubleBracket]1\[RightDoubleBracket], 1], 
              np\[LeftDoubleBracket]2\[RightDoubleBracket] - 1], 
            np]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MigrateExact[\[Phi] : {\((pr : NeutralRepresentations)\)[_, _] .. }, 
          m_, opts___Rule] := \[IndentingNewLine]Module[{pp, 
            os}, \n\t\tos = \(FixedEnds /. {opts}\) /. 
              Options[MigrateExact]; \n\t\tIf[
            os\[LeftDoubleBracket]\ \ 1\[RightDoubleBracket] === {} \[Or] 
              os\[LeftDoubleBracket]\ \ \ 1\[RightDoubleBracket] === {{}}, 
            os\[LeftDoubleBracket]\ \ \ 1\[RightDoubleBracket] = 
              First[\[Phi]]]; \n\t\tIf[
            os\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] === {} \[Or] 
              os\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] === {{}}, 
            os\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] = 
              Last[\[Phi]]]; \n\ \ \ \ \ \ \ \ pp = 
            Prepend[Append[\[Phi], Last[os]], 
              First[os]]; \[IndentingNewLine]pp = 
            pp /. {NeutralRepresentations[{\[Psi]_, u_}, 
                    n_] \[RuleDelayed] {n\ \[Psi], n\ \[Psi]\ u, 
                    n}}; \[IndentingNewLine]\(pr[{DivideZero[#\
\[LeftDoubleBracket]1\[RightDoubleBracket], #\[LeftDoubleBracket]3\
\[RightDoubleBracket]], 
                  DivideZero[#\[LeftDoubleBracket]2\[RightDoubleBracket], #\
\[LeftDoubleBracket]1\[RightDoubleBracket]]}, #\[LeftDoubleBracket]3\
\[RightDoubleBracket]] &\) /@ \((Drop[
                Drop[\((1 - m)\) 
                      pp + \(m\/2\) \((RotateLeft[pp] + RotateRight[pp])\), 
                  1], \(-1\)])\)];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MigrateExact[\[Phi] : {\((pr : 
                      FrequencyRepresentations)\)[_, _] .. }, m_, 
          opts___Rule] := \[IndentingNewLine]Module[{pp, 
            os}, \n\t\tos = \(FixedEnds /. {opts}\) /. 
              Options[MigrateExact]; \n\t\tIf[
            os\[LeftDoubleBracket]\ \ 1\[RightDoubleBracket] === {} \[Or] 
              os\[LeftDoubleBracket]\ \ \ 1\[RightDoubleBracket] === {{}}, 
            os\[LeftDoubleBracket]\ \ \ 1\[RightDoubleBracket] = 
              First[\[Phi]]]; \n\t\tIf[
            os\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] === {} \[Or] 
              os\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] === {{}}, 
            os\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] = 
              Last[\[Phi]]]; \n\ \ \ \ \ \ \ \ pp = 
            Prepend[Append[\[Phi], Last[os]], 
              First[os]]; \[IndentingNewLine]pp = 
            pp /. {FrequencyRepresentations[\[Psi]_, 
                    n_] \[RuleDelayed] {n\ \[Psi], 
                    n}}; \[IndentingNewLine]\(pr[
                DivideZero[#\[LeftDoubleBracket]1\[RightDoubleBracket], #\
\[LeftDoubleBracket]2\[RightDoubleBracket]], #\[LeftDoubleBracket]2\
\[RightDoubleBracket]] &\) /@ \((Drop[
                Drop[\((1 - m)\) 
                      pp + \(m\/2\) \((RotateLeft[pp] + RotateRight[pp])\), 
                  1], \(-1\)])\)];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(MigrateExact[\[Phi] : {\((ir : 
                      IndividualRepresentations)\)[_, _] .. }, m_, 
          opts___] := \[IndentingNewLine]Module[{pp, os, nd = Length[\[Phi]], 
            j, res, mig, migleft, migright, leftFree, rightFree, leftImm, 
            rightImm, npp, np, 
            hQ = MatchQ[ir, 
                HaploidIndividuals]}, \[IndentingNewLine]os = \(FixedEnds /. \
{opts}\) /. Options[
                MigrateExact]; \[IndentingNewLine]leftFree = \((os\
\[LeftDoubleBracket]\ \ 1\[RightDoubleBracket] === {} \[Or] 
                os\[LeftDoubleBracket]\ \ \ 1\[RightDoubleBracket] === \
{{}})\); rightFree = \((os\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] === \
{} \[Or] os\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] === {{}})\); \
\[IndentingNewLine]pp = \[Phi] /. {ir[\[Psi]_, 
                    n_] \[RuleDelayed] \[Psi]}; \[IndentingNewLine]npp = 
            Table[\[IndentingNewLine]res = 
                  RandomSet[
                    Random[BinomialDistribution[
                        Length[
                          pp\[LeftDoubleBracket]
                            j\[RightDoubleBracket]], \((1 - m)\)]], 
                    pp\[LeftDoubleBracket]
                      j\[RightDoubleBracket]]; \[IndentingNewLine]mig = 
                  TakeAway[pp\[LeftDoubleBracket]j\[RightDoubleBracket], 
                    res]; \[IndentingNewLine]migleft = 
                  RandomSet[Random[BinomialDistribution[Length[mig], 1\/2]], 
                    mig]; \[IndentingNewLine]migright = 
                  TakeAway[mig, migleft]; \[IndentingNewLine]{migleft, res, 
                  migright}, {j, nd}] // 
              Transpose; \[IndentingNewLine]leftImm = 
            If[leftFree, 
              npp\[LeftDoubleBracket]1, 
                1\[RightDoubleBracket], \(MakeIndividuals[
                  os\[LeftDoubleBracket]1\[RightDoubleBracket], 
                  Length[npp\[LeftDoubleBracket]1, 
                      1\[RightDoubleBracket]]]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]]; \[IndentingNewLine]rightImm = 
            If[rightFree, 
              npp\[LeftDoubleBracket]3, \(-1\)\[RightDoubleBracket], \
\(MakeIndividuals[os\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket], 
                  Length[npp\[LeftDoubleBracket]3, \
\(-1\)\[RightDoubleBracket]]]\)\[LeftDoubleBracket]1\[RightDoubleBracket]]; \
\[IndentingNewLine]npp = 
            ReplacePart[ReplacePart[npp, \ leftImm, \ {3, \(-1\)}], 
              rightImm, {1, 1}]; \[IndentingNewLine]\(If[
                hQ \[And] OddQ[Length[#]], 
                ir[Drop[Muddle[#], 1], Length[#] - 1], 
                ir[Muddle[#], Length[#]]] &\) /@ 
            Apply[Join, \(({RotateLeft[
                      npp\[LeftDoubleBracket]1\[RightDoubleBracket]], 
                    npp\[LeftDoubleBracket]2\[RightDoubleBracket], 
                    RotateRight[
                      npp\[LeftDoubleBracket]3\[RightDoubleBracket]]} // 
                  Transpose)\), {1}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["RandomDrift", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RandomDrift::symmetric = "\<Random drift is not allowed under the \
symmetric model\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \("Random drift is not allowed under the symmetric model"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RandomDrift::individuals = "\<RandomDrift does not apply to populations \
of individuals.\>"\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \("RandomDrift does not apply to populations of individuals."\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(RandomDrift[\[Psi] : {PopulationRepresentations[_, _] ... }, 
          n_List] := \[IndentingNewLine]MapThread[
          RandomDrift[#1, #2] &, {\[Psi], n}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(RandomDrift[\((pr : PopulationRepresentations)\)[\[Psi]_, 
            n_], \[Infinity]] := \[IndentingNewLine]pr[\[Psi], 
          n];\)\), "\[IndentingNewLine]", 
    \(\(RandomDrift[\((pr : IndividualRepresentations)\)[\[Psi]_, 
            n_], _] := \[IndentingNewLine]\((Message[
            RandomDrift::individuals]; 
          pr[\[Psi], n])\);\)\), "\[IndentingNewLine]", 
    \(\(RandomDrift[\((pr : SymmetricRepresentations)\)[\[Psi]_, 
            n_], _] := \[IndentingNewLine]\((Message[RandomDrift::symmetric]; 
          pr[\[Psi], n])\);\)\), "\[IndentingNewLine]", 
    \(\(RandomDrift[AlleleFrequencies[p_, n_], 
          ns_] := \[IndentingNewLine]Module[{nsr = 
              Max[1, Round[
                  ns]]}, \[IndentingNewLine]AlleleFrequencies[\(Last[
                    RandomMultinomial[nsr, {1 - #, #}]]/N[nsr] &\) /@ p, 
            ns]];\)\), "\[IndentingNewLine]", 
    \(\(RandomDrift[HaploidFrequencies[\[Psi]_, n_], ns_] := 
        Module[{nsr = 
              Max[1, Round[ns]]}, \[IndentingNewLine]HaploidFrequencies[
            RandomMultinomial[nsr, \[Psi]]/N[nsr], 
            ns]];\)\), "\[IndentingNewLine]", 
    \(\(RandomDrift[DiploidFrequencies[\[Psi]_, n_], 
          ns_] := \[IndentingNewLine]Module[{nsr = 
              Max[1, Round[ns]]}, \[IndentingNewLine]DiploidFrequencies[
            Partition[RandomMultinomial[nsr, Flatten[\[Psi]]], 
                Length[\[Psi]]]/N[nsr], ns]];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SelectionExact", "Subsubsection"],

Cell[BoxData[
    \(\(Options[
          SelectionExact] = {TruncationSelection \[Rule] False};\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(SelectionExact::badN = "\<New deme size `1` is greater than original \
size `2`\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(SelectionExact[\[Psi] : {PopulationRepresentations[_, _] ... }, 
          W_?\((Not[ListQ[#]] &)\), f_, 
          opts___Rule] := \[IndentingNewLine]MapIndexed[
          SelectionExact[#1, W[First[#2]], f[First[#2]], 
              opts] &, \[Psi]];\)\), "\[IndentingNewLine]", 
    \(\(SelectionExact[\[Psi] : {PopulationRepresentations[_, _] ... }, 
          W_List, f_, opts___Rule] := \[IndentingNewLine]MapIndexed[
          SelectionExact[#1, 
              W\[LeftDoubleBracket]First[#2]\[RightDoubleBracket], 
              f[First[#2]], opts] &, \[Psi]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(SelectionExact[\((pr : FrequencyRepresentations)\)[\[Psi]_, n0_], W_, 
          opts___Rule] := 
        SelectionExact[pr[\[Psi], n0], W, n0 &, 
          opts];\)\), "\[IndentingNewLine]", 
    \(\(SelectionExact[\[Psi] : {PopulationRepresentations[_, _] ... }, 
          W_?\((Not[ListQ[#]] &)\), 
          opts___Rule] := \[IndentingNewLine]MapIndexed[
          SelectionExact[#1, W[First[#2]], opts] &, \[Psi]];\)\), "\n", 
    \(\(SelectionExact[\[Psi] : {PopulationRepresentations[_, _] ... }, 
          W_List, opts___Rule] := \[IndentingNewLine]MapIndexed[
          SelectionExact[#1, 
              W\[LeftDoubleBracket]First[#2]\[RightDoubleBracket], 
              opts] &, \[Psi]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(SelectionExact[
          SymmetricNeutralHaploidFrequencies[{\[Psi]_, u_}, n0_], W_, n_, 
          opts___Rule] \
:= \[IndentingNewLine]SymmetricNeutralHaploidFrequencies[{SelectionExact[
              SymmetricHaploidFrequencies[\[Psi], n0], n], u}, 
          n];\)\), "\[IndentingNewLine]", 
    \(\(SelectionExact[
          SymmetricNeutralDiploidFrequencies[{\[Psi]_, u_}, n0_], W_, n_, 
          opts___Rule] \
:= \[IndentingNewLine]SymmetricNeutralDiploidFrequencies[{SelectionExact[
              SymmetricDiploidFrequencies[\[Psi], n0], n], u}, 
          n];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SelectionExact[AlleleFrequencies[p_, n0_], W_?\((Not[ListQ[#]] &)\), 
          f_, opts___Rule] := \[IndentingNewLine]Module[{wl = 
              W[p]}, \[IndentingNewLine]AlleleFrequencies[
            p \((1 + \((1 - p)\) 
                    wl\[LeftDoubleBracket]2\[RightDoubleBracket]\/wl\
\[LeftDoubleBracket]1\[RightDoubleBracket])\), 
            f[n0, wl\[LeftDoubleBracket]1\[RightDoubleBracket]]]];\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SelectionExact[\((fr : FrequencyRepresentations)\)[\[Psi]_, n0_], 
          W_?\((Not[ListQ[#]] &)\), f_, 
          opts___Rule] := \[IndentingNewLine]Module[{nn, ng, 
            wb}, \[IndentingNewLine]ng = 
            Switch[fr, \[IndentingNewLine]SymmetricRepresentations, \
\[IndentingNewLine]Length[\[Psi]] - 1, \[IndentingNewLine]_, 
              Log[2, Length[\[Psi]]]]; \[IndentingNewLine]nn = \[Psi]*
              FitnessTable[W, ng, NumericalModel \[Rule] fr, 
                opts]; \[IndentingNewLine]wb = Plus @@ \(Plus @@ nn\); 
          fr[nn\/wb, f[n0, wb]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SelectionExact[\((fr : FrequencyRepresentations)\)[\[Psi]_, n0_], 
          W_List, f_, 
          opts___Rule] := \[IndentingNewLine]Module[{nn, 
            wb}, \[IndentingNewLine]nn = \[Psi]*W; 
          wb = Plus @@ \(Plus @@ nn\); fr[nn\/wb, f[n0, wb]]];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
The somewhat elaborate procedure for truncation selection, below, \
is needed because many genotypes may have the same fitness.  These are chosen \
using RandomSet[], to avoid a bias for some genotypes over others induced by \
Sort[]\
\>", "Text"],

Cell[BoxData[{
    \(\(SelectionExact[HaploidIndividuals[\[Psi]_, n0_], 
          W_?\((Not[ListQ[#]] &)\), f_, 
          opts___Rule] := \[IndentingNewLine]Module[{wb = 
              MeanW[HaploidIndividuals[\[Psi], n0], W], nn, ss, tp, 
            np}, \[IndentingNewLine]nn = f[n0, wb]; \[IndentingNewLine]If[
            nn > n0, \[IndentingNewLine]Message[SelectionExact::badN, nn, 
              n0]; nn = 
              n0]; \[IndentingNewLine]If[\(TruncationSelection /. {opts}\) /. 
              Options[SelectionExact], \[IndentingNewLine]ss = \({W[#], #} \
&\) /@ \[Psi]; 
            tp = \(Sort[ss]\)\[LeftDoubleBracket]\(-nn\), 
                1\[RightDoubleBracket]; \[IndentingNewLine]np = 
              Select[ss, \((#\[LeftDoubleBracket]1\[RightDoubleBracket] > 
                      tp)\) &]; \[IndentingNewLine]HaploidIndividuals[
              Muddle[Last /@ \((np~Join~
                      RandomSet[nn - Length[np], 
                        Select[
                          ss, \((#\[LeftDoubleBracket]1\[RightDoubleBracket] == 
                                tp)\) &]])\)], 
              nn], \[IndentingNewLine]HaploidIndividuals[
              Muddle[RandomList[nn, W /@ \[Psi]\/\(n0*wb\), \[Psi], 
                  Replace \[Rule] False]], 
              nn]]];\)\), "\[IndentingNewLine]", 
    \(\(SelectionExact[DiploidIndividuals[\[Psi]_, n0_], 
          W_?\((Not[ListQ[#]] &)\), f_, 
          opts___Rule] := \[IndentingNewLine]Module[{wb = 
              MeanW[DiploidIndividuals[\[Psi], n0], W], nn, ss, tp, 
            np}, \[IndentingNewLine]nn = f[n0, wb]; \[IndentingNewLine]If[
            nn > n0, \[IndentingNewLine]Message[SelectionExact::badN, nn, 
              n0]; nn = 
              n0]; \[IndentingNewLine]If[\(TruncationSelection /. {opts}\) /. 
              Options[SelectionExact], \[IndentingNewLine]ss = \({W[#], #} \
&\) /@ \[Psi]; 
            tp = \(Sort[ss]\)\[LeftDoubleBracket]\(-nn\), 
                1\[RightDoubleBracket]; \[IndentingNewLine]np = 
              Select[ss, \((#\[LeftDoubleBracket]1\[RightDoubleBracket] > 
                      tp)\) &]; \[IndentingNewLine]DiploidIndividuals[
              Muddle[Last /@ \((np~Join~
                      RandomSet[nn - Length[np], 
                        Select[
                          ss, \((#\[LeftDoubleBracket]1\[RightDoubleBracket] == 
                                tp)\) &]])\)], 
              nn], \[IndentingNewLine]DiploidIndividuals[
              Muddle[RandomList[
                  nn, \(\((W @@ #)\) &\) /@ \[Psi]\/\(n0*wb\), \[Psi], 
                  Replace \[Rule] False]], nn]]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(SelectionExact[HaploidIndividuals[\[Psi]_, n0_], 
          W_?\((Not[ListQ[#]] &)\), 
          opts___Rule] := \[IndentingNewLine]Module[{n\[Psi] = 
              Select[\[Psi], \((Random[] < 
                      W[#])\) &]}, \[IndentingNewLine]HaploidIndividuals[
            n\[Psi], Length[n\[Psi]]]];\)\), "\[IndentingNewLine]", 
    \(\(SelectionExact[DiploidIndividuals[\[Psi]_, _], 
          W_?\((Not[ListQ[#]] &)\), 
          opts___Rule] := \[IndentingNewLine]Module[{n\[Psi] = 
              Select[\[Psi], \((Random[] < \((W @@ #)\))\) &]}, \
\[IndentingNewLine]DiploidIndividuals[n\[Psi], 
            Length[n\[Psi]]]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(SelectionExact[HaploidIndividuals[\[Psi]_, _], W_List, n_, 
          opts___Rule] := \[IndentingNewLine]Module[{ht, 
            n\[Psi]}, \[IndentingNewLine]If[
            Length[\[Psi]] = 0, \[IndentingNewLine]HaploidIndividuals[{}, 
              0], \[IndentingNewLine]ht = 
              HaploidTypes[Length[First[\[Psi]]], 
                opts]; \[IndentingNewLine]n\[Psi] = 
              Select[\[Psi], 
                Random[] < \((\(Extract[
                            W, #] &\) /@ \((First[
                              Position[
                                ht, #]] &)\))\) &]]; \
\[IndentingNewLine]HaploidIndividuals[n\[Psi], 
            Length[n\[Psi]]]];\)\), "\[IndentingNewLine]", 
    \(\(SelectionExact[DiploidIndividuals[\[Psi]_, _], W_List, n_, 
          opts___Rule] := \[IndentingNewLine]Module[{ht, 
            n\[Psi]}, \[IndentingNewLine]If[
            Length[\[Psi]] == 
              0, \[IndentingNewLine]Indeterminate, \[IndentingNewLine]ht = 
              HaploidTypes[
                Length[\[Psi]\[LeftDoubleBracket]1, 1\[RightDoubleBracket]], 
                opts]; \[IndentingNewLine]n\[Psi] = 
              Select[\[Psi], 
                Random[] < \((\(Extract[
                            W, #] &\) /@ \((\(Flatten[{Position[
                                    ht, #\[LeftDoubleBracket]1\
\[RightDoubleBracket]], 
                                  Position[
                                    ht, #\[LeftDoubleBracket]2\
\[RightDoubleBracket]]}] &\) /@ \[Psi])\))\) &]; \
\[IndentingNewLine]DiploidIndividuals[n\[Psi], 
              Length[n\[Psi]]]]];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`\(IterateExact\  - \ 
          Options\  &\)\ Messages\)], "Subsubsection"],

Cell[BoxData[
    \(\(Options[IterateExact] = {Compiled \[Rule] False, 
          MigrationOrder \[Rule] UMS, FixedEnds \[Rule] {{}, {}}, 
          DemeSize \[Rule] \((#1 &)\), 
          RandomDrift \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(IterateExact::badMigrationOrder = "\<`1` is not a valid setting for \
MigrationOrder\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`IterateExact\  - \ one\ deme\)], "Subsubsection"],

Cell[BoxData[
    \(\(IterateExact[\((pr : NonNeutralRepresentations)\)[\[Psi]_, nd_], ww_, 
          m_, opts___Rule] := 
        Module[{i, gg, \[Psi]s, f, cr, gt, dt, 
            ht, \[IndentingNewLine]iQ = 
              MatchQ[pr, 
                HaploidIndividuals], \[IndentingNewLine]cQ = \(Compiled /. \
{opts}\) /. Options[
                  IterateExact], \[IndentingNewLine]mo = \(MigrationOrder /. \
{opts}\) /. Options[
                  IterateExact], \[IndentingNewLine]fe = \(FixedEnds /. \
{opts}\) /. Options[
                  IterateExact], \[IndentingNewLine]rd = \(RandomDrift /. \
{opts}\) /. Options[IterateExact], \[IndentingNewLine]ng = 
              NumberOfGenes[pr[\[Psi], nd]], 
            spr}, \[IndentingNewLine]\[Psi]s = 
            If[fe\[LeftDoubleBracket]1\[RightDoubleBracket] === {} \[Or] 
                fe\[LeftDoubleBracket]1\[RightDoubleBracket] === {{}}, \
\[IndentingNewLine]spr = 
                Switch[pr, \[IndentingNewLine]HaploidIndividuals, 
                  HaploidFrequencies, \[IndentingNewLine]_, 
                  pr]; \[IndentingNewLine]MakePopulation[ng, 1, nd, 
                NumericalModel \[Rule] 
                  spr], \[IndentingNewLine]fe\[LeftDoubleBracket]1\
\[RightDoubleBracket]]; \[IndentingNewLine]If[
            cQ, \[IndentingNewLine]f = \(DemeSize /. {opts}\) /. 
                Options[IterateExact]; \[IndentingNewLine]f = 
              f /. {\((\((nn_?NumberQ)\) &)\) \[Rule] {nn, 0, 1, 
                      0}, \((#1 &)\) \[Rule] {1, 0, 0, 
                      0}, \[IndentingNewLine]PowerF[
                      r_, \[Beta]_, \[Gamma]_] \[Rule] {r, \[Beta], \[Gamma], 
                      0}, ExponentialF[
                      r_, \[Beta]_, \[Lambda]_] \[Rule] {r, \[Beta], 
                      0, \[Lambda]}, \[IndentingNewLine]\((PowerF | 
                          ExponentialF)\)[
                      r_, \[Beta]_, \[Gamma]_, \[Lambda]_] \[Rule] {r, \
\[Beta], \[Gamma], \[Lambda]}, 
                  ExponentialF[r_, \[Beta]_, \[Lambda]_] \[Rule] {r, \[Beta], 
                      0, \[Lambda]}}; \[IndentingNewLine]cr = 
              If[pr === 
                  AlleleFrequencies, \[IndentingNewLine]\(IterateCompiled[ww, 
                    oneDeme, mo]\)[\[Psi], nd, 
                  m, \[Psi]s\[LeftDoubleBracket]1\[RightDoubleBracket], \
\[Psi]s\[LeftDoubleBracket]2\[RightDoubleBracket], f, 
                  rd], \[IndentingNewLine]gt = 
                  GameteTable[ng, ww, NumericalModel \[Rule] pr, 
                    opts]; \[IndentingNewLine]If[
                  iQ, \[IndentingNewLine]ht = 
                    HaploidTypes[
                      Log[2, Length[\[Psi]s\[LeftDoubleBracket]1\
\[RightDoubleBracket]]], opts]; 
                  Flatten[Outer[List, ht, ht, 1], 
                    1]; \(IterateCompiled[oneDeme, ind, mo]\)[\[Psi], nd, gt, 
                    dt, m, \[Psi]s\[LeftDoubleBracket]1\[RightDoubleBracket], \
\[Psi]s\[LeftDoubleBracket]2\[RightDoubleBracket], 
                    f], \(IterateCompiled[oneDeme, mo]\)[\[Psi], nd, gt, 
                    m, \[Psi]s\[LeftDoubleBracket]1\[RightDoubleBracket], \
\[Psi]s\[LeftDoubleBracket]2\[RightDoubleBracket], f, 
                    rd]]]; \[IndentingNewLine]pr[Drop[cr, \(-1\)], 
              Last[cr]], \[IndentingNewLine]\ 
            Switch[mo, \[IndentingNewLine]UMS, \[IndentingNewLine]NewGametes[
                MigrateExact[MakeDiploid[pr[\[Psi], nd]], 
                  MakeDiploid[\[Psi]s], m], ww, 
                opts], \[IndentingNewLine]MUS, \[IndentingNewLine]NewGametes[
                MakeDiploid[MigrateExact[pr[\[Psi], nd], \[Psi]s, m]], ww, 
                opts], \[IndentingNewLine]USM, \[IndentingNewLine]\[Psi]2 = 
                If[iQ \[And] OddQ[nd], 
                  MakeDiploid[pr[Drop[\[Psi], 1], nd - 1]], 
                  MakeDiploid[
                    pr[\[Psi], nd]]]; \[IndentingNewLine]MigrateExact[
                NewGametes[\[Psi]2, ww, opts], \[Psi]s, 
                m], \[IndentingNewLine]\ _, 
              Message[IterateExact::badMigrationOrder, mo]; 
              pr[\[Psi], nd]]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`IterateExact\  - \ cline\)], "Subsubsection"],

Cell[BoxData[
    \(\(IterateExact[\[Psi] : {NonNeutralRepresentations[_, _] .. }, ww_, m_, 
          opts___] := 
        Module[{i, gg, nd = Length[\[Psi]], cr, gt, \[Psi]0, \[Psi]1, n0, n1, 
            pr = Head[\[Psi]\[LeftDoubleBracket]1\[RightDoubleBracket]], 
            cQ = \(Compiled /. {opts}\) /. 
                Options[
                  IterateExact], \[IndentingNewLine]mo = \(MigrationOrder /. \
{opts}\) /. Options[
                  IterateExact], \[IndentingNewLine]fe = \(FixedEnds /. \
{opts}\) /. Options[
                  IterateExact], \[IndentingNewLine]rd = \(RandomDrift /. \
{opts}\) /. Options[IterateExact], \[IndentingNewLine]\[Phi], nl, 
            dsrl, \[IndentingNewLine]ng = 
              NumberOfGenes[\[Psi]]}, \[IndentingNewLine]\ \ \ If[
            cQ, \[IndentingNewLine]\[Phi] = First /@ \[Psi]; 
            nl = Last /@ \[Psi]; \[IndentingNewLine]f = \(DemeSize /. \
{opts}\) /. Options[IterateExact]; 
            f = f /. {\((\((nn_?NumberQ)\) &)\) \[Rule] 
                    Array[{nn, 0, 1, 0} &, nd], \((#1 &)\) \[Rule] 
                    Array[{1, 0, 0, 0} &, nd], \[IndentingNewLine]PowerF[
                      r_, \[Beta]_, \[Gamma]_] \[Rule] 
                    Array[{r, \[Beta], \[Gamma], 0} &, 
                      nd], \[IndentingNewLine]ExponentialF[
                      r_, \[Beta]_, \[Lambda]_] \[Rule] 
                    Array[{r, \[Beta], 0, \[Lambda]} &, 
                      nd], \[IndentingNewLine]\((PowerF | ExponentialF)\)[
                      r_, \[Beta]_, \[Gamma]_, \[Lambda]_] \[Rule] 
                    Array[{r, \[Beta], \[Gamma], \[Lambda]} &, nd], 
                  ExponentialF[r_, \[Beta]_, \[Lambda]_] \[Rule] 
                    Array[{r, \[Beta], 0, \[Lambda]} &, 
                      nd]}; \[IndentingNewLine]If[
              fe\[LeftDoubleBracket]1\[RightDoubleBracket] === {}, \[Psi]0 = \
{}; n0 = 0, \[Psi]0 = fe\[LeftDoubleBracket]1, 1\[RightDoubleBracket]; 
              n0 = fe\[LeftDoubleBracket]1, 
                  2\[RightDoubleBracket]]; \[IndentingNewLine]If[
              fe\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] === {}, \
\[Psi]1 = {}; 
              n1 = 0, \[Psi]1 = 
                fe\[LeftDoubleBracket]\(-1\), 1\[RightDoubleBracket]; 
              n1 = fe\[LeftDoubleBracket]\(-1\), 
                  2\[RightDoubleBracket]]; \[IndentingNewLine]cr = 
              If[pr === 
                  AlleleFrequencies, \[IndentingNewLine]\(IterateCompiled[ww, 
                    cline, mo]\)[\[Phi], nl, m, \[Psi]0, \[Psi]1, n0, n1, f, 
                  rd], \[IndentingNewLine]gt = 
                  Table[GameteTable[ng, ww[i], 
                      NumericalModel \[Rule] 
                        Head[\[Psi]\[LeftDoubleBracket]1\[RightDoubleBracket]]\
, opts], {i, nd}]; \[IndentingNewLine]\(IterateCompiled[cline, mo]\)[\[Phi], 
                  nl, gt, m, \[Psi]0, \[Psi]1, n0, n1, f, 
                  rd]]; \[IndentingNewLine]\(pr[Drop[#, \(-1\)], 
                  Last[#]] &\) /@ 
              cr, \[IndentingNewLine]dsrl[
                j_] := {\((DemeSize \[Rule] 
                      f_?\((Not[
                              ListQ[#]] &)\))\) \[RuleDelayed] \((DemeSize \
\[Rule] f[j])\), \((DemeSize \[Rule] 
                      f_List)\) \[RuleDelayed] \((DemeSize \[Rule] 
                      f\[LeftDoubleBracket]j\[RightDoubleBracket])\)}; \
\[IndentingNewLine]Switch[
              mo, \[IndentingNewLine]UMS, \[IndentingNewLine]gg = 
                MigrateExact[MakeDiploid[\[Psi]], m, 
                  FixedEnds \[Rule] \((MakeDiploid /@ fe)\)]; 
              Table[\(NewGametes[
                      gg\[LeftDoubleBracket]i\[RightDoubleBracket], 
                      ww[i], ##] &\) @@ \(({opts} /. dsrl[i])\), {i, 
                  nd}], \[IndentingNewLine]MUS, \[IndentingNewLine]gg = 
                MakeDiploid[MigrateExact[\[Psi], m, FixedEnds \[Rule] fe]]; 
              Table[\(NewGametes[
                      gg\[LeftDoubleBracket]i\[RightDoubleBracket], 
                      ww[i], ##] &\) @@ \(({opts} /. dsrl[i])\), {i, 
                  nd}], \[IndentingNewLine]USM, \[IndentingNewLine]\ 
              gg = MakeDiploid[\[Psi]]; \[IndentingNewLine]MigrateExact[
                Table[\(NewGametes[
                        gg\[LeftDoubleBracket]i\[RightDoubleBracket], 
                        ww[i], ##] &\) @@ \(({opts} /. dsrl[i])\), {i, nd}], 
                m, FixedEnds \[Rule] 
                  fe], \[IndentingNewLine]_, \[IndentingNewLine]Message[
                IterateExact::badMigrationOrder, mo]; 
              pr[\[Psi], n]]]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`IterateExact\  - \ one\ deme, \ compiled\)], "Subsubsection"],

Cell[BoxData[
    \(\(IterateCompiled[oneDeme, UMS] = 
        Compile[{{\[Psi], _Real, 1}, n, {gt, _Real, 3}, 
            m, {\[Psi]s, _Real, 1}, 
            ns, {F, _Real, 1}, {rd, True | False}}, \n\t
          Module[{tt, wb, nm, rnm}, \n\tnm = m\ ns + \((1 - m)\) n; 
            tt = \((Plus @@ \(Plus @@ \((gt*\((n \((1 - m)\) 
                                Outer[Times, \[Psi], \[Psi]] + 
                              ns\ m\ Outer[
                                  Times, \[Psi]s, \[Psi]s])\))\)\))\)/nm; \n\t
            wb = Plus @@ tt; \[IndentingNewLine]nm = 
              F\[LeftDoubleBracket]1\[RightDoubleBracket]\ \(nm\^\(1 - 
                      F\[LeftDoubleBracket]3\[RightDoubleBracket]\)\) \(wb\^F\
\[LeftDoubleBracket]2\[RightDoubleBracket]\) 
                Exp[\(-\ 
                      nm\)\ F\[LeftDoubleBracket]4\[RightDoubleBracket]]; \
\[IndentingNewLine]Append[
              If[rd, \[IndentingNewLine]rnm = 
                  Max[1, Round[nm]]; \[IndentingNewLine]RandomMultinomial[
                    rnm, tt\/wb]/rnm, \[IndentingNewLine]tt\/wb], 
              nm]], \n\t\t{{wb, _Real}, {nm, _Real}, {rnm, _Integer}, {tt, \
_Real, 1}, {RandomMultinomial[_, _], _Integer, 1}}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(IterateCompiled[oneDeme, MUS] = 
        Compile[{{\[Psi], _Real, 1}, n, {gt, _Real, 3}, 
            m, {\[Psi]s, _Real, 1}, 
            ns, {F, _Real, 1}, {rd, 
              True | False}}, \[IndentingNewLine]Module[{tt, wb, nm, 
              rnm}, \[IndentingNewLine]nm = 
              m\ ns + \((1 - m)\) 
                  n; \[IndentingNewLine]tt = \((n \((1 - m)\) \[Psi] + 
                    ns\ m\ \[Psi]s)\)/nm; \[IndentingNewLine]tt = 
              Plus @@ \(Plus @@ \((gt*
                      Outer[Times, tt, tt])\)\); \[IndentingNewLine]wb = 
              Plus @@ tt; \[IndentingNewLine]nm = 
              F\[LeftDoubleBracket]1\[RightDoubleBracket]\ \(nm\^\(1 - 
                      F\[LeftDoubleBracket]3\[RightDoubleBracket]\)\) \(wb\^F\
\[LeftDoubleBracket]2\[RightDoubleBracket]\) 
                Exp[\(-\ 
                      nm\)\ F\[LeftDoubleBracket]4\[RightDoubleBracket]]; \
\[IndentingNewLine]Append[
              If[rd, \[IndentingNewLine]rnm = 
                  Max[1, Round[nm]]; \[IndentingNewLine]RandomMultinomial[
                    rnm, tt\/wb]/rnm, \[IndentingNewLine]tt\/wb], 
              nm]], \n\t\t{{wb, _Real}, {nm, _Real}, {rnm, _Integer}, {tt, \
_Real, 1}, {RandomMultinomial[_, _], _Integer, 1}}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(IterateCompiled[oneDeme, USM] = 
        Compile[{{\[Psi], _Real, 1}, n, {gt, _Real, 3}, 
            m, {\[Psi]s, _Real, 1}, 
            ns, {F, _Real, 1}, {rd, 
              True | False}}, \[IndentingNewLine]Module[{tt, wb, nn, nnn, 
              rnm}, \[IndentingNewLine]tt = 
              Plus @@ \(Plus @@ \((gt*
                      Outer[Times, \[Psi], \[Psi]])\)\); \
\[IndentingNewLine]wb = Plus @@ tt; 
            nn = F\[LeftDoubleBracket]1\[RightDoubleBracket]\ \(n\^\(1 - 
                      F\[LeftDoubleBracket]3\[RightDoubleBracket]\)\) \(wb\^F\
\[LeftDoubleBracket]2\[RightDoubleBracket]\) 
                Exp[\(-\ 
                      n\)\ F\[LeftDoubleBracket]4\[RightDoubleBracket]]; \
\[IndentingNewLine]nnn = \((1 - m)\) nn + ns\ m; \[IndentingNewLine]Append[
              If[rd, \[IndentingNewLine]rnm = 
                  Max[1, Round[nnn]]; \[IndentingNewLine]RandomMultinomial[
                    rnm, \(nn \((1 - m)\) tt\/wb + ns\ m\ \[Psi]s\)\/nnn]/
                  rnm, \[IndentingNewLine]\(nn \((1 - m)\) tt\/wb + ns\ m\ \
\[Psi]s\)\/nnn], 
              nnn]], \[IndentingNewLine]{{wb, _Real}, {nn, _Real}, {rnm, \
_Integer}, {nnn, _Real}, {tt, _Real, 1}, {RandomMultinomial[_, _], _Integer, 
              1}}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`\(\(IterateExact\  - \ 
      one\ deme\)\(,\)\(\ \)\(compiled\)\(,\)\(\ \)\(individuals\)\(\ \)\( \
(*\ UNFINISHED\ *) \)\)\)], "Subsubsection"],

Cell[BoxData[
    \(\(IterateCompiled[oneDeme, ind, UMS] = 
        Compile[{{\[Psi], _Integer, 2}, {n, _Integer}, {gt, _Real, 
              3}, {dt, _Integer, 3}, {Nm, _Integer}, {\[Psi]s, _Real, 
              2}, {ns, _Integer}, {F, _Real, 1}}, \n\t
          Module[{nStay, np, nd = Quotient[n, 2], 
              migrants}, \[IndentingNewLine]If[OddQ[n], 
              Message[MakeDiploid::odd, n]]; \n\t
            np = Partition[\[Psi], 2]; \[IndentingNewLine]If[
              Nm > 0, \[IndentingNewLine]migrants = \(f\[Psi]s\
\[LeftDoubleBracket]#\[RightDoubleBracket] &\) /@ 
                  RandomListCompiledReplace[Nm, 
                    Flatten[\[Psi]s]]; \[IndentingNewLine]nStay = 
                Random[BinomialDistribution[
                    n, \((1 - Nm\/n)\)]]; \[IndentingNewLine]If[
                nStay < nd, \[IndentingNewLine]np = 
                  Extract[np, 
                    List /@ RandomSetCompiled[nStay, 
                        nd]]]; \[IndentingNewLine]np = 
                Sort[Join[migrants\ , np], 
                  Random[] < 1\/2 &]]; \[IndentingNewLine] (*\ 
              need\ to\ implement\ a\ compiled\ version\ of\ NewGametes\ here\
\ *) ], \n\t\t{{nStay, _Integer}, {nd, _Integer}, {np, _Integer, 
              3}, {migrants, _Integer, 
              3}, {Random[
                BinomialDistribution[_, _]], _Integer}, \
{RandomListCompiledReplace[_, _], _Integer, 
              1}, {RandomSetCompiled[_, _], _Integer, 1}}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(NewGametes[
      MigrateExact[MakeDiploid[pr[\[Psi], nd]], MakeDiploid[\[Psi]s], m], ww, 
      opts]\)], "Input"],

Cell[BoxData[
    \(Module[{f = \(DemeSize /. {opts}\) /. 
            Options[NewGametes], \[IndentingNewLine]wb = 
          MeanW[\[Phi], W, opts], wl, newN, rl, ht, tp, np, 
        ss, \[IndentingNewLine]ts = \(TruncationSelection /. {opts}\) /. 
            Options[NewGametes], \[IndentingNewLine]mut = \(Mutation /. \
{opts}\) /. Options[NewGametes]}, \[IndentingNewLine]wl = 
        If[ListQ[W], \[IndentingNewLine]ht = 
            HaploidTypes[
              Length[\[Psi]\[LeftDoubleBracket]1, 1\[RightDoubleBracket]], 
              opts]; \[IndentingNewLine]\((\(Extract[
                  W, #] &\) /@ \((\(Flatten[{Position[
                          ht, #\[LeftDoubleBracket]1\[RightDoubleBracket]], 
                        Position[
                          ht, #\[LeftDoubleBracket]2\[RightDoubleBracket]]}] \
&\) /@ \[Psi])\))\), \[IndentingNewLine]\(W @@ # &\) /@ \[Psi]]; \
\[IndentingNewLine]f = 
        f /. {r_, \[Beta]_, \[Gamma]_, \[Lambda]_} \[Rule] 
            ExponentialF[
              r, \[Beta], \[Gamma], \[Lambda]]; \[IndentingNewLine]newN = 
        2  Round[f[n, wb]]; \[IndentingNewLine]rl = 
        If[ts, \[IndentingNewLine]If[
            newN > n, \[IndentingNewLine]Message[NewGametes::badN, newN, n]; 
            newN = n]; \[IndentingNewLine]ss = 
            Transpose[{wl, Range[n]}]; \[IndentingNewLine]tp = \(Sort[
                wl]\)\[LeftDoubleBracket]\(-newN\)\[RightDoubleBracket]; 
          np = Select[
              ss, \((#\[LeftDoubleBracket]1\[RightDoubleBracket] > 
                    tp)\) &]; \[IndentingNewLine]np = 
            Join[np, 
              RandomSet[newN - Length[np], 
                Select[ss, \((#\[LeftDoubleBracket]1\[RightDoubleBracket] == 
                        tp)\) &]]]; \[IndentingNewLine]Muddle[
            Last /@ np], \[IndentingNewLine]RandomList[newN, 
            wl\/Plus @@ wl]]; \[IndentingNewLine]If[
        mut === None, \[IndentingNewLine]HaploidIndividuals[\(RandomFamily[\
\[Psi]\[LeftDoubleBracket]#\[RightDoubleBracket], opts] &\) /@ rl, 
          newN], \[IndentingNewLine]HaploidIndividuals[\(\(MutateCompiled[
                  HaploidIndividuals]\)[
                RandomFamily[\[Psi]\[LeftDoubleBracket]#\[RightDoubleBracket],\
 opts], ConstructMutateList[mut, 
                  Length[\[Psi]\[LeftDoubleBracket]1, 
                      1\[RightDoubleBracket]]]] &\) /@ rl, newN]]]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`IterateExact\  - \ one\ deme, \ compiled, \ 
    allele\ frequencies\)], "Subsubsection"],

Cell[BoxData[
    \(\(IterateCompiled[ww_, oneDeme, 
          UMS] := \[IndentingNewLine]Module[{fw}, \[IndentingNewLine]fw[p_] := 
            Flatten[ww[p]]; \[IndentingNewLine]IterateCompiled[ww, oneDeme, 
              UMS] = Compile[{{p, _Real, 1}, n, m, {ps, _Real, 1}, 
                ns, {F, _Real, 1}, {rd, True | False}}, \n\t
              Module[{wv, np, wb, nm, rnm}, \[IndentingNewLine]nm = 
                  m\ ns + \((1 - m)\) 
                      n; \[IndentingNewLine]np = \(n \((1 - m)\) p + ns\ \
m\ \ ps\)\/nm; \[IndentingNewLine]wv = fw[np]; 
                wb = wv\[LeftDoubleBracket]1\[RightDoubleBracket]; \
\[IndentingNewLine]np = 
                  np \((1 + \((1 - np)\) 
                          Drop[wv, 1]\/wb)\); \[IndentingNewLine]nm = 
                  F\[LeftDoubleBracket]1\[RightDoubleBracket]\ \(nm\^\(1 - 
                          F\[LeftDoubleBracket]3\[RightDoubleBracket]\)\) \
\(wb\^F\[LeftDoubleBracket]2\[RightDoubleBracket]\) 
                    Exp[\(-\ 
                          nm\)\ F\[LeftDoubleBracket]4\[RightDoubleBracket]]; \
\[IndentingNewLine]Append[
                  If[rd, \[IndentingNewLine]rnm = 
                      Max[1, Round[
                          nm]]; \[IndentingNewLine]\((\(First[
                              RandomMultinomial[rnm, {#, 1 - #}]] &\) /@ 
                          np)\)/rnm, \[IndentingNewLine]np], \
\[IndentingNewLine]nm]], \[IndentingNewLine]{{wv, _Real, 1}, {np, _Real, 
                  1}, {wb, _Real}, {nm, _Real}, {rnm, _Integer}, \
{RandomMultinomial[_, _], _Integer, 1}, {fw[_], _Real, 1}}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(IterateCompiled[ww_, oneDeme, MUS] := 
        IterateCompiled[ww, oneDeme, UMS];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(IterateCompiled[ww_, oneDeme, 
          USM] := \[IndentingNewLine]Module[{fw}, \[IndentingNewLine]fw[p_] := 
            Flatten[ww[p]]; \[IndentingNewLine]IterateCompiled[ww, oneDeme, 
              USM] = Compile[{{p, _Real, 1}, n, m, {ps, _Real, 1}, 
                ns, {F, _Real, 1}, {rd, 
                  True | False}}, \[IndentingNewLine]Module[{np, wb, nn, nnn, 
                  rnm, wv}, \[IndentingNewLine]wv = fw[p]; 
                wb = wv\[LeftDoubleBracket]1\[RightDoubleBracket]; \
\[IndentingNewLine]np = 
                  p \((1 + \((1 - p)\) 
                          Drop[wv, 1]\/wb)\); \[IndentingNewLine]nn = 
                  F\[LeftDoubleBracket]1\[RightDoubleBracket]\ \(n\^\(1 - 
                          F\[LeftDoubleBracket]3\[RightDoubleBracket]\)\) \
\(wb\^F\[LeftDoubleBracket]2\[RightDoubleBracket]\) 
                    Exp[\(-\ 
                          n\)\ F\[LeftDoubleBracket]4\[RightDoubleBracket]]; \
\[IndentingNewLine]nnn = \((1 - m)\) nn + ns\ m; \[IndentingNewLine]Append[
                  If[rd, \[IndentingNewLine]rnm = 
                      Max[1, Round[
                          nnn]]; \[IndentingNewLine]\((\(First[
                              RandomMultinomial[
                                rnm, {#, 1 - #}]] &\) /@ \(\(nn \((1 - m)\) 
                                  np + ns\ m\ ps\)\/nnn\))\)/
                      rnm, \[IndentingNewLine]\((nn \((1 - m)\) np + 
                          ns\ m\ ps)\)/nnn], 
                  nnn]], \[IndentingNewLine]{{wb, _Real}, {wv, _Real, 
                  1}, {nn, _Real}, {rnm, _Integer}, {nnn, _Real}, {np, _Real, 
                  1}, {RandomMultinomial[_, _], _Integer, 1}}]];\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`IterateExact\  - \ cline, \ \ compiled\)], "Subsubsection"],

Cell[BoxData[
    \(\(IterateCompiled[cline, UMS] = 
        Compile[{{\[Psi], _Real, 2}, {nl, _Real, 1}, {gt, _Real, 4}, 
            m, {fe0, _Real, 1}, {fe1, _Real, 1}, n0, 
            n1, {F, _Real, 2}, {rd, True | False}}, 
          Module[{\[Phi], n\[Phi], nn, tt, i, nm, wb, rnm, 
              nnm}, \[IndentingNewLine]\[Phi] = \(Outer[
                    Times, #, #] &\) /@ \[Psi]; \[IndentingNewLine]\[Phi] = 
              Prepend[Append[\[Phi], \[IndentingNewLine]If[Length[fe1] == 0, 
                    Last[\[Phi]], Outer[Times, fe1, fe1]]], 
                If[Length[fe0] == 0, First[\[Phi]], Outer[Times, fe0, fe0]]]; 
            nn = Prepend[
                Append[nl, \[IndentingNewLine]If[Length[fe1] == 0, Last[nl], 
                    n1]], If[Length[fe0] == 0, First[nl], n0]]; 
            n\[Phi] = nn*\[Phi]; \[IndentingNewLine]n\[Phi] = 
              Drop[Drop[\((1 - m)\) 
                      n\[Phi] + \(m\/2\) \((RotateLeft[n\[Phi]] + 
                          RotateRight[n\[Phi]])\), 
                  1], \(-1\)]; \ \[IndentingNewLine]nm = 
              Drop[Drop[\((1 - m)\) 
                      nn + \(m\/2\) \((RotateLeft[nn] + RotateRight[nn])\), 
                  1], \(-1\)]; 
            Table[tt = \((Plus @@ \(Plus @@ \((gt\[LeftDoubleBracket]
                              i\[RightDoubleBracket]*
                            n\[Phi]\[LeftDoubleBracket]
                              i\[RightDoubleBracket])\)\))\)/
                  nm\[LeftDoubleBracket]i\[RightDoubleBracket]; 
              wb = Plus @@ tt; \[IndentingNewLine]nnm = 
                F\[LeftDoubleBracket]i, 
                    1\[RightDoubleBracket]\ \ \(nm\[LeftDoubleBracket]
                        i\[RightDoubleBracket]\^\(1 - 
                        F\[LeftDoubleBracket]i, 
                          3\[RightDoubleBracket]\)\) \(wb\^F\
\[LeftDoubleBracket]i, 2\[RightDoubleBracket]\) 
                  Exp[\(-\ 
                        nm\[LeftDoubleBracket]
                          i\[RightDoubleBracket]\)\ F\[LeftDoubleBracket]i, 
                        4\[RightDoubleBracket]]; 
              rnm = Max[1, Round[nnm]]; \[IndentingNewLine]Append[
                If[rd, RandomMultinomial[rnm, tt\/wb]/rnm, tt\/wb], nnm], {i, 
                Length[\[Psi]]}]], \n\t\t{{tt, _Real, 1}, {nm, _Real, 
              1}, {wb, _Real}, {nn, _Real, 1}, {\[Phi], _Real, 
              3}, {n\[Phi], _Real, 
              3}, {i, _Integer}, {RandomMultinomial[_, _], _Integer, 
              1}, {rnm, _Integer}, {nnm, _Real}}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(IterateCompiled[cline, MUS] = 
        Compile[{{\[Psi], _Real, 2}, {nl, _Real, 1}, {gt, _Real, 4}, 
            m, {fe0, _Real, 1}, {fe1, _Real, 1}, n0, 
            n1, {F, _Real, 2}, {rd, True | False}}, 
          Module[{\[Phi], y, ny, nn, nm, nnm, rnm, tt, 
              wb}, \((y = 
                Prepend[
                  Append[\[Psi], \[IndentingNewLine]If[Length[fe1] == 0, 
                      Last[\[Psi]], fe1]], \[IndentingNewLine]If[
                    Length[fe0] == 0, First[\[Psi]], 
                    fe0]]; \[IndentingNewLine]nn = 
                Prepend[
                  Append[nl, \[IndentingNewLine]If[Length[fe1] == 0, 
                      Last[nl], n1]], \[IndentingNewLine]If[Length[fe0] == 0, 
                    First[nl], n0]]; \[IndentingNewLine]ny = 
                nn*y; \[IndentingNewLine]ny = 
                Drop[Drop[\((1 - m)\) 
                        ny + \(m\/2\) \((RotateLeft[ny] + RotateRight[ny])\), 
                    1], \(-1\)]; \ 
              nm = Drop[
                  Drop[\((1 - m)\) 
                        nn + \(m\/2\) \((RotateLeft[nn] + RotateRight[nn])\), 
                    1], \(-1\)]; \ \[Phi] = \(Outer[
                      Times, #, #] &\) /@ \((ny\/nm)\); \
\[IndentingNewLine]Table[
                tt = Plus @@ \(Plus @@ \((gt\[LeftDoubleBracket]
                            i\[RightDoubleBracket]*\[Phi]\[LeftDoubleBracket]
                            i\[RightDoubleBracket])\)\); 
                wb = Plus @@ tt; \[IndentingNewLine]nnm = 
                  F\[LeftDoubleBracket]i, 
                      1\[RightDoubleBracket]\ \ \(wb\^F\[LeftDoubleBracket]i, 
                          2\[RightDoubleBracket]\) \(nm\[LeftDoubleBracket]
                          i\[RightDoubleBracket]\^\(1 - 
                          F\[LeftDoubleBracket]i, 3\[RightDoubleBracket]\)\) 
                    Exp[\(-\ 
                          nm\[LeftDoubleBracket]
                            i\[RightDoubleBracket]\)\ F\[LeftDoubleBracket]i, 
                          4\[RightDoubleBracket]]; \[IndentingNewLine]rnm = 
                  Max[1, Round[nnm]]; \[IndentingNewLine]Append[
                  If[rd, RandomMultinomial[rnm, tt\/wb]/rnm, tt\/wb], 
                  nnm], {i, Length[\[Psi]]}])\)], {{nn, _Real, 
              1}, {nm, _Real, 1}, {wb, _Real}, {tt, _Real, 1}, {y, _Real, 
              2}, {ny, _Real, 2}, {\[Phi], _Real, 
              3}, {i, _Integer}, {RandomMultinomial[_, _], _Integer, 
              1}, {rnm, _Integer}, {nnm, _Real}}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(IterateCompiled[cline, USM] = 
        Compile[{{\[Psi], _Real, 2}, {nl, _Real, 1}, {gt, _Real, 4}, 
            m, {fe0, _Real, 1}, {fe1, _Real, 1}, n0, 
            n1, {F, _Real, 2}, {rd, True | False}}, 
          Module[{\[Phi], n\[Phi], nn, nm, rnm, wb, ny, y, y0, y1, tt, 
              nd = Length[\[Psi]], 
              newy}, \((\[Phi] = \(Outer[
                      Times, #, #] &\) /@ \[Psi]; \[IndentingNewLine]y = 
                Table[Plus @@ \(Plus @@ \((gt\[LeftDoubleBracket]
                            i\[RightDoubleBracket]*\[Phi]\[LeftDoubleBracket]
                            i\[RightDoubleBracket])\)\), {i, nd}]; 
              nn = Table[
                  wb = Plus @@ y\[LeftDoubleBracket]i\[RightDoubleBracket]; 
                  F\[LeftDoubleBracket]i, 
                      1\[RightDoubleBracket]\ \ \(nl\[LeftDoubleBracket]
                          i\[RightDoubleBracket]\^\(1 - 
                          F\[LeftDoubleBracket]i, 
                            3\[RightDoubleBracket]\)\) \(wb\^F\
\[LeftDoubleBracket]i, 2\[RightDoubleBracket]\) 
                    Exp[\(-\ 
                          nl\[LeftDoubleBracket]
                            i\[RightDoubleBracket]\)\ F\[LeftDoubleBracket]i, 
                          4\[RightDoubleBracket]], {i, 
                    nd}]; \[IndentingNewLine]y = 
                Table[If[
                    rd, \[IndentingNewLine]rnm = 
                      Max[1, Round[
                          nn\[LeftDoubleBracket]
                            i\[RightDoubleBracket]]]; \
\[IndentingNewLine]RandomMultinomial[rnm, 
                        y\[LeftDoubleBracket]i\[RightDoubleBracket]\/Plus @@ \
y\[LeftDoubleBracket]i\[RightDoubleBracket]]/
                      rnm, \[IndentingNewLine]y\[LeftDoubleBracket]i\
\[RightDoubleBracket]\/Plus @@ y\[LeftDoubleBracket]i\[RightDoubleBracket]], \
{i, nd}]; \[IndentingNewLine]newy = 
                Prepend[Append[y, If[Length[fe1] == 0, Last[y], fe1]], 
                  If[Length[fe0] == 0, First[y], 
                    fe0]]; \[IndentingNewLine]nm = 
                Prepend[Append[nn, If[Length[fe1] == 0, Last[nn], n1]], 
                  If[Length[fe0] == 0, First[nn], 
                    n0]]; \[IndentingNewLine]ny = 
                newy*nm; \[IndentingNewLine]nm = 
                Drop[Drop[\((1 - m)\) 
                        nm + \(m\/2\) \((RotateLeft[nm] + RotateRight[nm])\), 
                    1], \(-1\)]; \[IndentingNewLine]y = 
                Drop[Drop[\((1 - m)\) 
                          ny + \(m\/2\) \((RotateLeft[ny] + 
                              RotateRight[ny])\), 1], \(-1\)]/
                  nm; \[IndentingNewLine]Table[
                Append[y\[LeftDoubleBracket]i\[RightDoubleBracket], 
                  nm\[LeftDoubleBracket]i\[RightDoubleBracket]], {i, 
                  nd}])\)], \[IndentingNewLine]{{nn, _Real, 1}, {nm, _Real, 
              1}, {rnm, _Integer}, {wb, _Real}, {y, _Real, 2}, {newy, _Real, 
              2}, {ny, _Real, 2}, {tt, _Real, 1}, {\[Phi], _Real, 
              3}, {n\[Phi], _Real, 
              3}, {i, _Integer}, {RandomMultinomial[_, _], _Integer, 
              1}, {rnm, _Integer}, {nnm, _Real}}];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`IterateExact\  - \ cline, \ \ compiled, \ 
    allele\ frequencies\)], "Subsubsection"],

Cell[BoxData[
    \(\(IterateCompiled[ww_, cline, UMS] := 
        Module[{fw}, \[IndentingNewLine]fw[p_, d_] := 
            Flatten[\(ww[d]\)[p]]; \[IndentingNewLine]IterateCompiled[ww, 
              cline, UMS] = 
            Compile[{{\[Psi], _Real, 2}, {nl, _Real, 1}, 
                m, {fe0, _Real, 1}, {fe1, _Real, 1}, n0, 
                n1, {F, _Real, 2}, {rd, True | False}}, 
              Module[{n\[Phi], nn, np, tt, i, nm, wb, rnm, nnm, 
                  wv, \[Psi]n}, \[IndentingNewLine]\[Psi]n = 
                  Prepend[
                    Append[\[Psi], \[IndentingNewLine]If[Length[fe1] == 0, 
                        Last[\[Psi]], fe1]], 
                    If[Length[fe0] == 0, First[\[Psi]], fe0]]; 
                nn = Prepend[
                    Append[nl, \[IndentingNewLine]If[Length[fe1] == 0, 
                        Last[nl], n1]], If[Length[fe0] == 0, First[nl], n0]]; 
                n\[Phi] = nn*\[Psi]n; \[IndentingNewLine]n\[Phi] = 
                  Drop[Drop[\((1 - m)\) 
                          n\[Phi] + \(m\/2\) \((RotateLeft[n\[Phi]] + 
                              RotateRight[n\[Phi]])\), 
                      1], \(-1\)]; \ \[IndentingNewLine]nm = 
                  Drop[Drop[\((1 - m)\) 
                          nn + \(m\/2\) \((RotateLeft[nn] + 
                              RotateRight[nn])\), 1], \(-1\)]; 
                Table[np = 
                    n\[Phi]\[LeftDoubleBracket]i\[RightDoubleBracket]\/nm\
\[LeftDoubleBracket]i\[RightDoubleBracket]; wv = fw[np, i]; 
                  wb = wv\[LeftDoubleBracket]1\[RightDoubleBracket]; \
\[IndentingNewLine]np = 
                    np \((1 + \((1 - np)\) 
                            Drop[wv, 1]\/wb)\); \[IndentingNewLine]nnm = 
                    F\[LeftDoubleBracket]i, 
                        1\[RightDoubleBracket]\ \ \(nm\[LeftDoubleBracket]
                            i\[RightDoubleBracket]\^\(1 - 
                            F\[LeftDoubleBracket]i, 
                              3\[RightDoubleBracket]\)\) \(wb\^F\
\[LeftDoubleBracket]i, 2\[RightDoubleBracket]\) 
                      Exp[\(-\ 
                            nm\[LeftDoubleBracket]
                              i\[RightDoubleBracket]\)\ F\[LeftDoubleBracket]
                            i, 4\[RightDoubleBracket]]; \
\[IndentingNewLine]Append[
                    If[rd, \[IndentingNewLine]rnm = 
                        Max[1, 
                          Round[nnm]]; \[IndentingNewLine]\((\(First[
                                RandomMultinomial[rnm, {#, 1 - #}]] &\) /@ 
                            np)\)/rnm, \[IndentingNewLine]np], nnm], {i, 
                    Length[\[Psi]]}]], \n\t\t{{\[Psi]n, _Real, 
                  2}, {wv, _Real, 1}, {nm, _Real, 
                  1}, {wb, _Real}, {nn, _Real, 
                  1}, {np, _Real}, {n\[Phi], _Real, 
                  3}, {i, _Integer}, {RandomMultinomial[_, _], _Integer, 
                  1}, {rnm, _Integer}, {nnm, _Real}, {fw[_, _], _Real, 
                  1}}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(IterateCompiled[ww_, cline, MUS] := 
        IterateCompiled[ww, cline, UMS];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(IterateCompiled[ww_, cline, USM] := 
        Module[{fw}, \[IndentingNewLine]fw[p_, d_] := 
            Flatten[\(ww[d]\)[p]]; \[IndentingNewLine]IterateCompiled[ww, 
              cline, USM] = 
            Compile[{{\[Phi], _Real, 2}, {nl, _Real, 1}, 
                m, {fe0, _Real, 1}, {fe1, _Real, 1}, n0, 
                n1, {F, _Real, 2}, {rd, True | False}}, 
              Module[{n\[Phi], nn, nm, rnm, ny, y, y0, y1, tt, 
                  nd = Length[\[Phi]], newy, 
                  wvl}, \((wvl = 
                    Table[fw[\[Phi]\[LeftDoubleBracket]
                          i\[RightDoubleBracket], i], {i, 
                        nd}]; \[IndentingNewLine]y = 
                    Table[\[Phi]\[LeftDoubleBracket]
                          i\[RightDoubleBracket] \((1 + \((1 - \[Phi]\
\[LeftDoubleBracket]i\[RightDoubleBracket])\) 
                              Drop[wvl\[LeftDoubleBracket]i\
\[RightDoubleBracket], 1]\/wvl\[LeftDoubleBracket]i, \
1\[RightDoubleBracket])\), {i, nd}]; \[IndentingNewLine]nn = 
                    Table[F\[LeftDoubleBracket]i, 
                          1\[RightDoubleBracket]\ \ \(nl\[LeftDoubleBracket]
                              i\[RightDoubleBracket]\^\(1 - 
                              F\[LeftDoubleBracket]i, 
                                3\[RightDoubleBracket]\)\) \(wvl\
\[LeftDoubleBracket]i, 1\[RightDoubleBracket]\^F\[LeftDoubleBracket]i, 
                              2\[RightDoubleBracket]\) 
                        Exp[\(-\ 
                              nl\[LeftDoubleBracket]
                                i\[RightDoubleBracket]\)\ F\
\[LeftDoubleBracket]i, 4\[RightDoubleBracket]], {i, 
                        nd}]; \[IndentingNewLine]y = 
                    Table[If[
                        rd, \[IndentingNewLine]rnm = 
                          Max[1, 
                            Round[nn\[LeftDoubleBracket]
                                i\[RightDoubleBracket]]]; \[IndentingNewLine]\
\((\(First[RandomMultinomial[rnm, {#, 1 - #}]] &\) /@ 
                              y\[LeftDoubleBracket]i\[RightDoubleBracket])\)/
                          rnm, \[IndentingNewLine]y\[LeftDoubleBracket]
                          i\[RightDoubleBracket]], {i, 
                        nd}]; \[IndentingNewLine]newy = 
                    Prepend[Append[y, If[Length[fe1] == 0, Last[y], fe1]], 
                      If[Length[fe0] == 0, First[y], 
                        fe0]]; \[IndentingNewLine]nm = 
                    Prepend[Append[nn, If[Length[fe1] == 0, Last[nn], n1]], 
                      If[Length[fe0] == 0, First[nn], 
                        n0]]; \[IndentingNewLine]ny = 
                    newy*nm; \[IndentingNewLine]nm = 
                    Drop[Drop[\((1 - m)\) 
                            nm + \(m\/2\) \((RotateLeft[nm] + 
                                RotateRight[nm])\), 
                        1], \(-1\)]; \[IndentingNewLine]y = 
                    Drop[Drop[\((1 - m)\) 
                              ny + \(m\/2\) \((RotateLeft[ny] + 
                                  RotateRight[ny])\), 1], \(-1\)]/
                      nm; \[IndentingNewLine]Table[
                    Append[y\[LeftDoubleBracket]i\[RightDoubleBracket], 
                      nm\[LeftDoubleBracket]i\[RightDoubleBracket]], {i, 
                      nd}])\)], \[IndentingNewLine]{{nn, _Real, 
                  1}, {nm, _Real, 1}, {rnm, _Integer}, {wvl, _Real, 
                  2}, {y, _Real, 2}, {newy, _Real, 2}, {ny, _Real, 
                  2}, {tt, _Real, 1}, {n\[Phi], _Real, 
                  3}, {i, _Integer}, {RandomMultinomial[_, _], _Integer, 
                  1}, {rnm, _Integer}, {nnm, _Real}, {fw[_, _], _Real, 
                  1}}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`IterateExact\  - \ one\ deme, \ 
    symmetric\ neutral\)], "Subsubsection"],

Cell[BoxData[
    \(\(IterateExact[\[Phi] : 
            SymmetricNeutralHaploidFrequencies[{\[Psi]_, u_}, nd_], ww_, m_, 
          opts___Rule] := 
        Module[{i, gg, \[Psi]s, f, cr, 
            gt, \[IndentingNewLine]cQ = \(Compiled /. {opts}\) /. 
                Options[
                  IterateExact], \[IndentingNewLine]mo = \(MigrationOrder /. \
{opts}\) /. Options[
                  IterateExact], \[IndentingNewLine]fe = \(FixedEnds /. \
{opts}\) /. Options[IterateExact], \[IndentingNewLine]ng = 
              NumberOfGenes[\[Phi]]}, \[IndentingNewLine]\[Psi]s = 
            If[fe\[LeftDoubleBracket]1\[RightDoubleBracket] === {} \[Or] 
                fe\[LeftDoubleBracket]1\[RightDoubleBracket] === {{}}, \
\[IndentingNewLine]MakePopulation[ng, {1, 1}, nd, 
                NumericalModel \[Rule] 
                  SymmetricNeutralHaploidFrequencies], \[IndentingNewLine]fe\
\[LeftDoubleBracket]1\[RightDoubleBracket]]; \[IndentingNewLine]If[
            cQ, \[IndentingNewLine]f = \(DemeSize /. {opts}\) /. 
                Options[IterateExact]; \[IndentingNewLine]f = 
              f /. {\((\((nn_?NumberQ)\) &)\) \[Rule] {nn, 0, 1, 
                      0}, \((#1 &)\) \[Rule] {1, 0, 0, 
                      0}, \[IndentingNewLine]PowerF[
                      r_, \[Beta]_, \[Gamma]_] \[Rule] {r, \[Beta], \[Gamma], 
                      0}, ExponentialF[
                      r_, \[Beta]_, \[Lambda]_] \[Rule] {r, \[Beta], 
                      0, \[Lambda]}, \[IndentingNewLine]\((PowerF | 
                          ExponentialF)\)[
                      r_, \[Beta]_, \[Gamma]_, \[Lambda]_] \[Rule] {r, \
\[Beta], \[Gamma], \[Lambda]}, 
                  ExponentialF[r_, \[Beta]_, \[Lambda]_] \[Rule] {r, \[Beta], 
                      0, \[Lambda]}}; \[IndentingNewLine]gt = 
              GameteTable[ng, ww, 
                NumericalModel \[Rule] SymmetricHaploidFrequencies, 
                opts]; \[IndentingNewLine]cr = \(IterateCompiled[neutral, 
                  oneDeme, mo]\)[\[Psi], u, nd, gt, 
                m, \[Psi]s\[LeftDoubleBracket]1, 
                  1\[RightDoubleBracket], \[Psi]s\[LeftDoubleBracket]1, 
                  2\[RightDoubleBracket], \[Psi]s\[LeftDoubleBracket]2\
\[RightDoubleBracket], 
                f]; \[IndentingNewLine]SymmetricNeutralHaploidFrequencies[
              Partition[Drop[cr, \(-1\)], ng + 1], 
              Last[cr]], \[IndentingNewLine]\ 
            Switch[mo, \[IndentingNewLine]UMS, 
              NewGametes[
                MigrateExact[MakeDiploid[\[Phi]], MakeDiploid[\[Psi]s], m], 
                ww, opts], \[IndentingNewLine]MUS, 
              NewGametes[MakeDiploid[MigrateExact[\[Phi], \[Psi]s, m]], ww, 
                opts], \[IndentingNewLine]USM, 
              MigrateExact[
                NewGametes[MakeDiploid[\[Phi]], ww, opts], \[Psi]s, 
                m], \[IndentingNewLine]\ _, 
              Message[IterateExact::badMigrationOrder, 
                mo]; \[Phi]]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`IterateExact\  - \ one\ deme, \ compiled, 
    symmetric\ \ neutral\)], "Subsubsection"],

Cell[BoxData[
    \(\(IterateCompiled[neutral, oneDeme, UMS] = 
        Compile[{{\[Psi], _Real, 1}, {u, _Real, 1}, n, {gt, _Real, 3}, 
            m, {\[Psi]s, _Real, 1}, {us, _Real, 1}, ns, {F, _Real, 1}}, \n\t
          Module[{tt, ttu, wb, nm}, \n\t
            nm = m\ ns + \((1 - m)\) 
                  n; \[IndentingNewLine]tt = \((Plus @@ \(Plus @@ \((gt*\((n \
\((1 - m)\) Outer[Times, \[Psi], \[Psi]] + 
                              ns\ m\ Outer[
                                  Times, \[Psi]s, \[Psi]s])\))\)\))\)/nm; \n\t
            ttu = \((Plus @@ \(Plus @@ \((gt*\((n \((1 - m)\) 
                                Outer[Times, \[Psi], \[Psi]] 
                                Outer[Plus, u, u] + 
                              ns\ m\ Outer[Times, \[Psi]s, \[Psi]s] 
                                Outer[Plus, us, us])\))\)\))\)/\((2  
                    nm)\); \n\t
            wb = Plus @@ tt; \[IndentingNewLine]nm = 
              F\[LeftDoubleBracket]1\[RightDoubleBracket]\ \(nm\^\(1 - 
                      F\[LeftDoubleBracket]3\[RightDoubleBracket]\)\) \(wb\^F\
\[LeftDoubleBracket]2\[RightDoubleBracket]\) 
                Exp[\(-\ 
                      nm\)\ F\[LeftDoubleBracket]4\[RightDoubleBracket]]; \
\[IndentingNewLine]Append[Join[tt\/wb, DivideZero[ttu, tt]], 
              nm]], \n\t\t{{wb, _Real}, {nm, _Real}, {tt, _Real, 
              1}, {ttu, _Real, 1}, {DivideZero[_, _], _Real, 
              1}}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(IterateCompiled[neutral, oneDeme, MUS] = 
        Compile[{{\[Psi], _Real, 1}, {u, _Real, 1}, n, {gt, _Real, 3}, 
            m, {\[Psi]s, _Real, 1}, {us, _Real, 1}, 
            ns, {F, _Real, 1}}, \[IndentingNewLine]Module[{tt, ttu, wb, nm, 
              nu, ngt}, \[IndentingNewLine]nm = 
              m\ ns + \((1 - m)\) 
                  n; \[IndentingNewLine]tt = \((n \((1 - m)\) \[Psi] + 
                    ns\ m\ \[Psi]s)\)/
                nm; \[IndentingNewLine]ttu = \((n \((1 - m)\) \[Psi]\ u + 
                    ns\ m\ \[Psi]s\ us)\)/nm; \[IndentingNewLine]nu = 
              DivideZero[ttu, tt]; \[IndentingNewLine]ngt = 
              gt*Outer[Times, tt, tt]; \[IndentingNewLine]tt = 
              Plus @@ \(Plus @@ 
                  ngt\); \[IndentingNewLine]ttu = \((Plus @@ \(Plus @@ \((ngt*
                          Outer[Plus, nu, nu])\)\))\)/
                2; \[IndentingNewLine]wb = 
              Plus @@ tt; \[IndentingNewLine]nm = 
              F\[LeftDoubleBracket]1\[RightDoubleBracket]\ \(nm\^\(1 - 
                      F\[LeftDoubleBracket]3\[RightDoubleBracket]\)\) \(wb\^F\
\[LeftDoubleBracket]2\[RightDoubleBracket]\) 
                Exp[\(-\ 
                      nm\)\ F\[LeftDoubleBracket]4\[RightDoubleBracket]]; \
\[IndentingNewLine]Append[Join[tt\/wb, DivideZero[ttu, tt]], 
              nm]], \n\t\t{{wb, _Real}, {nm, _Real}, {tt, _Real, 
              1}, {ttu, _Real, 1}, {ngt, _Real, 3}, {nu, _Real, 
              1}, {DivideZero[_, _], _Real, 1}}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(IterateCompiled[neutral, oneDeme, USM] = 
        Compile[{{\[Psi], _Real, 1}, {u, _Real, 1}, n, {gt, _Real, 3}, 
            m, {\[Psi]s, _Real, 1}, {us, _Real, 1}, 
            ns, {F, _Real, 1}}, \[IndentingNewLine]Module[{tt, ttu, wb, nn, 
              nnn, ttn}, \[IndentingNewLine]tt = 
              Plus @@ \(Plus @@ \((gt*
                      Outer[Times, \[Psi], \[Psi]])\)\); \
\[IndentingNewLine]ttu = \((Plus @@ \(Plus @@ \((gt*
                          Outer[Times, \[Psi], \[Psi]]*
                          Outer[Plus, u, u])\)\))\)/
                2; \[IndentingNewLine]wb = 
              Plus @@ tt; \[IndentingNewLine]nn = 
              F\[LeftDoubleBracket]1\[RightDoubleBracket]\ \(n\^\(1 - 
                      F\[LeftDoubleBracket]3\[RightDoubleBracket]\)\) \(wb\^F\
\[LeftDoubleBracket]2\[RightDoubleBracket]\) 
                Exp[\(-\ 
                      n\)\ F\[LeftDoubleBracket]4\[RightDoubleBracket]]; \
\[IndentingNewLine]nnn = \((1 - m)\) nn + ns\ m; \[IndentingNewLine]ttn = 
              nn \((1 - m)\) tt\/wb + 
                ns\ m\ \[Psi]s; \[IndentingNewLine]Append[
              Join[ttn\/nnn, 
                DivideZero[nn \((1 - m)\) ttu\/wb + ns\ m\ \[Psi]s\ us, 
                  ttn]], nnn]], \[IndentingNewLine]{{wb, _Real}, {nn, _Real}, \
{nnn, _Real}, {tt, _Real, 1}, {ttn, _Real, 1}, {ttu, _Real, 
              1}, {DivideZero[_, _], _Real, 1}}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`IterateExact\  - \ cline, 
    symmetric\ \ neutral\)], "Subsubsection"],

Cell[BoxData[
    \(\(IterateExact[\[Psi] : {SymmetricNeutralHaploidFrequencies[{_, _}, _] \
.. }, ww_, m_, opts___] := 
        Module[{i, gg, nd = Length[\[Psi]], cr, gt, \[Psi]0, \[Psi]1, u0, u1, 
            n0, n1, cQ = \(Compiled /. {opts}\) /. 
                Options[
                  IterateExact], \[IndentingNewLine]mo = \(MigrationOrder /. \
{opts}\) /. Options[
                  IterateExact], \[IndentingNewLine]fe = \(FixedEnds /. \
{opts}\) /. Options[IterateExact], \[IndentingNewLine]\[Phi], u, nl, 
            dsrl, \[IndentingNewLine]ng = 
              NumberOfGenes[\[Psi]]}, \[IndentingNewLine]\ \ \ If[
            cQ, \[IndentingNewLine]\[Phi] = 
              First /@ \(First /@ \[Psi]\); \[IndentingNewLine]u = 
              Last /@ \(First /@ \[Psi]\); \[IndentingNewLine]nl = 
              Last /@ \[Psi]; \[IndentingNewLine]f = \(DemeSize /. {opts}\) /. 
                Options[IterateExact]; 
            f = f /. {\((\((nn_?NumberQ)\) &)\) \[Rule] 
                    Array[{nn, 0, 1, 0} &, 
                      nd], \[IndentingNewLine]\((#1 &)\) \[Rule] 
                    Array[{1, 0, 0, 0} &, nd], \[IndentingNewLine]PowerF[
                      r_, \[Beta]_, \[Gamma]_] \[Rule] 
                    Array[{r, \[Beta], \[Gamma], 0} &, nd], 
                  ExponentialF[r_, \[Beta]_, \[Lambda]_] \[Rule] 
                    Array[{r, \[Beta], 0, \[Lambda]} &, 
                      nd], \((PowerF | ExponentialF)\)[
                      r_, \[Beta]_, \[Gamma]_, \[Lambda]_] \[Rule] 
                    Array[{r, \[Beta], \[Gamma], \[Lambda]} &, nd], 
                  ExponentialF[r_, \[Beta]_, \[Lambda]_] \[Rule] 
                    Array[{r, \[Beta], 0, \[Lambda]} &, 
                      nd]}; \[IndentingNewLine]If[
              fe\[LeftDoubleBracket]1\[RightDoubleBracket] === {}, \
\[IndentingNewLine]\[Psi]0 = {}; u0 = {}; 
              n0 = 0, \[IndentingNewLine]\[Psi]0 = 
                fe\[LeftDoubleBracket]1, 1, 1\[RightDoubleBracket]; 
              u0 = fe\[LeftDoubleBracket]1, 1, 2\[RightDoubleBracket]; 
              n0 = fe\[LeftDoubleBracket]1, 
                  2\[RightDoubleBracket]]; \[IndentingNewLine]If[
              fe\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] === {}, \
\[IndentingNewLine]\[Psi]1 = {}; u1 = {}; 
              n1 = 0, \[IndentingNewLine]\[Psi]1 = 
                fe\[LeftDoubleBracket]\(-1\), 1, 1\[RightDoubleBracket]; 
              u1 = fe\[LeftDoubleBracket]\(-1\), 1, 2\[RightDoubleBracket]; 
              n1 = 
                fe\[LeftDoubleBracket]\(-1\), 
                  2\[RightDoubleBracket]]; \[IndentingNewLine]gt = 
              Table[GameteTable[ng, ww[i], 
                  NumericalModel \[Rule] SymmetricNeutralHaploidFrequencies, 
                  opts], {i, nd}]; \[IndentingNewLine]cr = \(IterateCompiled[
                  neutral, cline, mo]\)[\[Phi], u, nl, gt, 
                m, \[Psi]0, \[Psi]1, u0, u1, n0, n1, 
                f]; \[IndentingNewLine]\(SymmetricNeutralHaploidFrequencies[
                  Partition[Drop[#, \(-1\)], ng + 1], Last[#]] &\) /@ 
              cr, \[IndentingNewLine]dsrl[
                j_] := {\((DemeSize \[Rule] 
                      f_?\((Not[
                              ListQ[#]] &)\))\) \[RuleDelayed] \((DemeSize \
\[Rule] f[j])\), \((DemeSize \[Rule] 
                      f_List)\) \[RuleDelayed] \((DemeSize \[Rule] 
                      f\[LeftDoubleBracket]
                        j\[RightDoubleBracket])\)}; \[IndentingNewLine]Switch[
              mo, \[IndentingNewLine]UMS, \[IndentingNewLine]gg = 
                MigrateExact[MakeDiploid[\[Psi]], m, 
                  FixedEnds \[Rule] \((MakeDiploid /@ fe)\)]; 
              Table[\(NewGametes[
                      gg\[LeftDoubleBracket]i\[RightDoubleBracket], 
                      ww[i], ##] &\) @@ \(({opts} /. dsrl[i])\), {i, 
                  nd}], \[IndentingNewLine]MUS, \[IndentingNewLine]gg = 
                MakeDiploid[MigrateExact[\[Psi], m, FixedEnds \[Rule] fe]]; 
              Table[\(NewGametes[
                      gg\[LeftDoubleBracket]i\[RightDoubleBracket], 
                      ww[i], ##] &\) @@ \(({opts} /. dsrl[i])\), {i, 
                  nd}], \[IndentingNewLine]USM, \[IndentingNewLine]\ 
              gg = MakeDiploid[\[Psi]]; \[IndentingNewLine]MigrateExact[
                Table[\(NewGametes[
                        gg\[LeftDoubleBracket]i\[RightDoubleBracket], 
                        ww[i], ##] &\) @@ \(({opts} /. dsrl[i])\), {i, nd}], 
                m, FixedEnds \[Rule] 
                  fe], \[IndentingNewLine]_, \[IndentingNewLine]Message[
                IterateExact::badMigrationOrder, mo]; 
              SymmetricNeutralHaploidFrequencies[\[Psi], n]]]];\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`IterateExact\  - \ cline, \ \ compiled, \ 
    symmetric\ \ neutral\)], "Subsubsection"],

Cell[BoxData[
    \(\(IterateCompiled[neutral, cline, UMS] = 
        Compile[{{\[Psi], _Real, 2}, {u, _Real, 2}, {nl, _Real, 
              1}, {gt, _Real, 4}, 
            m, {fe0, _Real, 1}, {fe1, _Real, 1}, {feU0, _Real, 
              1}, {feU1, _Real, 1}, n0, 
            n1, {F, _Real, 2}}, \[IndentingNewLine]Module[{\[Phi], \[Phi]u, 
              n\[Phi], n\[Phi]u, nn, tt, ttu, nu, i, nm, wb, 
              nnm}, \[IndentingNewLine]\[Phi] = \(Outer[
                    Times, #, #] &\) /@ \[Psi]; \[IndentingNewLine]\[Phi]u = 
              MapThread[
                  Outer[Times, #1, #1] Outer[Plus, #2, #2] &, {\[Psi], u}]/
                2; \[IndentingNewLine]\[Phi] = 
              Prepend[Append[\[Phi], \[IndentingNewLine]If[Length[fe1] == 0, 
                    Last[\[Phi]], Outer[Times, fe1, fe1]]], 
                If[Length[fe0] == 0, First[\[Phi]], 
                  Outer[Times, fe0, fe0]]]; \[Phi]u = 
              Prepend[Append[\[Phi]u, \[IndentingNewLine]If[Length[fe1] == 0, 
                    Last[\[Phi]u], 
                    Outer[Times, fe1, fe1] Outer[Plus, feU1, feU1]/2]], 
                If[Length[fe0] == 0, First[\[Phi]u], 
                  Outer[Times, fe0, fe0] Outer[Plus, feU0, feU0]/2]]; 
            nn = Prepend[
                Append[nl, \[IndentingNewLine]If[Length[fe1] == 0, Last[nl], 
                    n1]], \[IndentingNewLine]If[Length[fe0] == 0, First[nl], 
                  n0]]; \[IndentingNewLine]n\[Phi] = nn*\[Phi]; 
            n\[Phi]u = nn*\[Phi]u; \[IndentingNewLine]n\[Phi] = 
              Drop[Drop[\((1 - m)\) 
                      n\[Phi] + \(m\/2\) \((RotateLeft[n\[Phi]] + 
                          RotateRight[n\[Phi]])\), 
                  1], \(-1\)]; \ \[IndentingNewLine]n\[Phi]u = 
              Drop[Drop[\((1 - m)\) 
                      n\[Phi]u + \(m\/2\) \((RotateLeft[n\[Phi]u] + 
                          RotateRight[n\[Phi]u])\), 
                  1], \(-1\)]; \ \[IndentingNewLine]nm = 
              Drop[Drop[\((1 - m)\) 
                      nn + \(m\/2\) \((RotateLeft[nn] + RotateRight[nn])\), 
                  1], \(-1\)]; 
            nu = MapThread[DivideZero[#1, #2] &, {n\[Phi]u, n\[Phi]}, 
                2]; \[IndentingNewLine]Table[\[IndentingNewLine]tt = \((Plus @@ \
\(Plus @@ \((gt\[LeftDoubleBracket]i\[RightDoubleBracket]*
                            n\[Phi]\[LeftDoubleBracket]
                              i\[RightDoubleBracket])\)\))\)/
                  nm\[LeftDoubleBracket]
                    i\[RightDoubleBracket]; \[IndentingNewLine]ttu = \((Plus @@ \
\(Plus @@ \((gt\[LeftDoubleBracket]i\[RightDoubleBracket]*
                            n\[Phi]\[LeftDoubleBracket]i\[RightDoubleBracket]*
                            nu\[LeftDoubleBracket]
                              i\[RightDoubleBracket])\)\))\)/
                  nm\[LeftDoubleBracket]
                    i\[RightDoubleBracket]; \[IndentingNewLine]wb = 
                Plus @@ tt; \[IndentingNewLine]nnm = 
                F\[LeftDoubleBracket]i, 
                    1\[RightDoubleBracket]\ \ \(nm\[LeftDoubleBracket]
                        i\[RightDoubleBracket]\^\(1 - 
                        F\[LeftDoubleBracket]i, 
                          3\[RightDoubleBracket]\)\) \(wb\^F\
\[LeftDoubleBracket]i, 2\[RightDoubleBracket]\) 
                  Exp[\(-\ 
                        nm\[LeftDoubleBracket]
                          i\[RightDoubleBracket]\)\ F\[LeftDoubleBracket]i, 
                        4\[RightDoubleBracket]]; \[IndentingNewLine]Append[
                Join[tt\/wb, DivideZero[ttu, tt]], 
                nnm], \[IndentingNewLine]{i, 
                Length[\[Psi]]}]], \n\t\t{{tt, _Real, 1}, {ttu, _Real, 
              1}, {nm, _Real, 1}, {wb, _Real}, {nn, _Real, 
              1}, {\[Phi], _Real, 3}, {\[Phi]u, _Real, 3}, {nu, _Real, 
              3}, {n\[Phi], _Real, 3}, {n\[Phi]u, _Real, 
              3}, {i, _Integer}, {nnm, _Real}, {DivideZero[_, _], _Real, 
              1}}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(IterateCompiled[neutral, cline, MUS] = 
        Compile[{{\[Psi], _Real, 2}, {u, _Real, 2}, {nl, _Real, 
              1}, {gt, _Real, 4}, 
            m, {fe0, _Real, 1}, {fe1, _Real, 1}, {feU0, _Real, 
              1}, {feU1, _Real, 1}, n0, 
            n1, {F, _Real, 2}}, \[IndentingNewLine]Module[{\[Phi], \[Phi]u, 
              y, yu = \[Psi]*u, ny, nyu, nn, nm, nnm, tt, ttu, 
              wb}, \[IndentingNewLine]\((y = 
                Prepend[
                  Append[\[Psi], \[IndentingNewLine]If[Length[fe1] == 0, 
                      Last[\[Psi]], fe1]], \[IndentingNewLine]If[
                    Length[fe0] == 0, First[\[Psi]], 
                    fe0]]; \[IndentingNewLine]yu = 
                Prepend[
                  Append[yu, \[IndentingNewLine]If[Length[fe1] == 0, 
                      Last[yu], fe1*feU1]], \[IndentingNewLine]If[
                    Length[fe0] == 0, First[yu], 
                    fe0*feU0]]; \[IndentingNewLine]nn = 
                Prepend[
                  Append[nl, \[IndentingNewLine]If[Length[fe1] == 0, 
                      Last[nl], n1]], \[IndentingNewLine]If[Length[fe0] == 0, 
                    First[nl], n0]]; \[IndentingNewLine]ny = nn*y; 
              nyu = nn*yu; \[IndentingNewLine]ny = 
                Drop[Drop[\((1 - m)\) 
                        ny + \(m\/2\) \((RotateLeft[ny] + RotateRight[ny])\), 
                    1], \(-1\)]; \ 
              nyu = Drop[
                  Drop[\((1 - m)\) 
                        nyu + \(m\/2\) \((RotateLeft[nyu] + 
                            RotateRight[nyu])\), 1], \(-1\)]; \ 
              nm = Drop[
                  Drop[\((1 - m)\) 
                        nn + \(m\/2\) \((RotateLeft[nn] + RotateRight[nn])\), 
                    1], \(-1\)]; \ 
              ny = ny/nm; \[IndentingNewLine]nyu = 
                MapThread[
                  DivideZero[#1, #2] &, {nyu, 
                    ny}]; \[IndentingNewLine]\[Phi] = \(Outer[
                      Times, #, #] &\) /@ ny; \[IndentingNewLine]\[Phi]u = 
                MapThread[
                  Outer[Times, #1, #1] Outer[Plus, #2, #2]\/2 &, {ny, 
                    nyu}]; \[IndentingNewLine]Table[\[IndentingNewLine]tt = 
                  Plus @@ \(Plus @@ \((gt\[LeftDoubleBracket]
                            i\[RightDoubleBracket]*\[Phi]\[LeftDoubleBracket]
                            i\[RightDoubleBracket])\)\); \
\[IndentingNewLine]ttu = 
                  Plus @@ \(Plus @@ \((gt\[LeftDoubleBracket]
                            i\[RightDoubleBracket]*\[Phi]u\[LeftDoubleBracket]
                            i\[RightDoubleBracket])\)\); \
\[IndentingNewLine]wb = Plus @@ tt; \[IndentingNewLine]nnm = 
                  F\[LeftDoubleBracket]i, 
                      1\[RightDoubleBracket]\ \ \(wb\^F\[LeftDoubleBracket]i, 
                          2\[RightDoubleBracket]\) \(nm\[LeftDoubleBracket]
                          i\[RightDoubleBracket]\^\(1 - 
                          F\[LeftDoubleBracket]i, 3\[RightDoubleBracket]\)\) 
                    Exp[\(-\ 
                          nm\[LeftDoubleBracket]
                            i\[RightDoubleBracket]\)\ F\[LeftDoubleBracket]i, 
                          4\[RightDoubleBracket]]; \[IndentingNewLine]Append[
                  Join[tt\/wb, DivideZero[ttu, tt]], nnm], {i, 
                  Length[\[Psi]]}])\)], {{nn, _Real, 1}, {nm, _Real, 
              1}, {wb, _Real}, {tt, _Real, 1}, {ttu, _Real, 1}, {y, _Real, 
              2}, {yu, _Real, 2}, {ny, _Real, 2}, {nyu, _Real, 
              2}, {\[Phi], _Real, 3}, {\[Phi]u, _Real, 
              3}, {i, _Integer}, {DivideZero[_, _], _Real, 
              1}, {nnm, _Real}}];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(IterateCompiled[neutral, cline, USM] = 
        Compile[{{\[Psi], _Real, 2}, {u, _Real, 2}, {nl, _Real, 
              1}, {gt, _Real, 4}, 
            m, {fe0, _Real, 1}, {fe1, _Real, 1}, {feU0, _Real, 
              1}, {feU1, _Real, 1}, n0, n1, {F, _Real, 2}}, 
          Module[{\[Phi], n\[Phi], nn, nu, nm, rnm, wb, ny, y, yu, nyu, y0, 
              y1, tt, nd = Length[\[Psi]], newy, 
              newyu}, \[IndentingNewLine]\((\[Phi] = \(Outer[
                      Times, #, #] &\) /@ \[Psi]; 
              nu = \(Outer[Plus, #, #]\/2 &\) /@ u; \[IndentingNewLine]y = 
                Table[Plus @@ \(Plus @@ \((gt\[LeftDoubleBracket]
                            i\[RightDoubleBracket]*\[Phi]\[LeftDoubleBracket]
                            i\[RightDoubleBracket])\)\), {i, nd}]; 
              yu = Table[
                  Plus @@ \(Plus @@ \((gt\[LeftDoubleBracket]
                            i\[RightDoubleBracket]*\[Phi]\[LeftDoubleBracket]
                            i\[RightDoubleBracket]*
                          nu\[LeftDoubleBracket]
                            i\[RightDoubleBracket])\)\), {i, 
                    nd}]; \[IndentingNewLine]yu = 
                DivideZero[yu, y]; \[IndentingNewLine]nn = 
                Table[\[IndentingNewLine]wb = 
                    Plus @@ y\[LeftDoubleBracket]
                        i\[RightDoubleBracket]; \[IndentingNewLine]F\
\[LeftDoubleBracket]i, 
                      1\[RightDoubleBracket]\ \ \(nl\[LeftDoubleBracket]
                          i\[RightDoubleBracket]\^\(1 - 
                          F\[LeftDoubleBracket]i, 
                            3\[RightDoubleBracket]\)\) \(wb\^F\
\[LeftDoubleBracket]i, 2\[RightDoubleBracket]\) 
                    Exp[\(-\ 
                          nl\[LeftDoubleBracket]
                            i\[RightDoubleBracket]\)\ F\[LeftDoubleBracket]i, 
                          4\[RightDoubleBracket]], {i, 
                    nd}]; \[IndentingNewLine]y = 
                Table[y\[LeftDoubleBracket]i\[RightDoubleBracket]\/Plus @@ y\
\[LeftDoubleBracket]i\[RightDoubleBracket], {i, 
                    nd}]; \[IndentingNewLine]newy = 
                Prepend[
                  Append[y, \[IndentingNewLine]If[Length[fe1] == 0, Last[y], 
                      fe1]], \[IndentingNewLine]If[Length[fe0] == 0, 
                    First[y], fe0]]; \[IndentingNewLine]newyu = 
                Prepend[
                  Append[yu, \[IndentingNewLine]If[Length[fe1] == 0, 
                      Last[yu], feU1]], \[IndentingNewLine]If[
                    Length[fe0] == 0, First[yu], 
                    feU0]]; \[IndentingNewLine]nm = 
                Prepend[
                  Append[nn, \[IndentingNewLine]If[Length[fe1] == 0, 
                      Last[nn], n1]], \[IndentingNewLine]If[Length[fe0] == 0, 
                    First[nn], n0]]; \[IndentingNewLine]ny = newy*nm; 
              nyu = newy*newyu*nm; \[IndentingNewLine]nm = 
                Drop[Drop[\((1 - m)\) 
                        nm + \(m\/2\) \((RotateLeft[nm] + RotateRight[nm])\), 
                    1], \(-1\)]; \[IndentingNewLine]y = 
                Drop[Drop[\((1 - m)\) 
                        ny + \(m\/2\) \((RotateLeft[ny] + RotateRight[ny])\), 
                    1], \(-1\)]; \[IndentingNewLine]yu = 
                DivideZero[
                  Drop[Drop[\((1 - m)\) 
                          nyu + \(m\/2\) \((RotateLeft[nyu] + 
                              RotateRight[nyu])\), 1], \(-1\)], 
                  y]; \[IndentingNewLine]y = y/nm; \[IndentingNewLine]Table[
                Append[Join[y\[LeftDoubleBracket]i\[RightDoubleBracket], 
                    yu\[LeftDoubleBracket]i\[RightDoubleBracket]], 
                  nm\[LeftDoubleBracket]i\[RightDoubleBracket]], {i, 
                  nd}])\)], \[IndentingNewLine]{{nn, _Real, 1}, {nm, _Real, 
              1}, {rnm, _Integer}, {wb, _Real}, {y, _Real, 2}, {yu, _Real, 
              2}, {nyu, _Real, 2}, {newy, _Real, 2}, {newyu, _Real, 
              2}, {ny, _Real, 2}, {tt, _Real, 1}, {\[Phi], _Real, 
              3}, {nu, _Real, 3}, {n\[Phi], _Real, 
              3}, {i, _Integer}, {DivideZero[_, _], _Real, 
              2}, {rnm, _Integer}, {nnm, _Real}}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["StoreExact", "Subsubsection"],

Cell[BoxData[
    \(\(Options[StoreExact] = {SymmetricCline \[Rule] False, 
          FixedEnds \[Rule] {{}, {}}};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(StoreExact::usage = "\<StoreExact[\[Psi],\[Psi]0,W,m,{t,dt}] stores \
results at intervals dt in \[Psi][t], starting with \[Psi]0.  \[Psi]0 can \
represent a single population or a cline.  The options Compiled, FixedEnds, \
DemeSize and MigrationOrder can be used, as for IterateExact. NumericalModel \
specifies the representation. SymmetricCline\[Rule]True simulates a symmetric \
cline more efficiently.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(StoreExact[\[Psi]_, \[Psi]0 : PopulationRepresentations[_, _], ww_, 
          m_, {t_, dt_}, 
          opts___Rule] := \[IndentingNewLine]Module[{tt = 0, 
            fe = \(FixedEnds /. {opts}\) /. 
                Options[StoreExact]}, \[IndentingNewLine]\[Psi][
              0] = \[Psi]0; \[IndentingNewLine]While[
            tt + dt < t, \[IndentingNewLine]\[Psi][tt + dt] = 
              Nest[IterateExact[#, ww, m, opts] &, \[Psi][tt], dt]; 
            tt += dt]; \n\t\[Psi][t] = 
            Nest[IterateExact[#, ww, m, opts] &, \[Psi][tt], 
              t - tt]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(StoreExact[\[Psi]_, \[Psi]0 : {PopulationRepresentations[_, _] .. }, 
          ww_, m_, {t_, dt_}, opts___Rule] := 
        Module[{\[Psi]t, ff, tt = 0, nd2 = Ceiling[nd/2], optsNF, \n\t
            eQ = EvenQ[Length[\[Psi]0]], \n\t
            sQ = \(SymmetricCline /. {opts}\) /. Options[StoreExact], \n\t
            fe = \(FixedEnds /. {opts}\) /. Options[StoreExact], nfe}, \n\t
          optsNF = 
            Sequence @@ \(({opts} /. {{a___, FixedEnds \[Rule] _, 
                        b___} :> {a, b}})\); \n\t\[Psi][
              0] = \[Psi]0; \n\ \ \ \ \ \ If[
            sQ, \[IndentingNewLine]nfe = 
              If[eQ, \[Psi]t\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket], \
\[Psi]t\[LeftDoubleBracket]\(-2\)\[RightDoubleBracket]] /. {\((pr : 
                          NeutralRepresentations)\)[{\[Phi]_List, u_List}, 
                      n_] \[RuleDelayed] 
                    pr[{Reverse[\[Phi]], Reverse[u]}, 
                      n], \((pr : NonNeutralRepresentations)\)[\[Phi]_List, 
                      n_] \[RuleDelayed] 
                    pr[Reverse[\[Phi]], n]}; \[IndentingNewLine]ff[
                g_] := \((\[Psi]t = Take[g, nd2]; 
                DoubleCline[
                  IterateExact[\[Psi]t, ww, m, optsNF, 
                    FixedEnds \[Rule] {fe\[LeftDoubleBracket]1\
\[RightDoubleBracket], nfe}], eQ])\), \n\t
            ff[g_] := IterateExact[g, ww, m, opts]]; \n\t
          While[tt + dt < t, \[Psi][tt + dt] = Nest[ff, \[Psi][tt], dt]; 
            tt += dt]; \n\t\[Psi][t] = 
            Nest[ff, \[Psi][tt], t - tt]];\)\), "\[IndentingNewLine]", 
    \( (*\ needs\ rewriting\ for\ AlleleFrequencies\ etc\ *) \)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(StoreNeutral[\[Psi]_, ww_, m_, {t_, dt_}, {nd_, ng_, dp___}, 
          opts___] := \n\t
        Module[{\[Psi]t, ff, tt = 0, nd2 = Ceiling[\((nd + 1)\)/2], 
            optsNF, \n\t\t\teQ = 
              EvenQ[nd], \n\t\t\tsQ = \(SymmetricCline /. {opts}\) /. 
                Options[StoreExact], \n\t\t\tfe = \(FixedEnds /. {opts}\) /. 
                Options[StoreExact]}, \n\t\ \ optsNF = 
            opts /. {{a___, FixedEnds \[Rule] _, b___} :> {a, 
                    b}}; \n\t\ \ \ \[Psi][0] = 
            InitialiseDemes[nd, ng, dp, opts, Neutral \[Rule] True]; \n\t\tIf[
            sQ, \n\t\t\t\ \ \ ff[g_] := \((\[Psi]t = Take[g, nd2]; 
                DoubleCline[
                  IterateNeutral[\[Psi]t, ww, m, optsNF, 
                    FixedEnds \[Rule] {fe\[LeftDoubleBracket]1\
\[RightDoubleBracket], Reverse /@ 
                          If[eQ, 
                            g\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket], 
                            g\[LeftDoubleBracket]\(-2\)\[RightDoubleBracket]]}\
], eQ])\), \n\t\t\t\ \ \ ff[g_] := IterateNeutral[g, ww, m, opts]]; \n\t
          While[tt + dt < t, \[Psi][tt + dt] = Nest[ff, \[Psi][tt], dt]; 
            tt += dt]; \n\t\[Psi][t] = 
            Nest[ff, \[Psi][tt], t - tt]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`MidParent\)], "Subsubsection"],

Cell[BoxData[
    \(\(MidParent[u_] := Outer[Plus, u, u]/2;\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`ClassToGenotypes\)], "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(ClassToGenotypes::badList = "\<`1` is not an appropriate argument for \
ClassToGenotypes\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(ClassToGenotypes[SymmetricHaploidFrequencies[\[Psi]_, n_], 
          opts___Rule] := 
        HaploidFrequencies[ClassToGenotypes[\[Psi], opts], 
          n];\)\), "\[IndentingNewLine]", 
    \(\(ClassToGenotypes[SymmetricDiploidFrequencies[\[Psi]_, n_], 
          opts___Rule] := 
        DiploidFrequencies[ClassToGenotypes[\[Psi], opts], 
          n];\)\), "\[IndentingNewLine]", 
    \(\(ClassToGenotypes[\[Psi] : {\((SymmetricHaploidFrequencies | 
                      SymmetricDiploidFrequencies)\)[_, _] .. }, 
          opts___Rule] := \(ClassToGenotypes[#, 
              opts] &\) /@ \[Psi];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ClassToGenotypes[g_List, 
          opts___Rule] := \[IndentingNewLine]Module[{n = Length[g] - 1, i, j, 
            dt, ht}, \[IndentingNewLine]ht = 
            HaploidTypes[n, opts]; \[IndentingNewLine]Switch[
            TensorRank[
              g], \[IndentingNewLine]1, \[IndentingNewLine]ht /. \
{{a___Integer} :> \((i = Plus[a]; 
                    g\[LeftDoubleBracket]i + 1\[RightDoubleBracket]/
                      Binomial[n, 
                        i])\)}, \[IndentingNewLine]2, \[IndentingNewLine]dt = 
              Outer[List, ht, ht, 
                1]; \[IndentingNewLine]dt /. {{{a___Integer}, {b___Integer}} :> \
\((i = Plus[a]; j = Plus[b]; 
                    g\[LeftDoubleBracket]i + 1, 
                        j + 1\[RightDoubleBracket]/\((Binomial[n, i] 
                          Binomial[n, 
                            j])\))\)}, \[IndentingNewLine]_, \
\[IndentingNewLine]Message[ClassToGenotypes::badList, g]; 
            Indeterminate]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["GenotypePosition", "Subsubsection"],

Cell[BoxData[
    \(\(GenotypePosition[X_, 
          opts___Rule] := \(Position[HaploidTypes[Length[X], opts], 
            X]\)\[LeftDoubleBracket]1, 1\[RightDoubleBracket];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExponentialF", "Subsubsection"],

Cell[BoxData[{
    \(\(\(ExponentialF[r_, \[Beta]_, \[Lambda]_]\)[n_, wb_]\  := \ 
        r\[VeryThinSpace]\ n\ \[VeryThinSpace]\(wb\^\[Beta]\) 
          Exp[\(-\[Lambda]\)\[VeryThinSpace]n];\)\), "\[IndentingNewLine]", 
    \(\(\(ExponentialF[r_, \[Beta]_, \[Gamma]_, \[Lambda]_]\)[n_, wb_]\  := \ 
        r\[VeryThinSpace]\ n\^\(1 - \[Gamma]\)\ \[VeryThinSpace]\(wb\^\[Beta]\
\) Exp[\(-\[Lambda]\)\[VeryThinSpace]n];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(\(\(ExponentialF[r_, \[Beta]_, \[Lambda]_]\)[_]\)[n_, wb_]\  := \ 
        r\[VeryThinSpace]\ n\ \[VeryThinSpace]\(wb\^\[Beta]\) 
          Exp[\(-\[Lambda]\)\[VeryThinSpace]n];\)\), "\[IndentingNewLine]", 
    \(\(\(\(ExponentialF[r_, \[Beta]_, \[Gamma]_, \[Lambda]_]\)[_]\)[n_, 
          wb_]\  := \ 
        r\[VeryThinSpace]\ n\^\(1 - \[Gamma]\)\ \[VeryThinSpace]\(wb\^\[Beta]\
\) Exp[\(-\[Lambda]\)\[VeryThinSpace]n];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PowerF", "Subsubsection"],

Cell[BoxData[{
    \(\(\(PowerF[r_, \[Beta]_, \[Gamma]_]\)[n_, wb_]\  := \ 
        r\[VeryThinSpace]\ n\^\(1 - \
\[Gamma]\)\ \[VeryThinSpace]wb\^\[Beta];\)\), "\[IndentingNewLine]", 
    \(\(\(PowerF[r_, \[Beta]_, \[Gamma]_, \[Lambda]_]\)[n_, wb_]\  := \ 
        r\[VeryThinSpace]\ n\^\(1 - \[Gamma]\)\ \[VeryThinSpace]\(wb\^\[Beta]\
\) Exp[\(-\[Lambda]\)\[VeryThinSpace]n];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(\(\(PowerF[r_, \[Beta]_, \[Gamma]_]\)[_]\)[n_, wb_]\  := \ 
        r\[VeryThinSpace]\ n\^\(1 - \
\[Gamma]\)\ \[VeryThinSpace]wb\^\[Beta];\)\), "\[IndentingNewLine]", 
    \(\(\(\(PowerF[r_, \[Beta]_, \[Gamma]_, \[Lambda]_]\)[_]\)[n_, 
          wb_]\  := \ 
        r\[VeryThinSpace]\ n\^\(1 - \[Gamma]\)\ \[VeryThinSpace]\(wb\^\[Beta]\
\) Exp[\(-\[Lambda]\)\[VeryThinSpace]n];\)\)}], "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stability", "Subsection"],

Cell[CellGroupData[{

Cell["StabilityMatrix", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(StabilityMatrix[a_, n_Integer] := \(StabilityMatrix[a, n] = 
          Outer[a[Plus @@ #1, Plus @@ #2, CountHeterozygotes[#1, #2]] &, 
            HaploidTypes[n, SortByClass \[Rule] True], 
            HaploidTypes[n, SortByClass \[Rule] True], 1]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`StabilityK\)], "Subsubsection"],

Cell[BoxData[
    \(\(Options[StabilityK] = {MigrationOrder \[Rule] UMS, 
          FixedEnds \[Rule] {{}, {}}};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(StabilityK[k_, i_, h_, \[Psi]_SymmetricHaploidFrequencies, W_, 
          opts___Rule] := 
        StabilityK[k, i, h, \[Psi], \[Psi], W, opts];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(StabilityK[k_, i_, 
          h_, \[Psi] : 
            SymmetricHaploidFrequencies[g_List, nd_], \[Psi]\[Psi] : 
            SymmetricHaploidFrequencies[gg_List, ndnd_], W_, 
          opts___Rule] := \[IndentingNewLine]Module[\[IndentingNewLine]{q, 
            l = Quotient[i + k - h, 2], 
            n = Length[g] - 1, \[IndentingNewLine]mW = 
              MarginalW[MakeDiploid[\[Psi]\[Psi]], W, 
                opts]}, \[IndentingNewLine]Sum[
              gg\[LeftDoubleBracket]j + 
                    1\[RightDoubleBracket] \(2\^\(\(-i\) - j\)\) 
                Sum[\(4\^q\) Binomial[l, q] 
                      Binomial[n - i - k + l, j - q - k + l] 
                      W[i, j, i + j - 2  q], {q, Max[0, i + j - n], 
                      Min[j - k + l, l]}]/Binomial[n, j], {j, k - l, 
                n - i + 
                  l}] - \(g\[LeftDoubleBracket]k + 1\[RightDoubleBracket] mW\
\[LeftDoubleBracket]i + 1\[RightDoubleBracket]\)\/Binomial[n, k]];\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(StabilityK[k_, i_, 
          h_, \[Psi] : {SymmetricHaploidFrequencies[_, _] .. }, W_, m_, 
          opts___Rule] := 
        Module[{ff, q, nd = Length[\[Psi]], mW, dm, wb, \[Psi]m, offD, trd, 
            j, l, fe = \(FixedEnds /. {opts}\) /. 
                Options[
                  StabilityK], \[IndentingNewLine]mo = \(MigrationOrder /. \
{opts}\) /. Options[StabilityK]}, 
          offD[{g1_, g2_}, j_, {q0_, q1_}] := \[IndentingNewLine]Table[\ 
              StabilityK[k, i, h, 
                  g1\[LeftDoubleBracket]q\[RightDoubleBracket], 
                  g2\[LeftDoubleBracket]q + j\[RightDoubleBracket], W[q], 
                  opts]/wb\[LeftDoubleBracket]q\[RightDoubleBracket], {q, q0, 
                q1}]; \ trd[gl_, kk_, rQ_] := \ 
            TridiagonalMatrix[\[IndentingNewLine]\ 
              m\ offD[gl, kk, 
                  If[rQ, {1, nd - 1}, {2, nd}]], \[IndentingNewLine]dm = 
                2 \((1 - m)\) offD[gl, 0, {1, nd}]; \[IndentingNewLine]If[
                fe\[LeftDoubleBracket]1\[RightDoubleBracket] === {} || 
                  fe\[LeftDoubleBracket]1\[RightDoubleBracket] === {{}}, 
                dm\[LeftDoubleBracket]1\[RightDoubleBracket] = 
                  dm\[LeftDoubleBracket]1\[RightDoubleBracket] \(1 - \
m/2\)\/\(1 - m\)]; \[IndentingNewLine]If[
                fe\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] === {} || 
                  fe\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] === {{}}, 
                dm\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] = 
                  dm\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] \(1 - m/2\
\)\/\(1 - m\)]; \[IndentingNewLine]dm, \[IndentingNewLine]m\ offD[
                  gl, \(-kk\), 
                  If[\(! rQ\), {1, nd - 1}, {2, 
                      nd}]]\ ]; \[IndentingNewLine]Switch[
            mo, \[IndentingNewLine]UMS, \[IndentingNewLine]ff = 
              MigrateExact[MakeDiploid[\[Psi]], m, 
                opts]; \[IndentingNewLine]wb = 
              Table[MeanW[ff\[LeftDoubleBracket]q\[RightDoubleBracket], W[q], 
                  opts], {q, 
                  Length[ff]}]; \[IndentingNewLine]trd[{\[Psi], \[Psi]}, 1, 
              True], \[IndentingNewLine]MUS, \[IndentingNewLine]\[Psi]m = 
              MigrateExact[\[Psi], m, opts]; \[IndentingNewLine]wb = 
              Table[MeanW[gm\[LeftDoubleBracket]q\[RightDoubleBracket], W[q], 
                  opts], {q, 
                  Length[gm]}]; \[IndentingNewLine]trd[{\[Psi], \[Psi]m}, 0, 
              True], \n\ \ \ \ \ \ \ \ \ \ USM, \[IndentingNewLine]\ 
            ff = MakeDiploid[\[Psi]]; \[IndentingNewLine]\[Psi]m = 
              Table[NewGametes[ff\[LeftDoubleBracket]q\[RightDoubleBracket], 
                  W[q], opts], {q, Length[ff]}]; 
            wb = Table[
                MeanW[\[Psi]\[LeftDoubleBracket]q\[RightDoubleBracket], W[q], 
                  opts], {q, 
                  Length[g]}]; \[IndentingNewLine]trd[{\[Psi]m, \[Psi]}, 0, 
              False]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`StabilityKTable\)], "Subsubsection"],

Cell[BoxData[
    \(\(Options[StabilityKTable] = {MigrationOrder \[Rule] UMS, 
          FixedEnds \[Rule] {{}, {}}};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(StabilityKTable[k_, i_, h_, \[Psi]_SymmetricHaploidFrequencies, 
          wt_List] := 
        StabilityKTable[k, i, h, \[Psi], \[Psi], wt];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(StabilityKTable[k_, i_, 
          h_, \[Psi] : 
            SymmetricHaploidFrequencies[g_List, nd_], \[Psi]\[Psi] : 
            SymmetricHaploidFrequencies[gg_List, ndnd_], wt_List] := 
        Module[{q, l = Quotient[i + k - h, 2], n = Length[g] - 1, mW, m, j, 
            ii}, \[IndentingNewLine]mW = 
            MarginalW[MakeDiploid[\[Psi]\[Psi]], SymmetricMeanW[n, wt]]; 
          Sum[gg\[LeftDoubleBracket]j + 
                    1\[RightDoubleBracket] \(2\^\(\(-i\) - j\)\) 
                Sum[\(4\^q\) Binomial[l, q] 
                      Binomial[n - i - k + l, j - q - k + l] 
                      wt\[LeftDoubleBracket]i + 1, j + 1, 
                        i + j - 2  q + 1\[RightDoubleBracket], {q, 
                      Max[0, i + j - n], Min[j - k + l, l]}]/
                  Binomial[n, j], {j, k - l, 
                n - i + 
                  l}] - \(g\[LeftDoubleBracket]k + 1\[RightDoubleBracket] mW\
\[LeftDoubleBracket]i + 1\[RightDoubleBracket]\)\/Binomial[n, k]];\)\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(StabilityKTable[k_, i_, 
          h_, \[Psi] : {SymmetricHaploidFrequencies[_, _] .. }, wt_List, m_, 
          opts___Rule] := 
        Module[{ff, q, ww, nd = Length[\[Psi]], 
            n = Length[\[Psi]\[LeftDoubleBracket]1, 1\[RightDoubleBracket]] - 
                1, mW, wth, dma, dmb, dmc, wb, \[Psi]m, offD, trd, j, 
            fe = \(FixedEnds /. {opts}\) /. Options[StabilityKTable], 
            mo = \(MigrationOrder /. {opts}\) /. Options[StabilityKTable]}, 
          offD[{g1_, g2_}, j_, {q0_, q1_}] := \[IndentingNewLine]Table[\ 
              StabilityKTable[k, i, h, 
                  g1\[LeftDoubleBracket]q\[RightDoubleBracket], 
                  g2\[LeftDoubleBracket]q + j\[RightDoubleBracket], 
                  wt\[LeftDoubleBracket]q\[RightDoubleBracket]]/
                wb\[LeftDoubleBracket]q\[RightDoubleBracket], {q, q0, q1}]; \ 
          trd[gl_, kk_, 
              rQ_] := \[IndentingNewLine]\((dma = 
                m\ offD[gl, kk, 
                    If[rQ, {1, nd - 1}, {2, nd}]]; \[IndentingNewLine]dmc = 
                m\ offD[gl, \(-kk\), 
                    If[\(! rQ\), {1, nd - 1}, {2, 
                        nd}]]; \[IndentingNewLine]dmb = 
                2 \((1 - m)\) offD[gl, 0, {1, nd}]; \[IndentingNewLine]If[
                fe\[LeftDoubleBracket]1\[RightDoubleBracket] === {} || 
                  fe\[LeftDoubleBracket]1\[RightDoubleBracket] === {{}}, 
                dmb\[LeftDoubleBracket]1\[RightDoubleBracket] = 
                  dmb\[LeftDoubleBracket]1\[RightDoubleBracket] \(1 - m/2\)\/\
\(1 - m\)]; \ If[
                fe\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] === {} || 
                  fe\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] === {{}}, 
                dmb\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] = 
                  dmb\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] \(1 - \
m/2\)\/\(1 - m\)]; \[IndentingNewLine]TridiagonalMatrix[dma, dmb, 
                dmc])\); \[IndentingNewLine]wth = \(SymmetricMeanW[n, #] &\) /@ 
              wt; \[IndentingNewLine]Switch[
            mo, \[IndentingNewLine]UMS, \[IndentingNewLine]ff = 
              MigrateExact[MakeDiploid[\[Psi]], m, 
                opts]; \[IndentingNewLine]\ 
            wb = Table[
                MeanW[ff\[LeftDoubleBracket]q\[RightDoubleBracket], 
                  wth\[LeftDoubleBracket]q\[RightDoubleBracket]], {q, 
                  Length[ff]}]; \ \ \[IndentingNewLine]trd[{\[Psi], \[Psi]}, 
              1, 
              True], \[IndentingNewLine]MUS, \ \ \ \ \
\[IndentingNewLine]\[Psi]m = 
              MigrateExact[\[Psi], m, opts]; \[IndentingNewLine]ff = 
              MakeDiploid[\[Psi]m]; \[IndentingNewLine]wb = 
              Table[MeanW[ff\[LeftDoubleBracket]q\[RightDoubleBracket], 
                  wth\[LeftDoubleBracket]q\[RightDoubleBracket]], {q, 
                  Length[ff]}]; \[IndentingNewLine]trd[{\[Psi], \[Psi]m}, 0, 
              True], \ \[IndentingNewLine]\ 
            USM, \[IndentingNewLine]ff = 
              MakeDiploid[\[Psi]]; \ \ \[IndentingNewLine]\[Psi]m = 
              Table[NewGametes[ff\[LeftDoubleBracket]q\[RightDoubleBracket], 
                  wth\[LeftDoubleBracket]q\[RightDoubleBracket], opts], {q, 
                  Length[ff]}]; \ 
            wb = Table[
                MeanW[\[Psi]\[LeftDoubleBracket]q\[RightDoubleBracket], 
                  wth\[LeftDoubleBracket]q\[RightDoubleBracket]], {q, 
                  Length[g]}]; \[IndentingNewLine]trd[{\[Psi]m, \[Psi]}, 0, 
              False]]];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["SigmaMatrix", "Subsubsection"],

Cell[BoxData[
    \(\(SigmaMatrix[a_, p_, n_] := \n\t\tModule[{i, j}, 
          Table[SigmaMatrix[a, i, j, p, n], {i, p, n - p}, {j, p, 
              n - p}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SigmaMatrix[a_, i_, j_, p_, n_] := 
        Module[{r, k}, 
          Sum[a[i, j, i + j - 2  r] 
              Sum[\(\((\(-1\))\)\^k\) Binomial[p, k] 
                  Binomial[i - p, k + r - p] 
                  Binomial[n - i - p, j - k - r], {k, 0, p}], {r, 
              Max[0, i + j - n], Min[i, j]}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExactEigenvalues", "Subsubsection"],

Cell[BoxData[
    \(\(ExactEigenvalues[a_, n_] := 
        Module[{sm}, \n\t\tTable[\n\t\t\tsm = 
              SigmaMatrix[a, p, n]; \n\t\t\tIf[
              TensorRank[sm] == 4, \n\t\t\t\tEigenvalues[
                BlockMatrix[sm]], \n\t\t\t\tEigenvalues[sm]], {p, 0, 
              Floor[n/2]}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`StabilityDirect\)], "Subsubsection"],

Cell[BoxData[
    \(\(StabilityDirect[\((pr : 
                HaploidFrequencies | AlleleFrequencies)\)[\[Psi]_, nd_], W_, 
          m_, opts___Rule] := \[IndentingNewLine]Module[{pn, 
            n = Length[\[Psi]], gt, g}, \[IndentingNewLine]gt = 
            Array[g, n + 1]; 
          gn = Append[\[Psi], nd]; \[IndentingNewLine]pn = 
            IterateExact[
              pr[Drop[gt, \(-1\)], 
                gt\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]], W, m, 
              opts]; \[IndentingNewLine]pn = 
            Append[pn\[LeftDoubleBracket]1\[RightDoubleBracket], 
              pn\[LeftDoubleBracket]2\[RightDoubleBracket]]; \
\[IndentingNewLine]Outer[D[#1, #2] &, pn, gt] /. 
            g[j_] :> gn\[LeftDoubleBracket]
                j\[RightDoubleBracket]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(StabilityDirect[\[Psi] : {\((pr : 
                      HaploidFrequencies | AlleleFrequencies)\)[_, _] .. }, 
          W_, m_, opts___Rule] := \[IndentingNewLine]Module[{nd = 
              Length[\[Psi]], 
            ng = Length[\[Psi]\[LeftDoubleBracket]1, 1\[RightDoubleBracket]], 
            gn, g, d, j, ppn}, \[IndentingNewLine]gn = 
            Table[pr[Array[g[d, #] &, ng], g[d, ng + 1]], {d, 
                nd}]; \[IndentingNewLine]ppn = 
            IterateExact[gn, W, m, opts] /. 
              pr[\[Phi]_, n_] \[RuleDelayed] 
                Append[\[Phi], 
                  n]; \[IndentingNewLine]Transpose[\[IndentingNewLine]Table[
              D[ppn, g[d, j]] /. 
                g[dd_, jj_] \[RuleDelayed] 
                  If[jj > ng, \[Psi]\[LeftDoubleBracket]dd, 
                      2\[RightDoubleBracket], \[Psi]\[LeftDoubleBracket]dd, 
                      1, jj\[RightDoubleBracket]], {d, nd}, {j, 
                ng + 1}], \[IndentingNewLine]{4, 2, 3, 1}]];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises", "Subsection"],

Cell[CellGroupData[{

Cell["NmMLE", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(NmMLE[p_List, k_List] := 
        Module[{lnm, NmEst}, \[IndentingNewLine]NmEst = 
            Min[Max[0.1, 
                1/\((Variance[p]\/\(Mean[p] \((1 - Mean[p])\)\) - 
                      1\/Mean[k])\)], 10]; \[IndentingNewLine]Exp[
              lnm] /. \(FindMinimum[\(-logLikNm[p, k, Exp[lnm]]\), {lnm, 
                  Log[NmEst]}]\)\[LeftDoubleBracket]2\[RightDoubleBracket]];\)\
\), "\[IndentingNewLine]", 
    \(\(NmMLE[p_List, k_Integer] := 
        NmMLE[p, Array[k &, Length[p]]];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["logLikNm", "Subsubsection"],

Cell[BoxData[{
    \(\(logLikNm[p_, k_Integer, pb_, Nm_] := 
        Module[{j, kp = Round[k\ p], 
            kq = Round[
                k \((1 - 
                      p)\)]}, \[IndentingNewLine]\[Sum]\+\(j = 0\)\%\(kp - \
1\)Log[4  Nm\ pb + j] + \[Sum]\+\(j = 0\)\%\(kq - 1\)Log[
                4  Nm \((1 - pb)\) + j] - \((\[Sum]\+\(j = 0\)\%\(k - 1\)Log[
                  4  Nm + j])\)];\)\), "\[IndentingNewLine]", 
    \(\(logLikNm[p_List, k_List, 
          Nm_] := \[IndentingNewLine]Module[{pb = 
              p . k\/Plus @@ k}, \[IndentingNewLine]Plus @@ 
            MapThread[
              logLikNm[#1, #2, pb, Nm] &, {p, 
                k}]];\)\), "\[IndentingNewLine]", 
    \(\(logLikNm[p_List, k_Integer, Nm_] := 
        logLikNm[p, Array[k &, Length[p]], Nm];\)\)}], "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ending", "Subsection"],

Cell[BoxData[{
    \(\(End[];\)\), "\n", 
    \(\(On[General::spell1, General::spell];\)\), "\n", 
    \(\(EndPackage[];\)\)}], "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1276}, {0, 832}},
AutoGeneratedPackage->Automatic,
EvaluationCompletionAction->"ShowTiming",
WindowSize->{936, 805},
WindowMargins->{{Automatic, 25}, {Automatic, 0}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\[Placeholder]", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->8],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    Hyphenation->True,
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "EnhancedPrintout"],
    StyleMenuListing->None,
    FontFamily->"Futura",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 418, 8, 123, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2197, 63, 113, 3, 50, "Section",
  Evaluatable->False,
  InitializationCell->True],
Cell[2313, 68, 102, 2, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2440, 74, 53, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[2518, 78, 90, 2, 42, "Subsubsection"],
Cell[2611, 82, 887, 17, 171, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3535, 104, 64, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[3602, 107, 497, 7, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4136, 119, 36, 0, 28, "Subsubsection"],
Cell[4175, 121, 489, 7, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4701, 133, 40, 0, 28, "Subsubsection"],
Cell[4744, 135, 778, 11, 155, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5559, 151, 43, 0, 28, "Subsubsection"],
Cell[5605, 153, 223, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5865, 162, 65, 1, 28, "Subsubsection"],
Cell[5933, 165, 228, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[6198, 174, 69, 1, 28, "Subsubsection"],
Cell[6270, 177, 349, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[6656, 188, 69, 1, 28, "Subsubsection"],
Cell[6728, 191, 544, 9, 80, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[7309, 205, 68, 1, 28, "Subsubsection"],
Cell[7380, 208, 345, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[7762, 218, 78, 1, 28, "Subsubsection"],
Cell[7843, 221, 523, 9, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8403, 235, 78, 1, 28, "Subsubsection"],
Cell[8484, 238, 763, 11, 115, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9284, 254, 69, 1, 28, "Subsubsection"],
Cell[9356, 257, 348, 7, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9741, 269, 69, 1, 28, "Subsubsection"],
Cell[9813, 272, 394, 7, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[10244, 284, 59, 0, 28, "Subsubsection"],
Cell[10306, 286, 589, 9, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[10932, 300, 59, 0, 28, "Subsubsection"],
Cell[10994, 302, 1071, 16, 116, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[12102, 323, 50, 0, 28, "Subsubsection"],
Cell[12155, 325, 205, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[12397, 334, 49, 0, 28, "Subsubsection"],
Cell[12449, 336, 244, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[12730, 345, 50, 0, 28, "Subsubsection"],
Cell[12783, 347, 230, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[13050, 356, 47, 0, 28, "Subsubsection"],
Cell[13100, 358, 207, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[13344, 367, 47, 0, 28, "Subsubsection"],
Cell[13394, 369, 207, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[13638, 378, 47, 0, 28, "Subsubsection"],
Cell[13688, 380, 230, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[13955, 390, 50, 0, 28, "Subsubsection"],
Cell[14008, 392, 219, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[14264, 401, 49, 0, 28, "Subsubsection"],
Cell[14316, 403, 189, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[14542, 411, 52, 0, 28, "Subsubsection"],
Cell[14597, 413, 246, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[14880, 422, 41, 0, 28, "Subsubsection"],
Cell[14924, 424, 280, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[15241, 434, 64, 1, 28, "Subsubsection"],
Cell[15308, 437, 281, 5, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[15626, 447, 70, 1, 28, "Subsubsection"],
Cell[15699, 450, 505, 8, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[16241, 463, 71, 1, 28, "Subsubsection"],
Cell[16315, 466, 488, 8, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[16840, 479, 43, 0, 28, "Subsubsection"],
Cell[16886, 481, 477, 7, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[17400, 493, 44, 0, 28, "Subsubsection"],
Cell[17447, 495, 473, 7, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[17957, 507, 33, 0, 28, "Subsubsection"],
Cell[17993, 509, 209, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[18239, 518, 35, 0, 28, "Subsubsection"],
Cell[18277, 520, 523, 8, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[18837, 533, 64, 1, 28, "Subsubsection"],
Cell[18904, 536, 969, 13, 98, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[19910, 554, 66, 1, 42, "Subsubsection"],
Cell[19979, 557, 1207, 18, 126, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[21223, 580, 62, 1, 42, "Subsubsection",
  InitializationCell->True],
Cell[21288, 583, 490, 7, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[21815, 595, 43, 0, 28, "Subsubsection"],
Cell[21861, 597, 196, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[22094, 606, 36, 0, 28, "Subsubsection"],
Cell[22133, 608, 546, 8, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[22716, 621, 56, 1, 28, "Subsubsection"],
Cell[22775, 624, 579, 9, 60, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[23391, 638, 39, 0, 42, "Subsubsection"],
Cell[23433, 640, 1051, 15, 109, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[24521, 660, 60, 1, 42, "Subsubsection"],
Cell[24584, 663, 584, 9, 76, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[25205, 677, 63, 1, 42, "Subsubsection"],
Cell[25271, 680, 407, 6, 91, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[25727, 692, 32, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[25784, 696, 37, 0, 42, "Subsubsection"],
Cell[25824, 698, 188, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[26049, 706, 62, 1, 28, "Subsubsection"],
Cell[26114, 709, 968, 14, 140, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[27119, 728, 58, 1, 28, "Subsubsection"],
Cell[27180, 731, 1163, 17, 142, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[28380, 753, 38, 0, 28, "Subsubsection"],
Cell[28421, 755, 343, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[28801, 765, 61, 1, 28, "Subsubsection"],
Cell[28865, 768, 1249, 18, 208, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[30151, 791, 31, 0, 28, "Subsubsection"],
Cell[30185, 793, 484, 7, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[30706, 805, 39, 0, 28, "Subsubsection"],
Cell[30748, 807, 968, 14, 156, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[31753, 826, 44, 0, 28, "Subsubsection"],
Cell[31800, 828, 239, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[32076, 837, 46, 0, 28, "Subsubsection"],
Cell[32125, 839, 429, 7, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[32591, 851, 54, 0, 28, "Subsubsection"],
Cell[32648, 853, 508, 9, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[33193, 867, 33, 0, 42, "Subsubsection"],
Cell[33229, 869, 394, 6, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[33660, 880, 39, 0, 28, "Subsubsection"],
Cell[33702, 882, 758, 11, 141, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[34497, 898, 44, 0, 28, "Subsubsection"],
Cell[34544, 900, 510, 8, 108, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[35091, 913, 36, 0, 28, "Subsubsection"],
Cell[35130, 915, 347, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[35514, 925, 63, 1, 28, "Subsubsection"],
Cell[35580, 928, 2597, 37, 404, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[38214, 970, 37, 0, 28, "Subsubsection"],
Cell[38254, 972, 893, 13, 100, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[39184, 990, 31, 0, 28, "Subsubsection"],
Cell[39218, 992, 1068, 16, 101, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[40323, 1013, 39, 0, 28, "Subsubsection"],
Cell[40365, 1015, 224, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[40626, 1024, 28, 0, 28, "Subsubsection"],
Cell[40657, 1026, 228, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[40922, 1035, 28, 0, 28, "Subsubsection"],
Cell[40953, 1037, 228, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[41218, 1046, 28, 0, 28, "Subsubsection"],
Cell[41249, 1048, 228, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[41514, 1057, 39, 0, 28, "Subsubsection"],
Cell[41556, 1059, 211, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[41804, 1068, 65, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[41872, 1071, 786, 11, 155, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[42695, 1087, 35, 0, 28, "Subsubsection"],
Cell[42733, 1089, 488, 7, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[43258, 1101, 60, 1, 28, "Subsubsection"],
Cell[43321, 1104, 183, 3, 28, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[43541, 1112, 34, 0, 28, "Subsubsection"],
Cell[43578, 1114, 415, 6, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[44030, 1125, 95, 2, 28, "Subsubsection",
  InitializationCell->True],
Cell[44128, 1129, 412, 7, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[44577, 1141, 41, 0, 28, "Subsubsection"],
Cell[44621, 1143, 279, 5, 75, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[44949, 1154, 31, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[45005, 1158, 68, 1, 42, "Subsubsection",
  InitializationCell->True],
Cell[45076, 1161, 188, 3, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[45301, 1169, 61, 1, 28, "Subsubsection"],
Cell[45365, 1172, 614, 9, 163, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[46016, 1186, 66, 1, 28, "Subsubsection"],
Cell[46085, 1189, 1224, 18, 199, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[47346, 1212, 36, 0, 28, "Subsubsection"],
Cell[47385, 1214, 273, 4, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[47695, 1223, 41, 0, 28, "Subsubsection"],
Cell[47739, 1225, 253, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[48029, 1234, 66, 1, 28, "Subsubsection"],
Cell[48098, 1237, 690, 10, 139, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[48837, 1253, 31, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[48893, 1257, 33, 0, 42, "Subsubsection"],
Cell[48929, 1259, 467, 8, 76, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[49433, 1272, 58, 1, 42, "Subsubsection",
  InitializationCell->True],
Cell[49494, 1275, 370, 6, 59, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[49925, 1288, 32, 0, 30, "Section"],
Cell[49960, 1290, 114, 2, 27, "Input",
  InitializationCell->True],
Cell[50077, 1294, 146, 4, 32, "Text",
  InitializationCell->True],
Cell[50226, 1300, 104, 2, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[50355, 1306, 53, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[50433, 1310, 39, 0, 42, "Subsubsection"],
Cell[50475, 1312, 141, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[50653, 1320, 69, 1, 28, "Subsubsection"],
Cell[50725, 1323, 151, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[50913, 1331, 69, 1, 28, "Subsubsection"],
Cell[50985, 1334, 151, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[51173, 1342, 68, 1, 28, "Subsubsection"],
Cell[51244, 1345, 137, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[51418, 1353, 78, 1, 28, "Subsubsection"],
Cell[51499, 1356, 157, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[51693, 1364, 78, 1, 28, "Subsubsection"],
Cell[51774, 1367, 157, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[51968, 1375, 59, 0, 28, "Subsubsection"],
Cell[52030, 1377, 171, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[52238, 1385, 59, 0, 28, "Subsubsection"],
Cell[52300, 1387, 171, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[52508, 1395, 69, 1, 28, "Subsubsection"],
Cell[52580, 1398, 152, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[52769, 1406, 69, 1, 28, "Subsubsection"],
Cell[52841, 1409, 152, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[53030, 1417, 50, 0, 28, "Subsubsection"],
Cell[53083, 1419, 382, 7, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[53502, 1431, 49, 0, 28, "Subsubsection"],
Cell[53554, 1433, 328, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[53919, 1444, 50, 0, 28, "Subsubsection"],
Cell[53972, 1446, 142, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[54151, 1454, 47, 0, 28, "Subsubsection"],
Cell[54201, 1456, 248, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[54486, 1466, 47, 0, 28, "Subsubsection"],
Cell[54536, 1468, 248, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[54821, 1478, 47, 0, 28, "Subsubsection"],
Cell[54871, 1480, 182, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[55090, 1489, 50, 0, 28, "Subsubsection"],
Cell[55143, 1491, 286, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[55466, 1501, 49, 0, 28, "Subsubsection"],
Cell[55518, 1503, 255, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[55810, 1513, 52, 0, 28, "Subsubsection"],
Cell[55865, 1515, 197, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[56099, 1524, 90, 2, 28, "Subsubsection"],
Cell[56192, 1528, 173, 3, 27, "Input",
  InitializationCell->True],
Cell[56368, 1533, 190, 4, 43, "Input",
  InitializationCell->True],
Cell[56561, 1539, 2961, 52, 573, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[59559, 1596, 43, 0, 28, "Subsubsection"],
Cell[59605, 1598, 704, 12, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[60346, 1615, 64, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[60413, 1618, 202, 4, 59, "Input",
  InitializationCell->True],
Cell[60618, 1624, 1195, 22, 171, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[61850, 1651, 36, 0, 28, "Subsubsection"],
Cell[61889, 1653, 1286, 23, 171, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[63212, 1681, 40, 0, 28, "Subsubsection"],
Cell[63255, 1683, 250, 4, 43, "Input",
  InitializationCell->True],
Cell[63508, 1689, 3217, 59, 395, "Input",
  InitializationCell->True],
Cell[66728, 1750, 172, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[66937, 1758, 41, 0, 28, "Subsubsection"],
Cell[66981, 1760, 344, 8, 54, "Input",
  InitializationCell->True],
Cell[67328, 1770, 206, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[67571, 1779, 64, 1, 28, "Subsubsection"],
Cell[67638, 1782, 138, 3, 27, "Input",
  InitializationCell->True],
Cell[67779, 1787, 184, 3, 43, "Input",
  InitializationCell->True],
Cell[67966, 1792, 1152, 20, 251, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[69155, 1817, 70, 1, 28, "Subsubsection"],
Cell[69228, 1820, 506, 9, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[69771, 1834, 71, 1, 28, "Subsubsection"],
Cell[69845, 1837, 1651, 28, 267, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[71533, 1870, 43, 0, 28, "Subsubsection"],
Cell[71579, 1872, 1165, 19, 219, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[72781, 1896, 44, 0, 28, "Subsubsection"],
Cell[72828, 1898, 2881, 48, 612, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[75746, 1951, 33, 0, 28, "Subsubsection"],
Cell[75782, 1953, 251, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[76070, 1963, 35, 0, 28, "Subsubsection"],
Cell[76108, 1965, 150, 3, 27, "Input",
  InitializationCell->True],
Cell[76261, 1970, 817, 16, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[77115, 1991, 64, 1, 28, "Subsubsection"],
Cell[77182, 1994, 119, 2, 27, "Input",
  InitializationCell->True],
Cell[77304, 1998, 480, 9, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[77821, 2012, 66, 1, 28, "Subsubsection"],
Cell[77890, 2015, 123, 3, 27, "Input",
  InitializationCell->True],
Cell[78016, 2020, 591, 11, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[78644, 2036, 62, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[78709, 2039, 154, 4, 27, "Input",
  InitializationCell->True],
Cell[78866, 2045, 628, 10, 164, "Input",
  InitializationCell->True],
Cell[79497, 2057, 667, 11, 164, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[80201, 2073, 43, 0, 28, "Subsubsection"],
Cell[80247, 2075, 169, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[80453, 2083, 36, 0, 28, "Subsubsection"],
Cell[80492, 2085, 363, 7, 43, "Input",
  InitializationCell->True],
Cell[80858, 2094, 445, 8, 107, "Input",
  InitializationCell->True],
Cell[81306, 2104, 358, 7, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[81701, 2116, 30, 0, 28, "Subsubsection"],
Cell[81734, 2118, 174, 3, 29, "Input",
  InitializationCell->True],
Cell[81911, 2123, 547, 10, 75, "Input",
  InitializationCell->True],
Cell[82461, 2135, 469, 8, 75, "Input",
  InitializationCell->True],
Cell[82933, 2145, 1179, 20, 235, "Input",
  InitializationCell->True],
Cell[84115, 2167, 1627, 31, 267, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[85779, 2203, 60, 1, 28, "Subsubsection"],
Cell[85842, 2206, 162, 3, 43, "Input",
  InitializationCell->True],
Cell[86007, 2211, 425, 10, 75, "Input",
  InitializationCell->True],
Cell[86435, 2223, 563, 10, 91, "Input",
  InitializationCell->True],
Cell[87001, 2235, 373, 7, 59, "Input",
  InitializationCell->True],
Cell[87377, 2244, 508, 8, 112, "Input",
  InitializationCell->True],
Cell[87888, 2254, 689, 12, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[88614, 2271, 39, 0, 28, "Subsubsection"],
Cell[88656, 2273, 143, 3, 27, "Input",
  InitializationCell->True],
Cell[88802, 2278, 243, 5, 43, "Input",
  InitializationCell->True],
Cell[89048, 2285, 377, 7, 59, "Input",
  InitializationCell->True],
Cell[89428, 2294, 237, 4, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[89702, 2303, 63, 1, 28, "Subsubsection"],
Cell[89768, 2306, 157, 4, 27, "Input",
  InitializationCell->True],
Cell[89928, 2312, 279, 5, 75, "Input",
  InitializationCell->True],
Cell[90210, 2319, 1206, 21, 251, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[91465, 2346, 32, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[91522, 2350, 62, 1, 42, "Subsubsection"],
Cell[91587, 2353, 204, 4, 43, "Input",
  InitializationCell->True],
Cell[91794, 2359, 138, 3, 27, "Input",
  InitializationCell->True],
Cell[91935, 2364, 139, 3, 27, "Input",
  InitializationCell->True],
Cell[92077, 2369, 967, 17, 251, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[93081, 2391, 58, 1, 28, "Subsubsection"],
Cell[93142, 2394, 108, 2, 27, "Input",
  InitializationCell->True],
Cell[93253, 2398, 254, 5, 43, "Input",
  InitializationCell->True],
Cell[93510, 2405, 461, 9, 125, "Input",
  InitializationCell->True],
Cell[93974, 2416, 214, 4, 43, "Input",
  InitializationCell->True],
Cell[94191, 2422, 1494, 25, 331, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[95722, 2452, 38, 0, 28, "Subsubsection"],
Cell[95763, 2454, 448, 9, 75, "Input",
  InitializationCell->True],
Cell[96214, 2465, 224, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[96475, 2475, 61, 1, 28, "Subsubsection"],
Cell[96539, 2478, 247, 4, 43, "Input",
  InitializationCell->True],
Cell[96789, 2484, 144, 3, 27, "Input",
  InitializationCell->True],
Cell[96936, 2489, 408, 8, 59, "Input",
  InitializationCell->True],
Cell[97347, 2499, 1164, 22, 199, "Input",
  InitializationCell->True],
Cell[98514, 2523, 1408, 25, 251, "Input",
  InitializationCell->True],
Cell[99925, 2550, 1479, 27, 267, "Input",
  InitializationCell->True],
Cell[101407, 2579, 1306, 23, 251, "Input",
  InitializationCell->True],
Cell[102716, 2604, 2714, 49, 425, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[105467, 2658, 44, 0, 28, "Subsubsection"],
Cell[105514, 2660, 547, 13, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[106098, 2678, 31, 0, 28, "Subsubsection"],
Cell[106132, 2680, 108, 2, 27, "Input",
  InitializationCell->True],
Cell[106243, 2684, 424, 7, 75, "Input",
  InitializationCell->True],
Cell[106670, 2693, 236, 4, 43, "Input",
  InitializationCell->True],
Cell[106909, 2699, 693, 13, 107, "Input",
  InitializationCell->True],
Cell[107605, 2714, 270, 5, 43, "Input",
  InitializationCell->True],
Cell[107878, 2721, 351, 6, 59, "Input",
  InitializationCell->True],
Cell[108232, 2729, 159, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[108428, 2737, 46, 0, 28, "Subsubsection"],
Cell[108477, 2739, 177, 3, 27, "Input",
  InitializationCell->True],
Cell[108657, 2744, 178, 3, 43, "Input",
  InitializationCell->True],
Cell[108838, 2749, 3018, 52, 527, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[111893, 2806, 58, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[111976, 2810, 264, 4, 80, "Input"],
Cell[112243, 2816, 282, 4, 47, "Output"]
}, Open  ]],
Cell[112540, 2823, 343, 6, 100, "Input"],

Cell[CellGroupData[{
Cell[112908, 2833, 490, 8, 134, "Input"],
Cell[113401, 2843, 165, 3, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[113603, 2851, 532, 9, 134, "Input"],
Cell[114138, 2862, 183, 3, 28, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[114370, 2871, 54, 0, 28, "Subsubsection"],
Cell[114427, 2873, 991, 16, 107, "Input",
  InitializationCell->True],
Cell[115421, 2891, 1437, 25, 233, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[116895, 2921, 39, 0, 28, "Subsubsection"],
Cell[116937, 2923, 615, 12, 75, "Input",
  InitializationCell->True],
Cell[117555, 2937, 483, 9, 59, "Input",
  InitializationCell->True],
Cell[118041, 2948, 278, 5, 43, "Input",
  InitializationCell->True],
Cell[118322, 2955, 331, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[118690, 2966, 65, 1, 28, "Subsubsection",
  InitializationCell->True],
Cell[118758, 2969, 118, 2, 27, "Input",
  InitializationCell->True],
Cell[118879, 2973, 1848, 32, 241, "Input",
  InitializationCell->True],
Cell[120730, 3007, 1536, 26, 173, "Input",
  InitializationCell->True],
Cell[122269, 3035, 1433, 25, 157, "Input",
  InitializationCell->True],
Cell[123705, 3062, 3080, 55, 317, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[126822, 3122, 36, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[126883, 3126, 147, 3, 27, "Input",
  InitializationCell->True],
Cell[127033, 3131, 89, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[127159, 3137, 153, 3, 27, "Input",
  InitializationCell->True],
Cell[127315, 3142, 93, 1, 70, "Output"]
}, Open  ]],
Cell[127423, 3146, 224, 4, 43, "Input",
  InitializationCell->True],
Cell[127650, 3152, 1517, 27, 267, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[129204, 3184, 39, 0, 28, "Subsubsection"],
Cell[129246, 3186, 140, 4, 27, "Input",
  InitializationCell->True],
Cell[129389, 3192, 148, 3, 27, "Input",
  InitializationCell->True],
Cell[129540, 3197, 634, 11, 75, "Input",
  InitializationCell->True],
Cell[130177, 3210, 767, 14, 107, "Input",
  InitializationCell->True],
Cell[130947, 3226, 639, 13, 75, "Input",
  InitializationCell->True],
Cell[131589, 3241, 477, 9, 81, "Input",
  InitializationCell->True],
Cell[132069, 3252, 647, 11, 157, "Input",
  InitializationCell->True],
Cell[132719, 3265, 327, 6, 77, "Input",
  InitializationCell->True],
Cell[133049, 3273, 257, 5, 46, "Text"],
Cell[133309, 3280, 2684, 47, 415, "Input",
  InitializationCell->True],
Cell[135996, 3329, 706, 13, 107, "Input",
  InitializationCell->True],
Cell[136705, 3344, 1679, 33, 267, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[138421, 3382, 106, 2, 28, "Subsubsection"],
Cell[138530, 3386, 259, 5, 43, "Input",
  InitializationCell->True],
Cell[138792, 3393, 153, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[138982, 3401, 79, 1, 28, "Subsubsection"],
Cell[139064, 3404, 4204, 74, 587, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[143305, 3483, 75, 1, 28, "Subsubsection"],
Cell[143383, 3486, 4694, 81, 603, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[148114, 3572, 91, 1, 42, "Subsubsection"],
Cell[148208, 3575, 1265, 22, 272, "Input",
  InitializationCell->True],
Cell[149476, 3599, 1326, 24, 288, "Input",
  InitializationCell->True],
Cell[150805, 3625, 1325, 24, 272, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[152167, 3654, 175, 3, 28, "Subsubsection"],
Cell[152345, 3659, 1534, 28, 323, "Input",
  InitializationCell->True],
Cell[153882, 3689, 135, 3, 27, "Input"],
Cell[154020, 3694, 2423, 42, 408, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[156480, 3741, 119, 2, 28, "Subsubsection"],
Cell[156602, 3745, 1651, 28, 356, "Input",
  InitializationCell->True],
Cell[158256, 3775, 146, 3, 27, "Input",
  InitializationCell->True],
Cell[158405, 3780, 1766, 30, 327, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[160208, 3815, 89, 1, 28, "Subsubsection"],
Cell[160300, 3818, 2607, 45, 380, "Input",
  InitializationCell->True],
Cell[162910, 3865, 2615, 46, 427, "Input",
  InitializationCell->True],
Cell[165528, 3913, 3286, 58, 456, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[168851, 3976, 117, 2, 42, "Subsubsection"],
Cell[168971, 3980, 3081, 55, 499, "Input",
  InitializationCell->True],
Cell[172055, 4037, 142, 3, 27, "Input",
  InitializationCell->True],
Cell[172200, 4042, 3810, 66, 516, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[176047, 4113, 106, 2, 28, "Subsubsection"],
Cell[176156, 4117, 3045, 54, 395, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[179238, 4176, 118, 2, 28, "Subsubsection"],
Cell[179359, 4180, 1492, 26, 299, "Input",
  InitializationCell->True],
Cell[180854, 4208, 1578, 27, 299, "Input",
  InitializationCell->True],
Cell[182435, 4237, 1477, 26, 269, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[183949, 4268, 102, 2, 28, "Subsubsection"],
Cell[184054, 4272, 4822, 82, 731, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[188913, 4359, 118, 2, 28, "Subsubsection"],
Cell[189034, 4363, 4064, 70, 655, "Input",
  InitializationCell->True],
Cell[193101, 4435, 3768, 67, 621, "Input",
  InitializationCell->True],
Cell[196872, 4504, 4319, 74, 681, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[201228, 4583, 35, 0, 28, "Subsubsection"],
Cell[201266, 4585, 157, 3, 27, "Input",
  InitializationCell->True],
Cell[201426, 4590, 475, 7, 91, "Input",
  InitializationCell->True],
Cell[201904, 4599, 643, 12, 107, "Input",
  InitializationCell->True],
Cell[202550, 4613, 1738, 30, 267, "Input",
  InitializationCell->True],
Cell[204291, 4645, 1328, 23, 235, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[205656, 4673, 60, 1, 28, "Subsubsection"],
Cell[205719, 4676, 102, 2, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[205858, 4683, 95, 2, 28, "Subsubsection",
  InitializationCell->True],
Cell[205956, 4687, 157, 3, 27, "Input",
  InitializationCell->True],
Cell[206116, 4692, 673, 13, 123, "Input",
  InitializationCell->True],
Cell[206792, 4707, 1042, 20, 203, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[207871, 4732, 41, 0, 28, "Subsubsection"],
Cell[207915, 4734, 218, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[208170, 4743, 37, 0, 28, "Subsubsection"],
Cell[208210, 4745, 465, 7, 47, "Input",
  InitializationCell->True],
Cell[208678, 4754, 490, 8, 47, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[209205, 4767, 31, 0, 28, "Subsubsection"],
Cell[209239, 4769, 420, 7, 47, "Input",
  InitializationCell->True],
Cell[209662, 4778, 445, 8, 47, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[210156, 4792, 31, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[210212, 4796, 68, 1, 42, "Subsubsection",
  InitializationCell->True],
Cell[210283, 4799, 316, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[210636, 4809, 61, 1, 28, "Subsubsection"],
Cell[210700, 4812, 155, 3, 27, "Input",
  InitializationCell->True],
Cell[210858, 4817, 209, 4, 43, "Input",
  InitializationCell->True],
Cell[211070, 4823, 1041, 20, 150, "Input",
  InitializationCell->True],
Cell[212114, 4845, 3075, 52, 511, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[215226, 4902, 66, 1, 28, "Subsubsection"],
Cell[215295, 4905, 160, 3, 27, "Input",
  InitializationCell->True],
Cell[215458, 4910, 206, 4, 43, "Input",
  InitializationCell->True],
Cell[215667, 4916, 1067, 20, 134, "Input",
  InitializationCell->True],
Cell[216737, 4938, 3619, 61, 550, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[220393, 5004, 36, 0, 42, "Subsubsection"],
Cell[220432, 5006, 204, 4, 43, "Input",
  InitializationCell->True],
Cell[220639, 5012, 375, 8, 104, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[221051, 5025, 41, 0, 28, "Subsubsection"],
Cell[221095, 5027, 345, 7, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[221477, 5039, 66, 1, 28, "Subsubsection"],
Cell[221546, 5042, 831, 16, 123, "Input",
  InitializationCell->True],
Cell[222380, 5060, 1062, 19, 155, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[223491, 5085, 31, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[223547, 5089, 58, 1, 42, "Subsubsection",
  InitializationCell->True],
Cell[223608, 5092, 569, 11, 101, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[224214, 5108, 33, 0, 28, "Subsubsection"],
Cell[224250, 5110, 828, 17, 164, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[225127, 5133, 28, 0, 46, "Subsection"],
Cell[225158, 5135, 164, 4, 59, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

