(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     18414,        558]*)
(*NotebookOutlinePosition[     91451,       3179]*)
(*  CellTagsIndexPosition[     90900,       3161]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Bugs and features", "Section"],

Cell[CellGroupData[{

Cell["Applying rules", "SubsectionIcon"],

Cell["\<\
If a list of rules is given, the first one that applies is used, \
and the rest are ignored - even if the first rule in fact makes no change.  \
\
\>", "Text",
  CellTags->"Applying rules"],

Cell["For example:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rl1 = {x_List :> \((Print["\<rl1 \>", x]; x)\)}; 
    rl2 = {x_List :> \((Print["\<rl2 \>", x]; x)\)}; {aa, bb} /. 
      rl1\[Vee]rl2\)], "Input",
  CellLabel->"In[7]:=  (19:40:40 on 3/7/01)"],

Cell[BoxData[
    InterpretationBox[\("rl1 "\[InvisibleSpace]{aa, bb}\),
      SequenceForm[ "rl1 ", {aa, bb}],
      Editable->False]], "Print",
  CellLabel->"From In[7]:=  (19:40:40 on 3/7/01)"],

Cell[BoxData[
    \({aa, bb}\)], "Output",
  CellLabel->"Out[7]=  (19:40:40 on 3/7/01)"]
}, Open  ]],

Cell[TextData[{
  "Thus, a list of rules of the kind used to describe a ",
  ButtonBox["complete life cycle ",
    ButtonData:>{"Complete life cycle", "Complete rules"},
    ButtonStyle->"AddOnsLink"],
  "might not be applied thoroughly, if one rule is applied, but makes no \
change, thus blocking later rules.  There are two ways round this \
difficulty:"
}], "Text"],

Cell["Apply the rules successively: ", "Text",
  CellDingbat->"\[GrayCircle]",
  CellMargins->{{53, Inherited}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({aa, bb} /. rl1\) /. rl2\)], "Input",
  CellLabel->"In[8]:=  (19:40:41 on 3/7/01)"],

Cell[BoxData[
    InterpretationBox[\("rl1 "\[InvisibleSpace]{aa, bb}\),
      SequenceForm[ "rl1 ", {aa, bb}],
      Editable->False]], "Print",
  CellLabel->"From In[8]:=  (19:40:41 on 3/7/01)"],

Cell[BoxData[
    InterpretationBox[\("rl2 "\[InvisibleSpace]{aa, bb}\),
      SequenceForm[ "rl2 ", {aa, bb}],
      Editable->False]], "Print",
  CellLabel->"From In[8]:=  (19:40:41 on 3/7/01)"],

Cell[BoxData[
    \({aa, bb}\)], "Output",
  CellLabel->"Out[8]=  (19:40:41 on 3/7/01)"]
}, Open  ]],

Cell["\<\
This is cumbersome when rules need to be applied several times \
until there is no further change. \
\>", "Text",
  CellDingbat->None,
  CellMargins->{{53, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Ensure that rules only apply when they will in fact make a change.  \
The packages aim to ensure this: most rules necessarily change a \
representation at one stage into one at another, and RandomUnion[], \
NonMendelian[] and SymmetricRecombination[] include checks that prevent \
application where no change would be made.  \
\>", "Text",
  CellDingbat->"\[GrayCircle]",
  CellMargins->{{53, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Some such problems might have been missed, and problems do show up (eg in \
",
  ButtonBox["Natural and sexual selection on haploids",
    ButtonData:>{"Haploid selection", "block"},
    ButtonStyle->"AddOnsLink"],
  ").  The solution is just to keep applying the rules until the expression \
is fully reduced."
}], "Text"],

Cell[TextData[{
  "Whether or not rules and functions are applied only to specific patterns \
varies: for example, some functions check that the stage has been defined, \
using ",
  ButtonBox["ContextStageQ[]",
    ButtonData:>{"Stages", "ContextStageQ"},
    ButtonStyle->"AddOnsLink"],
  ", whilst others do not.  The same rule may make different kinds of checks \
in different circumstances.  For example, ",
  ButtonBox["Biallelic[]",
    ButtonData:>{"Two alleles", "Applying rules"},
    ButtonStyle->"AddOnsLink"],
  " can be applied with the gene-in-context being represented by (say) \
\[DoubleStruckI], but if it is restricted to specific loci, using the form \
Biallelic[{i,j}], then the genes-in-context must be spelt out as (say) ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(i\_{\[GothicCapitalZ], \[GothicCapitalM]}\)\(.\)\
\)\)]]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Clashes between packages", "SubsectionIcon"],

Cell[TextData[{
  "There is an obscure clash in loading both the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " packages ",
  ButtonBox["DiscreteMath`Combinatorica`",
    ButtonData:>{"DiscreteMath`Combinatorica`", None},
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["Statistics`DataManipulation`",
    ButtonData:>{"Statistics`DataManipulation`", None},
    ButtonStyle->"AddOnsLink"],
  ": both define Ordering[]. Since Utilities`SetManuipulation` loads both \
packages, DiscreteMath`Combinatorica`Ordering[] will be shadowed. (Similarly, \
both  ",
  ButtonBox["DiscreteMath`Combinatorica`",
    ButtonData:>{"DiscreteMath`Combinatorica`", None},
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["Graphics`MultipleListPlot` ",
    ButtonData:>{"Graphics`MultipleListPlot` ", None},
    ButtonStyle->"AddOnsLink"],
  " define Star[]).  An error message is generated when \
Utilities`SetManuipulation` is loaded, but this can be ignored."
}], "Text",
  CellTags->"Clashes between packages"],

Cell[TextData[{
  "Two sets of packages are named Utilities`  - the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " packages, which include Utilities`Notation`, and various additional \
packages.  There is no difficulty, provided packages are loaded individually, \
by their full name (e.g. <<Utilities`Notation`).  However, <<Utilities` will \
only load one of the sets.  This may be responsible for an error message \
which sometimes comes up when Utilities`Notation` is loaded (or any of the \
several packages which depend on it): \"File not found\".  As far as I can \
see, this can be ignored."
}], "Text",
  CellTags->"Utilities clash"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Incompatibilities with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.0"
}], "SubsectionIcon"],

Cell[TextData[{
  "The Notation Package will in principle work with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.0 but in practice may crash.   Further information can be found in the \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " documentation for ",
  ButtonBox["Utilities`Notation`",
    ButtonData:>{"Notation Documentation", None},
    ButtonStyle->"AddOnsLink"],
  ", or via ",
  ButtonBox["http://www.wolfram.com/",
    ButtonData:>{
      URL[ "http://www.wolfram.com/"], None},
    ButtonStyle->"Hyperlink"],
  "; in particular, there may be versions of the Notation Package for \
specific versions of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Incompatibilities"],

Cell["\<\
There has been a subtle change in Replace[] which can cause \
incompatibility.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Manipulating notebooks", "SubsectionIcon"],

Cell["\<\
Functions such as FindHyperlink[] and FindTags[] may leave all \
cells selected.  This is because there seems to be no obvious way to move  \
the selection back to its original value.  This is not a serious \
problem.\
\>", "Text",
  CellTags->"Manipulating notebooks"],

Cell[TextData[{
  "A problem arose with FindTags, which may be due to a change in \
NotebookFind between ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.0 and 4.0.  FindTags may now only work when executed at the start of \
the notebook, because it does not return to the start when it gets to the \
end.  It will also fail if two equations have the same tag."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Multilocus conventions", "SubsectionIcon"],

Cell["\<\
There are several conventions within these packages, with different \
degrees of generality.  Genotypes can be represented as:\
\>", "Text",
  CellTags->"Multilocus notation"],

Cell["\<\
Biallelic loci represented by {0,1}, and haplotypes by a list such \
as {0,1,0,0,1\[Ellipsis]}.  Full diploid genotypes are represented by \
{{0,1,0,\[Ellipsis]},{1,0,0\[Ellipsis]}}, and observed genotypes by \
{{0,1},{1,0},{0,0}\[Ellipsis]}\
\>", "Text",
  CellDingbat->"\[GrayCircle]",
  CellMargins->{{53, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Multiple alleles are represented by ",
  Cell[BoxData[
      \(TraditionalForm\`{a\_1, b\_2, \[Ellipsis]}\ in\ haploids, \ 
      and\ {{a\_1, a\_2}, {b\_1, b\_1}, \[Ellipsis]}\ in\ diploids\)]]
}], "Text",
  CellDingbat->"\[GrayCircle]",
  CellMargins->{{53, Inherited}, {Inherited, Inherited}}],

Cell["Genes-in-context can be represented by:", "Text"],

Cell["Simple position in a list", "Text",
  CellDingbat->"\[GrayCircle]",
  CellMargins->{{53, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "i for locus i in a female, ",
  Cell[BoxData[
      \(TraditionalForm\`\(i\^*\)\)]],
  "for locus i in a male (hardly used; see ",
  ButtonBox["fitness documentation",
    ButtonData:>{"Fitness", "Obsolete notation"},
    ButtonStyle->"AddOnsLink"],
  ")"
}], "Text",
  CellDingbat->"\[GrayCircle]",
  CellMargins->{{53, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`i\_{\[GothicCapitalZ], \[GothicCapitalM]\[Ellipsis]}\
\)]],
  " where {\[GothicCapitalZ], \[GothicCapitalM]\[Ellipsis]} represents the ",
  StyleBox["context",
    FontSlant->"Italic"]
}], "Text",
  CellDingbat->"\[GrayCircle]",
  CellMargins->{{53, Inherited}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Numerical errors with compiled code", "SubsectionIcon"],

Cell[TextData[{
  ButtonBox[" Numerical errors",
    ButtonData:>{"Allele frequencies: iterating a cline", "Numerical bug"},
    ButtonStyle->"AddOnsLink"],
  StyleBox[" arise when compiled code is used with more loci, and when \
populations are represented by AlleleFrequencies[].  This may be some kind of \
underflow error.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold",
  CellTags->"Numerical bug"]
}, Closed]],

Cell[CellGroupData[{

Cell["Numerical models of migration", "SubsectionIcon"],

Cell[TextData[{
  "In the NumericalModels` package, a constant fraction ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " of individuals are assumed to migrate.  Other kinds of migration are \
difficult to implement.  However, there are some ",
  ButtonBox["notes",
    ButtonData:>{"Allele frequencies: migration", "Constant numbers"},
    ButtonStyle->"AddOnsLink"],
  " on how to allow for a constant ",
  StyleBox["number",
    FontSlant->"Italic"],
  " of immigrants from a source deme."
}], "Text",
  CellTags->"Numerical models of migration"]
}, Closed]],

Cell[CellGroupData[{

Cell["Obsolete notation in EstimatingD", "SubsectionIcon"],

Cell[TextData[{
  "EstimatingD` originally represented linkage disequilibria as within- and \
between-genome associations.  However, this is unsatisfactory: the best \
representation is as a matrix of associations which includes both within- and \
between-genome associations.  The original 'reduced' representation has been \
retained in some ",
  ButtonBox["obsolete",
    ButtonData:>{"Obsolete functions", None},
    ButtonStyle->"AddOnsLink"],
  " functions; however, these have not been updated and may fail.  "
}], "Text",
  CellTags->"Obsolete EstimatingD"],

Cell[TextData[{
  "EstimatingD` was written using the older, less general, multilocus \
convention, in which ",
  Cell[BoxData[
      \(TraditionalForm\`\(i\^*\)\)]],
  "denotes locus i in a male. ",
  "Similarly, ",
  ButtonBox["DiploidSubsets",
    ButtonData:>{"Subsets of loci", "DiploidSubsets"},
    ButtonStyle->"AddOnsLink"],
  " has not been made compatible with the more general multilocus notation, \
using ",
  ButtonBox["genes-in-context",
    ButtonData:>{"Genes and contexts", "Genes and contexts"},
    ButtonStyle->"AddOnsLink"],
  ".  The former was written before the generalised notation was developed."
}], "Text"],

Cell[TextData[{
  "The notation ",
  Cell[BoxData[
      \(TraditionalForm\`\(i\^*\)\)]],
  "is implemented in an awkward way, using expressions such as \
Cases[U,Global;`OverHat[_]].  This approach is limited to symbols such as ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\&^\), \(x\^*\), 
      x\^\[Dagger], \ \(\(which\)\(\ \)\(are\)\(\ \)\(interpreted\)\(\ \)\(as\
\)\(\ \ \)\)\)]],
  "OverHat[x], SuperDagger[x] and SuperStar[x].  This has been superseded by \
use of the Notation Package, which allows arbitrary symbols to be used, and \
handles them more cleanly."
}], "Text"],

Cell["\<\
EstimatingD` includes a small section which calculates associations \
after migration and recombination; this remnant uses old conventions, and \
relies on obsolete functions such as ChangeSex and Recombined, which are \
defined within EstimatingD`.  This package does not invoke \
Multilocus`Multilocus`; however, there should be no clash between the \
functions defined in each.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Pasting hyperlinks", "SubsectionIcon"],

Cell["\<\
Note  that the target notebook of a hyperlink is specified relative \
to the current notebook, using ParentDirectory[].  Thus, copying and pasting \
hyperlinks between notebooks will cause trouble unless these notebooks are in \
the same folder.\
\>", "Text",
  CellTags->"Pasting hyperlinks"]
}, Closed]],

Cell[CellGroupData[{

Cell["Repeated \\\\\\\\\\\\\\", "SubsectionIcon"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.0 has the feature that if strings (for example, in usage statements) \
contain special formatting, then when the notebook is saved, \\\\ are \
inserted.  These have no immediate effect, but may accumulate until they \
cause the front end to crash.  If this happens, try searching for spurious \\\
\\\\\\\\\\, and delete them.  Until this bug is fixed, it is best to avoid \
special formatting in usage statements.  "
}], "Text",
  CellTags->"Repeated \\\\"]
}, Closed]],

Cell[CellGroupData[{

Cell["Special notation", "SubsectionIcon"],

Cell[TextData[{
  "Note that in order to set up these package files correctly, they ",
  StyleBox["must",
    FontWeight->"Bold"],
  " be saved by running ",
  ButtonBox["PackageSaver_4.06.nb",
    ButtonData:>{
      FrontEnd`FileName[ {
        ParentDirectory[ 
          ParentDirectory[ 
            ParentDirectory[ ]]], "Working"}, "PackageSaver_4.06.nb", 
        CharacterEncoding -> "MacintoshRoman"], None},
    ButtonStyle->"Hyperlink"],
  "; this avoids generation of obscure error messages.  Also, the package.nb \
file itself must retain its ",
  StyleBox["private",
    FontWeight->"Bold"],
  " style sheets: this contains essential information from the Notation \
Package.  These are only concerns if you need to change or extend the \
packages.\n",
  StyleBox["Note: ",
    FontWeight->"Bold"],
  "If you open a package file (",
  StyleBox["package.nb",
    FontSlant->"Italic"],
  ", say), and then save changes (even trivial ones) then the default ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " generated package.m will overwrite the version specially generated by \
PackageSaver.  There may then be obscure problems with the special notations. \
 If this happens,  open PackageSaver_4.06.nb; select and evaluate all cells; \
and in the browser dialog that opens, select the required ",
  StyleBox["package.nb",
    FontSlant->"Italic"],
  ".  That will regenerate the correct ",
  StyleBox["package.m  ",
    FontSlant->"Italic"]
}], "Text",
  CellTags->"Special notation"],

Cell["\<\
There may be trivial error messages when PackageSaver_4.06.nb is \
run: for example, if similar names are defined, General::spell messages will \
be generated.\
\>", "Text"],

Cell[TextData[{
  "There can be problems in using the notation package with older versions of \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ": it is using the special features of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to the limit."
}], "Text"],

Cell[TextData[{
  "Further information can be found in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " documentation for ",
  ButtonBox["Utilities`Notation`",
    ButtonData:>{"Notation Documentation", None},
    ButtonStyle->"AddOnsLink"],
  " , or via ",
  ButtonBox["http://www.wolfram.com/",
    ButtonData:>{
      URL[ "http://www.wolfram.com/"], None},
    ButtonStyle->"Hyperlink"]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Style sheets", "SubsectionIcon"],

Cell[TextData[{
  "Occasionally, a help file reverts to the default style sheet - special \
styles such as headings and pink definition boxes are lost.  To fix, open the \
file (",
  StyleBox["not",
    FontWeight->"Bold"],
  " within the Help Browser); set Style Sheet... to Help Browser; and save."
}], "Text",
  CellTags->"Style sheets"]
}, Closed]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1248}, {0, 832}},
WindowToolbars->{},
WindowSize->{873, 614},
WindowMargins->{{0, Automatic}, {Automatic, 4}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions for On-line Help", "Subtitle"],
  
  Cell["\<\
These styles are carefully tuned for all aspects of the online \
help. It's recommended that they remain unchanged.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsubsection"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ShowCellBracket->False,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Brackets"],
    PageWidth->WindowWidth,
    ShowAutoStyles->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowAutoStyles->False,
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsubsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "PageHeader"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}, {None, Cell[ 
            
            TextData[ {
              "\[Copyright]1999 Wolfram Research, Inc. All rights \
reserved."}], "PageFooter"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FacingPages"->True},
    CellLabelAutoDelete->False,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    CellMargins->{{10, 4}, {4, 24}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+3\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->22]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {12, 18}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"+2\" FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT SIZE=\"+1\" FACE=\"Helvetica, \
Arial\"><P><B>", "</B></P></FONT>\n"}},
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {"<FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionColor"],
    CellMargins->{{10, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    ConversionRules:>{"HTML" -> {
      "<FONT FACE=\"Helvetica, Arial\" COLOR=\"660099\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.297993, 0, 0.454994]],
  
  Cell[StyleData["SubsubsectionColor", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><FONT FACE=\"Helvetica, Arial\"><P><B>", 
      "</B></P></FONT>\n"}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CompactText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"-1\">", "</FONT>\n"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["CompactText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Compact12Text"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<P>", "</P>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["Compact12Text", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextSans"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {
      "<FONT SIZE=\"-1\" FACE=\"Helvetica, Arial\">", "</FONT>\n"}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["TextSans", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{12, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ConversionRules:>{"HTML" -> {"<BLOCKQUOTE>", "</BLOCKQUOTE>"}},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{12, 0}, {0, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{19, 62}, {0, 14}},
    ConversionRules:>{"HTML" -> {
      "<LI TYPE=\"SQUARE\"><P><FONT COLOR=\"000066\">", "</FONT></P></LI>"}},
    PageBreakBelow->False,
    CellFrameLabelMargins->4,
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{9, 0}, {0, 14}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{10, 4}, {0, 8}},
    ConversionRules:>{"HTML" -> {"<FONT SIZE=\"1\"><P>", "</P></FONT>"}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0.7, 0},
    CounterIncrements->"SmallText",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    TextJustification->1,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsubsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{46, 4}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->StandardForm],
  
  Cell[StyleData["Output", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->True,
    CellMargins->{{47, 4}, {4, 2}},
    CellGroupingRules->"GraphicsGrouping",
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultFormatTypeForOutput,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontWeight->"Plain"],
  
  Cell[StyleData["Graphics", "Printout"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Name"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Name", "Printout"],
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlinks", "Subsubsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks. The others point to the various sections of the help \
browser. These styles will modify individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLinkMR"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLinkMR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLinkMR", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsubsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->Automatic,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Subsubsection"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["JT"],
    StyleMenuListing->None,
    FontFamily->"JFontText"],
  
  Cell[StyleData["JS"],
    StyleMenuListing->None,
    FontFamily->"JFontSans"],
  
  Cell[StyleData["JSB"],
    StyleMenuListing->None,
    FontFamily->"JFontSansBold"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.31}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 4}, {0, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 0}, {0, 3}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    ScriptLevel->1,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["InlineOutput", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayMath"],
    CellMargins->{{42, 10}, {7, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input"],
  
  Cell[StyleData["DisplayMath", "Printout"],
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{42, 10}, {7, 7}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{34, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EquationNumber"],
    LineSpacing->{1.83, 0},
    LanguageCategory->"Formula"],
  
  Cell[StyleData["EquationNumber", "Printout"],
    LineSpacing->{1.7, 0},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{16, Inherited}, {Inherited, 10}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{8, Inherited}, {Inherited, 10}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Help Browser Styles", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel1"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{12, 10}, {2, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-38,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel1", "Brackets"]],
  
  Cell[StyleData["InspectorLevel1", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InspectorLevel2"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{48, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["InspectorLevel2", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    CellMargins->{{10, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {1, 10}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 90},
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectNameClosed", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {1, 10}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{90, 4}, {1, 14}},
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["SubObjectName", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontFamily->"Courier",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectName"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectName", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GroupObjectNameClosed"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 14}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->{"SectionGrouping", 80},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Brackets"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{72, 10}, {2, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["GroupObjectNameClosed", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectNameWarningMessages"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Brackets"],
    CellMargins->{{10, 4}, {1, 10}},
    CellGroupingRules->{"SectionGrouping", 65},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectNameWarningMessages", "Printout"],
    CellMargins->{{2, 0}, {1, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Command"],
    CellMargins->{{10, 4}, {0, 14}},
    CounterIncrements->"Section",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Command", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    PageBreakBelow->False,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CharacterName"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->4,
    StyleMenuListing->None],
  
  Cell[StyleData["CharacterName", "Brackets"],
    CellMargins->{{72, 4}, {1, 14}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["CharacterName", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 4}},
    CellFrameMargins->5,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Brackets"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{72, 4}, {0, 4}},
    CellFrameMargins->5,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None],
  
  Cell[StyleData["Usage", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    FontSize->10,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ErrorMessage"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {0, 4}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    CellFrameMargins->5,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["ErrorMessage", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ErrorMessage", "Printout"],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Brackets"],
    CellMargins->{{72, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 6},
    ParagraphIndent->-10,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["Notes", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NotesList"],
    CellMargins->{{20, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Brackets"],
    CellMargins->{{82, 4}, {2, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell[StyleData["NotesList", "Printout"],
    CellMargins->{{12, 0}, {2, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{11, 4}, {0, 10}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameMargins->12,
    StyleMenuListing->None,
    FontSize->13,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellMargins->{{3, 0}, {0, 10}},
    PageBreakBelow->False,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleText"],
    CellMargins->{{20, 40}, {0, 18}},
    Hyphenation->True,
    ParagraphSpacing->{0, 6},
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["ExampleText", "Printout"],
    CellMargins->{{2, 80}, {0, 8}},
    PageBreakBelow->False,
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSubsection"],
    ShowCellBracket->True,
    CellMargins->{{20, 4}, {0, 16}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSubsection", "Printout"],
    CellMargins->{{12, 0}, {0, 16}},
    PageBreakBelow->False,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LineHead"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellMargins->{{10, 4}, {8, 18}},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["LineHead", "Printout"],
    CellMargins->{{2, 0}, {8, 18}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushInput"],
    CellMargins->{{10, 4}, {1, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["FlushInput", "Printout"],
    CellMargins->{{2, 0}, {1, 4}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FlushOutput"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->StandardForm,
    StyleMenuListing->None],
  
  Cell[StyleData["FlushOutput", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DialogItem"],
    CellDingbat->"\[EmptyDiamond]",
    CellMargins->{{20, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["DialogItem", "Printout"],
    CellMargins->{{12, 0}, {0, 12}},
    PageBreakBelow->False,
    FontSize->8]
  }, Closed]],
  
  Cell[StyleData["GroupDivider"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellEditDuplicate->True,
    CellGroupingRules->{"TitleGrouping", 0},
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Highlight"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Highlight", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    LineSpacing->{1, 3}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserNotes"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["UserNotes", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MoreInfo"],
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.700008, 0.4, 0.100008]],
  
  Cell[StyleData["MoreInfo", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["UserTips"],
    CellFrame->{{2, 0}, {0, 0.25}},
    CellMargins->{{10, 4}, {0, 4}},
    Hyphenation->True,
    ParagraphIndent->-7,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.500008, 0.700008]],
  
  Cell[StyleData["UserTips", "Printout"],
    CellMargins->{{2, 0}, {0, 4}},
    LineSpacing->{1, 3},
    FontSize->8,
    Background->GrayLevel[0.700008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{12, 62}, {0, 14}},
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0, 0, 0.8],
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{2, 0}, {0, 14}},
    CellFrameMargins->3,
    CellFrameColor->GrayLevel[0.8],
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{36, 10}, {7, 7}},
    PageBreakBelow->False,
    CellFrameMargins->8,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontSlant->"Italic"],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{32, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0.8],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level1Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level1Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Level2Icon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None],
  
  Cell[StyleData["Level2Icon", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Contents and Index", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{10, 4}, {0, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {3, 18}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{12, 0}, {3, 18}},
    PageBreakBelow->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Contents"],
    CellMargins->{{21, 4}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Contents", "Printout"],
    CellMargins->{{13, 0}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Horizontal Lines", "Subsubsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Line1"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-16, 9}},
    StyleMenuListing->None,
    FontSize->2],
  
  Cell[StyleData["Line1", "Printout"],
    CellMargins->{{2, 0}, {-16, 9}}]
  }, Closed]],
  
  Cell["\<\

The item above is horizontal 0.5 pt line\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramTop"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{10, 4}, {-18, 18}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramTop", "Printout"],
    CellMargins->{{2, 0}, {-18, 18}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramTop line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramBottom"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{10, 4}, {-10, -2}},
    LineSpacing->{1, -4},
    StyleMenuListing->None,
    FontSize->4],
  
  Cell[StyleData["ProgramBottom", "Printout"],
    CellMargins->{{2, 0}, {-10, -2}}]
  }, Closed]],
  
  Cell["\<\

The item above is a ProgramBottom line
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SessionLabel"],
    CellFrame->{{0.5, 0}, {0, 0.5}},
    CellMargins->{{10, 4}, {-4, 18}},
    LineSpacing->{1, -3},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SessionLabel", "Printout"],
    CellMargins->{{2, 0}, {-4, 18}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Page Headers and Footers", "Subsubsection"],
  
  Cell[StyleData["PageHeader"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontSize->8,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {2, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Applying rules"->{
    Cell[1858, 57, 199, 5, 22, "Text",
      CellTags->"Applying rules"]},
  "Clashes between packages"->{
    Cell[5721, 174, 1019, 25, 56, "Text",
      CellTags->"Clashes between packages"]},
  "Utilities clash"->{
    Cell[6743, 201, 654, 12, 56, "Text",
      CellTags->"Utilities clash"]},
  "Incompatibilities"->{
    Cell[7564, 225, 746, 23, 40, "Text",
      CellTags->"Incompatibilities"]},
  "Manipulating notebooks"->{
    Cell[8503, 260, 279, 6, 36, "Text",
      CellTags->"Manipulating notebooks"]},
  "Multilocus notation"->{
    Cell[9258, 283, 185, 4, 22, "Text",
      CellTags->"Multilocus notation"]},
  "Numerical bug"->{
    Cell[11137, 342, 416, 10, 37, "Text",
      CellTags->"Numerical bug"]},
  "Numerical models of migration"->{
    Cell[11648, 359, 554, 14, 38, "Text",
      CellTags->"Numerical models of migration"]},
  "Obsolete EstimatingD"->{
    Cell[12300, 380, 565, 11, 51, "Text",
      CellTags->"Obsolete EstimatingD"]},
  "Pasting hyperlinks"->{
    Cell[14584, 440, 303, 6, 36, "Text",
      CellTags->"Pasting hyperlinks"]},
  "Repeated \\\\"->{
    Cell[14976, 453, 531, 10, 52, "Text",
      CellTags->"Repeated \\\\"]},
  "Special notation"->{
    Cell[15589, 470, 1506, 38, 124, "Text",
      CellTags->"Special notation"]},
  "Style sheets"->{
    Cell[18058, 547, 340, 8, 38, "Text",
      CellTags->"Style sheets"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Applying rules", 89506, 3118},
  {"Clashes between packages", 89613, 3121},
  {"Utilities clash", 89724, 3124},
  {"Incompatibilities", 89827, 3127},
  {"Manipulating notebooks", 89937, 3130},
  {"Multilocus notation", 90048, 3133},
  {"Numerical bug", 90150, 3136},
  {"Numerical models of migration", 90264, 3139},
  {"Obsolete EstimatingD", 90385, 3142},
  {"Pasting hyperlinks", 90495, 3145},
  {"Repeated \\\\", 90597, 3148},
  {"Special notation", 90698, 3151},
  {"Style sheets", 90800, 3154}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 36, 0, 52, "Section"],

Cell[CellGroupData[{
Cell[1815, 55, 40, 0, 36, "SubsectionIcon"],
Cell[1858, 57, 199, 5, 22, "Text",
  CellTags->"Applying rules"],
Cell[2060, 64, 35, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2120, 68, 213, 4, 54, "Input"],
Cell[2336, 74, 196, 4, 20, "Print"],
Cell[2535, 80, 88, 2, 32, "Output"]
}, Open  ]],
Cell[2638, 85, 369, 8, 37, "Text"],
Cell[3010, 95, 136, 2, 22, "Text"],

Cell[CellGroupData[{
Cell[3171, 101, 105, 2, 38, "Input"],
Cell[3279, 105, 196, 4, 20, "Print"],
Cell[3478, 111, 196, 4, 20, "Print"],
Cell[3677, 117, 88, 2, 32, "Output"]
}, Open  ]],
Cell[3780, 122, 202, 5, 22, "Text"],
Cell[3985, 129, 439, 8, 50, "Text"],
Cell[4427, 139, 342, 8, 38, "Text"],
Cell[4772, 149, 859, 18, 66, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5668, 172, 50, 0, 26, "SubsectionIcon"],
Cell[5721, 174, 1019, 25, 56, "Text",
  CellTags->"Clashes between packages"],
Cell[6743, 201, 654, 12, 56, "Text",
  CellTags->"Utilities clash"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7434, 218, 127, 5, 36, "SubsectionIcon"],
Cell[7564, 225, 746, 23, 40, "Text",
  CellTags->"Incompatibilities"],
Cell[8313, 250, 102, 3, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8452, 258, 48, 0, 36, "SubsectionIcon"],
Cell[8503, 260, 279, 6, 36, "Text",
  CellTags->"Manipulating notebooks"],
Cell[8785, 268, 385, 8, 52, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9207, 281, 48, 0, 26, "SubsectionIcon"],
Cell[9258, 283, 185, 4, 22, "Text",
  CellTags->"Multilocus notation"],
Cell[9446, 289, 355, 7, 36, "Text"],
Cell[9804, 298, 315, 7, 22, "Text"],
Cell[10122, 307, 55, 0, 22, "Text"],
Cell[10180, 309, 131, 2, 22, "Text"],
Cell[10314, 313, 376, 11, 23, "Text"],
Cell[10693, 326, 343, 9, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[11073, 340, 61, 0, 26, "SubsectionIcon"],
Cell[11137, 342, 416, 10, 37, "Text",
  CellTags->"Numerical bug"]
}, Closed]],

Cell[CellGroupData[{
Cell[11590, 357, 55, 0, 26, "SubsectionIcon"],
Cell[11648, 359, 554, 14, 38, "Text",
  CellTags->"Numerical models of migration"]
}, Closed]],

Cell[CellGroupData[{
Cell[12239, 378, 58, 0, 26, "SubsectionIcon"],
Cell[12300, 380, 565, 11, 51, "Text",
  CellTags->"Obsolete EstimatingD"],
Cell[12868, 393, 635, 16, 52, "Text"],
Cell[13506, 411, 587, 13, 52, "Text"],
Cell[14096, 426, 404, 7, 50, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[14537, 438, 44, 0, 26, "SubsectionIcon"],
Cell[14584, 440, 303, 6, 36, "Text",
  CellTags->"Pasting hyperlinks"]
}, Closed]],

Cell[CellGroupData[{
Cell[14924, 451, 49, 0, 26, "SubsectionIcon"],
Cell[14976, 453, 531, 10, 52, "Text",
  CellTags->"Repeated \\\\"]
}, Closed]],

Cell[CellGroupData[{
Cell[15544, 468, 42, 0, 26, "SubsectionIcon"],
Cell[15589, 470, 1506, 38, 124, "Text",
  CellTags->"Special notation"],
Cell[17098, 510, 183, 4, 36, "Text"],
Cell[17284, 516, 277, 9, 38, "Text"],
Cell[17564, 527, 416, 13, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[18017, 545, 38, 0, 26, "SubsectionIcon"],
Cell[18058, 547, 340, 8, 38, "Text",
  CellTags->"Style sheets"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

