(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    190079,       5184]*)
(*NotebookOutlinePosition[    191348,       5226]*)
(*  CellTagsIndexPosition[    191216,       5218]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Overview of the packages", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["Genealogies", "SubsubsectionIcon"],

Cell[TextData[{
  "The relationship between genes (i.e. their ",
  ButtonBox["genealogy",
    ButtonData:>{"Structure of genealogies", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"genealogy"],
  ") can be described and manipulated.  "
}], "Text"],

Cell["\<\
For example, this represents a rooted genealogy that relates genes \
{a\[Ellipsis]h}:\
\>", "MathCaption"],

Cell[BoxData[
    \(rg = 
      Node[{a, b, c, d, e, f, g, 
          h}, {2.3}, {Node[{a, b}, {0.4}, {Node[{a}, {0}, {}], 
              Node[{b}, {0}, {}]}], 
          Node[{c, d, e, f, g, 
              h}, {1.8}, {Node[{c, d}, {1}, {Node[{c}, {0}, {}], 
                  Node[{d}, {0}, {}]}], 
              Node[{e, f, g, 
                  h}, {1.7}, {Node[{e, f, g}, {1.5}, {Node[{e}, {0}, {}], 
                      Node[{f}, {0}, {}], Node[{g}, {0}, {}]}], 
                  Node[{h}, {0}, {}]}]}]}]; \)], "Input"],

Cell[TextData[{
  "This ",
  ButtonBox["plots",
    ButtonData:>{"Plotting genealogies", "PlotGenealogy"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"plots"],
  " the genealogy:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[PlotGenealogy[rg]]; \)], "Input",
  CellLabel->"In[26]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.111111 0.111111 0.0882906 0.0882906 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .52974 m
.11111 .08829 L
s
.5 .52974 m
.22222 .08829 L
s
.5 .52974 m
.61111 .44145 L
s
.38889 .17658 m
.33333 .08829 L
s
.38889 .17658 m
.44444 .08829 L
s
.66667 .17658 m
.55556 .08829 L
s
.66667 .17658 m
.66667 .08829 L
s
.66667 .17658 m
.77778 .08829 L
s
.72222 .26487 m
.66667 .17658 L
s
.72222 .26487 m
.88889 .08829 L
s
.61111 .35316 m
.38889 .17658 L
s
.61111 .35316 m
.72222 .26487 L
s
.61111 .44145 m
.61111 .35316 L
s
gsave
.47778 .5474 -79.7812 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
90.562500 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.36667 .19424 -79.7812 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
90.562500 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.64444 .19424 -87.5625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
90.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
100.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(g) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
106.125000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.7 .28253 -95.3438 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
90.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
100.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(g) show
106.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
115.687500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(h) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
121.687500 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.58889 .37082 -110.906 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
90.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
100.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
106.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
115.687500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
121.687500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
131.250000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(g) show
137.250000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
146.812500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(h) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
152.812500 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.58889 .45911 -126.469 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
75.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
84.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
90.562500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
100.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
106.125000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
115.687500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
121.687500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
131.250000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
137.250000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
146.812500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
152.812500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
162.375000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(g) show
168.375000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
177.937500 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(h) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
183.937500 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.11111 .07063 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.22222 .07063 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.33333 .07063 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.44444 .07063 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.55556 .07063 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.66667 .07063 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.77778 .07063 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(g) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.88889 .07063 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 13.000000 moveto
(8) show
69.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(h) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.000000 13.000000 moveto
(<) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`006`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`03000000<0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo01/0oooo000J0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0
oooo00D000000?ooo`3oool0oooo0000000C0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool06P3oool001X0oooo00@000000?ooo`3oool0oooo100000030?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0100000040?ooo`030000003oool0oooo0140oooo00@000000?oo
o`3oool0oooo0`0000040?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool0oooo1000
00030?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool0oooo0`0000040?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool01@0000030?ooo`030000003oool0oooo0180oooo
00@000000?ooo`3oool0oooo100000030?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool01P0000020?ooo`030000003oool0oooo01X0oooo000J0?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000001<0oooo00@000000?ooo`3oool000000`3o
ool01@000000oooo0?ooo`3oool0000001@0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool000001`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0B0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo0000
000C0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000001`0
oooo000I0?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00l0
oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo0100oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool0
10000000oooo0?ooo`3oool5000000@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0403oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0I0?ooo`00
6P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool04P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000C
0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`04
0000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0
oooo000000<0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool0000001`0oooo000J0?ooo`040000003oool0oooo0?oo
o`8000001@3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo0?ooo`<00000103oool0
0`000000oooo0?ooo`0A0?ooo`040000003oool0oooo0?ooo`<00000103oool00`000000oooo0?oo
o`0B0?ooo`040000003oool0oooo0?ooo`<00000103oool00`000000oooo0?ooo`0B0?ooo`040000
003oool0oooo0?ooo`<00000103oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo0?oo
o`@000000`3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo0?ooo`D000000P3oool0
0`000000oooo0?ooo`0A0?ooo`040000003oool0oooo0?ooo`<00000103oool00`000000oooo0?oo
o`0J0?ooo`006`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
5P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0C0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool06`3oool003d0
oooo0P00000o0?ooo`800000?`3oool2000003X0oooo0P00000S0?ooo`00803oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0M0?ooo`8000007P3oool00`000000oooo0?ooo`0L0?ooo`8000007P3oool00`000000oooo
0?ooo`0O0?ooo`00803oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01l0oooo000Q
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0803oool00280oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0Q0?ooo`008`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0T0?ooo`80
00006@3oool00`000000oooo0?ooo`0G0?ooo`800000803oool00`000000oooo0?ooo`0R0?ooo`00
903oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02<0oooo000U0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool0903oool002H0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0:P3oool2
000001D0oooo00<000000?ooo`3oool04`3oool200000240oooo00<000000?ooo`3oool09@3oool0
02L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0V0?ooo`009`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo02L0oooo000X0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0:03oool002T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0<P3oool200000100oooo00<0
00000?ooo`3oool03P3oool200000280oooo00<000000?ooo`3oool0:@3oool002X0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo02/0oooo000/0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03P0oooo0P00000<0?ooo`03
0000003oool0oooo00X0oooo0P00000S0?ooo`030000003oool0oooo02`0oooo000]0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0;@3oool002h0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0^0?ooo`00;`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo02l0oooo000_0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo03l0oooo0P0000070?ooo`030000003oool0oooo
00D0oooo0P00000U0?ooo`030000003oool0oooo02l0oooo000`0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0<03oool00340oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0a0?ooo`00<P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`8000000`3oool010000000oooo0?oo
o`3oool2000002H0oooo00<000000?ooo`3oool0<P3oool003<0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0M0?ooo`050000003oool0oooo0?ooo`000000BP3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0<`3oool003@0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0M0?ooo`050000003oool0oooo0?ooo`00
0000B`3oool01@000000oooo0000003oool0000002L0oooo00<000000?ooo`3oool0=03oool003D0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0000004d0
oooo0`00000W0?ooo`030000003oool0oooo03D0oooo000f0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool07@3oool2000004h0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0f0?ooo`00=P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000
;P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000
1P3oool3000000<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0g0?ooo`00=`3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000;03oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000203oool01@000000oooo
0?ooo`3oool0000001L0oooo00<000000?ooo`3oool0>03oool003P0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo0?ooo`<000001@3oool00`000000
oooo0?ooo`050?ooo`D000000P3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0oooo0?oo
o`<000001@3oool00`000000oooo0?ooo`030?ooo`D00000103oool010000000oooo0?ooo`000004
0?ooo`@000000`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03T0oooo000i0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool000000P3oool3000002`0oooo00@0
00000?ooo`3oool00000403oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000001D0oooo00<000000?ooo`3oool0>P3oool003X0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?oo
o`0000003`3oool010000000oooo0?ooo`0000040?ooo`800000:P3oool010000000oooo0?ooo`3o
ool5000000`0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0k0?ooo`00>`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000@0oooo0P00000[0?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`030000003oool0
oooo03`0oooo000l0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool01000
0000oooo0?ooo`3oool3000000d0oooo0`0000040?ooo`030000003oool0000002X0oooo00@00000
0?ooo`3oool0oooo0`00000<0?ooo`@000002@3oool00`000000oooo0?ooo`0500000080oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0m0?ooo`00?@3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo0P00000Y0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0?P3o
ool003h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0I0?ooo`8000002@3oool0
0`000000oooo0?ooo`0j0?ooo`8000002P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo03h0oooo000n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0?`3oool003l0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`100?ooo`00@03oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo02D0oooo0P0000160?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0@@3oool00440oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`120?ooo`00@P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04<0oooo00130?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0A03oool004@0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0W0?ooo`800000A03oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo04D0oooo00150?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
AP3oool004D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`170?ooo`00AP3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo04P0oooo00170?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0:P3oool200000440oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`190?ooo`00B03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04X0
oooo00190?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0B`3oool004X0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo03h0oooo00D0
00000?ooo`3oool0oooo0000001>0?ooo`00B`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo02`0oooo0P00000o0?ooo`030000003oool0000004l0oooo001<0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0l0?ooo`800000D03oool0
04`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00D0oooo100000040?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0>@3oool004d0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0^0?ooo`800000603oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0h0?ooo`00CP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool05@3oool010000000oooo0?ooo`3oool3000000D0oooo00<000000?ooo`3o
ool00`3oool5000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04000000@0
oooo00<000000?ooo`3oool0103oool600000080oooo00<000000?ooo`3oool0>03oool004l0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01@0oooo
00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`070?ooo`8000000P3oool01@000000
oooo0?ooo`3oool0000000`0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0h
0?ooo`00D03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool04P3oool010000000oooo0?ooo`3oool5000000`0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000303oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo03L0oooo001A0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0<@3oool2000001<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`3oool0000000`0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0h0?oo
o`00DP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0403oool010000000oooo0?ooo`3oool3000000`0oooo100000040?ooo`030000003oool0oooo
00D0oooo1@00000;0?ooo`<00000103oool00`000000oooo0?ooo`0h0?ooo`00D`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo03T0oooo001D0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0S0?ooo`80000000<0oooo000000000000
603oool200000440oooo001D0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<`3o
ool2000002D0oooo00<000000?ooo`3oool0F`3oool005D0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0G03oool0
05H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0G@3oool005L0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo01`0oooo0P00001P0?ooo`00F03oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo03H0oooo0P00000K0?ooo`030000003oool0oooo0600oooo
001I0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo0640oooo001J0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0680oooo001K0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0B0?oo
o`800000I@3oool005/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0h0?ooo`80
00004@3oool00`000000oooo0?ooo`1U0?ooo`00G03oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1V0?ooo`00G@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`1W0?ooo`00GP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1X0?ooo`00G`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo03/0oooo0P0000070?ooo`800000J`3oool00600
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0J`3oool00640oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0l0?ooo`050000003oool0oooo0?ooo`000000KP3oool00680oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0000006l0oooo001S0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1^0?ooo`00H`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo0`0000040?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0BP3oool006@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`190?ooo`00I@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0
oooo00@000000?ooo`3oool0oooo0`0000050?ooo`030000003oool0oooo00@0oooo100000040?oo
o`030000003oool0oooo00D0oooo0`0000050?ooo`030000003oool0oooo00<0oooo1@0000040?oo
o`030000003oool0oooo00D0oooo100000040?ooo`030000003oool0oooo00<0oooo1P0000020?oo
o`030000003oool0oooo04T0oooo001V0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00P0oooo00@000000?oo
o`3oool00000303oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo00D00000
0?ooo`3oool0oooo0000000;0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
B@3oool006L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`050000003o
ool0oooo0?ooo`0000003P3oool010000000oooo0?ooo`00000<0?ooo`D00000303oool00`000000
oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000002`3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo04P0oooo001X0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00P0oooo00@00000
0?ooo`3oool00000303oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0
2`3oool01@000000oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`190?ooo`00J@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0
oooo00@000000?ooo`3oool0oooo0`00000<0?ooo`<000003@3oool3000000`0oooo1000000<0?oo
o`D000002P3oool3000000@0oooo00<000000?ooo`3oool0B@3oool006X0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0BP3oool006X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0H0?ooo`800000
7@3oool3000001X0oooo0P00001B0?ooo`00J`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0KP3oool006`0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo06h0oooo001]0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1^0?ooo`00KP3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0KP3oool006l0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo06h0oooo
001`0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`1^0?ooo`00L@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool0KP3oool00740oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo06h0oooo001b0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`1^0?ooo`00L`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool0KP3oool007@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo06h0oooo001e0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1^0?ooo`00MP3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0KP3oool007L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo06h0
oooo001h0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`1^0?ooo`00N@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02`0oooo0P00
001`0?ooo`00K@3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool01@3oool3000000@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0j
0?ooo`00K03oool00`000000oooo0?ooo`090?ooo`030000003oool0000000D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0>@3oool006`0oooo00@000000?ooo`3oool0oooo100000040?ooo`040000003oool0oooo
000000<0oooo100000050?ooo`030000003oool0oooo00@0oooo0`0000050?ooo`030000003oool0
oooo00D0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool3000000D0oooo00<0
00000?ooo`3oool0103oool5000000@0oooo00<000000?ooo`3oool0103oool4000000@0oooo00<0
00000?ooo`3oool0103oool600000080oooo00<000000?ooo`3oool0>@3oool006`0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0?ooo`800000
00<0oooo0000003oool02@3oool01@000000oooo0?ooo`3oool0000000/0oooo00@000000?ooo`3o
ool000001`3oool200000080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?oo
o`050000003oool0oooo0?ooo`000000303oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo03T0oooo001[0?ooo`030000003oool0oooo0080oooo0`00000:0?ooo`050000003oool0
oooo0000003oool00P00000:0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000
1P3oool00`000000oooo0?ooo`020?ooo`D000003@3oool00`000000oooo0?ooo`0:0?ooo`050000
003oool0oooo0?ooo`000000303oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
03P0oooo001/0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool02@3oool00`00
0000oooo000000020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?oo
o`3oool0000000d0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000000`0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0i0?ooo`00K03oool010000000
oooo0?ooo`3oool2000000d0oooo1@00000;0?ooo`<000003@3oool3000000<0oooo0P0000070?oo
o`<000003@3oool4000000/0oooo1@00000;0?ooo`<00000103oool00`000000oooo0?ooo`0i0?oo
o`00K@3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`000000703oool01000
0000oooo0?ooo`00000J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0j0?ooo`00O`3oool2000000@0oooo00<000000?ooo`3oool0603oool20000
00030?ooo`000000oooo01/0oooo0P00000J0?ooo`800000@P3oool00840oooo00D000000?ooo`3o
ool0oooo0000000L0?ooo`030000003oool0oooo07/0oooo00220?ooo`050000003oool0oooo0?oo
o`0000006@3oool2000007h0oooo00230?ooo`040000003oool0oooo000001P0oooo00<000000?oo
o`3oool0OP3oool008@0oooo00@000000?ooo`3oool000005P3oool00`000000oooo0?ooo`1o0?oo
o`00Q@3oool010000000oooo0?ooo`00000C0?ooo`800000PP3oool008H0oooo00<000000?ooo`00
00004P3oool00`000000oooo0?ooo`220?ooo`00Q`3oool00`000000oooo0000000@0?ooo`030000
003oool0oooo08<0oooo00280?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool0Q03o
ool008P0oooo00<000000?ooo`000000303oool2000008L0oooo00290?ooo`030000003oool00000
00X0oooo00<000000?ooo`3oool0Q`3oool008X0oooo00<000000?ooo`000000203oool00`000000
oooo0?ooo`280?ooo`00R`3oool2000000H0oooo0P00002;0?ooo`00S03oool2000000@0oooo00<0
00000?ooo`3oool0R`3oool008d0oooo00D000000?ooo`3oool0oooo0000002>0?ooo`00SP3oool0
0`000000oooo0000002?0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00O03oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0R@3oool007/0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo08P0oooo
001k0?ooo`040000003oool0oooo0?ooo`@00000103oool00`000000oooo0?ooo`030?ooo`@00000
103oool00`000000oooo0?ooo`280?ooo`00N`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00X0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`280?ooo`00
NP3oool00`000000oooo0?ooo`020?ooo`<00000303oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo08L0oooo001k0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool02P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo08P0oooo001k0?ooo`04
0000003oool0oooo0?ooo`8000003@3oool3000000@0oooo00<000000?ooo`3oool0R03oool007`0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08T0
oooo002=0?ooo`800000T@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.01116, -1.00004, \
0.0314367, 0.0395621}}]
}, Open  ]],

Cell[TextData[{
  ButtonBox["Random genealogies",
    ButtonData:>{"Drawing a genealogy", "RandomGenealogy"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Random genealogies"],
  " can be produced according to the coalescent process:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(rg = RandomGenealogy[{a, b, c, d, e}]; \), "\n", 
    \(Show[PlotGenealogy[rg]]; \)}], "Input",
  CellLabel->"In[19]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.166667 0.166667 0.103006 0.103006 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.25 .20601 m
.16667 .10301 L
s
.25 .20601 m
.33333 .10301 L
s
.75 .20601 m
.66667 .10301 L
s
.75 .20601 m
.83333 .10301 L
s
.66667 .30902 m
.5 .10301 L
s
.66667 .30902 m
.75 .20601 L
s
.5 .41202 m
.25 .20601 L
s
.5 .41202 m
.66667 .30902 L
s
.5 .51503 m
.5 .41202 L
s
[(1)] .21667 .22661 0 0 Mshowa
[(2)] .71667 .22661 0 0 Mshowa
[(3)] .63333 .32962 0 0 Mshowa
[(4)] .46667 .43262 0 0 Mshowa
[(5)] .46667 .53563 0 0 Mshowa
gsave
.16667 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(a) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.33333 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.66667 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(d) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.83333 .0824 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(e) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[21]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00;P3oool4000002/0oooo0`00000/0?ooo`@00000;@3oool4000002/0oooo0`00000a0?oo
o`00;@3oool010000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000;03oool0
10000000oooo0?ooo`00000[0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0
<P3oool002h0oooo0`00000[0?ooo`030000003oool0oooo02h0oooo00@000000?ooo`3oool00000
:`3oool010000000oooo0?ooo`00000[0?ooo`D00000<03oool002d0oooo00@000000?ooo`3oool0
0000:`3oool01@000000oooo0?ooo`3oool0000002`0oooo00@000000?ooo`3oool00000:`3oool0
10000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`000000<03oool002h0oooo0P00
000]0?ooo`<00000;@3oool3000002d0oooo0`00000/0?ooo`<00000<@3oool008d0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`1N0?ooo`00S03oool200000300oooo0P00001P0?oo
o`00o`3ooolQ0?ooo`00<03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02l0oooo
000`0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool00340oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`00<P3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo0340oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0<P3oool003<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0b0?ooo`00=03o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03<0oooo000e0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0=03oool003H0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0e0?ooo`00=`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03H0
oooo000g0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=P3oool003P0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0g0?ooo`00>@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo03P0oooo000j0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0>@3oool003X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0i0?ooo`00
>`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03X0oooo000l0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0>`3oool003d0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0l0?ooo`00?@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
03`0oooo000n0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0?@3oool003l0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0n0?ooo`00@03oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo03l0oooo00100?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0?`3oool00440oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1A0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`100?oo
o`00@P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0440oooo00130?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0@P3oool004@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`130?ooo`00A03oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo04<0oooo00150?ooo`050000003oool0oooo0?ooo`000000F`3oool00`000000oooo0?ooo`0]
0?ooo`050000003oool0oooo0?ooo`000000AP3oool004H0oooo00<000000?ooo`000000G@3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0000004L0oooo00170?ooo`800000GP3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo04H0oooo00190?ooo`030000003oool0oooo05`0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`160?ooo`00BP3oool00`000000oooo
0?ooo`1L0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0A`3oool003`0oooo0`00
000<0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool07P3oool5000000H0oooo00<0
00000?ooo`3oool0B03oool003d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo01h0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`190?ooo`00?@3oool00`000000oooo0?ooo`0=0?ooo`800000G03oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0BP3oool003d0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1;0?ooo`00?@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool06P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool0B`3oool003`0oooo0P00000C0?ooo`030000003oool0oooo05X0
oooo00<000000?ooo`3oool06@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0C03oool003d0oooo00<000000?ooo`3oool04P3oool2000005X0oooo00<000000?ooo`3o
ool06P3oool300000080oooo00<000000?ooo`3oool0C@3oool005@0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04h0oooo001E0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1?0?ooo`00EP3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0D03oool0
05L0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
0500oooo001H0?ooo`800000F03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0540
oooo001J0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`1B0?ooo`00F`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0D`3oool005`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo05@0oooo001M0?ooo`800000E`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo05@0oooo001O0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`1E0?ooo`00H03oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0EP3oool00640oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05L0oooo001R0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1H0?ooo`00H`3oool20000
05D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1I0?ooo`00I@3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0F@3oool006H0oooo
00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo
001W0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1K0?ooo`00J03oool2000005<0oooo00D000000?ooo`3oool0oooo0000001N0?ooo`00JP3oool0
0`000000oooo0?ooo`1A0?ooo`030000003oool0000005l0oooo001[0?ooo`030000003oool0oooo
0500oooo0P00001P0?ooo`00K03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0600
oooo001]0?ooo`030000003oool0oooo04/0oooo0P00001S0?ooo`00KP3oool2000004<0oooo0`00
00030?ooo`800000I@3oool00700oooo00<000000?ooo`3oool0?`3oool01`000000oooo0?ooo`3o
ool000000?ooo`000000I`3oool00740oooo00<000000?ooo`3oool0@P3oool2000006P0oooo001b
0?ooo`030000003oool0oooo03l0oooo0P00001Z0?ooo`00L`3oool2000003h0oooo0P0000000`3o
ool000000?ooo`1X0?ooo`00M@3oool00`000000oooo0?ooo`0i0?ooo`8000000`3oool00`000000
oooo0?ooo`1W0?ooo`00MP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00<00000
JP3oool007L0oooo00<000000?ooo`3oool0=03oool200000700oooo001h0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool0L03oool007T0oooo0P00000`0?ooo`800000L`3oool007/0
oooo00<000000?ooo`3oool0:`3oool2000007D0oooo001l0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0M@3oool007d0oooo00<000000?ooo`3oool09P3oool2000007P0oooo001n
0?ooo`8000009@3oool00`000000oooo0?ooo`1h0?ooo`00P03oool00`000000oooo0?ooo`0P0?oo
o`800000N`3oool00840oooo00<000000?ooo`3oool07@3oool2000007d0oooo00220?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0O@3oool008<0oooo00<000000?ooo`3oool0603o
ool200000800oooo00240?ooo`8000005`3oool00`000000oooo0?ooo`200?ooo`00QP3oool00`00
0000oooo0?ooo`0B0?ooo`800000P`3oool008L0oooo00<000000?ooo`3oool03`3oool2000008D0
oooo00280?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0Q@3oool008T0oooo0P00
000;0?ooo`800000R03oool008/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`28
0?ooo`00S03oool00`000000oooo0?ooo`040?ooo`800000R`3oool008d0oooo00@000000?ooo`3o
ool0oooo0P00002=0?ooo`00SP3oool00`000000oooo0000002?0?ooo`00S`3oool00`000000oooo
0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>
0?ooo`00Q03oool3000000P0oooo00<000000?ooo`3oool0SP3oool008D0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`2>0?ooo`00PP3oool5000000P0oooo00<000000?ooo`3oool0
SP3oool00880oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`2>0?ooo`00P`3o
ool00`000000oooo000000090?ooo`030000003oool0oooo08h0oooo00240?ooo`8000002@3oool0
0`000000oooo0?ooo`2>0?ooo`00Q@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo
002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?oo
o`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000
003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0
oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0
oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?
0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`03
0000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003o
ool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo
08h0oooo003o0?ooob40oooo003o0?ooob40oooo00230?ooo`<00000VP3oool00880oooo00D00000
0?ooo`3oool0oooo0000002I0?ooo`00QP3oool00`000000oooo0?ooo`2G0?ooo`00QP3oool00`00
0000oooo0?ooo`2G0?ooo`00PP3oool4000009X0oooo00220?ooo`030000003oool0oooo09/0oooo
00220?ooo`D00000V@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.00744, -1.00003, \
0.0209577, 0.0339103}}]
}, Open  ]],

Cell[TextData[{
  "Genealogies can be inferred from a data matrix under the infinite-sites \
model.  The ",
  ButtonBox["Griffiths-Tavare ",
    ButtonData:>{"Griffiths-Tavare algorithm", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Griffiths-Tavare "],
  "algorithm is implemented, in both stochastic and exact forms. "
}], "Text"],

Cell["\<\
For example, this gives the probability of observing a certain \
configuration of mutations as a function of the scaled mutation rate:\
\>", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"GriffithsTavare", "[", 
      RowBox[{
        TagBox[
          RowBox[{"(", GridBox[{
                {"0", "0", "0", "0", "0", "0", "0", "0", "0"},
                {"1", "1", "1", "0", "0", "1", "0", "0", "0"},
                {"1", "1", "1", "0", "0", "0", "0", "0", "0"},
                {"0", "0", "0", "1", "1", "0", "1", "0", "0"},
                {"0", "0", "0", "1", "1", "0", "0", "1", "1"}
                }], ")"}],
          (MatrixForm[ #]&)], ",", "\[Theta]"}], "]"}]], "Input"],

Cell[BoxData[
    \(\((\[Theta]\^9\ \((3141821952 + 13483366272\ \[Theta] + 
              25217739648\ \[Theta]\^2 + 26937488864\ \[Theta]\^3 + 
              18096993360\ \[Theta]\^4 + 7930297836\ \[Theta]\^5 + 
              2268383044\ \[Theta]\^6 + 408842683\ \[Theta]\^7 + 
              42184385\ \[Theta]\^8 + 
              1900974\ \[Theta]\^9)\))\)/\((259200000\ \((1 + \[Theta])\)\^4\ \
\((2 + \[Theta])\)\^6\ \((3 + \[Theta])\)\^7\ \((4 + \[Theta])\)\^5)\)\)], \
"Output",
  CellLabel->"Out[54]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Spatially continuous populations", "SubsubsectionIcon"],

Cell[TextData[{
  "A ",
  ButtonBox["population",
    ButtonData:>{"The model", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"population"],
  " reproducing in two dimensions can be simulated; the full genealogy can be \
stored, and samples can be taken."
}], "Text"],

Cell[TextData[{
  "For example, this shows a snapshot of ",
  ButtonBox["individuals",
    ButtonData:>{"Sampling individuals", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"individuals"],
  " in such a population:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[ExtractExtant[Location, p1], PlotRange -> {{0, R}, {0, R}}, 
      AspectRatio -> 1]; \)], "Input",
  CellLabel->"In[33]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0166667 0 0.0166667 [
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .16667 -12 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .33333 -12 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .66667 -12 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[-0.0125 .83333 -12 -4.5 ]
[-0.0125 .83333 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(10)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(20)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(30)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(40)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(50)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(60)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .16667 m
.00625 .16667 L
s
[(10)] -0.0125 .16667 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(20)] -0.0125 .33333 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(30)] -0.0125 .5 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(40)] -0.0125 .66667 1 0 Mshowa
0 .83333 m
.00625 .83333 L
s
[(50)] -0.0125 .83333 1 0 Mshowa
0 1 m
.00625 1 L
s
[(60)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .03333 m
.00375 .03333 L
s
0 .06667 m
.00375 .06667 L
s
0 .1 m
.00375 .1 L
s
0 .13333 m
.00375 .13333 L
s
0 .2 m
.00375 .2 L
s
0 .23333 m
.00375 .23333 L
s
0 .26667 m
.00375 .26667 L
s
0 .3 m
.00375 .3 L
s
0 .36667 m
.00375 .36667 L
s
0 .4 m
.00375 .4 L
s
0 .43333 m
.00375 .43333 L
s
0 .46667 m
.00375 .46667 L
s
0 .53333 m
.00375 .53333 L
s
0 .56667 m
.00375 .56667 L
s
0 .6 m
.00375 .6 L
s
0 .63333 m
.00375 .63333 L
s
0 .7 m
.00375 .7 L
s
0 .73333 m
.00375 .73333 L
s
0 .76667 m
.00375 .76667 L
s
0 .8 m
.00375 .8 L
s
0 .86667 m
.00375 .86667 L
s
0 .9 m
.00375 .9 L
s
0 .93333 m
.00375 .93333 L
s
0 .96667 m
.00375 .96667 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.80552 .49046 Mdot
.71845 .14967 Mdot
.5465 .5356 Mdot
.81999 .28994 Mdot
.37454 .7154 Mdot
.16374 .40516 Mdot
.30753 .51357 Mdot
.27877 .43742 Mdot
.63175 .29982 Mdot
.8218 .35774 Mdot
.67009 .62291 Mdot
.17999 .29315 Mdot
.68191 .10391 Mdot
.15769 .19063 Mdot
.86935 .3407 Mdot
.26846 .5303 Mdot
.4073 .03581 Mdot
.51545 .97717 Mdot
.72211 .28831 Mdot
.87288 .29622 Mdot
.3544 .44965 Mdot
.90224 .31548 Mdot
.69358 .12752 Mdot
.83663 .18279 Mdot
.80754 .43687 Mdot
.00134 .39714 Mdot
.69111 .95975 Mdot
.5749 .0401 Mdot
.65208 .15634 Mdot
.44499 .9698 Mdot
.04673 .23617 Mdot
.71321 .31462 Mdot
.83683 .43935 Mdot
.72683 .34262 Mdot
.68165 .5014 Mdot
.42833 .01866 Mdot
.91737 .25106 Mdot
.87144 .34563 Mdot
.1365 .30938 Mdot
.82669 .37251 Mdot
.22069 .54891 Mdot
.94496 .5825 Mdot
.293 .4617 Mdot
.35296 .81344 Mdot
.11053 .40368 Mdot
.50295 .55399 Mdot
.90224 .5509 Mdot
.63437 .92933 Mdot
.69286 .58304 Mdot
.65971 .53746 Mdot
.61889 .91992 Mdot
.16587 .50408 Mdot
.80775 .3427 Mdot
.16451 .44695 Mdot
.64327 .98898 Mdot
.63545 .46935 Mdot
.67193 .63574 Mdot
.54986 .96396 Mdot
.35235 .46153 Mdot
.66957 .53961 Mdot
.17712 .43091 Mdot
.7413 .08237 Mdot
.76656 .08881 Mdot
.79295 .16455 Mdot
.6141 .10442 Mdot
.27708 .52553 Mdot
.82096 .2591 Mdot
.17873 .37194 Mdot
.22117 .56827 Mdot
.48157 .7474 Mdot
.48535 .74536 Mdot
.77927 .24072 Mdot
.61344 .00833 Mdot
.76943 .35619 Mdot
.64513 .50926 Mdot
.80695 .48088 Mdot
.39513 .80396 Mdot
.78751 .43065 Mdot
.66984 .64638 Mdot
.19961 .34308 Mdot
.70787 .11989 Mdot
.78069 .51161 Mdot
.2973 .56917 Mdot
.78375 .31953 Mdot
.29655 .51237 Mdot
.59887 .82926 Mdot
.57774 .83981 Mdot
.57328 .78322 Mdot
.73206 .28417 Mdot
.13918 .17106 Mdot
.13632 .46088 Mdot
.88755 .5361 Mdot
.25843 .5572 Mdot
.72571 .14249 Mdot
.81036 .38529 Mdot
.6942 .19658 Mdot
.37051 .80325 Mdot
.4943 .72082 Mdot
.53009 .9518 Mdot
.72923 .22555 Mdot
.56136 .93956 Mdot
.6363 .08128 Mdot
.90237 .41322 Mdot
.9058 .56108 Mdot
.18708 .41133 Mdot
.72873 .20446 Mdot
.88473 .58387 Mdot
.80621 .37112 Mdot
.73573 .23458 Mdot
.65561 .49205 Mdot
.2488 .52488 Mdot
.09848 .43535 Mdot
.58887 .05619 Mdot
.72565 .36532 Mdot
.57893 .02893 Mdot
.11118 .46336 Mdot
.62715 .54841 Mdot
.18448 .32629 Mdot
.30269 .44756 Mdot
.65484 .54896 Mdot
.28633 .54913 Mdot
.61718 .08257 Mdot
.32188 .4602 Mdot
.42003 .02944 Mdot
.7514 .49914 Mdot
.88954 .57652 Mdot
.17038 .17773 Mdot
.19024 .57502 Mdot
.80953 .44431 Mdot
.07299 .40084 Mdot
.64332 .86696 Mdot
.68314 .18159 Mdot
.87306 .56836 Mdot
.43704 .02708 Mdot
.18882 .58064 Mdot
.44054 .02816 Mdot
.20511 .43963 Mdot
.19051 .48439 Mdot
.12002 .4241 Mdot
.5647 .82739 Mdot
.55559 .96593 Mdot
.67164 .07458 Mdot
.8728 .29903 Mdot
.17786 .28848 Mdot
.67532 .48778 Mdot
.42319 .04125 Mdot
.25043 .51294 Mdot
.73151 .37503 Mdot
.89975 .55587 Mdot
.63445 .11638 Mdot
.90586 .28419 Mdot
.29598 .48639 Mdot
.8267 .36248 Mdot
.20866 .54034 Mdot
.68789 .11605 Mdot
.90044 .56764 Mdot
.8077 .18864 Mdot
.8296 .48079 Mdot
.5456 .9424 Mdot
.27792 .55594 Mdot
.18098 .41892 Mdot
.26531 .62474 Mdot
.48454 .71386 Mdot
.24403 .56418 Mdot
.51005 .70581 Mdot
.25876 .50481 Mdot
.60854 .55054 Mdot
.61103 .30706 Mdot
.789 .17077 Mdot
.90373 .32234 Mdot
.69876 .13794 Mdot
.16887 .28376 Mdot
.38776 .8062 Mdot
.55879 .77801 Mdot
.27146 .42472 Mdot
.318 .45172 Mdot
.79656 .16903 Mdot
.36866 .70128 Mdot
.28458 .57219 Mdot
.66964 .0719 Mdot
.85116 .36286 Mdot
.82666 .36224 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[33]:=",
  ImageSize->{366, 366},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005^0001KR000`400?l00000o`00003oo`3ooom_
0?ooo`00o`3ooom_0?ooo`00o`3ooom_0?ooo`00o`3ooom_0?ooo`00A03oool3000000@0oooo0P00
000_0?ooo`D000000`3oool200000300oooo0`0000040?ooo`800000<@3oool3000000<0oooo0P00
000`0?ooo`<00000103oool200000340oooo0`0000040?ooo`8000000`3oool004D0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`00000_0?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000;P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool00000<@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0;03o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000;`3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool004D0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`00000`0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000<P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02`0oooo
1@0000020?ooo`040000003oool0oooo00000380oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0]0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`00A@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000340oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02h0oooo0P0000030?ooo`040000
003oool0oooo000002h0oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00000b
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0;@3oool4000000<0oooo00@0
00000?ooo`3oool000000P3oool004D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`00000^0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000b0?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0;@3oool00`000000oooo00000003
0?ooo`040000003oool0oooo000002h0oooo100000030?ooo`040000003oool0oooo000002l0oooo
00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`00A03oool2000000@0oooo
00@000000?ooo`3oool00000;P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool00000;P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
<03oool2000000<0oooo00@000000?ooo`3oool00000;P3oool00`000000oooo0?ooo`040?ooo`04
0000003oool0oooo00000300oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`000002
0?ooo`00A@3oool00`000000oooo0?ooo`030?ooo`800000<03oool3000000@0oooo0P00000`0?oo
o`<00000103oool200000380oooo00<000000?ooo`3oool00P3oool2000002l0oooo1@0000030?oo
o`800000<P3oool2000000@0oooo0P0000030?ooo`00o`3ooom_0?ooo`00o`3ooom_0?ooo`00o`3o
oom_0?ooo`00o`3ooom_0?ooo`00o`3ooom_0?ooo`00403ooooo000005T000001P3oool00100oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0103oool00100oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0103oool00100oooo00<00000
0?ooo`3oool0cP3oool2000008/0oooo000@0?ooo`030000003oool0oooo0<h0oooo0P00002;0?oo
o`00403oool00`000000oooo0?ooo`3o0?oooe`0oooo000@0?ooo`030000003oool0oooo08l0oooo
0P00003:0?ooo`00403oool00`000000oooo0?ooo`2?0?ooo`800000bP3oool00100oooo00<00000
0?ooo`3oool0o`3ooomL0?ooo`00403oool00`000000oooo0?ooo`2B0?ooo`<00000aP3oool00100
oooo00<000000?ooo`3oool0S03oool2000000@0oooo0`00000]0?ooo`800000U`3oool00100oooo
0P00002=0?ooo`800000=03oool2000009L0oooo000@0?ooo`030000003oool0oooo08P0oooo0P00
003A0?ooo`00403oool00`000000oooo0?ooo`280?ooo`800000d@3oool00100oooo00<000000?oo
o`3oool0S@3oool200000380oooo0P00002H0?ooo`00403oool00`000000oooo0?ooo`2=0?ooo`80
0000<P3oool2000009P0oooo000@0?ooo`030000003oool0oooo0?l0ooooG03oool00100oooo00<0
00000?ooo`3oool0o`3ooomL0?ooo`00403oool00`000000oooo0?ooo`3o0?oooe`0oooo000@0?oo
o`030000003oool0oooo0<H0oooo0P00002C0?ooo`00403oool00`000000oooo0?ooo`360?ooo`80
0000T`3oool00100oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00403oool00`000000oooo0?oo
o`3o0?oooe`0oooo000@0?ooo`800000o`3ooomM0?ooo`00403oool00`000000oooo0?ooo`3Q0?oo
o`800000N03oool00100oooo00<000000?ooo`3oool0h@3oool3000007L0oooo000@0?ooo`030000
003oool0oooo0>80oooo0P00001g0?ooo`00403oool00`000000oooo0?ooo`3o0?oooe`0oooo000@
0?ooo`030000003oool0oooo0<l0oooo0P0000050?ooo`8000008P3oool2000005l0oooo000@0?oo
o`030000003oool0oooo0<l0oooo0P0000050?ooo`8000008P3oool2000005l0oooo000@0?ooo`03
0000003oool0oooo0?l0oooo103oool2000005H0oooo000@0?ooo`030000003oool0oooo0?l0oooo
103oool2000005H0oooo000@0?ooo`030000003oool0oooo0?l0ooooG03oool00100oooo00<00000
0?ooo`3oool0o`3ooomL0?ooo`00403oool200000?l0ooooG@3oool00100oooo00<000000?ooo`3o
ool0iP3oool2000007<0oooo000@0?ooo`030000003oool0oooo0<h0oooo0P00000F0?ooo`800000
L`3oool00100oooo00<000000?ooo`3oool0cP3oool2000008/0oooo000@0?ooo`030000003oool0
oooo0?l0ooooG03oool00100oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00403oool00`000000
oooo0?ooo`3E0?ooo`8000004@3oool200000740oooo000@0?ooo`030000003oool0oooo0=D0oooo
0P00000A0?ooo`8000001@3oool2000006X0oooo000@0?ooo`030000003oool0oooo0>l0oooo0P00
001Z0?ooo`00403oool00`000000oooo0?ooo`3o0?oooe`0oooo000@0?ooo`030000003oool0oooo
0>X0oooo0P00001_0?ooo`00403oool00`000000oooo0?ooo`3Z0?ooo`800000K`3oool00100oooo
0P00003o0?oooed0oooo000@0?ooo`030000003oool0oooo0>/0oooo0P00001^0?ooo`00403oool0
0`000000oooo0?ooo`3[0?ooo`800000KP3oool00100oooo00<000000?ooo`3oool0m@3oool20000
06@0oooo000@0?ooo`030000003oool0oooo0?D0oooo0P00001T0?ooo`00403oool00`000000oooo
0?ooo`3b0?ooo`800000I`3oool00100oooo00<000000?ooo`3oool0lP3oool2000006L0oooo000@
0?ooo`030000003oool0oooo0=/0oooo0P00001n0?ooo`00403oool00`000000oooo0?ooo`3K0?oo
o`800000OP3oool000040?ooo`0000000000000000@0oooo0P0000060?ooo`030000003oool0oooo
0?l0ooooG03oool00080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo0?l0oooo3@3oool2000004d0oooo00020?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000001@3oool300000?l0oooo3@3oool2000004d0oooo00020?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0/0?oo
o`800000g03oool2000000030?ooo`000000000004`0oooo00020?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0/0?ooo`800000g03oool20000
00030?ooo`000000000004`0oooo00000`3oool00000000000040?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0o`3ooomL0?ooo`000P3oool00`000000oooo0?ooo`030?ooo`80
00001P3oool00`000000oooo0?ooo`0f0?ooo`800000o`3ooolT0?ooo`00403oool00`000000oooo
0?ooo`0f0?ooo`800000[P3oool2000003<0oooo0P00000n0?ooo`00403oool00`000000oooo0?oo
o`3V0?ooo`800000<`3oool2000003h0oooo000@0?ooo`030000003oool0oooo0?l0oooo4P3oool2
000004P0oooo000@0?ooo`030000003oool0oooo0380oooo0P00003M0?ooo`800000B03oool00100
oooo00<000000?ooo`3oool0<P3oool200000?l0oooo:03oool00100oooo00<000000?ooo`3oool0
jP3oool2000006l0oooo000@0?ooo`030000003oool0oooo0>X0oooo0P00001_0?ooo`00403oool2
00000?l0ooooG@3oool00100oooo00<000000?ooo`3oool0mP3oool2000006<0oooo000@0?ooo`03
0000003oool0oooo0?H0oooo0P00001S0?ooo`00403oool00`000000oooo0?ooo`3o0?oooe`0oooo
000@0?ooo`030000003oool0oooo0?l0ooooG03oool00100oooo00<000000?ooo`3oool0o`3ooomL
0?ooo`00403oool00`000000oooo0?ooo`3o0?oooe`0oooo000@0?ooo`030000003oool0oooo0?l0
ooooG03oool00100oooo00<000000?ooo`3oool0mP3oool2000006<0oooo000@0?ooo`030000003o
ool0oooo0?H0oooo0P00001S0?ooo`00403oool00`000000oooo0?ooo`3o0?oooe`0oooo000@0?oo
o`800000n@3oool200000640oooo000@0?ooo`030000003oool0oooo00`0oooo0P00003Z0?ooo`80
0000H@3oool00100oooo00<000000?ooo`3oool0303oool200000?T0oooo0P00001B0?ooo`00403o
ool00`000000oooo0?ooo`3o0?ooo`P0oooo0P00001B0?ooo`00403oool00`000000oooo0?ooo`3o
0?oooe`0oooo000@0?ooo`030000003oool0oooo0?l0ooooG03oool00100oooo00<000000?ooo`3o
ool0o`3ooolg0?ooo`8000008`3oool00100oooo00<000000?ooo`3oool0o`3ooolg0?ooo`800000
8`3oool00100oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00403oool00`000000oooo0?ooo`3o
0?oooaH0oooo0P0000140?ooo`00403oool00`000000oooo0?ooo`3o0?oooaH0oooo0P0000140?oo
o`00403oool200000?l0ooooG@3oool00100oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00403o
ool00`000000oooo0?ooo`3o0?oooe`0oooo000@0?ooo`030000003oool0oooo0?l0ooooG03oool0
0100oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00403oool00`000000oooo0?ooo`3o0?oooe`0
oooo000@0?ooo`030000003oool0oooo03H0oooo0P00002o0?ooo`800000>@3oool2000002L0oooo
000@0?ooo`030000003oool0oooo03H0oooo0P00002o0?ooo`800000>@3oool2000002L0oooo000@
0?ooo`030000003oool0oooo03T0oooo0P00002h0?ooo`800000803oool2000004@0oooo000@0?oo
o`030000003oool0oooo03T0oooo0`00002g0?ooo`800000803oool2000004@0oooo000@0?ooo`03
0000003oool0oooo03X0oooo0P00003[0?ooo`800000<P3oool00100oooo00<000000?ooo`3oool0
o`3ooolX0?ooo`800000<P3oool00100oooo0P00003E0?ooo`800000D@3oool200000380oooo000@
0?ooo`030000003oool0oooo0=@0oooo0P0000250?ooo`00403oool00`000000oooo0?ooo`3=0?oo
o`800000S03oool00100oooo00<000000?ooo`3oool0:`3oool200000:00oooo0P00002<0?ooo`00
403oool00`000000oooo0?ooo`0[0?ooo`800000o`3oool_0?ooo`00403oool00`000000oooo0?oo
o`3`0?ooo`800000?`3oool2000002P0oooo000@0?ooo`030000003oool0oooo0?00oooo0P00000G
0?ooo`8000009P3oool2000002P0oooo000@0?ooo`030000003oool0oooo0?l0oooo2P3oool20000
02L0oooo0P00000W0?ooo`00403oool00`000000oooo0?ooo`3o0?oooc<0oooo0P00000W0?ooo`00
1@0000030?ooo`8000001P3oool00`000000oooo0?ooo`0k0?ooo`800000o`3ooolO0?ooo`0000D0
oooo0000003oool0oooo000000020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3o
ool0>`3oool200000?l0oooo7`3oool00080oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000050?ooo`<00000o`3ooomL0?ooo`000`3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oooe`0oooo00001@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`3o0?oo
oe`0oooo00001@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`100?ooo`800000/`3oool2000001X0oooo0P00000C0?ooo`800000<`3oool0
00040?ooo`0000000000000000@0oooo0P0000060?ooo`030000003oool0oooo0400oooo0P00002c
0?ooo`8000006P3oool2000001<0oooo0`00000b0?ooo`00403oool00`000000oooo0?ooo`3o0?oo
obP0oooo0P00000b0?ooo`00403oool00`000000oooo0?ooo`3o0?oooe`0oooo000@0?ooo`030000
003oool0oooo0?l0ooooG03oool00100oooo00<000000?ooo`3oool0o`3oool50?ooo`800000403o
ool2000004<0oooo000@0?ooo`030000003oool0oooo0?l0oooo1@3oool200000100oooo0P000013
0?ooo`00403oool00`000000oooo0?ooo`3o0?oooaP0oooo0P0000070?ooo`800000>@3oool00100
oooo00<000000?ooo`3oool0m@3oool200000200oooo0P0000070?ooo`800000>@3oool00100oooo
0P00003f0?ooo`800000I03oool00100oooo00<000000?ooo`3oool0>@3oool200000=D0oooo0P00
00190?ooo`00403oool00`000000oooo0?ooo`0i0?ooo`800000_03oool2000001L0oooo0P000005
0?ooo`800000@P3oool00100oooo00<000000?ooo`3oool0m`3oool2000001h0oooo0P0000120?oo
o`00403oool00`000000oooo0?ooo`3o0?oooe`0oooo000@0?ooo`030000003oool0oooo0?l0oooo
G03oool00100oooo00<000000?ooo`3oool0o`3ooolC0?ooo`800000A`3oool00100oooo00<00000
0?ooo`3oool0o`3ooolC0?ooo`800000A`3oool00100oooo00<000000?ooo`3oool0o`3ooomL0?oo
o`00403oool00`000000oooo0?ooo`3o0?oooe`0oooo000?0?ooo`800000o`3ooomN0?ooo`003`3o
ool3000001H0oooo0P00003o0?ooodD0oooo000@0?ooo`030000003oool0oooo01D0oooo0P00000;
0?ooo`800000o`3ooolh0?ooo`00403oool00`000000oooo0?ooo`0R0?ooo`800000403oool20000
0?l0oooo9P3oool00100oooo00<000000?ooo`3oool0=03oool200000?l0oooo9P3oool00100oooo
00<000000?ooo`3oool0?03oool200000?<0oooo0P00000X0?ooo`00403oool00`000000oooo0?oo
o`0l0?ooo`800000l`3oool2000002P0oooo000@0?ooo`030000003oool0oooo03X0oooo0P00003o
0?ooob00oooo000@0?ooo`030000003oool0oooo03X0oooo0P00003o0?ooob00oooo000@0?ooo`03
0000003oool0oooo02D0oooo0P00000b0?ooo`800000o`3oool10?ooo`00403oool00`000000oooo
0?ooo`0U0?ooo`800000<P3oool200000?l0oooo0@3oool00100oooo00<000000?ooo`3oool0o`3o
ool;0?ooo`800000C`3oool00100oooo00<000000?ooo`3oool0>@3oool200000<l0oooo0P00001?
0?ooo`00403oool2000001l0oooo0P00000I0?ooo`800000o`3ooolQ0?ooo`00403oool00`000000
oooo0?ooo`0N0?ooo`800000?03oool200000;<0oooo0P0000080?ooo`800000?P3oool00100oooo
00<000000?ooo`3oool0@P3oool2000001P0oooo0P00002c0?ooo`800000203oool2000003h0oooo
000@0?ooo`030000003oool0oooo0480oooo0P00003=0?ooo`800000B03oool00100oooo00<00000
0?ooo`3oool0=03oool2000002h0oooo0P00002[0?ooo`800000B03oool00100oooo00<000000?oo
o`3oool0=03oool2000002h0oooo0P00000?0?ooo`800000i03oool00100oooo00<000000?ooo`3o
ool0J@3oool2000000X0oooo0P00003T0?ooo`00403oool00`000000oooo0?ooo`1Y0?ooo`800000
l03oool00100oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00403oool00`000000oooo0?ooo`0[
0?ooo`800000<`3oool2000000P0oooo0P0000090?ooo`800000i03oool00100oooo00<000000?oo
o`3oool08P3oool2000000L0oooo0P00000c0?ooo`800000203oool2000000T0oooo0P00003T0?oo
o`00403oool2000002<0oooo0P00003o0?ooocP0oooo000@0?ooo`030000003oool0oooo0=H0oooo
0P0000230?ooo`00403oool00`000000oooo0?ooo`3F0?ooo`800000P`3oool00100oooo00<00000
0?ooo`3oool0o`3ooomL0?ooo`00403oool00`000000oooo0?ooo`3o0?oooe`0oooo000@0?ooo`03
0000003oool0oooo0?l0oooo4P3oool2000000D0oooo0P0000110?ooo`00403oool00`000000oooo
0?ooo`0m0?ooo`800000dP3oool2000000D0oooo0P0000110?ooo`00403oool00`000000oooo0?oo
o`0m0?ooo`8000008P3oool200000800oooo0P00001f0?ooo`00403oool00`000000oooo0?ooo`1Q
0?ooo`800000NP3oool2000000@0oooo0P00000[0?ooo`800000B@3oool000040?ooo`0000000000
000000@0oooo0P0000060?ooo`030000003oool0oooo0=d0oooo0P00000a0?ooo`800000B@3oool0
00050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo0?l0ooooG03oool000@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`030?ooo`<00000o@3oool2000005`0oooo00020?ooo`8000000`3oool010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo0>H0oooo0P00000E0?ooo`800000G03oool000@0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03D0oooo0P00
000N0?ooo`800000S`3oool2000007<0oooo00001@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`0e0?ooo`8000007P3oool200000880oooo
0P0000200?ooo`0000@0oooo0000000000000000103oool2000000H0oooo00<000000?ooo`3oool0
HP3oool2000007D0oooo0P00000]0?ooo`800000D@3oool00100oooo00<000000?ooo`3oool0DP3o
ool2000000h0oooo0P0000000`3oool000000000002Q0?ooo`800000D@3oool00100oooo00<00000
0?ooo`3oool0DP3oool200000140oooo0P00003d0?ooo`00403oool00`000000oooo0?ooo`3o0?oo
oe`0oooo000@0?ooo`030000003oool0oooo0?l0ooooG03oool00100oooo00<000000?ooo`3oool0
D@3oool2000000P0oooo0P00003n0?ooo`00403oool00`000000oooo0?ooo`1A0?ooo`800000203o
ool200000?h0oooo000@0?ooo`030000003oool0oooo05P0oooo0P00003o0?ooo`80oooo000@0?oo
o`800000F@3oool2000005d0oooo0P00002R0?ooo`00403oool00`000000oooo0?ooo`2g0?ooo`80
00009@3oool2000004`0oooo0P00000]0?ooo`00403oool00`000000oooo0?ooo`130?ooo`800000
V@3oool2000000030?ooo`000000000004T0oooo0P00000]0?ooo`00403oool00`000000oooo0?oo
o`130?ooo`800000W03oool2000007P0oooo000@0?ooo`030000003oool0oooo0?l0ooooG03oool0
0100oooo00<000000?ooo`3oool0B03oool2000001@0oooo0P00001c0?ooo`8000001`3oool20000
07d0oooo000@0?ooo`030000003oool0oooo04P0oooo0P00000D0?ooo`800000K@3oool2000000@0
oooo0P0000070?ooo`800000D`3oool2000002P0oooo000@0?ooo`030000003oool0oooo05/0oooo
0P00001;0?ooo`8000008`3oool200000640oooo0`00000X0?ooo`00403oool00`000000oooo0?oo
o`1E0?ooo`800000103oool2000004/0oooo0P0000260?ooo`800000:@3oool00100oooo00<00000
0?ooo`3oool0E@3oool200000=/0oooo0P00000W0?ooo`00403oool00`000000oooo0?ooo`1@0?oo
o`800000h03oool2000002L0oooo000@0?ooo`800000D@3oool200000=l0oooo0P00000X0?ooo`00
403oool00`000000oooo0?ooo`180?ooo`800000603oool200000<<0oooo0P0000080?ooo`800000
:03oool00100oooo00<000000?ooo`3oool0B03oool2000001@0oooo0P0000020?ooo`800000``3o
ool200000380oooo000@0?ooo`030000003oool0oooo03d0oooo0P00000O0?ooo`800000c@3oool2
000002`0oooo000@0?ooo`030000003oool0oooo03d0oooo0P00003^0?ooo`800000;03oool00100
oooo00<000000?ooo`3oool0?@3oool200000?l0oooo0P3oool2000001T0oooo000@0?ooo`030000
003oool0oooo03d0oooo0P00002Z0?ooo`800000@03oool2000001<0oooo0P00000I0?ooo`00403o
ool00`000000oooo0?ooo`3Y0?ooo`800000@03oool2000002h0oooo000@0?ooo`030000003oool0
oooo0?l0ooooG03oool00100oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00403oool00`000000
oooo0?ooo`3o0?oooe`0oooo000@0?ooo`030000003oool0oooo0?l0ooooG03oool00100oooo0P00
003o0?oooed0oooo000@0?ooo`030000003oool0oooo0?l0ooooG03oool00100oooo00<000000?oo
o`3oool0o`3ooomL0?ooo`00403oool00`000000oooo0?ooo`3o0?oooe`0oooo000@0?ooo`030000
003oool0oooo0?l0ooooG03oool00100oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00403oool0
0`000000oooo0?ooo`3o0?oooe`0oooo000@0?ooo`030000003oool0oooo0>80oooo0P00001g0?oo
o`00403oool00`000000oooo0?ooo`1G0?ooo`800000R@3oool2000007L0oooo000@0?ooo`030000
003oool0oooo05L0oooo0P00003o0?ooo`<0oooo000@0?ooo`030000003oool0oooo0?l0ooooG03o
ool00100oooo0P00003o0?oooed0oooo000@0?ooo`030000003oool0oooo0>80oooo0P00001g0?oo
o`00403oool00`000000oooo0?ooo`3R0?ooo`800000M`3oool00100oooo00<000000?ooo`3oool0
o`3ooomL0?ooo`00403oool00`000000oooo0?ooo`3R0?ooo`800000M`3oool00100oooo00<00000
0?ooo`3oool0hP3oool2000007L0oooo000@0?ooo`030000003oool0oooo0?l0ooooG03oool00100
oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00403oool00`000000oooo0?ooo`3o0?oooe`0oooo
00020?ooo`<000000`3oool2000000H0oooo00<000000?ooo`3oool0o`3ooomL0?ooo`000`3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`3o0?oooe`0oooo000500000080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`3o0?oooe`0oooo000010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000D0oooo
0`00003o0?oooe`0oooo0000103oool000000?ooo`0000030?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`3oool0o`3ooomL0?ooo`000P3oool2000000<0oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`3o0?oooe`0oooo00030?ooo`030000003oool0oooo0080oooo
0P0000060?ooo`030000003oool0oooo0?l0ooooG03oool00100oooo00<000000?ooo`3oool0o`3o
oomL0?ooo`00403oool00`000000oooo0?ooo`3o0?oooe`0oooo000@0?ooo`030000003oool0oooo
0?l0ooooG03oool00100oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00403oool00`000000oooo
0?ooo`3o0?oooe`0oooo000@0?ooo`030000003oool0oooo0?l0ooooG03oool00100oooo00<00000
0?ooo`3oool0o`3ooomL0?ooo`00403oool2000007/0oooo0P00003O0?ooo`00403oool00`000000
oooo0?ooo`1j0?ooo`800000g`3oool00100oooo00<000000?ooo`3oool0Z`3oool200000:h0oooo
000@0?ooo`030000003oool0oooo0:/0oooo0P00002^0?ooo`00403oool00`000000oooo0?ooo`2R
0?ooo`800000]`3oool00100oooo00<000000?ooo`3oool0O03oool2000002@0oooo0P00002g0?oo
o`00403oool00`000000oooo0?ooo`1l0?ooo`800000g@3oool00100oooo00<000000?ooo`3oool0
Y@3oool200000;@0oooo000@0?ooo`030000003oool0oooo0:D0oooo0P00002d0?ooo`00403oool0
0`000000oooo0?ooo`3o0?oooe`0oooo000@0?ooo`030000003oool0oooo0?l0ooooG03oool00100
oooo0P00003o0?oooed0oooo000@0?ooo`030000003oool0oooo0?l0ooooG03oool00100oooo00<0
00000?ooo`3oool0o`3ooomL0?ooo`00403oool00`000000oooo0?ooo`3o0?oooe`0oooo000@0?oo
o`030000003oool0oooo0:80oooo0P00002g0?ooo`00403oool00`000000oooo0?ooo`2Q0?ooo`<0
0000]`3oool00100oooo00<000000?ooo`3oool0X@3oool200000;P0oooo000@0?ooo`030000003o
ool0oooo0?l0ooooG03oool00100oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00403oool00`00
0000oooo0?ooo`3o0?oooe`0oooo000@0?ooo`030000003oool0oooo0?l0ooooG03oool00100oooo
00<000000?ooo`3oool0o`3ooomL0?ooo`00403oool200000?l0ooooG@3oool00100oooo00<00000
0?ooo`3oool0o`3ooomL0?ooo`00403oool00`000000oooo0?ooo`3o0?oooe`0oooo000@0?ooo`03
0000003oool0oooo0;/0oooo0P00002N0?ooo`00403oool00`000000oooo0?ooo`2k0?ooo`800000
WP3oool00100oooo00<000000?ooo`3oool0`03oool2000009T0oooo000@0?ooo`030000003oool0
oooo0<00oooo0P00002I0?ooo`00403oool00`000000oooo0?ooo`3o0?oooe`0oooo000@0?ooo`03
0000003oool0oooo0?l0ooooG03oool00100oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00403o
ool00`000000oooo0?ooo`3o0?oooe`0oooo000@0?ooo`800000o`3ooomM0?ooo`00403oool00`00
0000oooo0?ooo`1k0?ooo`8000001P3oool200000=H0oooo000@0?ooo`030000003oool0oooo07/0
oooo0P0000040?ooo`@00000eP3oool00100oooo00<000000?ooo`3oool0P@3oool200000=P0oooo
000@0?ooo`030000003oool0oooo0?l0ooooG03oool00100oooo00<000000?ooo`3oool0M@3oool2
00000>@0oooo000@0?ooo`030000003oool0oooo07D0oooo0P00003T0?ooo`00403oool00`000000
oooo0?ooo`3o0?oooe`0oooo000@0?ooo`030000003oool0oooo0?l0ooooG03oool000040?ooo`00
00000000000000@0oooo0P0000060?ooo`030000003oool0oooo0;h0oooo0P00002K0?ooo`0000D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3o
ool0_P3oool2000000T0oooo0P00002@0?ooo`00103oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0b@3oool200000900oooo00040?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool300000?l0ooooG03oool000@00000
0`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0?l0ooooG03oool000030000
003oool0oooo00@0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`320?ooo`80
0000U`3oool000D000000`3oool2000000H0oooo00<000000?ooo`3oool0`P3oool2000009L0oooo
000@0?ooo`030000003oool0oooo0?l0ooooG03oool00100oooo00<000000?ooo`3oool0o`3ooomL
0?ooo`00403oool00`000000oooo0?ooo`3o0?oooe`0oooo000@0?ooo`030000003oool0oooo0?l0
ooooG03oool00100oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00403oool00`000000oooo0?oo
o`3o0?oooe`0oooo000@0?ooo`030000003oool0oooo0?l0ooooG03oool00100oooo0P00003I0?oo
o`800000P@3oool00100oooo00<000000?ooo`3oool0f03oool200000840oooo000@0?ooo`030000
003oool0oooo0?l0ooooG03oool00100oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00403oool0
0`000000oooo0?ooo`3o0?oooe`0oooo000@0?ooo`030000003oool0oooo0?l0ooooG03oool00100
oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00403oool00`000000oooo0?ooo`3o0?oooe`0oooo
000@0?ooo`030000003oool0oooo0?l0ooooG03oool00100oooo00<000000?ooo`3oool0o`3ooomL
0?ooo`00403oool00`000000oooo0?ooo`3o0?oooe`0oooo000@0?ooo`800000o`3ooomM0?ooo`00
403oool00`000000oooo0?ooo`3o0?oooe`0oooo000@0?ooo`030000003oool0oooo0?l0ooooG03o
ool00100oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00403oool00`000000oooo0?ooo`3o0?oo
oe`0oooo000@0?ooo`030000003oool0oooo0?l0ooooG03oool00100oooo00<000000?ooo`3oool0
o`3ooomL0?ooo`00403oool00`000000oooo0?ooo`3@0?ooo`800000R@3oool00100oooo00<00000
0?ooo`3oool0d03oool2000008T0oooo000@0?ooo`030000003oool0oooo0?l0ooooG03oool00100
oooo00<000000?ooo`3oool0e@3oool2000008@0oooo000@0?ooo`030000003oool0oooo0=D0oooo
0P0000240?ooo`00403oool200000?l0ooooG@3oool00100oooo00<000000?ooo`3oool0o`3ooomL
0?ooo`00403oool00`000000oooo0?ooo`2l0?ooo`800000W@3oool00100oooo00<000000?ooo`3o
ool0]`3oool2000000<0oooo0P00002M0?ooo`00403oool00`000000oooo0?ooo`2g0?ooo`800000
XP3oool00100oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00403oool00`000000oooo0?ooo`2b
0?ooo`800000Y`3oool00100oooo00<000000?ooo`3oool0/P3oool200000:L0oooo000@0?ooo`03
0000003oool0oooo0?l0ooooG03oool00100oooo00<000000?ooo`3oool0j@3oool200000700oooo
000@0?ooo`030000003oool0oooo0;P0oooo0P00000_0?ooo`800000L03oool00100oooo0P00002i
0?ooo`@00000W`3oool00100oooo00<000000?ooo`3oool0U03oool2000002@0oooo0P00002O0?oo
o`00403oool00`000000oooo0?ooo`2D0?ooo`800000a@3oool00100oooo00<000000?ooo`3oool0
o`3ooomL0?ooo`00403oool00`000000oooo0?ooo`2]0?ooo`800000[03oool00100oooo00<00000
0?ooo`3oool0[@3oool200000:`0oooo000@0?ooo`030000003oool0oooo0?l0ooooG03oool00100
oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00403oool00`000000oooo0?ooo`3H0?ooo`800000
P@3oool000040?ooo`0000000000000000@0oooo0P0000060?ooo`030000003oool0oooo0=P0oooo
0P0000210?ooo`0000D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`3oool0o`3ooomL0?ooo`0000D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0o`3ooomL0?ooo`00100000030?ooo`04
0000003oool0oooo000000D0oooo0`00003o0?oooe`0oooo00000`000000oooo0?ooo`040?ooo`04
0000003oool0oooo00000?l0ooooI03oool000030?ooo`000000oooo00@0oooo00@000000?ooo`3o
ool00000o`3ooomT0?ooo`000P3oool2000000@0oooo0P00003o0?ooofD0oooo003o0?ooofl0oooo
003o0?ooofl0oooo003o0?ooofl0oooo0000\
\>"],
  ImageRangeCache->{{{0, 365}, {365, 0}} -> {-2.85118, -2.71988, 0.175073, \
0.175073}}]
}, Open  ]],

Cell[TextData[{
  "This shows a ",
  ButtonBox["sampled genealogy",
    ButtonData:>{"Sampling genealogies", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"sampled genealogy"],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[
      PlotGenealogy[tr, LeafLabels \[Rule] None, NodeLabels \[Rule] None, 
        NodeFunction \[Rule] \(({#2\[LeftDoubleBracket]\(-1\), 
                  1\[RightDoubleBracket], 
                5 - #2\[LeftDoubleBracket]1\[RightDoubleBracket]/
                    20} &)\)]]; \)], "Input",
  CellLabel->"In[59]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0909091 0.0909091 0.0882906 0.0882906 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .52974 m
.18182 .18699 L
s
.5 .52974 m
.63636 .45921 L
s
.63636 .45921 m
.45455 .1773 L
s
.63636 .45921 m
.77273 .28454 L
s
.77273 .28454 m
.63636 .1107 L
s
.77273 .28454 m
.81818 .22063 L
s
.81818 .22063 m
.72727 .1094 L
s
.81818 .22063 m
.86364 .1429 L
s
.18182 .18699 m
.13636 .13055 L
s
.18182 .18699 m
.27273 .10938 L
s
.45455 .1773 m
.36364 .11428 L
s
.45455 .1773 m
.5 .16774 L
s
.5 .16774 m
.45455 .11058 L
s
.5 .16774 m
.54545 .1073 L
s
.86364 .1429 m
.81818 .10905 L
s
.86364 .1429 m
.90909 .10752 L
s
.13636 .13055 m
.09091 .11554 L
s
.13636 .13055 m
.18182 .10713 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[59]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<`3oool2
000006L0oooo00<000000?ooo`3oool0I03oool2000001/0oooo000a0?ooo`8000006P3oool20000
03<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool05`3oool2000001H0oooo00<000000?ooo`3oool06`3oool002l0
oooo0P00000K0?ooo`030000003oool0oooo01T0oooo0P00000H0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0L0?ooo`006P3oool300000100oooo
0P00000L0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0I0?ooo`800000403oool2000001l0oooo000M0?ooo`<00000303oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo01h0oooo0P00000G0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0O0?ooo`00803oool3000000L0oooo0P00000M
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0J
0?ooo`8000002`3oool00`000000oooo0?ooo`0P0?ooo`008`3oool300000080oooo0P00000M0?oo
o`8000009@3oool2000001D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0240oooo000V0?ooo`8000007P3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`040?ooo`80
0000903oool002L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0703oool2000000<0oooo00<000000?ooo`3oool0
903oool002P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0[0?ooo`800000503o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0000002L0oooo000Y0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool09P3oool002X0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0`0?ooo`8000004P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
02H0oooo000[0?ooo`030000003oool0oooo0180oooo0P00000e0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0W0?ooo`00:`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo03H0oooo0P00000A0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool09`3oool002`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0X0?ooo`00;@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03/0oooo0P00000?
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0:@3oool002h0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo00D000000?oo
o`3oool0oooo0000000_0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0Y0?ooo`00;`3oool00`000000oooo0?ooo`080?ooo`800000@P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool000000340oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo02X0oooo000`0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0@`3oool2000000/0oooo1000000c0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0Z0?ooo`00<03oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo04H0oooo00@000000?ooo`3oool0oooo1`00000h0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0[0?ooo`00
<@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04P0oooo0`00000o0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0[0?ooo`00<P3o
ool01@000000oooo0?ooo`3oool0000004/0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0;03oool003<0oooo00<0
00000?ooo`000000C@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo02d0oooo000d0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0;P3oool003D0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0^0?ooo`00
=P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02l0oooo000g0?ooo`030000003o
ool0oooo04`0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0;`3oool003P0oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0`0?ooo`00>@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0300oooo000j0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<@3oool003/0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo01P0oooo
00@000000?ooo`3oool00000=03oool003`0oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo01P0oooo00<000000?ooo`000000=03oool003d0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0<`3oool003h0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0<`3oool003l0oooo00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0=03oool00400oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0=@3oool00440oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
=P3oool00440oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0=P3oool00480oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0=`3oool0
04<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0>03oool004@0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0>03oool004D0oooo
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0>@3oool004H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0>P3oool004L0oooo00<00000
0?ooo`3oool0A`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0>`3oool004P0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0>`3oool004T0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0?03oool004X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`130?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0?@3oool004/0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0?@3o
ool004`0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`140?ooo`050000003oool0
oooo0?ooo`000000@03oool004d0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`14
0?ooo`030000003oool000000440oooo001>0?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`100?ooo`00CP3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool0@03oool004l0oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0440oooo001@0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`120?ooo`00D@3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0@`3oool0
0580oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
04@0oooo001C0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`140?ooo`00E03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0A@3oool005D0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo04H0oooo001F0?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`170?ooo`00E`3oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0A`3oool005P0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo04P0oooo001I0?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`190?ooo`00FP3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0BP3o
ool005/0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo04/0oooo001K0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`1;0?ooo`00G03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0C03oool005d0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo04d0oooo001N0?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`1>0?ooo`00G`3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0CP3oool00600oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo04l0oooo001Q0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1@0?ooo`00
HP3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
D@3oool006<0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo0580oooo001T0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`1B0?ooo`00I@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0D`3oool006H0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo05@0oooo001W0?ooo`030000003oool0oooo03d0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1E0?ooo`00J03oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0E@3oool006P0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05H0oooo001Y0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1G0?oo
o`00JP3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0F03oool006/0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo05T0oooo001/0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`1I0?ooo`00K@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0FP3oool006h0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo05/0oooo001_0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1L0?ooo`00L03oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0G03oool00740oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05d0oooo001b
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1N
0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0G`3oool007@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0600oooo001e0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`1P0?ooo`00M@3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0H@3oool007H0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0680oooo001g0?ooo`030000003oool0oooo
03P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1S0?ooo`00N03oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0H`3oool007T0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06@0oooo
001j0?ooo`030000003oool0oooo03L0oooo00D000000?ooo`3oool0oooo0000001W0?ooo`00N`3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0000006P0oooo001l0?ooo`030000003oool0
oooo03H0oooo0P00001Y0?ooo`00O@3oool00`000000oooo0?ooo`0c0?ooo`800000J`3oool007h0
oooo00<000000?ooo`3oool0<03oool2000006d0oooo001o0?ooo`030000003oool0oooo02d0oooo
0P00001_0?ooo`00P03oool00`000000oooo0?ooo`0Z0?ooo`800000L@3oool00840oooo00<00000
0?ooo`3oool09`3oool2000007<0oooo00220?ooo`030000003oool0oooo02@0oooo0P00001e0?oo
o`00PP3oool00`000000oooo0?ooo`0R0?ooo`800000M`3oool008<0oooo00<000000?ooo`3oool0
7`3oool2000007T0oooo00240?ooo`030000003oool0oooo01`0oooo0P00001k0?ooo`00Q@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo07/0oooo00260?ooo`030000003oool0oooo
01L0oooo0P00001n0?ooo`00Q`3oool00`000000oooo0?ooo`0D0?ooo`800000P03oool008P0oooo
00<000000?ooo`3oool04@3oool200000880oooo00290?ooo`030000003oool0oooo00h0oooo0P00
00240?ooo`00RP3oool00`000000oooo0?ooo`0;0?ooo`800000QP3oool008/0oooo00<000000?oo
o`3oool0203oool2000008P0oooo002<0?ooo`030000003oool0oooo00D0oooo0P00002:0?ooo`00
S@3oool00`000000oooo0?ooo`020?ooo`800000S03oool008h0oooo00@000000?ooo`0000000000
SP3oool008l0oooo00<000000?ooo`3oool0SP3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.01364, -1.00004, \
0.0384226, 0.0395621}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Multilocus algebra", "SubsubsectionIcon"],

Cell[TextData[{
  "The packages provide a general mathematical ",
  ButtonBox["framework",
    ButtonData:>{"Introduction to multilocus algebra", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"framework"],
  " for the evolution of systems of many genes; this is applied to various \
examples of ",
  ButtonBox["diploid sexual populations",
    ButtonData:>{"Introduction to selection on diploids", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"diploid sexual populations"],
  ".  Natural and ",
  ButtonBox["sexual selection",
    ButtonData:>{"Sexual selection", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"sexual selection"],
  ", sex-dependent ",
  ButtonBox["recombination",
    ButtonData:>{"Recombination", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"recombination"],
  ", ",
  ButtonBox["migration",
    ButtonData:>{"Migration example", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"migration"],
  ", and ",
  ButtonBox["non-Mendelian inheritance",
    ButtonData:>{"Non-Mendelian inheritance", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"non-Mendelian inheritance"],
  " are included.  An extension to ",
  ButtonBox["random genetic drift",
    ButtonData:>{"Introduction to random drift", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"random genetic drift"],
  " is also outlined."
}], "Text"],

Cell[TextData[{
  "For example, these rules describe a complete life cycle, including a ",
  ButtonBox["cytoplasmically inherited",
    ButtonData:>{"Cytoplasmic inheritance", "Complete life cycle"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"cytoplasmically inherited"],
  " locus i:"
}], "MathCaption"],

Cell[BoxData[
    \(rules = \((Recombination[]\[Vee]NonMendelian[
            CytoplasmicLoci -> \
{i}]\[Vee]SymmetricRecombination[]\[Vee]Selection[]\[Vee]UnionOfGametes[]\
\[Vee]RandomUnion[\[GothicCapitalG]]\[Vee]ReferencePointSame[\[GothicCapitalG]\
, {\[GothicCapitalA], \[GothicCapitalZ]}]\[Vee]ReferencePointZero[{\(\
\[GothicCapitalG]\^*\), \[GothicCapitalG]}])\); \)], "Input",
  CellLabel->"In[83]:=  (8:27:16 on 3/11/01)"],

Cell[TextData[{
  "The cytonuclear association in female gametes decreases by ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\ in\ each\ \(\(generation\)\(:\)\)\)]],
  " "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}, j\
\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalF]}} //. rules\)], "Input",
  CellLabel->"In[84]:=  (8:27:21 on 3/11/01)"],

Cell[BoxData[
    \(1\/2\ \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, \
j\_{\[GothicCapitalG], \[GothicCapitalF]}}\)], "Output",
  CellLabel->"Out[84]=  (8:27:21 on 3/11/01)"]
}, Open  ]],

Cell["\<\
This is the three-way association between two autosomal loci and a \
cytoplasmic locus:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[GothicCapitalD]\_{i\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, \
j\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}, \
k\_{\(\[GothicCapitalG]\^*\), \[GothicCapitalM]}} //. 
          rules\) /. {\[GothicR]\_\({}, {j, k}\) -> \(1 - r\_\(j, k\)\)\/2, \
\[GothicR]\_\({j}, {k}\) -> r\_\(j, k\)\/2} // Simplify\)], "Input",
  CellLabel->"In[90]:=  (8:31:31 on 3/11/01)"],

Cell[BoxData[
    \(\(1\/2\) \[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, \
j\_{\[GothicCapitalG], \[GothicCapitalF]}, k\_{\[GothicCapitalG], \
\[GothicCapitalF]}}\ \((1 - r\_\(j, k\))\) + 
      1\/4\ \((\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, \
k\_{\[GothicCapitalG], \[GothicCapitalF]}}\ \((\[GothicM]\_\(j\_{\
\[GothicCapitalG], \[GothicCapitalF]}\) - \
\[GothicM]\_\(j\_{\[GothicCapitalG], \[GothicCapitalM]}\))\) + \
\[GothicCapitalD]\_{i\_{\[GothicCapitalG], \[GothicCapitalF]}, j\_{\
\[GothicCapitalG], \[GothicCapitalF]}}\ \
\((\[GothicM]\_\(k\_{\[GothicCapitalG], \[GothicCapitalF]}\) - \
\[GothicM]\_\(k\_{\[GothicCapitalG], \[GothicCapitalM]}\))\))\)\ \((1 - 
            2\ r\_\(j, k\))\)\)], "Output",
  CellLabel->"Out[161]=  (19:23:32 on 3/6/01)"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Numerical models", "SubsubsectionIcon"],

Cell[TextData[{
  ButtonBox["Deterministic recursions",
    ButtonData:>{"Representing the population", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Deterministic recursions"],
  " are defined for single populations, or one-dimensional stepping-stone \
models.  There must be two alleles at each locus, but otherwise these \
recursions are fairly general.  They are designed for numerical iteration, \
and are reasonably fast for up to ~6 loci."
}], "Text"],

Cell[TextData[{
  "For ",
  ButtonBox["example",
    ButtonData:>{"Example: epistasis", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"example"],
  ", this iterates a model of epistatic selection against heterozygotes, with \
3 loci and 20 demes:"
}], "MathCaption"],

Cell[BoxData[{
    \(\(\(hetWfull[s_, k_]\)[_]\)[X_, 
        Y_] := \((1 - s)\)\^\(CountHeterozygotes[X, Y]\^k\); \), "\n", 
    \(StoreExact[\[Psi], hetWfull[0.01, 4], 0.5, {200, 50}, {20, 3}, 
      SymmetricModel \[Rule] False, Compiled \[Rule] True, 
      SortByClass \[Rule] True]; \)}], "Input",
  CellLabel->"In[182]:="],

Cell["\<\
Cline width reaches equilibrium at w=5.31 for all 3 loci within 200 \
generations\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[{t, 
            ClineWidth[\[Psi][t], SymmetricModel \[Rule] False, 
              SortByClass \[Rule] True]} // Flatten, {t, 0, 200, 50}] // 
      TableForm\)], "Input",
  CellLabel->"In[183]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0", "1", "1", "1"},
          {"50", "5.20775486910014517`", "5.20775486910014695`", 
            "5.20775486910014695`"},
          {"100", "5.29734636763913169`", "5.29734636763913169`", 
            "5.29734636763913524`"},
          {"150", "5.30619373083351941`", "5.30619373083352208`", 
            "5.3061937308335203`"},
          {"200", "5.30728884369828612`", "5.30728884369828612`", 
            "5.30728884369828168`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[183]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "More loci can be followed if one can assume that all genotypes carrying \
x/n '1' alleles are equivalent.  Such '",
  Cell[BoxData[
      FormBox[
        ButtonBox[
          ButtonBox["symmetric",
            ButtonData:>{
              FrontEnd`FileName[ {
                ParentDirectory[ 
                  ParentDirectory[ 
                    ParentDirectory[ ]]], "Multilocus", "Documentation", 
                "English"}, "SymmetricDescription.nb", CharacterEncoding -> 
                "MacintoshRoman"], None},
            ButtonStyle->"Hyperlink"],
          ButtonData:>{"Genotype frequencies", None},
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  "' models can be iterated in one population or across a one-dimensional \
stepping sone model.  The ",
  ButtonBox["stability",
    ButtonData:>{"Outline", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"stability"],
  " of the symmetric solution can be determined."
}], "Text"],

Cell[TextData[{
  "For ",
  ButtonBox["example",
    ButtonData:>{"Example: a cline", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"example"],
  ", this gives the eigenvalues that describe the stability of the above \
model, with 3 genes and 20 demes:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(sm = 
      SigmaMatrix[StabilityK[#1, #2, #3, \[Psi][100], hetW[0.01, 4], 0.5] &, 
        0, 3]; \), "\n", 
    \(Eigenvalues[BlockMatrix[sm]] // Chop\)}], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \({1.0000143361900291`, 0.959742070386500856`, 0.957022829485979187`, 
      0.911073150945283494`, 0.883032531976953904`, 0.831945428235556505`, 
      0.777811494354213195`, 0.713691709701287635`, 0.645810860387220575`, 
      0.572768332407631586`, 0.499170022237636867`, 0.492949381457207458`, 
      0.42774024837641047`, 0.425197764933650379`, 0.420730161484023845`, 
      0.413464860566897041`, 0.395191602895506033`, 0.373861042504097751`, 
      0.353055416711139802`, 0.347611494007043475`, 0.317712616298858119`, 
      0.287693333631603476`, 
      0.282072426597266279`, \(\(0.252379711655309213`\)\(\[InvisibleSpace]\)\
\) + 0.00331572111100560196`\ I, \(\(0.252379711655309213`\)\(\
\[InvisibleSpace]\)\) - 0.00331572111100560196`\ I, 0.219535823272194852`, 
      0.218224214029124663`, 0.20356562937544087`, 0.184991844411386168`, 
      0.169438333676420738`, 0.163463819247224773`, 0.156258668469488775`, 
      0.143750812914807291`, 0.138580120290631182`, 0.13038528162202303`, 
      0.127350290844467006`, 0.120529279974109093`, 0.116614095040102894`, 
      0.110476830737948339`, 0.100720890023488363`, 0.098332977900976175`, 
      0.0848722499843202982`, 0.0819040689536946153`, 0.0705576270639002878`, 
      0.0650639417458242874`, 0.0644709272581272507`, 0.0493197129987581561`, 
      0.0483689873353282351`, \(\(0.0363464411120563424`\)\(\[InvisibleSpace]\
\)\) + 0.00268588874362431617`\ I, \(\(0.0363464411120563424`\)\(\
\[InvisibleSpace]\)\) - 0.00268588874362431617`\ I, 0.031043852979444404`, 
      0.0204146838520639484`, 0.0192719659619875791`, 0.0191588634026986444`, 
      0.0104292437421209394`, 
      0.0103880959369845582`, \
\(\(0.00483624796544466128`\)\(\[InvisibleSpace]\)\) + 
        0.00298598897511975636`\ I, \(\(0.00483624796544466128`\)\(\
\[InvisibleSpace]\)\) - 
        0.00298598897511975636`\ I, \(-0.00361205181315396872`\), 
      0.00182093635683948225`, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Estimating genotype frequencies", "SubsubsectionIcon"],

Cell[TextData[{
  "Describing the frequencies of genotypes with more than a few loci is \
diffiult, because there are so many possible genotypes.  However, if \
associations between genes (\"linkage disequilibria\") are generated by some \
kind of population mixing, then they take on a particularly simple form.  The \
strength of associations, and the genotype frequencies, can be ",
  ButtonBox["estimated",
    ButtonData:>{"Introduction to estimating D", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"estimated"],
  " using a Monte Carlo method."
}], "Text"],

Cell[TextData[{
  "For example, this estimates a matrix of linkage disequilibria for data \
held in an array Data[1063], using the ",
  Cell[BoxData[
      FormBox[
        ButtonBox[
          FormBox[
            ButtonBox[
              FormBox[
                ButtonBox["Metropolis",
                  ButtonData:>{
                    FrontEnd`FileName[ {
                      ParentDirectory[ 
                        ParentDirectory[ 
                          ParentDirectory[ ]]], "Multilocus", "Documentation",
                       "English"}, "EstimatingDMLExample.nb", 
                      CharacterEncoding -> "MacintoshRoman"], None},
                  ButtonStyle->"Hyperlink"],
                "TraditionalForm"],
              ButtonData:>{
                FrontEnd`FileName[ {
                  ParentDirectory[ 
                    ParentDirectory[ 
                      ParentDirectory[ ]]], "Multilocus", "Documentation", 
                  "English"}, "EstimatingDEstimating.nb", CharacterEncoding -> 
                  "MacintoshRoman"], None},
              ButtonStyle->"Hyperlink"],
            "TraditionalForm"],
          ButtonData:>{"Metropolis algorithm", None},
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  " algorithm:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(met = MetropolisDisequilibrium[1063, 0, {200, 100}, met]; \), "\n", 
    \(met\[LeftDoubleBracket]2, 3\[RightDoubleBracket] // 
      MatrixForm\)}], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", "0", 
              "0.0348831558912528016`", \(-0.00848239094186541464`\), \
\(-0.00118471820488195401`\)},
            {"0", 
              "0.0464456459785946584`", \(-0.00434131417169414302`\), \
\(-0.00377906809035033974`\), "0.00160125855735155582`"},
            {
              "0.0348831558912528016`", \(-0.00434131417169414302`\), \
\(-0.00312112782592878845`\), "0.00174985792243318432`", 
              "0.000899555896628374007`"},
            {\(-0.00848239094186541464`\), \(-0.00377906809035033974`\), 
              "0.00174985792243318432`", 
              "0.000849144007797611344`", \(-0.00136684662823027913`\)},
            {\(-0.00118471820488195401`\), "0.00160125855735155582`", 
              "0.000899555896628374007`", \(-0.00136684662823027913`\), \
\(-0.000749940890586429542`\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[65]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "There is also a ",
  ButtonBox["simpler",
    ButtonData:>{"Estimating the matrix of moments", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"simpler"],
  " method based on the sample moments; this extends to inferences about \
mated pairs from samples of the ",
  ButtonBox["families",
    ButtonData:>{"Estimation from families", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"families"],
  " which they produce."
}], "Text"],

Cell[TextData[{
  "For example, this estimates associations among genes in the parents from a \
set of data on families, held in ",
  StyleBox["familydata",
    FontSlant->"Italic"],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FamilyEffects[familydata\[LeftDoubleBracket]2\[RightDoubleBracket], 
        pp] // MatrixForm\)], "Input",
  CellLabel->"In[362]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.7154040404040405`", "0.552128427128427`", 
              "0.5360068943402276`", 
              "0.42261904761904756`", \(-0.10765993265993279`\), 
              "0.3665784832451501`"},
            {\(-0.12723214285714285`\), \(-0.14508928571428564`\), 
              "0.3482142857142857`", "1.0000000000000002`", 
              "1.0000000000000004`", "0.6406249999999999`"},
            {\(-0.025348529486787008`\), \(-0.37882709997834474`\), \
\(-0.9813483046098721`\), \(-1.9106965702947851`\), \(-1.9942046694498303`\), \
\(-1.4640601078108424`\)},
            {\(-0.07472331217141354`\), \(-0.33288034923544535`\), \
\(-0.47400200991734176`\), \(-0.20187419120674066`\), 
              "0.053673985105773064`", \(-0.42515359128377866`\)},
            {"0.09449407285881652`", "0.09525204743961654`", 
              "0.012543617178793591`", "0.22817258648351593`", 
              "0.24855326647846918`", "0.05605517296412771`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[362]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "There is also a simpler set of algorithms for estimating ",
  ButtonBox["pairwise",
    ButtonData:>{"Pairwise example", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"pairwise"],
  " disequilibria using maximum likelihood."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Manipulating genetic data", "SubsubsectionIcon"],

Cell[TextData[{
  "Methods are provided for basic ",
  ButtonBox["manipulation",
    ButtonData:>{"Notation for genetic data", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"manipulation"],
  " of genetic data on multiple loci, with multiple alleles:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Data[
        s1] = {{{f, s}, {f, m}, {s}}, {{f, f}, {s, m}, {f}}, {{f, 
            f}, \[EmptySet], \[EmptySet]}}; \), "\n", 
    \(Data[s1] // MatrixForm\)}], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\({f, s}\), \({f, m}\), \({s}\)},
            {\({f, f}\), \({s, m}\), \({f}\)},
            {\({f, f}\), "\[EmptySet]", "\[EmptySet]"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[25]//MatrixForm="]
}, Open  ]],

Cell["\<\
This describes the allele frequencies; there are 3 loci each with 3 \
alleles:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlleleFrequencyTable[s1, {{s, m, f}, 3}] // MatrixForm\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\(1\/6\), "0", \(5\/6\)},
            {\(1\/4\), \(1\/2\), \(1\/4\)},
            {\(1\/2\), "0", \(1\/2\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[27]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "Offspring can be generated ",
  ButtonBox["randomly",
    ButtonData:>{"Generating families", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"randomly"],
  " from given parents:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RandomFamily[{{a, b, c}, {A, B, C}}, 10, Linkage \[Rule] {0, 0.5}] // 
      TableForm\)], "Input",
  CellLabel->"In[4]:=  (10:55:47 on 2/9/01)"],

Cell[BoxData[
    TagBox[GridBox[{
          {"a", "b", "C"},
          {"A", "B", "c"},
          {"a", "b", "c"},
          {"A", "B", "c"},
          {"a", "b", "c"},
          {"A", "B", "c"},
          {"A", "B", "C"},
          {"a", "b", "C"},
          {"A", "B", "C"},
          {"A", "B", "C"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[4]//TableForm=  (10:55:47 on 2/9/01)"]
}, Closed]],

Cell[TextData[{
  "The ",
  ButtonBox["probability",
    ButtonData:>{"Genotype probabilities", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"probability"],
  " that a given genotype or set of genotypes came from a certain cross can \
be found:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GenotypeProbability[{a, b, c, d}, {{a, b, C, d}, {A, B, c, d}}, 
      Linkage \[Rule] {r\_ab, r\_bc, r\_cd}]\)], "Input",
  CellLabel->"In[116]:=  (12:48:42 on 2/9/01)"],

Cell[BoxData[
    \(\((1 - r\_ab)\)\ r\_bc\)], "Output",
  CellLabel->"Out[116]=  (12:48:42 on 2/9/01)"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Structured models", "SubsubsectionIcon"],

Cell[TextData[{
  "The likelihood of a '",
  ButtonBox["structured model",
    ButtonData:>{"Likelihood of a structured model", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"structured model"],
  "', which includes interactions between various factors, can be calculated. \
"
}], "Text"],

Cell["\<\
For example, this is the likelihood of a particular set of \
parameters, under a model with density effects, and line\[Times]replicate \
interaction:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"StructuredLogLikelihood", "[", 
      RowBox[{
      "dd", ",", \({line, rep, density}\), ",", \({density, {rep, line}}\), 
        ",", 
        RowBox[{"{", 
          RowBox[{"2.", ",", \({0, 1, 2, 3}\), ",", 
            RowBox[{"(", GridBox[{
                  {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
                  {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"}
                  }], ")"}]}], "}"}], ",", "LogL"}], "]"}]], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(\(-2987.8868636305597`\)\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell["\<\
The model can specify an arbitrary probability distribution, and is \
more flexible than standard AVOVA.  For example, the variance and mean of the \
distribution can depend in different ways on the factors.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Random numbers", "SubsubsectionIcon"],

Cell[TextData[{
  "Various extensions to the usual ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " random number generators are provided:"
}], "Text"],

Cell[TextData[{
  "This ",
  ButtonBox["muddles",
    ButtonData:>{"Muddling and subdividing sets", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"muddles"],
  " a set:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Muddle[{a, b, c, d}]\)], "Input",
  CellLabel->"In[134]:="],

Cell[BoxData[
    \({c, d, a, b}\)], "Output",
  CellLabel->"Out[134]="]
}, Open  ]],

Cell[TextData[{
  "Here is a ",
  ButtonBox["random sample",
    ButtonData:>{"Random lists", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"random sample"],
  " from the probability distribution, given as a list of 10 integers:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RandomList[10, {0.1, 0.4, 0.5}]\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \({3, 2, 3, 3, 3, 3, 3, 3, 1, 2}\)], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell[TextData[{
  "This generates 1000 random numbers drawn from a ",
  ButtonBox["specified",
    ButtonData:>{"Sampling from arbitrary distributions", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"specified"],
  " cumulative distribution, CDF[PoissonDistribution[1.5],#]&:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tt = 
      Table[RandomCum[CDF[PoissonDistribution[1.5], #] &, 
          1], {1000}]\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \({2, 1, 2, 1, 1, 1, 1, 1, 1, 0, 1, 3, 0, 1, 3, 2, 5, 3, 1, 1, 1, 0, 0, 
      3, 2, 1, 1, 2, 1, 0, 3, 1, 2, 0, 2, 1, 2, 2, 2, 3, 2, 3, 1, 1, 1, 2, 1, 
      1, 1, 1, 0, 3, 1, 0, 1, 1, 1, 2, 2, 0, 3, 0, 3, 0, 0, 1, 1, 2, 2, 1, 0, 
      1, 1, 1, 4, 1, 4, 1, 2, 3, 1, 1, 0, 3, 2, 1, 0, 2, 1, 0, 2, 3, 2, 2, 2, 
      2, 1, 1, 2, 1, 1, 0, 4, 1, 0, 2, 3, 2, 1, 1, 2, 3, 3, 0, 4, 0, 0, 1, 1, 
      1, 2, 0, 2, 0, 0, 0, 2, 2, 0, 1, 2, 0, 2, 0, 0, 1, 2, 5, 0, 1, 2, 1, 3, 
      3, 3, 1, 1, 2, 2, 0, 2, 4, 2, 2, 3, 2, 4, 2, 3, 1, 0, 2, 2, 0, 2, 0, 3, 
      0, 2, 4, 2, 1, 0, 2, 4, 1, 1, 4, 0, 2, 1, 1, 1, 1, 1, 2, 2, 1, 2, 1, 2, 
      0, 3, 1, 0, 2, 3, 3, 0, 0, 1, 3, 0, 1, 6, 1, 2, 3, 2, 3, 0, 2, 0, 1, 1, 
      1, 0, 2, 1, 3, 1, 4, 1, 2, 3, 0, 0, 1, 3, 2, 1, 1, 0, 2, 0, 3, 0, 1, 2, 
      1, 3, 2, 1, 2, 1, 2, 0, 2, 2, 2, 3, 1, 2, 4, 1, 3, 1, 0, 1, 3, 1, 2, 2, 
      1, 2, 0, 1, 3, 0, 1, 1, 0, 1, 2, 1, 2, 3, 3, 0, 3, 1, 2, 2, 0, 3, 5, 0, 
      2, 0, 4, 2, 2, 0, 2, 1, 2, 1, 3, 6, 3, 2, 5, 5, 4, 1, 1, 1, 4, 1, 1, 0, 
      1, 1, 1, 1, 2, 1, 2, 3, 0, 2, 3, 3, 1, 0, 3, 4, 1, 3, 2, 2, 1, 1, 1, 1, 
      4, 0, 4, 0, 0, 2, 1, 0, 0, 5, 1, 1, 3, 2, 1, 1, 1, 4, 2, 2, 0, 2, 1, 0, 
      1, 1, 1, 0, 0, 2, 1, 2, 4, 2, 4, 1, 0, 3, 2, 0, 2, 4, 2, 1, 1, 1, 1, 1, 
      0, 3, 2, 1, 0, 0, 1, 1, 0, 1, 1, 0, 0, 2, 5, 3, 1, 2, 0, 1, 0, 0, 3, 0, 
      4, 1, 0, 2, 3, 0, 2, 0, 2, 1, 0, 0, 2, 4, 0, 1, 1, 1, 3, 3, 0, 0, 4, 3, 
      1, 3, 3, 0, 1, 3, 1, 4, 2, 1, 1, 2, 3, 1, 1, 1, 2, 4, 1, 2, 1, 2, 1, 2, 
      0, 3, 2, 2, 2, 0, 1, 2, 0, 3, 0, 3, 1, 1, 2, 1, 2, 2, 1, 2, 1, 2, 3, 5, 
      1, 3, 1, 1, 1, 3, 4, 2, 1, 5, 3, 2, 0, 1, 0, 1, 1, 3, 2, 1, 0, 0, 3, 1, 
      4, 0, 1, 0, 1, 1, 2, 2, 0, 1, 2, 3, 3, 3, 1, 2, 1, 0, 2, 0, 0, 4, 4, 1, 
      1, 2, 1, 1, 3, 1, 3, 2, 2, 5, 0, 3, 4, 0, 2, 1, 2, 0, 2, 0, 1, 0, 3, 2, 
      0, 1, 1, 1, 1, 4, 2, 2, 1, 4, 1, 2, 2, 3, 3, 1, 5, 3, 0, 1, 2, 2, 0, 2, 
      1, 1, 2, 1, 0, 1, 0, 2, 2, 1, 2, 3, 0, 2, 3, 1, 0, 2, 3, 0, 1, 5, 2, 1, 
      0, 1, 3, 1, 3, 0, 2, 2, 0, 1, 4, 2, 0, 3, 0, 1, 4, 0, 1, 0, 1, 0, 2, 2, 
      1, 1, 2, 1, 1, 1, 0, 2, 1, 0, 0, 0, 0, 0, 0, 2, 1, 0, 3, 1, 2, 0, 0, 3, 
      1, 1, 1, 1, 3, 4, 1, 2, 2, 3, 0, 2, 1, 2, 5, 4, 0, 2, 0, 1, 1, 2, 4, 1, 
      4, 0, 1, 0, 0, 0, 1, 1, 1, 1, 0, 2, 4, 1, 0, 2, 2, 4, 0, 0, 1, 1, 0, 2, 
      1, 1, 1, 2, 1, 0, 1, 1, 4, 2, 0, 2, 0, 1, 3, 0, 1, 1, 2, 4, 3, 4, 2, 1, 
      1, 2, 0, 2, 0, 2, 3, 1, 0, 3, 2, 2, 0, 2, 4, 1, 4, 1, 0, 2, 0, 1, 1, 1, 
      1, 2, 1, 1, 1, 4, 1, 0, 0, 0, 2, 1, 5, 1, 3, 0, 0, 0, 2, 1, 7, 2, 0, 0, 
      1, 0, 2, 2, 0, 0, 0, 1, 3, 0, 1, 4, 3, 2, 2, 3, 3, 2, 4, 1, 3, 2, 2, 1, 
      1, 2, 0, 2, 1, 1, 3, 0, 1, 1, 1, 0, 1, 1, 3, 1, 2, 4, 3, 2, 2, 0, 0, 1, 
      1, 1, 0, 3, 0, 0, 0, 2, 2, 3, 2, 2, 0, 1, 3, 1, 1, 1, 5, 2, 2, 0, 3, 0, 
      1, 2, 2, 0, 1, 1, 1, 1, 2, 2, 2, 2, 2, 1, 3, 1, 0, 0, 3, 3, 1, 3, 0, 2, 
      0, 1, 1, 2, 2, 2, 2, 1, 0, 0, 4, 1, 1, 2, 0, 0, 1, 2, 0, 1, 4, 3, 0, 1, 
      3, 2, 3, 3, 0, 3, 0, 2, 0, 3, 0, 0, 2, 0, 0, 3, 0, 1, 4, 2, 1, 1, 3, 0, 
      1, 3, 4, 0, 0, 0, 3, 2, 0, 0, 2, 2, 1, 0, 1, 2, 1, 2, 1, 0, 0, 0, 2, 4, 
      2, 0, 2, 2, 1, 0, 3, 0, 1, 6, 1, 1, 3, 3, 3, 3, 2, 1, 1, 2, 1, 0, 2, 3, 
      2, 3, 7, 0, 1, 2, 0, 3, 3, 2, 3, 1, 4, 3, 5, 1, 1, 2, 2, 2, 3, 1, 4, 3, 
      0, 1, 4, 3, 3, 2, 3, 3, 0, 0, 0, 1, 0, 1, 0, 0, 2}\)], "Output",
  CellLabel->"Out[18]="]
}, Closed]],

Cell[TextData[{
  "Here is a sample of 100 from the ",
  ButtonBox["multinomial",
    ButtonData:>{"Multinomial distribution", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"multinomial"],
  " distribution, with probabilities {0.1,0.3,0.6}"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(pp = {0.1, 0.3, 0.6}; \), "\n", 
    \(RandomMultinomial[100, pp]\)}], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \({12, 32, 56}\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[TextData[{
  "This adds ",
  ButtonBox["NegativeHypergeometricDistribution[n,p,\[Alpha]]",
    ButtonData:>{"Negative hypergeometric distribution", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"NegativeHypergeometricDistribution[n,p,\[Alpha]]"],
  " to the set of statistical distributions:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PDF[NegativeHypergeometricDistribution[n, p, \[Alpha]], i]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(\(Binomial[n, i]\ Pochhammer[\((1 - p)\)\ \[Alpha], \(-i\) + n]\ \
Pochhammer[p\ \[Alpha], i]\)\/Pochhammer[\[Alpha], n]\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell[TextData[{
  "This ",
  ButtonBox["tests",
    ButtonData:>{"Likelihood tests", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"tests"],
  " for deviations between observed numbers {7,25,8} and expected numbers \
{10,20,10}:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LogLikelihoodTest[{7, 25, 8}, {10, 20, 10}] // N\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \(1.29671576477043437`\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Set manipulation", "SubsubsectionIcon"],

Cell[TextData[{
  "There are various extensions to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ",
  ButtonBox["set manipulation",
    ButtonData:>{"Overview of set manipulation", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"set manipulation"],
  " algorithms."
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          ButtonBox["AddUp",
            ButtonData:>{"AddUp", "AddUp"},
            ButtonStyle->"AddOnsLink",
            ButtonNote->"AddUp"], "[", 
          RowBox[{
            StyleBox["expr",
              FontSlant->"Italic"], ",", "e", ",", "U"}], "]"}], 
        TraditionalForm]]],
  " sums over elements in the set U.  It can be represented compactly using \
the Notation package:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sum]\+\(x \[Element] {i, j, k}\)x\^2\)], "Input",
  CellLabel->"In[101]:="],

Cell[BoxData[
    \(i\^2 + j\^2 + k\^2\)], "Output",
  CellLabel->"Out[101]="]
}, Open  ]],

Cell[TextData[{
  "This ",
  ButtonBox["subdivides",
    ButtonData:>{"Muddling and subdividing sets", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"subdivides"],
  " a set into lists of length {1,2,3,4}:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Subdivide[{a, b, c, d, e, f, g, h, i, j}, {1, 2, 3, 4}]\)], "Input",
  CellLabel->"In[38]:=  (10:01:47 on 2/23/01)"],

Cell[BoxData[
    \({{a}, {b, c}, {d, e, f}, {g, h, i, j}}\)], "Output",
  CellLabel->"Out[38]=  (10:01:47 on 2/23/01)"]
}, Open  ]],

Cell[TextData[{
  ButtonBox["TakeAway",
    ButtonData:>{"TakeAway", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"TakeAway"],
  "[U,V]  or U\[Backslash]V removes ",
  StyleBox["exactly",
    FontSlant->"Italic"],
  " the elements in V from U:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, b, c, c}\[Backslash]{b, c}\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \({a, c}\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell[TextData[{
  "There are 7 ways of ",
  ButtonBox["partitioning",
    ButtonData:>{"Set partitions", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"partitioning"],
  " a set of 4 elements into 2 parts:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetPartition[{a, b, c, d}, 2]\)], "Input",
  CellLabel->"In[152]:=  (5:57:29 on 4/7/00)"],

Cell[BoxData[
    \({{{a, d}, {b, c}}, {{d}, {a, b, c}}, {{a, c}, {b, d}}, {{c}, {a, b, 
          d}}, {{a, b}, {c, d}}, {{b}, {a, c, d}}, {{a}, {b, c, 
          d}}}\)], "Output",
  CellLabel->"Out[152]=  (5:57:29 on 4/7/00)"]
}, Open  ]],

Cell[TextData[{
  ButtonBox["FlattenList",
    ButtonData:>{"Flattening lists by pattern", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FlattenList"],
  " extracts elements in the nested list of the form {_,_}:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FlattenList[{{a, 1}, {{b, 2}, {c, 3}}}, {_, _}]\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    \({{a, 1}, {b, 2}, {c, 3}}\)], "Output",
  CellLabel->"Out[50]="]
}, Open  ]],

Cell["\<\
Flatten[] cannot be used, because it would remove the list \
structure entirely.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Automatic equation numbering", "SubsubsectionIcon"],

Cell[TextData[{
  "This sets up cells containing links to each numbered equation in a \
notebook.  They will maintain their ",
  ButtonBox["numbering",
    ButtonData:>{"Automatic Numbering", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"numbering"],
  " automatically."
}], "Text"],

Cell[BoxData[
    \(Scan[NumberedLink, FindTags["\<NumberedEquation\>"]]; \)], "Input",
  CellLabel->"In[81]:="],

Cell[TextData[{
  "f eqn",
  "   ",
  ButtonBox["(",
    ButtonData:>"f eqn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "f eqn"],
  ButtonBox[")",
    ButtonData:>"f eqn",
    ButtonStyle->"Hyperlink"]
}],
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "psi eqn",
  "   ",
  ButtonBox["(",
    ButtonData:>"psi eqn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "psi eqn"],
  ButtonBox[")",
    ButtonData:>"psi eqn",
    ButtonStyle->"Hyperlink"]
}],
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "psi soln",
  "   ",
  ButtonBox["(",
    ButtonData:>"psi soln",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "psi soln"],
  ButtonBox[")",
    ButtonData:>"psi soln",
    ButtonStyle->"Hyperlink"]
}],
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[BoxData[
    \(f[t] = \[Alpha] + \[Beta]t\)], "NumberedEquation",
  CellFrame->False,
  CellTags->"f eqn"],

Cell[BoxData[
    \(\[PartialD]\ \[Psi]\/\[PartialD]t = f[t] \[Psi]\)], "NumberedEquation",
  CellFrame->False,
  CellTags->"psi eqn"],

Cell[BoxData[
    \(\[Psi][t] = 
      C\ Exp[\[Alpha]\[VeryThinSpace]t + \[Beta]t\^2\/2]\)], \
"NumberedEquation",
  CellFrame->False,
  CellTags->"psi soln"],

Cell["Other numbered cells can be handled in the same way.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Cumulants and moments", "SubsubsectionIcon"],

Cell[TextData[{
  "This writes the fourth ",
  ButtonBox["cumulant",
    ButtonData:>{"Cumulants", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"cumulant"],
  " in terms of the moments:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cumulant[m, 4]\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\(-6\)\ m[1]\^4 + 12\ m[1]\^2\ m[2] - 3\ m[2]\^2 - 4\ m[1]\ m[3] + 
      m[4]\)], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell["Multivariate cumulants are defined:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cumulant[m, {i, j, k, l}]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(\(-6\)\ m[{i}]\ m[{j}]\ m[{k}]\ m[{l}] + 2\ m[{k}]\ m[{l}]\ m[{i, j}] + 
      2\ m[{j}]\ m[{l}]\ m[{i, k}] + 2\ m[{j}]\ m[{k}]\ m[{i, l}] + 
      2\ m[{i}]\ m[{l}]\ m[{j, k}] - m[{i, l}]\ m[{j, k}] + 
      2\ m[{i}]\ m[{k}]\ m[{j, l}] - m[{i, k}]\ m[{j, l}] + 
      2\ m[{i}]\ m[{j}]\ m[{k, l}] - m[{i, j}]\ m[{k, l}] - 
      m[{l}]\ m[{i, j, k}] - m[{k}]\ m[{i, j, l}] - m[{j}]\ m[{i, k, l}] - 
      m[{i}]\ m[{j, k, l}] + m[{i, j, k, l}]\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Fourier transforms", "SubsubsectionIcon"],

Cell[TextData[{
  ButtonBox["FourierNormalised",
    ButtonData:>{"Fourier transforms", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"FourierNormalised"],
  "[]  gives an interpolation function for the Fourier transform of ",
  Cell[BoxData[
      \(TraditionalForm\`f[x]\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[x_] := \(Sin[x + 0.5] \[ExponentialE]\^\(\(-\((x - \
1)\)\^2\)/2\)\)\/\@\(2  \[Pi]\); 
    fn = FourierNormalised[f, 20, 256]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{\(-19.9494201464527627`\), 
            19.9494201464527627`}}, "<>"]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell["This is an accurate approximation to the true expression:", \
"MathCaption"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.309017 1.03006 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.16667 .29652 -6 -9 ]
[.16667 .29652 6 0 ]
[.33333 .29652 -6 -9 ]
[.33333 .29652 6 0 ]
[.66667 .29652 -3 -9 ]
[.66667 .29652 3 0 ]
[.83333 .29652 -3 -9 ]
[.83333 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 .10301 -24 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -24 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -18 -4.5 ]
[.4875 .51503 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-6)] 0 .29652 0 1 Mshowa
.16667 .30902 m
.16667 .31527 L
s
[(-4)] .16667 .29652 0 1 Mshowa
.33333 .30902 m
.33333 .31527 L
s
[(-2)] .33333 .29652 0 1 Mshowa
.66667 .30902 m
.66667 .31527 L
s
[(2)] .66667 .29652 0 1 Mshowa
.83333 .30902 m
.83333 .31527 L
s
[(4)] .83333 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(6)] 1 .29652 0 1 Mshowa
.125 Mabswid
.04167 .30902 m
.04167 .31277 L
s
.08333 .30902 m
.08333 .31277 L
s
.125 .30902 m
.125 .31277 L
s
.20833 .30902 m
.20833 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.29167 .30902 m
.29167 .31277 L
s
.375 .30902 m
.375 .31277 L
s
.41667 .30902 m
.41667 .31277 L
s
.45833 .30902 m
.45833 .31277 L
s
.54167 .30902 m
.54167 .31277 L
s
.58333 .30902 m
.58333 .31277 L
s
.625 .30902 m
.625 .31277 L
s
.70833 .30902 m
.70833 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.79167 .30902 m
.79167 .31277 L
s
.875 .30902 m
.875 .31277 L
s
.91667 .30902 m
.91667 .31277 L
s
.95833 .30902 m
.95833 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .10301 m
.50625 .10301 L
s
[(-0.2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-0.1)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.1)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(0.2)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
0 .30902 m
.00286 .30902 L
.00664 .30902 L
.01076 .30902 L
.01825 .30902 L
.02316 .30902 L
.02778 .30902 L
.03642 .30902 L
.04571 .30902 L
.05575 .30903 L
.07374 .30904 L
.07826 .30904 L
.08253 .30904 L
.08636 .30904 L
.09052 .30904 L
.09457 .30904 L
.09887 .30904 L
.10254 .30904 L
.10659 .30903 L
.11086 .30902 L
.11547 .30901 L
.11981 .30899 L
.12379 .30896 L
.1282 .30893 L
.13229 .30888 L
.13678 .30881 L
.14157 .30872 L
.14662 .3086 L
.15137 .30845 L
.16027 .30805 L
.16453 .3078 L
.16921 .30746 L
.17866 .30656 L
.18742 .30538 L
.1956 .30393 L
.20525 .30166 L
.21405 .299 L
.23385 .2906 L
.2506 .28082 L
.2684 .26844 L
.28379 .25753 L
.29188 .25242 L
.3004 .248 L
.30482 .24624 L
.30715 .24549 L
.30965 .24484 L
.31405 .24411 L
.31814 .24395 L
.32263 .2444 L
.32688 .24549 L
Mistroke
.33069 .24706 L
.33482 .2494 L
.33939 .25283 L
.34442 .25766 L
.3546 .2708 L
.36402 .28697 L
.37284 .30538 L
.4042 .3884 L
.43761 .47959 L
.44751 .50182 L
.45684 .51968 L
.46592 .5339 L
.47426 .54409 L
.48221 .55117 L
.48621 .55375 L
.4906 .55583 L
.49502 .55713 L
.49749 .55751 L
.49974 .55764 L
.50412 .55729 L
.50827 .55624 L
.51251 .55444 L
.51492 .55308 L
.51719 .5516 L
.52665 .54311 L
.53483 .53285 L
.54365 .51883 L
.56372 .47638 L
.58211 .42761 L
.59969 .37723 L
.61846 .32616 L
.62757 .30444 L
.63617 .2866 L
.64384 .27323 L
.65226 .26143 L
.66029 .25311 L
.66467 .24974 L
.66878 .24732 L
.67261 .24567 L
.67612 .24465 L
.68016 .24404 L
.684 .24397 L
.68813 .2444 L
.69254 .2454 L
.69669 .24679 L
.70045 .24838 L
.71838 .25901 L
.73672 .27212 L
.75606 .28498 L
.77257 .29371 L
Mistroke
.78205 .29762 L
.79067 .3005 L
.79874 .30268 L
.80751 .30453 L
.81678 .30599 L
.82554 .307 L
.83374 .30768 L
.83823 .30797 L
.84244 .30819 L
.84986 .30849 L
.8538 .30861 L
.85804 .30871 L
.86255 .3088 L
.86735 .30888 L
.87262 .30893 L
.87752 .30897 L
.87992 .30899 L
.88251 .309 L
.8848 .30901 L
.88722 .30902 L
.89181 .30903 L
.89603 .30904 L
.90016 .30904 L
.9046 .30904 L
.90878 .30904 L
.9126 .30904 L
.91707 .30904 L
.9196 .30904 L
.92194 .30904 L
.9308 .30903 L
.94696 .30903 L
.95605 .30902 L
.96438 .30902 L
.97172 .30902 L
.97975 .30902 L
.9838 .30902 L
.98813 .30902 L
.99593 .30902 L
Mfstroke
.99593 .30902 m
1 .30902 L
s
1 0 0 r
0 .30902 m
.00389 .30902 L
.00813 .30902 L
.01669 .30902 L
.02149 .30902 L
.02585 .30902 L
.03416 .30902 L
.04182 .30902 L
.05024 .30903 L
.05915 .30903 L
.07528 .30904 L
.07913 .30904 L
.08323 .30904 L
.0871 .30904 L
.09061 .30904 L
.09484 .30904 L
.09883 .30904 L
.10314 .30904 L
.10557 .30903 L
.1078 .30903 L
.11144 .30902 L
.11544 .30901 L
.11962 .30899 L
.12351 .30896 L
.1281 .30893 L
.13245 .30888 L
.13635 .30882 L
.14059 .30874 L
.1452 .30863 L
.15009 .30849 L
.15468 .30832 L
.15888 .30812 L
.16643 .30767 L
.17456 .30699 L
.18173 .30619 L
.18927 .30509 L
.19757 .30351 L
.20529 .30165 L
.22279 .29572 L
.23199 .29155 L
.24045 .28703 L
.25958 .27475 L
.27611 .26288 L
.28488 .25681 L
.29429 .25105 L
.29866 .2488 L
.30281 .24699 L
.30653 .24567 L
.31059 .24463 L
.31442 .24407 L
Mistroke
.3185 .24395 L
.32235 .24434 L
.32583 .24515 L
.33014 .24679 L
.3341 .24894 L
.33845 .25205 L
.34303 .2562 L
.35075 .26528 L
.3592 .27823 L
.39726 .36855 L
.43324 .46885 L
.44892 .50473 L
.46554 .53339 L
.47422 .54405 L
.47915 .54875 L
.48377 .55225 L
.48801 .5547 L
.49188 .55629 L
.49636 .55736 L
.50061 .55763 L
.50502 .55712 L
.50917 .55592 L
.5129 .55423 L
.51694 .55177 L
.52135 .54832 L
.52601 .54381 L
.53435 .53353 L
.54929 .50832 L
.56568 .47155 L
.60284 .36827 L
.62044 .32121 L
.63672 .28556 L
.64484 .27164 L
.65347 .25999 L
.65764 .25554 L
.66213 .25158 L
.66706 .24824 L
.66946 .24697 L
.67169 .246 L
.67571 .24474 L
.68011 .24403 L
.6844 .24398 L
.68897 .24455 L
.69324 .24561 L
.69728 .24702 L
.70482 .25057 L
.74028 .27465 L
.75968 .2871 L
.76917 .29211 L
.77783 .29598 L
Mistroke
.79387 .30142 L
.80271 .30357 L
.8111 .30515 L
.82018 .30642 L
.8286 .30728 L
.83785 .30794 L
.84301 .30821 L
.84769 .30841 L
.85174 .30855 L
.856 .30867 L
.86364 .30882 L
.8679 .30888 L
.87187 .30893 L
.87622 .30896 L
.88088 .30899 L
.88491 .30901 L
.88928 .30902 L
.89341 .30903 L
.89722 .30904 L
.90066 .30904 L
.90445 .30904 L
.9084 .30904 L
.91211 .30904 L
.94337 .30903 L
.95237 .30903 L
.96086 .30902 L
.96848 .30902 L
.97673 .30902 L
.98114 .30902 L
.98599 .30902 L
.99072 .30902 L
.99578 .30902 L
Mfstroke
.99578 .30902 m
1 .30902 L
s
0 0 1 r
0 .30902 m
.00176 .30902 L
.00591 .30902 L
.01032 .30902 L
.01448 .30902 L
.01825 .30902 L
.02279 .30902 L
.02758 .30902 L
.03167 .30902 L
.03615 .30902 L
.04098 .30902 L
.04616 .30902 L
.05104 .30903 L
.05549 .30903 L
.05997 .30903 L
.06412 .30904 L
.06866 .30905 L
.07349 .30905 L
.08159 .30908 L
.0862 .30909 L
.09052 .30911 L
.09905 .30916 L
.10697 .30922 L
.11566 .30932 L
.12494 .30946 L
.1347 .30967 L
.14391 .30992 L
.16112 .31058 L
.17621 .31135 L
.19216 .3122 L
.19618 .31239 L
.2005 .31257 L
.20297 .31266 L
.20523 .31272 L
.20966 .31279 L
.21362 .3128 L
.21793 .31272 L
.222 .31254 L
.22577 .31227 L
.22986 .31185 L
.23418 .31124 L
.23787 .31055 L
.24191 .30961 L
.24626 .30835 L
.25092 .30668 L
.25932 .30271 L
.26781 .29725 L
.27583 .29059 L
.29085 .27376 L
.30878 .24603 L
Mistroke
.32533 .21423 L
.34336 .17626 L
.36274 .13799 L
.37179 .12328 L
.38039 .11217 L
.38412 .10836 L
.38811 .10504 L
.39247 .10235 L
.39653 .10077 L
.40063 .10006 L
.40507 .10038 L
.40927 .1017 L
.41312 .10378 L
.41661 .10638 L
.42044 .11002 L
.42816 .11971 L
.43757 .13554 L
.44615 .15335 L
.46542 .2027 L
.50019 .30962 L
.53253 .40949 L
.55024 .45634 L
.56687 .49048 L
.57549 .50328 L
.58033 .50881 L
.58478 .51277 L
.58937 .51569 L
.59198 .51683 L
.5944 .51754 L
.59697 .51795 L
.5993 .51798 L
.60199 .51763 L
.60453 .51694 L
.60876 .51503 L
.61323 .51196 L
.61705 .50854 L
.62125 .504 L
.63936 .47626 L
.67715 .39876 L
.69576 .36424 L
.71301 .33939 L
.7286 .32357 L
.73731 .31731 L
.7452 .31303 L
.75389 .30964 L
.75878 .30825 L
.76327 .30725 L
.76722 .30658 L
.77154 .30602 L
.77606 .30562 L
Mistroke
.78026 .30539 L
.78466 .30526 L
.78872 .30523 L
.79317 .30528 L
.79542 .30533 L
.79789 .30541 L
.80204 .30556 L
.8065 .30577 L
.81456 .30618 L
.82948 .30699 L
.84578 .30775 L
.8555 .30809 L
.86454 .30835 L
.87317 .30854 L
.88238 .30869 L
.89142 .3088 L
.89994 .30887 L
.9076 .30891 L
.91193 .30893 L
.91588 .30895 L
.92415 .30897 L
.92871 .30898 L
.93302 .30899 L
.94069 .309 L
.94503 .309 L
.94904 .30901 L
.95308 .30901 L
.95743 .30901 L
.96221 .30901 L
.96669 .30901 L
.97146 .30901 L
.97385 .30902 L
.97648 .30902 L
.98078 .30902 L
.98321 .30902 L
.98545 .30902 L
.99041 .30902 L
.99264 .30902 L
.9951 .30902 L
.99935 .30902 L
Mfstroke
.99935 .30902 m
1 .30902 L
s
1 0 0 r
0 .30902 m
.0002 .30902 L
.00432 .30902 L
.00823 .30902 L
.0124 .30902 L
.01701 .30902 L
.02182 .30902 L
.02634 .30902 L
.03055 .30902 L
.03441 .30902 L
.03865 .30902 L
.04312 .30902 L
.04766 .30903 L
.05251 .30903 L
.05709 .30903 L
.06125 .30904 L
.06614 .30904 L
.07145 .30905 L
.07647 .30906 L
.08109 .30907 L
.08546 .30909 L
.0896 .30911 L
.09738 .30915 L
.10576 .30921 L
.11489 .30931 L
.12284 .30942 L
.13131 .30959 L
.1393 .30979 L
.14654 .31001 L
.16479 .31075 L
.18407 .31177 L
.19201 .31219 L
.19638 .3124 L
.20052 .31257 L
.20286 .31265 L
.20541 .31272 L
.20986 .31279 L
.21438 .31279 L
.21857 .31269 L
.22242 .31251 L
.22657 .3122 L
.23049 .31177 L
.23408 .31125 L
.23807 .31051 L
.24242 .30948 L
.24702 .3081 L
.2512 .30657 L
.25988 .30239 L
.26915 .29625 L
.27773 .28879 L
Mistroke
.28583 .28004 L
.304 .25421 L
.32074 .22352 L
.33897 .18555 L
.35854 .14565 L
.36763 .12968 L
.37626 .1171 L
.384 .10846 L
.38838 .10484 L
.39243 .10236 L
.39659 .10073 L
.40049 .10006 L
.404 .10019 L
.40779 .1011 L
.41193 .10304 L
.4163 .10612 L
.42003 .10959 L
.42412 .11425 L
.43356 .12827 L
.44215 .14466 L
.46143 .19163 L
.4962 .29689 L
.52864 .39818 L
.5464 .44694 L
.56303 .48365 L
.57168 .49809 L
.57613 .5041 L
.58098 .50947 L
.58373 .51194 L
.58628 .51386 L
.58892 .51547 L
.59131 .51659 L
.59588 .51783 L
.59839 .51801 L
.60076 .51785 L
.60499 .5168 L
.60947 .51462 L
.61329 .51193 L
.61749 .50813 L
.62685 .49673 L
.63559 .48297 L
.66713 .41955 L
.68441 .38449 L
.70064 .35643 L
.71811 .33353 L
.72739 .32458 L
.73739 .31726 L
.74604 .31265 L
.75038 .31085 L
.75514 .30925 L
Mistroke
.75921 .30814 L
.76356 .3072 L
.76767 .30651 L
.77141 .30604 L
.77379 .3058 L
.77603 .30562 L
.77836 .30548 L
.78092 .30536 L
.78516 .30525 L
.7897 .30524 L
.79225 .30527 L
.79502 .30532 L
.79764 .3054 L
.80007 .30549 L
.80954 .30592 L
.82843 .30694 L
.84554 .30774 L
.85397 .30804 L
.86307 .30831 L
.87167 .30851 L
.87956 .30865 L
.88797 .30876 L
.89719 .30885 L
.90184 .30888 L
.90681 .30891 L
.91579 .30895 L
.92006 .30896 L
.92476 .30898 L
.92935 .30898 L
.93429 .30899 L
.9389 .309 L
.94311 .309 L
.94712 .30901 L
.95139 .30901 L
.95606 .30901 L
.9604 .30901 L
.96556 .30901 L
.97024 .30901 L
.97514 .30902 L
.97772 .30902 L
.98045 .30902 L
.98283 .30902 L
.98545 .30902 L
.99007 .30902 L
.99232 .30902 L
.99477 .30902 L
.99923 .30902 L
Mfstroke
.99923 .30902 m
1 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[22]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0
oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`800000S@3oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo0P00002=0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?oo
o`2<0?ooo`00T@3oool2000008d0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo001m0?ooo`800000103oool010000000oooo0?ooo`3oool5000000D0
oooo00<000000?ooo`3oool0S03oool007`0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo08`0oooo001d0?ooo`@0o`000P0000020?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2<0?oo
o`00L@3oool30?l000@0oooo00D0o`000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0103oool2000008d0oooo001`0?ooo`030?l0003oool0oooo00H0
oooo00@0o`000?ooo`3oool000000P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`2<0?ooo`00K`3oool00`000?l0o`000?ooo`080?oo
o`030?l000000?l000000080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0
000000D0oooo00<000000?ooo`3oool0S03oool006l0oooo00<0o`000?ooo`3oool02@3oool0103o
0000003o0000000000090?ooo`<000001P3oool00`000000oooo0?ooo`2<0?ooo`00KP3oool00`3o
0000oooo0?ooo`0:0?ooo`030?l0003oool0003o01<0oooo00<000000?ooo`3oool0S03oool006d0
oooo00<0003o0?l0003oool0303oool00`3o0000003o0?ooo`0B0?ooo`800000S@3oool006d0oooo
00<0o`000?ooo`3oool03@3oool00`3o0000003o0?ooo`0A0?ooo`030000003oool0oooo08`0oooo
001/0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool0403oool00`000000oooo0?oo
o`2<0?ooo`00J`3oool00`000?l0o`000?ooo`0@0?ooo`030?l0003oool0oooo0100oooo00<00000
0?ooo`3oool0S03oool006X0oooo00<0003o0?l0003oool04P3oool00`3o0000oooo0?ooo`0?0?oo
o`030000003oool0oooo08`0oooo001Z0?ooo`030?l0003oool0oooo0180oooo00<0o`000?ooo`3o
ool03`3oool00`000000oooo0?ooo`2<0?ooo`00J@3oool00`000?l0o`000?ooo`0D0?ooo`030?l0
003oool0oooo00h0oooo0P00002=0?ooo`00J@3oool00`3o0000oooo0?ooo`0D0?ooo`030?l00000
0?l0oooo00h0oooo00<000000?ooo`3oool0S03oool006P0oooo00<0003o0?l0003oool05P3oool0
0`3o0000oooo0?ooo`0=0?ooo`030000003oool0oooo08`0oooo001X0?ooo`030?l0003oool0oooo
01H0oooo00<0o`000000o`3oool03@3oool00`000000oooo0?ooo`2<0?ooo`00I`3oool00`000?l0
o`000?ooo`0H0?ooo`030?l0003oool0oooo00`0oooo00<000000?ooo`3oool0S03oool006L0oooo
00<0o`000?ooo`3oool0603oool00`3o0000003o0?ooo`0<0?ooo`030000003oool0oooo08`0oooo
001W0?ooo`030?l0003oool0oooo01T0oooo00<0o`000?ooo`3oool02`3oool2000008d0oooo001V
0?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool02`3oool00`000000oooo0?ooo`2<
0?ooo`00IP3oool00`3o0000oooo0?ooo`0J0?ooo`030?l000000?l0oooo00/0oooo00<000000?oo
o`3oool0S03oool006D0oooo00<0003o0?l0003oool0703oool00`3o0000oooo0?ooo`0:0?ooo`03
0000003oool0oooo08`0oooo001U0?ooo`030?l0003oool0oooo01`0oooo00<0o`000000o`3oool0
2P3oool00`000000oooo0?ooo`2<0?ooo`00I03oool00`000?l0o`000?ooo`0N0?ooo`030?l0003o
ool0oooo00T0oooo00<000000?ooo`3oool0S03oool006@0oooo00<0o`000?ooo`3oool07P3oool0
0`3o0000oooo0?ooo`090?ooo`800000S@3oool006<0oooo00<0003o0?l0003oool0803oool00`3o
0000oooo0?ooo`080?ooo`030000003oool0oooo08`0oooo001S0?ooo`030?l0003oool0oooo0200
oooo00<0o`000?ooo`3oool0203oool00`000000oooo0?ooo`2<0?ooo`00HP3oool00`000?l0o`00
0?ooo`0H0?ooo`800000103oool01@000000oooo0?ooo`3o0000oooo00<000001P3oool00`000000
oooo0?ooo`2<0?ooo`00HP3oool00`3o0000oooo0?ooo`0G0?ooo`040000003oool0oooo000000L0
oooo00<0o`000?ooo`0000001`3oool00`000000oooo0?ooo`2<0?ooo`00HP3oool00`3o0000oooo
0?ooo`0@0?ooo`D000000P3oool010000000oooo0?ooo`0000070?ooo`030?l0003oool0000000L0
oooo0P00002=0?ooo`00H@3oool00`3o0000oooo0?ooo`0H0?ooo`040000003oool0oooo000000L0
oooo00<0o`000000o`0000001`3oool00`000000oooo0?ooo`2<0?ooo`00H@3oool00`3o0000oooo
0?ooo`0H0?ooo`040000003oool0oooo000000P0oooo00<0o`000000003oool01P3oool00`000000
oooo0?ooo`2<0?ooo`00H03oool00`3o0000oooo0?ooo`0I0?ooo`040000003oool0oooo000000P0
oooo00<0o`000000003oool01P3oool00`000000oooo0?ooo`2<0?ooo`00H03oool00`3o0000oooo
0?ooo`0J0?ooo`8000002@3oool00`3o0000003o0?ooo`060?ooo`030000003oool0oooo08`0oooo
001O0?ooo`030?l0003oool0oooo02L0oooo00<0o`000?ooo`3oool01@3oool00`000000oooo0?oo
o`2<0?ooo`00G`3oool00`3o0000oooo0?ooo`0W0?ooo`030?l0003oool0oooo00D0oooo0P00002=
0?ooo`00GP3oool00`3o0000oooo0?ooo`0X0?ooo`030?l000000?l0oooo00D0oooo00<000000?oo
o`3oool0S03oool005d0oooo00<0003o0?l0003oool0:@3oool00`3o0000003o0?ooo`050?ooo`03
0000003oool0oooo08`0oooo001M0?ooo`030?l0003oool0oooo02X0oooo00<0o`000?ooo`3oool0
103oool00`000000oooo0?ooo`2<0?ooo`00G03oool00`3o0000oooo0?ooo`0[0?ooo`030?l00000
0?l0oooo00@0oooo00<000000?ooo`3oool0S03oool005/0oooo1P3o000Y0?ooo`030?l000000?l0
oooo00@0oooo00<000000?ooo`3oool0;03oool00`000?l0o`000?l000040?l005T0oooo001H0?oo
o`@0o`001@3oool30?l002L0oooo00<0o`000?ooo`3oool00`3oool2000002`0oooo0P3o00060?oo
o`80o`0000<0003o0?ooo`3oool0E03oool005H0oooo00<0003o0?l0003oool00P3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo02@0oooo00<0o`000000o`3oool00`3oool00`000000
oooo0?ooo`0Y0?ooo`80o`002P3oool20?l000030000o`3oool0oooo0580oooo001E0?ooo`030000
o`3o0000oooo0080oooo00<0o`000?ooo`3oool01`3oool00`000?l0o`000?ooo`0T0?ooo`030?l0
00000?l0oooo00<0oooo00<000000?ooo`3oool0:03oool00`3o0000003o0?ooo`0<0?ooo`80o`00
D`3oool005<0oooo00<0003o0?l0003o00000`3oool00`000?l0o`000?ooo`090?ooo`030?l0003o
ool0oooo02@0oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`0W0?ooo`030?l00000
0?l0oooo00l0oooo00<0o`000000o`3oool0D03oool00580oooo0P3o00040?ooo`030000o`3o0000
oooo00/0oooo00<0o`000?ooo`3oool08`3oool00`3o0000003o0?ooo`020?ooo`030000003oool0
oooo02L0oooo00<0o`000?ooo`3oool0403oool20?l00500oooo001A0?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0R0?ooo`030?l000000?l0oooo
0080oooo00<000000?ooo`3oool09P3oool00`3o0000oooo0?ooo`0C0?ooo`80o`00CP3oool000L0
oooo0`00000/0?ooo`<000005P3oool00`000?l0o`000?ooo`050?ooo`030?l0003oool0oooo00P0
oooo1@0000000`3o0000003o0?ooo`0R0?ooo`030?l000000?l0oooo0080oooo0P00000V0?ooo`03
0000o`3o0000oooo00D00000403oool00`000?l0o`000?ooo`0H0?ooo`<00000:`3oool3000000<0
oooo00060?ooo`050000003oool0oooo0?ooo`000000;03oool00`000000oooo0?ooo`0C0?ooo`80
003o00<0o`000?ooo`3oool0103oool00`000?l0o`000?ooo`0:0?ooo`060000003oool0oooo0000
003oool0o`00903oool01@3o0000003o0?ooo`3oool0000002H0oooo00<0003o0?l0003oool00P3o
ool010000000oooo0?ooo`00000A0?ooo`030000o`3o0000o`0001P0oooo00<000000?ooo`3oool0
:@3oool01@000000oooo0?ooo`3oool000000080oooo0005000000030?ooo`000000oooo0080oooo
00<000000?ooo`3oool08@3oool5000000030?ooo`000000000000<000004`3oool00`000?l0o`00
0?l000070?ooo`030?l0003oool0oooo00<0oooo1@0000030?ooo`030000003oool0oooo0080oooo
00<0o`000?ooo`3oool08@3oool01@3o0000003o0?ooo`3oool0000002H0oooo00<0003o0?l0003o
ool00`3oool00`000000oooo0?ooo`0C0?ooo`030000o`3o0000oooo01<0oooo1@00000Z0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool000H0oooo1000000Z0?ooo`040000003oool0oooo0000
0180oooo00<0003o0?l0003o0000203oool00`3o0000oooo0?ooo`0=0?ooo`060000003oool0oooo
0?ooo`3o0000003o8P3oool01@3o0000003o0?ooo`3oool0000002D0oooo00<0003o0?l0003oool0
1@3oool00`000000oooo0?ooo`0D0?ooo`80o`004P3oool010000000oooo0?ooo`00000[0?ooo`@0
00000`3oool000H0oooo00<000000?ooo`3oool0;03oool00`000000oooo0000000A0?ooo`80o`00
2@3oool00`3o0000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`3o0000
oooo0?ooo`0Q0?ooo`040?l000000?l0oooo000002D0oooo00<0003o0?l0003oool00P3oool01@00
0000oooo0?ooo`3oool0000001L0oooo00<0o`000000o`3oool0403oool00`000000oooo0000000[
0?ooo`030000003oool0oooo00@0oooo00070?ooo`030000003oool0oooo02`0oooo0P00000?0?oo
o`80o`002@3oool20?l000h0oooo00D000000?ooo`3oool0oooo000000030?ooo`030?l000000?l0
oooo0240oooo00<0o`000000o`3oool00P00000S0?ooo`030000o`3o0000oooo00<0oooo00D00000
0?ooo`3oool0oooo0000000H0?ooo`80o`004@3oool2000002`0oooo00<000000?ooo`3oool00`3o
ool000P0oooo0P00000]0?ooo`030000003oool0oooo00/0oooo0P3o00000`000?l0oooo0?ooo`07
0?ooo`030?l000000?l0oooo00l0oooo0`0000040?ooo`030?l000000?l0oooo0240oooo00@0o`00
0000o`3oool00000903oool00`000?l0o`000?ooo`040?ooo`<000006`3oool30?l000l0oooo00<0
00000?ooo`3oool0:`3oool2000000<0oooo00120?ooo`<0o`0000<0003o0?ooo`3oool0203oool0
0`3o0000003o0?ooo`0H0?ooo`030?l000000?l0oooo0240oooo00<0o`000000o`0000008`3oool0
0`000?l0o`000?ooo`0T0?ooo`80003o0P3o00100?ooo`00@03oool20?l000030000o`3oool0oooo
00X0oooo00<0o`000000o`3oool06@3oool00`3o0000003o0?ooo`0Q0?ooo`030?l000000?l00000
02<0oooo00<0003o0?l0003oool09`3oool00`000?l0o`000?l0000n0?ooo`00>`3oool50?l000d0
oooo0P3o000M0?ooo`030?l0003oool0oooo0200oooo00<0o`000000o`0000008`3oool00`3o0000
oooo0?ooo`0Y0?ooo`050000o`3o0000o`000?l000000?l0>P3oool003D0oooo1P3o00030000o`d0
oooo0P3o000O0?ooo`030?l000000?l0oooo0200oooo00<0o`000?ooo`000?l08P3oool00`3o0000
oooo0?ooo`0T0?oooaD0o`00<03oool000H0oooo;03o00040000oa8000000`3o000R000000030?l0
0000000000000200000000<0o`000000o`0000008@0000000`3o000000000000000O000000030000
o`3o0000o`000080o`004@00000a0?l000<0oooo00060?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo5P3o
00030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030?l000000?l0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`080?ooo`030?l000000?l0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`080?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`070?ooo`<0o`002`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00@3oool000H0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo00P0oooo00<0o`000000o`3oool0803oool00`3o0000003o0?ooo`0P
0?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool0403oool20?l001T0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`010?ooo`00KP3oool00`3o0000oooo0?ooo`0P0?oo
o`030?l000000?l0oooo01h0oooo00<0o`000?ooo`3oool0703oool00`3o0000oooo0?ooo`1<0?oo
o`00KP3oool00`3o0000003o0?ooo`0P0?ooo`030?l000000?l0oooo01h0oooo00<0o`000?ooo`3o
ool06`3oool00`3o0000oooo0?ooo`1=0?ooo`00K`3oool00`3o0000oooo0?ooo`0O0?ooo`030?l0
00000?l0oooo01d0oooo00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`1>0?ooo`00K`3o
ool00`3o0000003o0?ooo`0O0?ooo`030000003o0000003o01d0oooo00<0o`000?ooo`3oool06P3o
ool00`3o0000oooo0?ooo`1?0?ooo`00L03oool00`3o0000oooo0?ooo`0N0?ooo`030000003o0000
003o01`0oooo00<0003o0?l0003oool06P3oool00`3o0000oooo0?ooo`1@0?ooo`00L03oool00`3o
0000oooo0?ooo`0N0?ooo`030000003o0000003o01`0oooo00<0o`000?ooo`3oool06@3oool00`00
0?l0o`000?ooo`1A0?ooo`00L03oool00`3o0000003o0?ooo`0N0?ooo`040000003oool0o`000000
oa/0oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo0?ooo`1A0?ooo`00L@3oool00`3o0000
oooo0?ooo`0M0?ooo`040000003oool0o`000000oaX0oooo00<0003o0?l0003oool06@3oool00`3o
0000oooo0?ooo`1B0?ooo`00L@3oool00`3o0000003o0?ooo`0M0?ooo`80000000<0o`000000o`3o
ool06@3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003oool0oooo05<0oooo001b0?ooo`030?l0
003oool0oooo01`0oooo00D000000?ooo`3oool0o`000000o`0I0?ooo`030?l0003oool0oooo01L0
oooo00<0o`000?ooo`3oool0E03oool00780oooo00<0o`000?ooo`3oool0703oool01@000000oooo
0?ooo`3o0000003o01P0oooo00<0003o0?l0003oool05`3oool00`3o0000003o0?ooo`1E0?ooo`00
L`3oool00`3o0000oooo0?ooo`0K0?ooo`050000003oool0oooo0?l000000?l0603oool00`3o0000
oooo0?ooo`0G0?ooo`030?l0003oool0oooo05D0oooo001c0?ooo`030?l0003oool0oooo01/0oooo
00H000000?ooo`3oool0oooo0?l000000?lG0?ooo`030?l0003oool0oooo01H0oooo00<0o`000?oo
o`3oool0EP3oool007<0oooo00<0o`000?ooo`3oool06`3oool01P000000oooo0?ooo`3oool0o`00
0000oaH0oooo00<0003o0?l0003oool05`3oool00`3o0000oooo0?ooo`1F0?ooo`00M03oool00`3o
0000oooo0?ooo`0J0?ooo`8000000P3oool00`3o0000003o0?ooo`0E0?ooo`030?l0003oool0oooo
01H0oooo00<0o`000?ooo`3oool0E`3oool007@0oooo00<0o`000?ooo`3oool06P3oool00`000000
oooo0?ooo`020?ooo`030?l000000?l0oooo01@0oooo00<0o`000?ooo`3oool05P3oool00`3o0000
oooo0?ooo`1G0?ooo`00M@3oool00`3o0000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo
00<0o`000000o`3oool04`3oool00`3o0000oooo0?ooo`0F0?ooo`030?l0003oool0oooo05P0oooo
001e0?ooo`030?l0003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool00`3o0000003o0?oo
o`0C0?ooo`030?l0003oool0oooo01H0oooo00<0o`000?ooo`3oool0F03oool007D0oooo00<0o`00
0?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`030?l000000?l0oooo0140oooo00<0003o
0?l0003oool05P3oool00`3o0000oooo0?ooo`1I0?ooo`00MP3oool00`3o0000oooo0?ooo`0H0?oo
o`030000003oool0oooo00<0oooo00<0o`000000o`3oool04@3oool00`3o0000oooo0?ooo`0F0?oo
o`030?l0003oool0oooo05T0oooo001f0?ooo`030?l0003oool0oooo01P0oooo0P0000040?ooo`03
0?l000000?l0oooo0140oooo00<0o`000?ooo`3oool05@3oool00`3o0000oooo0?ooo`1J0?ooo`00
MP3oool00`3o0000003o0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00<0o`000000o`3oool0
3`3oool00`000?l0o`000?ooo`0F0?ooo`030?l0003oool0oooo05X0oooo001g0?ooo`030?l0003o
ool0oooo01L0oooo00<000000?ooo`3oool0103oool00`3o0000003o0?ooo`0?0?ooo`030?l0003o
ool0oooo01D0oooo00<0o`000?ooo`3oool0F`3oool007L0oooo00<0o`000?ooo`3oool00`3oool2
000000@0oooo00<000000?ooo`3oool00P3oool3000000H0oooo00<000000?ooo`3oool0103oool0
0`3o0000003o0?ooo`0?0?ooo`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3oool0F`3oool0
07P0oooo00D0o`000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030?l000000?l0oooo00d0oooo00<0003o
0?l0003oool05@3oool00`3o0000oooo0?ooo`1L0?ooo`00N03oool01@3o0000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<0o`000000o`3oool03@3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0
oooo05`0oooo001h0?ooo`050?l0003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00D0oooo0P0000060?ooo`030?l000000?l0oooo00d0oooo00<0o`00
0?ooo`3oool0503oool00`3o0000oooo0?ooo`1M0?ooo`00N@3oool0103o0000oooo0?ooo`000002
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?l0003oool05@3oool00`3o0000oooo0?ooo`1M
0?ooo`00N@3oool0103o0000oooo0?ooo`0000020?ooo`030000003oool0oooo00H0oooo0P000007
0?ooo`030000003oool0oooo00H0oooo00<0o`000000o`3oool02`3oool00`3o0000oooo0?ooo`0D
0?ooo`030?l0003oool0oooo05h0oooo001i0?ooo`040?l0003oool0oooo0?ooo`8000002P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo05h0oooo001j0?ooo`030?l0003oool0oooo
01@0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo
01@0oooo00<0o`000?ooo`3oool0G`3oool007X0oooo00<0o`000?ooo`3oool0503oool2000000P0
oooo00<0o`000000o`3oool02@3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003oool0oooo05l0
oooo001j0?ooo`030?l000000?l0oooo01@0oooo00<000000?ooo`3oool0203oool00`3o0000oooo
0?ooo`070?ooo`030000o`3o0000oooo01@0oooo00<0o`000?ooo`3oool0H03oool007/0oooo00<0
o`000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0
o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`1P0?ooo`00N`3oool00`3o0000oooo0?ooo`0C
0?ooo`030000003oool0oooo00P0oooo00<0o`000000o`3oool01`3oool00`3o0000oooo0?ooo`0C
0?ooo`030?l0003oool0oooo0640oooo001l0?ooo`030?l0003oool0oooo0180oooo00<000000?oo
o`3oool02@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o0000oooo01@0oooo00<0o`000?oo
o`3oool0H@3oool007`0oooo00<0o`000?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`03
0?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool04`3oool00`3o0000oooo0?ooo`1R0?ooo`00
O03oool00`3o0000oooo0?ooo`0B0?ooo`8000002`3oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo0180oooo00<0o`000000o`3oool0H`3oool007d0oooo00<0o`000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?l0003oool04`3o
ool00`3o0000oooo0?ooo`1S0?ooo`00O@3oool00`3o0000oooo0?ooo`0A0?ooo`030000003oool0
oooo00X0oooo00<0003o0?l0003oool00`3oool00`3o0000oooo0?ooo`0B0?ooo`030?l000000?l0
oooo06@0oooo001m0?ooo`030?l0003oool0oooo0140oooo00<000000?ooo`3oool02`3oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool0I03oool007h0
oooo00<0o`000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?ooo`060000o`3o0000oooo0?oo
o`000?l0o`004`3oool00`3o0000003o0?ooo`1U0?ooo`00OP3oool00`3o0000oooo0?ooo`0@0?oo
o`030000003oool0oooo00`0oooo00@0o`000?ooo`3oool0o`00503oool00`3o0000oooo0?ooo`1U
0?ooo`00OP3oool00`000?l0o`000?ooo`0@0?ooo`8000003@3oool0103o0000003o0?ooo`3o000C
0?ooo`030?l000000?l0oooo06H0oooo001o0?ooo`030?l0003oool0oooo00l0oooo00<000000?oo
o`3oool03@3oool20?l001@0oooo00<0o`000?ooo`3oool0IP3oool007l0oooo00<0o`000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0=0?ooo`030?l000000?l0oooo0180oooo00<0o`000000o`3o
ool0I`3oool00800oooo00<0o`000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`80o`00
4`3oool00`3o0000oooo0?ooo`1W0?ooo`00P03oool00`3o0000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00d0oooo0P3o00000`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo06P0oooo0021
0?ooo`030?l0003oool0oooo00d0oooo00<000000?ooo`3oool0303oool0103o0000oooo0?ooo`3o
000@0?ooo`030000o`3o0000oooo06T0oooo00210?ooo`030?l0003oool0oooo00d0oooo0P00000=
0?ooo`050?l0003oool0oooo0?l000000?l03`3oool00`3o0000oooo0?ooo`1Y0?ooo`00P@3oool0
0`3o0000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool2
0?l000d0oooo00<0o`000?ooo`3oool0JP3oool00880oooo00<0o`000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?l0003oool02P3oool00`3o
0000oooo0?ooo`1[0?ooo`00O@3oool2000000<0oooo00<0o`000000003oool00P3oool5000000D0
oooo00<000000?ooo`3oool02P3oool00`3o0000003o0?ooo`050?ooo`030?l0003oool0oooo00P0
oooo00<0o`000?ooo`3oool0K03oool007`0oooo00@000000?ooo`3oool000000`3oool00`3o0000
oooo0?ooo`020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool02P3oool00`3o
0000oooo0?ooo`060?ooo`80o`001`3oool00`3o0000oooo0?ooo`1]0?ooo`00O03oool010000000
oooo0?ooo`0000040?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool01@3oool20000
00X0oooo00<0o`000000o`3oool0203oool20?l000D0oooo00<0o`000?ooo`3oool0KP3oool007`0
oooo00@000000?ooo`3oool00000103oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`D0o`00L@3oool007`0
oooo00@000000?ooo`3oool000001@3oool00`3o0000oooo000000030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0203oool00`3o0000003o0?ooo`210?ooo`00O03oool010000000
oooo0?ooo`0000050?ooo`030?l0003oool0000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`070?ooo`030?l000000?l0oooo0880oooo001m0?ooo`8000001`3oool00`3o0000
oooo00000002000000H0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`220?ooo`00
QP3oool00`000?l0o`000?ooo`080?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool0
P`3oool008L0oooo00<0o`000?ooo`3oool01`3oool2000000L0oooo00<0o`000?ooo`3oool0P`3o
ool008P0oooo00<0o`000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0
oooo08@0oooo00290?ooo`030?l000000?l0oooo00D0oooo00<000000?ooo`3oool00`3oool00`00
0?l0o`000?ooo`260?ooo`00RP3oool00`3o0000003o0?ooo`040?ooo`030000003oool0oooo0080
oooo00<0003o0?l0003oool0Q`3oool008/0oooo00<0o`000000o`3oool00`3oool01P000000oooo
0?ooo`3oool0003o0?l008T0oooo002<0?ooo`80o`000`3oool00`000000oooo0?ooo`020?l008X0
oooo002>0?ooo`H0o`00S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<00000
0?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3o
ool0S03oool00940oooo0P00002=0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000
oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool2000008d0oooo002A
0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`03
0000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003o
ool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo003o0?ooob40oooo003o0?ooob40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-6.25906, -0.308951, \
0.0431659, 0.00349218}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Documentation", "SubsubsectionIcon"],

Cell[TextData[{
  "There is detailed documentation for all the packages, which is available \
through the Help Browser - just place the Applications folder containing the \
packages into the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " folder, and ",
  ButtonBox["Rebuild Help Index...",
    ButtonData:>{"Setting up the packages", "Setting up the packages"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Rebuild Help Index..."]
}], "Text"],

Cell[TextData[{
  "Known ",
  ButtonBox["bugs and features",
    ButtonData:>{"Bugs", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"bugs and features"],
  " are listed."
}], "Text"],

Cell["\<\
All functions are indexed in the Master Index, which can be \
searched using the Help Browser.\
\>", "Text"],

Cell[BoxData[
    \(<< Utilities`Hyperlinks`; \)], "Input",
  CellLabel->"In[1]:=  (17:14:19 on 3/15/01)"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{792, 616},
WindowMargins->{{Automatic, 102}, {Automatic, 46}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "f eqn"->{
    Cell[154237, 3970, 111, 3, 28, "NumberedEquation",
      CellTags->"f eqn"]},
  "psi eqn"->{
    Cell[154351, 3975, 134, 3, 44, "NumberedEquation",
      CellTags->"psi eqn"]},
  "psi soln"->{
    Cell[154488, 3980, 159, 5, 47, "NumberedEquation",
      CellTags->"psi soln"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"f eqn", 190909, 5205},
  {"psi eqn", 191006, 5208},
  {"psi soln", 191106, 5211}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 50, 0, 36, "SubsectionIcon"],

Cell[CellGroupData[{
Cell[1814, 55, 40, 0, 24, "SubsubsectionIcon"],
Cell[1857, 57, 256, 7, 23, "Text"],
Cell[2116, 66, 116, 3, 28, "MathCaption"],
Cell[2235, 71, 527, 11, 90, "Input"],
Cell[2765, 84, 202, 7, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[2992, 95, 83, 2, 26, "Input"],
Cell[3078, 99, 53319, 1389, 184, 25784, 1044, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[56412, 1491, 256, 6, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[56693, 1501, 141, 3, 42, "Input"],
Cell[56837, 1506, 16757, 389, 184, 4794, 236, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[73609, 1898, 342, 8, 37, "Text"],
Cell[73954, 1908, 167, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[74146, 1916, 521, 11, 88, "Input"],
Cell[74670, 1929, 510, 9, 41, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[75229, 1944, 61, 0, 20, "SubsubsectionIcon"],
Cell[75293, 1946, 275, 8, 23, "Text"],
Cell[75571, 1956, 243, 7, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[75839, 1967, 153, 3, 26, "Input"],
Cell[75995, 1972, 30457, 748, 372, 6589, 448, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[106467, 2723, 209, 7, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[106701, 2734, 344, 7, 42, "Input"],
Cell[107048, 2743, 16030, 281, 184, 1212, 93, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[123127, 3030, 47, 0, 20, "SubsubsectionIcon"],
Cell[123177, 3032, 1371, 38, 53, "Text"],
Cell[124551, 3072, 309, 7, 29, "MathCaption"],
Cell[124863, 3081, 433, 7, 70, "Input"],
Cell[125299, 3090, 191, 5, 34, "MathCaption"],

Cell[CellGroupData[{
Cell[125515, 3099, 211, 3, 45, "Input"],
Cell[125729, 3104, 194, 3, 48, "Output"]
}, Open  ]],
Cell[125938, 3110, 118, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[126081, 3117, 394, 6, 54, "Input"],
Cell[126478, 3125, 804, 13, 82, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[127331, 3144, 45, 0, 20, "SubsubsectionIcon"],
Cell[127379, 3146, 467, 9, 37, "Text"],
Cell[127849, 3157, 274, 8, 29, "MathCaption"],
Cell[128126, 3167, 329, 6, 64, "Input"],
Cell[128458, 3175, 112, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[128595, 3182, 224, 5, 42, "Input"],
Cell[128822, 3189, 684, 17, 95, "Output"]
}, Open  ]],
Cell[129521, 3209, 980, 24, 37, "Text"],
Cell[130504, 3235, 280, 8, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[130809, 3247, 211, 5, 42, "Input"],
Cell[131023, 3254, 2045, 31, 125, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[133117, 3291, 60, 0, 20, "SubsubsectionIcon"],
Cell[133180, 3293, 572, 11, 51, "Text"],
Cell[133755, 3306, 1294, 31, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[135074, 3341, 204, 4, 42, "Input"],
Cell[135281, 3347, 979, 21, 95, "Output"]
}, Open  ]],
Cell[136275, 3371, 462, 13, 37, "Text"],
Cell[136740, 3386, 207, 6, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[136972, 3396, 153, 3, 26, "Input"],
Cell[137128, 3401, 1127, 21, 95, "Output"]
}, Open  ]],
Cell[138270, 3425, 263, 7, 23, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[138570, 3437, 54, 0, 20, "SubsubsectionIcon"],
Cell[138627, 3439, 278, 7, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[138930, 3450, 216, 5, 42, "Input"],
Cell[139149, 3457, 300, 8, 63, "Output"]
}, Open  ]],
Cell[139464, 3468, 109, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[139598, 3475, 112, 2, 26, "Input"],
Cell[139713, 3479, 272, 8, 89, "Output"]
}, Open  ]],
Cell[140000, 3490, 223, 7, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[140248, 3501, 165, 3, 38, "Input"],
Cell[140416, 3506, 528, 18, 70, "Output"]
}, Closed]],
Cell[140959, 3527, 273, 8, 19, "MathCaption"],

Cell[CellGroupData[{
Cell[141257, 3539, 190, 3, 38, "Input"],
Cell[141450, 3544, 104, 2, 32, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[141603, 3552, 46, 0, 20, "SubsubsectionIcon"],
Cell[141652, 3554, 296, 8, 23, "Text"],
Cell[141951, 3564, 180, 4, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[142156, 3572, 508, 11, 60, "Input"],
Cell[142667, 3585, 83, 2, 20, "Output"]
}, Open  ]],
Cell[142765, 3590, 231, 4, 36, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[143033, 3599, 43, 0, 20, "SubsubsectionIcon"],
Cell[143079, 3601, 161, 5, 24, "Text"],
Cell[143243, 3608, 196, 7, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[143464, 3619, 79, 2, 26, "Input"],
Cell[143546, 3623, 72, 2, 20, "Output"]
}, Open  ]],
Cell[143633, 3628, 256, 7, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[143914, 3639, 89, 2, 26, "Input"],
Cell[144006, 3643, 89, 2, 20, "Output"]
}, Open  ]],
Cell[144110, 3648, 303, 7, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[144438, 3659, 144, 4, 26, "Input"],
Cell[144585, 3665, 3346, 43, 70, "Output"]
}, Closed]],
Cell[147946, 3711, 267, 7, 19, "MathCaption"],

Cell[CellGroupData[{
Cell[148238, 3722, 124, 3, 42, "Input"],
Cell[148365, 3727, 70, 2, 20, "Output"]
}, Open  ]],
Cell[148450, 3732, 324, 7, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[148799, 3743, 115, 2, 26, "Input"],
Cell[148917, 3747, 178, 3, 38, "Output"]
}, Open  ]],
Cell[149110, 3753, 256, 8, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[149391, 3765, 106, 2, 70, "Input"],
Cell[149500, 3769, 79, 2, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[149628, 3777, 45, 0, 20, "SubsubsectionIcon"],
Cell[149676, 3779, 299, 10, 24, "Text"],
Cell[149978, 3791, 477, 14, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[150480, 3809, 97, 2, 43, "Input"],
Cell[150580, 3813, 78, 2, 22, "Output"]
}, Open  ]],
Cell[150673, 3818, 233, 7, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[150931, 3829, 136, 2, 38, "Input"],
Cell[151070, 3833, 120, 2, 32, "Output"]
}, Open  ]],
Cell[151205, 3838, 272, 9, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[151502, 3851, 88, 2, 26, "Input"],
Cell[151593, 3855, 65, 2, 20, "Output"]
}, Open  ]],
Cell[151673, 3860, 233, 7, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[151931, 3871, 109, 2, 38, "Input"],
Cell[152043, 3875, 229, 4, 47, "Output"]
}, Open  ]],
Cell[152287, 3882, 240, 6, 70, "MathCaption"],

Cell[CellGroupData[{
Cell[152552, 3892, 105, 2, 70, "Input"],
Cell[152660, 3896, 83, 2, 70, "Output"]
}, Open  ]],
Cell[152758, 3901, 104, 3, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[152899, 3909, 57, 0, 20, "SubsubsectionIcon"],
Cell[152959, 3911, 291, 8, 23, "Text"],
Cell[153253, 3921, 112, 2, 26, "Input"],
Cell[153368, 3925, 280, 13, 22, InheritFromParent],
Cell[153651, 3940, 288, 13, 22, InheritFromParent],
Cell[153942, 3955, 292, 13, 22, InheritFromParent],
Cell[154237, 3970, 111, 3, 28, "NumberedEquation",
  CellTags->"f eqn"],
Cell[154351, 3975, 134, 3, 44, "NumberedEquation",
  CellTags->"psi eqn"],
Cell[154488, 3980, 159, 5, 47, "NumberedEquation",
  CellTags->"psi soln"],
Cell[154650, 3987, 68, 0, 22, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[154755, 3992, 50, 0, 20, "SubsubsectionIcon"],
Cell[154808, 3994, 214, 7, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[155047, 4005, 71, 2, 26, "Input"],
Cell[155121, 4009, 136, 3, 22, "Output"]
}, Open  ]],
Cell[155272, 4015, 58, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[155355, 4019, 82, 2, 26, "Input"],
Cell[155440, 4023, 503, 8, 65, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[155992, 4037, 47, 0, 20, "SubsubsectionIcon"],
Cell[156042, 4039, 310, 9, 29, "MathCaption"],

Cell[CellGroupData[{
Cell[156377, 4052, 185, 4, 52, "Input"],
Cell[156565, 4058, 196, 5, 20, "Output"]
}, Open  ]],
Cell[156776, 4066, 82, 1, 28, "MathCaption"],
Cell[156861, 4069, 32228, 1075, 184, 12101, 821, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[189126, 5149, 42, 0, 20, "SubsubsectionIcon"],
Cell[189171, 5151, 457, 11, 38, "Text"],
Cell[189631, 5164, 190, 7, 23, "Text"],
Cell[189824, 5173, 118, 3, 22, "Text"],
Cell[189945, 5178, 106, 2, 38, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

