(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6259,        186]*)
(*NotebookOutlinePosition[      7337,        221]*)
(*  CellTagsIndexPosition[      7247,        215]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Setting up new help files", "SubsectionIcon",
  CellTags->"Setting up new help files"],

Cell[TextData[{
  "Note: ",
  StyleBox[" These details are only needed if you want to set up new help \
files, diocumenting extensions to the packages",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "See the notebook",
  Cell[BoxData[
      FormBox[
        ButtonBox[\(\(\ \)\(SettingUp . nb\)\),
          ButtonData:>{
            FrontEnd`FileName[ {
              ParentDirectory[ 
                ParentDirectory[ 
                  ParentDirectory[ ]]], "Working..."}, "SettingUp.nb", 
              CharacterEncoding -> "MacintoshRoman"], None},
          ButtonStyle->"Hyperlink"], TraditionalForm]]],
  " for details of how the current notebooks were processed."
}], "Text"],

Cell["\<\
1)  Add the name of the new file into the BrowserCategories.m file \
that will sit in the same folder. Note that the file name MUST appear as a \
string, \"filename\".   The entry must have the form Item[\"name\", \
\"filename\", IndexTag\[Rule]\"indextag\",CopyTag\[Rule]None]. The IndexTag \
must be provided to identify the target of hyperlinks, and to aid index \
entries. It must be distinct from all other index tags.\
\>", "Text"],

Cell["\<\
2)  Save the new file in the same folder, with style sheet \
HelpBrowser.\
\>", "Text"],

Cell[TextData[{
  "3)  Write the documentation.  Remember that files are opened in the Help \
Browser as ",
  StyleBox["read-only",
    FontWeight->"Bold"],
  ".  Thus, one can play with example code without permanently changing the \
documentation.  "
}], "Text"],

Cell["\<\
4)  Label key cells (usually, definition boxes) with appropriate \
cell tags; these can be the targets of hyperlinks.\
\>", "Text"],

Cell["\<\
5)  Make hyperlinks to other files (usually, other documentation \
files), using Create Hyperlink.... under the Input\[Ellipsis] menu.  \
Optionally, specify a target cell tag.\
\>", "Text"],

Cell["\<\
6)  These hyperlinks would open the target files in the usual way.  \
The ButtonStyle AddOnsLink must be used to open them within the Help Browser. \
 To do this, either:\
\>", "Text"],

Cell[TextData[{
  "* Generate a new notebook using",
  ButtonBox[" ConvertHyperlinkToAddOnsLink[]",
    ButtonData:>{"Hyperlinks", "ConvertHyperlinkToAddOnsLink"},
    ButtonStyle->"AddOnsLink"],
  ".  Save the new notebook with the correct name.  (Either replace the \
original file or save a copy)."
}], "Text",
  CellMargins->{{62, Inherited}, {Inherited, Inherited}}],

Cell["or", "Text",
  CellMargins->{{62, Inherited}, {Inherited, Inherited}}],

Cell["\<\
* Use \[CloverLeaf]-\[ShiftKey]-E to see the internal form of the \
ButtonBox, and alter it to the form:\
\>", "Text",
  CellMargins->{{62, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(ButtonBox[name, ButtonData \[RuleDelayed] {indexTag, cellTag}, 
      ButtonStyle \[Rule] "\<AddOnsLink\>"]\)], "Input",
  CellMargins->{{62, Inherited}, {Inherited, Inherited}}],

Cell["\<\
The indexTag is a string which appears in BrowserCategories.m, in \
the form Item[\[Ellipsis]IndexTag\[Rule]indextag\[Ellipsis]]\
\>", "Text",
  CellMargins->{{62, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  StyleBox["Note:",
    FontWeight->"Bold"],
  "  Links to built-in functions should be pasted in directly from ",
  ButtonBox["RefGuide:BrowserIndex.nb",
    ButtonData:>{
      FrontEnd`FileName[ {
        ParentDirectory[ 
          ParentDirectory[ 
            ParentDirectory[ 
              ParentDirectory[ 
                ParentDirectory[ ]]]]], "Documentation", "English", 
        "RefGuide"}, "BrowserIndex.nb", CharacterEncoding -> 
        "MacintoshRoman"], None},
    ButtonStyle->"Hyperlink"],
  " or ",
  ButtonBox["MainBook:BrowserIndex.nb",
    ButtonData:>{
      FrontEnd`FileName[ {
        ParentDirectory[ 
          ParentDirectory[ 
            ParentDirectory[ 
              ParentDirectory[ 
                ParentDirectory[ ]]]]], "Documentation", "English", 
        "MainBook"}, "BrowserIndex.nb", CharacterEncoding -> 
        "MacintoshRoman"], None},
    ButtonStyle->"Hyperlink"],
  ".  These have a slightly different form, with styles such as \
\"MainBookLink\"."
}], "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}}],

Cell["\<\
7)  Add entries into BrowserIndex.nb as necessary.  These will \
include hyperlinks, which must be converted by reprocessing the \
BrowserIndex.nb as above.\
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowToolbars->{},
WindowSize->{691, 618},
WindowMargins->{{20, Automatic}, {Automatic, 8}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Setting up new help files"->{
    Cell[1739, 51, 92, 1, 36, "SubsectionIcon",
      CellTags->"Setting up new help files"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Setting up new help files", 7127, 208}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 92, 1, 36, "SubsectionIcon",
  CellTags->"Setting up new help files"],
Cell[1834, 54, 211, 6, 24, "Text"],
Cell[2048, 62, 503, 13, 22, "Text"],
Cell[2554, 77, 447, 7, 50, "Text"],
Cell[3004, 86, 97, 3, 22, "Text"],
Cell[3104, 91, 264, 7, 38, "Text"],
Cell[3371, 100, 141, 3, 22, "Text"],
Cell[3515, 105, 200, 4, 36, "Text"],
Cell[3718, 111, 194, 4, 36, "Text"],
Cell[3915, 117, 371, 8, 37, "Text"],
Cell[4289, 127, 76, 1, 22, "Text"],
Cell[4368, 130, 186, 4, 22, "Text"],
Cell[4557, 136, 198, 3, 27, "Input"],
Cell[4758, 141, 210, 4, 22, "Text"],
Cell[4971, 147, 1089, 30, 38, "Text"],
Cell[6063, 179, 180, 4, 36, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

