(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11874,        361]*)
(*NotebookOutlinePosition[     13807,        421]*)
(*  CellTagsIndexPosition[     13522,        409]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "These notes explain how the packages link to the Help Browser, and how \
they are entered into the Master Index.  These details are only relevant if \
you wish to extend the packages and their documentation.  They do not seem to \
be explained in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " documentation."
}], "Text"],

Cell[CellGroupData[{

Cell["Browser categories", "SubsectionIcon",
  CellTags->"Browser categories"],

Cell["\<\
The structure of the documentation is defined by a file named \
BrowserCategories.m, which is within the documentation folder.  This is \
processed by \"Rebuild Help Index\" to set up the browser structure.  The \
typical contents of BrowserCategories.m might be:\
\>", "Text"],

Cell[BoxData[
    \(BrowserCategory["\<Genealogies\>", 
      None, \[IndentingNewLine]{BrowserCategory["\<Genealogies\>", 
          None, \[IndentingNewLine]{Item["\<Describing genealogies\>", \
"\<DescribingGenealogies.nb\>", CopyTag \[Rule] None], 
            Item["\<Family structures\>", "\<FamilyStructures.nb\>", 
              CopyTag \[Rule] None], 
            Item["\<Random genealogies\>", "\<RandomGenealogies.nb\>", 
              CopyTag \[Rule] None], 
            Item["\<Infinite-sites mutation\>", "\<InfiniteSites.nb\>", 
              CopyTag \[Rule] None], 
            Item["\<Probability of genealogies\>", "\<TracingBack.nb\>", 
              CopyTag \[Rule] None], 
            Item["\<Griffiths-Tavare\>", "\<GriffithsTavare.nb\>", 
              CopyTag \[Rule] None]}], 
        BrowserCategory["\<Continuous populations\>", 
          None, {Item["\<Describing populations\>", \
"\<DescribingPopulations.nb\>", CopyTag \[Rule] None], 
            Item["\<Simulating populations\>", \
"\<SimulatingPopulations.nb\>", CopyTag \[Rule] None], 
            Item["\<Extracting genealogies\>", \
"\<ExtractingGenealogies.nb\>", CopyTag \[Rule] None]}]}]\)], "DisplayMath"],

Cell["\<\
BrowserCategory[\[Ellipsis]] sets up a heading, and a list of \
either further BrowserCategory[\[Ellipsis]] headings, or of items, defined by \
Item[\[Ellipsis]].  The Item[\[Ellipsis]] function names the notebook in \
which the documentation is found.  This allows a flexible hierarchy of \
documentation to be defined.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Setting up links to the Help Browser", "SubsectionIcon",
  CellTags->"Setting up links"],

Cell["\<\
Hyperlinks would usually just open a specified notebook, at a \
specified cell tag.  The HelpBrowser style sheet defines a new ButtonStyle, \
AddOnsLink, which ensures that the notebook is opened within the Help \
Browser.  It also simplifies the location of the relevant notebook, by \
searching for a meaningful tag, rather than for the file name.  \
\>", "Text"],

Cell["The style AddOnsLink includes:", "Text"],

Cell[BoxData[
    \(ButtonFunction \[RuleDelayed] 
        FrontEndExecute[{FrontEnd`HelpBrowserLookup["\<AddOns\>", #]}] &\)], \
"DisplayMath"],

Cell["\<\
This takes ButtonData passed from the AddOnsLink, and uses it to \
locate a specified tag within a specified file.  The AddOnsLink itself might \
have the structure:\
\>", "Text"],

Cell[BoxData[
    RowBox[{" ", 
      ButtonBox["Algebra`Quaternions`",
        ButtonData:>{"Algebra`Quaternions`", "1.13"},
        ButtonStyle->"AddOnsLink"], " "}]], "Input"],

Cell[TextData[{
  "The crucial ButtonData consist of the form {",
  StyleBox["file,call tag",
    FontSlant->"Italic"],
  "}.  The ",
  StyleBox["file",
    FontSlant->"Italic"],
  " is specified an IndexTag that is defined in BrowserCategories.m.  Thus, \
clicking on ",
  Cell[BoxData[
      RowBox[{" ", 
        ButtonBox["Algebra`Quaternions`",
          ButtonData:>{"Algebra`Quaternions`", "1.13"},
          ButtonStyle->"AddOnsLink"], " "}]]],
  " will open, within the Help Browser, a file with \
IndexTag->\"Algebra`Quaternions`\" at cell tag \"1.13\"."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Setting up entries in the Master Index: details", "SubsectionIcon",
  CellTags->"Setting up Master Index"],

Cell["\<\
Entries into the Master Index are defined by a file \
BrowserIndex.nb, in the same place as BrowserCategories.m within the \
documentation folder. This is processed by Rebuild Help Index.  \
\>", "Text"],

Cell["\<\
The BrowserIndex.nb file begins with a heading, tagged as \
MasterIndexHeading, such as:\
\>", "Text"],

Cell["Standard Packages", "IndexSection",
  CellTags->"MasterIndexHeading"],

Cell["\<\
This will appear in the Master Index to indicate the section of \
documentation. A typical entry might appear as:\
\>", "Text"],

Cell[TextData[{
  "Packages, automatic loading of, ",
  ButtonBox["Using Packages",
    ButtonData:>{"6.14.3", "3.5"},
    ButtonStyle->"AddOnsLink"],
  " , ",
  ButtonBox["Using Packages",
    ButtonData:>{"6.14.3", "3.11"},
    ButtonStyle->"AddOnsLink"],
  " "
}], "Index",
  CellTags->"Packages"],

Cell["\<\
Use \[CloverLeaf]\[ShiftKey]E to see the internal structure.  \
\
\>", "Text"],

Cell["\<\
The first piece of text, \"Packages, automatic loading of, \" is \
the entry; it si followed by one or more \
ButtonBox[...ButtonStyle->\"AddOnsLink\"] which point to the help files.  The \
cell style is \"Index\" (defined in the style sheet), and the cell tag \
determines where it will appear in the index.\
\>", "Text"],

Cell["A subentry would appear as:", "Text"],

Cell[TextData[{
  "auxiliary, ",
  ButtonBox["Using Packages",
    ButtonData:>{"6.14.5", "5.4"},
    ButtonStyle->"AddOnsLink"],
  " \nauxiliery, ",
  ButtonBox["Using Packages",
    ButtonData:>{"6.14.5", "5.3"},
    ButtonStyle->"AddOnsLink"],
  " \nfile extension, ",
  ButtonBox["Using Packages",
    ButtonData:>{"6.14.4", "4.2"},
    ButtonStyle->"AddOnsLink"],
  " \nin the same directory, ",
  ButtonBox["Using Packages",
    ButtonData:>{"6.14.3", "3.5"},
    ButtonStyle->"AddOnsLink"],
  " \nlist of loaded, ",
  StyleBox["$Packages", "MR"],
  ", ",
  ButtonBox["Using Packages",
    ButtonData:>{"6.14.2", "2.2"},
    ButtonStyle->"AddOnsLink"],
  " \nlocation of files for, ",
  ButtonBox["Using Packages",
    ButtonData:>{"6.14.3", "3.10"},
    ButtonStyle->"AddOnsLink"],
  " \nreading in, ",
  ButtonBox["Introduction",
    ButtonData:>{"5.0.1", "1.5"},
    ButtonStyle->"AddOnsLink"],
  " , ",
  ButtonBox["Using Packages",
    ButtonData:>{"6.14.1", "1.3"},
    ButtonStyle->"AddOnsLink"],
  " , ",
  ButtonBox["Using Packages",
    ButtonData:>{"6.14.5", "5.5"},
    ButtonStyle->"AddOnsLink"],
  " \nsearching, ",
  ButtonBox["Utilities`Package`",
    ButtonData:>{"Utilities`Package`", "1.3"},
    ButtonStyle->"AddOnsLink"],
  " \nwriting, ",
  ButtonBox["Using Packages",
    ButtonData:>{"6.14.5", "5.4"},
    ButtonStyle->"AddOnsLink"],
  " "
}], "IndexSubentry",
  CellTags->"Packages"],

Cell["\<\
Use \[CloverLeaf]\[ShiftKey]E to see the internal structure.  This \
consists of a series of lines consisting of text and a \
ButtonBox[\[Ellipsis]ButtonStyle->\"AddOnsLink\"]; the cell style is \
\"IndexSubentry\", and the tag is \"Packages\".  \
\>", "Text"],

Cell["\<\
An expanded font style \"MR\" can be used if necessary:\
\>", "Text"],

Cell[TextData[{
  StyleBox["Absolute", "MR"],
  ", ",
  ButtonBox["Graphics`Arrow`",
    ButtonData:>{"Graphics`Arrow`", "1.8"},
    ButtonStyle->"AddOnsLink"],
  " "
}], "Index",
  CellTags->"Absolute"],

Cell[TextData[{
  "Accuracy, in estimates, ",
  ButtonBox["Statistics`ConfidenceIntervals`",
    ButtonData:>{"Statistics`ConfidenceIntervals`", "1.2"},
    ButtonStyle->"AddOnsLink"],
  " "
}], "Index",
  CellTags->"Accuracy"],

Cell[TextData[{
  "A tip:  ",
  StyleBox["Selecting single cells in the BrowserIndex.nb can be tricky: use \
",
    FontWeight->"Plain"],
  "\[CloverLeaf]\[ShiftKey]E",
  StyleBox[" to convert to internal form, select, and then use ",
    FontWeight->"Plain"],
  "\[CloverLeaf]\[ShiftKey]E",
  StyleBox[" to convert back.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"]
}, Closed]],

Cell[CellGroupData[{

Cell["Making the index: simple method", "SubsectionIcon"],

Cell[TextData[{
  "In the notebook ",
  ButtonBox["SettingUp.nb",
    ButtonData:>{
      FrontEnd`FileName[ {
        ParentDirectory[ 
          ParentDirectory[ 
            ParentDirectory[ ]]], "Working..."}, "SettingUp.nb", 
        CharacterEncoding -> "MacintoshRoman"], None},
    ButtonStyle->"Hyperlink"],
  ", functions are defined which generate an index automatically from a \
matrix which consists of entries {\"entry, subentry\",\"index tag\", \"cell \
tag\"}.  The easiest way to generate an index is to edit that matrix, \
generate the index entries from it, and then paste into ",
  ButtonBox["BrowserIndex.nb.",
    ButtonData:>{
      FrontEnd`FileName[ {
        ParentDirectory[ 
          ParentDirectory[ 
            ParentDirectory[ ]]], "Multilocus", "Documentation", "English"}, 
        "BrowserIndex.nb", CharacterEncoding -> "MacintoshRoman"], None},
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell["\<\
To change or add to the index:
\t- Edit MasterIndexMatrix (at the end of this notebook) as necessary
\t- Evaluate Initialisation 
\t- Scan[MakeIndexEntry,ProcessIndexMatrix[MasterIndexMatrix]];
\t- Paste the output into \
Multilocus:Documentation:English:BrowserIndex.nb\
\>", "Text"],

Cell[TextData[StyleBox["It is easiest to add or change index entries using \
this matrix, and then convert it to produce an entire new index.  This is \
much simpler than fiddling with the internal form of the hyperlinks, and has \
the advantage that subentries are gathered together properly.",
  FontWeight->"Plain"]], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "The ",
  ButtonBox["BrowserIndex.nb ",
    ButtonData:>{
      FrontEnd`FileName[ {
        ParentDirectory[ 
          ParentDirectory[ 
            ParentDirectory[ ]]], "Multilocus", "Documentation", "English"}, 
        "BrowserIndex.nb", CharacterEncoding -> "MacintoshRoman"], None},
    ButtonStyle->"Hyperlink"],
  "file is with the documentation for Multilocus`, but contains entries for \
all the packages."
}], "Text"]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{710, 610},
WindowMargins->{{Automatic, 27}, {Automatic, 29}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Browser categories"->{
    Cell[2098, 61, 78, 1, 36, "SubsectionIcon",
      CellTags->"Browser categories"]},
  "Setting up links"->{
    Cell[4050, 105, 94, 1, 26, "SubsectionIcon",
      CellTags->"Setting up links"]},
  "Setting up Master Index"->{
    Cell[5707, 156, 112, 1, 26, "SubsectionIcon",
      CellTags->"Setting up Master Index"]},
  "MasterIndexHeading"->{
    Cell[6153, 170, 75, 1, 41, "IndexSection",
      CellTags->"MasterIndexHeading"]},
  "Packages"->{
    Cell[6371, 178, 300, 11, 15, "Index",
      CellTags->"Packages"],
    Cell[7146, 206, 1414, 49, 135, "IndexSubentry",
      CellTags->"Packages"]},
  "Absolute"->{
    Cell[8918, 268, 203, 8, 15, "Index",
      CellTags->"Absolute"]},
  "Accuracy"->{
    Cell[9124, 278, 227, 7, 15, "Index",
      CellTags->"Accuracy"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Browser categories", 12716, 382},
  {"Setting up links", 12828, 385},
  {"Setting up Master Index", 12946, 388},
  {"MasterIndexHeading", 13067, 391},
  {"Packages", 13170, 394},
  {"Absolute", 13339, 399},
  {"Accuracy", 13426, 402}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 356, 8, 38, "Text"],

Cell[CellGroupData[{
Cell[2098, 61, 78, 1, 36, "SubsectionIcon",
  CellTags->"Browser categories"],
Cell[2179, 64, 287, 5, 36, "Text"],
Cell[2469, 71, 1197, 21, 145, "DisplayMath"],
Cell[3669, 94, 344, 6, 36, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4050, 105, 94, 1, 26, "SubsectionIcon",
  CellTags->"Setting up links"],
Cell[4147, 108, 375, 6, 50, "Text"],
Cell[4525, 116, 46, 0, 22, "Text"],
Cell[4574, 118, 144, 3, 28, "DisplayMath"],
Cell[4721, 123, 189, 4, 36, "Text"],
Cell[4913, 129, 178, 4, 27, "Input"],
Cell[5094, 135, 576, 16, 38, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5707, 156, 112, 1, 26, "SubsectionIcon",
  CellTags->"Setting up Master Index"],
Cell[5822, 159, 213, 4, 36, "Text"],
Cell[6038, 165, 112, 3, 22, "Text"],
Cell[6153, 170, 75, 1, 41, "IndexSection",
  CellTags->"MasterIndexHeading"],
Cell[6231, 173, 137, 3, 22, "Text"],
Cell[6371, 178, 300, 11, 15, "Index",
  CellTags->"Packages"],
Cell[6674, 191, 88, 3, 22, "Text"],
Cell[6765, 196, 332, 6, 50, "Text"],
Cell[7100, 204, 43, 0, 22, "Text"],
Cell[7146, 206, 1414, 49, 135, "IndexSubentry",
  CellTags->"Packages"],
Cell[8563, 257, 270, 5, 36, "Text"],
Cell[8836, 264, 79, 2, 22, "Text"],
Cell[8918, 268, 203, 8, 15, "Index",
  CellTags->"Absolute"],
Cell[9124, 278, 227, 7, 15, "Index",
  CellTags->"Accuracy"],
Cell[9354, 287, 382, 12, 38, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9773, 304, 57, 0, 26, "SubsectionIcon"],
Cell[9833, 306, 924, 22, 50, "Text"],
Cell[10760, 330, 294, 7, 110, "Text"],
Cell[11057, 339, 350, 5, 36, "Text"],
Cell[11410, 346, 448, 12, 22, "Text"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

