(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     16228,        374]*)
(*NotebookOutlinePosition[     17112,        402]*)
(*  CellTagsIndexPosition[     17068,        398]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Extracting submatrices", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(ExtractSubMatrix[
              M, {i\_\[Alpha], 
                i\_\[Beta], \[Ellipsis]}, {\[Alpha], \[Beta], \
\[Ellipsis]}]\), \(extracts\ the\ submatrix\ of\ M\ which\ is\ defined\ by\ \
setting\ levels\ {\[Alpha], \[Beta], \[Ellipsis]}\ to\ \(\({i\_\[Alpha], 
                  i\_\[Beta], \[Ellipsis]}\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->"ExtractSubMatrix"]], "DefinitionBox"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Utilities`Matrices`;\)\)], "Input",
  CellLabel->"In[9]:="],

Cell["This is an array with five dimensions:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ff = Array[f\_## &, {2, 3, 2, 3, 2}]; ff // MatrixForm\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 1, 1, 1, 1\)\)},
                            {\(f\_\(1, 1, 1, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 1, 1, 2, 1\)\)},
                            {\(f\_\(1, 1, 1, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 1, 1, 3, 1\)\)},
                            {\(f\_\(1, 1, 1, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]},
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 1, 2, 1, 1\)\)},
                            {\(f\_\(1, 1, 2, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 1, 2, 2, 1\)\)},
                            {\(f\_\(1, 1, 2, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 1, 2, 3, 1\)\)},
                            {\(f\_\(1, 1, 2, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 2, 1, 1, 1\)\)},
                            {\(f\_\(1, 2, 1, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 2, 1, 2, 1\)\)},
                            {\(f\_\(1, 2, 1, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 2, 1, 3, 1\)\)},
                            {\(f\_\(1, 2, 1, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]},
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 2, 2, 1, 1\)\)},
                            {\(f\_\(1, 2, 2, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 2, 2, 2, 1\)\)},
                            {\(f\_\(1, 2, 2, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 2, 2, 3, 1\)\)},
                            {\(f\_\(1, 2, 2, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 3, 1, 1, 1\)\)},
                            {\(f\_\(1, 3, 1, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 3, 1, 2, 1\)\)},
                            {\(f\_\(1, 3, 1, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 3, 1, 3, 1\)\)},
                            {\(f\_\(1, 3, 1, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]},
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 3, 2, 1, 1\)\)},
                            {\(f\_\(1, 3, 2, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 3, 2, 2, 1\)\)},
                            {\(f\_\(1, 3, 2, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 3, 2, 3, 1\)\)},
                            {\(f\_\(1, 3, 2, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 1, 1, 1, 1\)\)},
                            {\(f\_\(2, 1, 1, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 1, 1, 2, 1\)\)},
                            {\(f\_\(2, 1, 1, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 1, 1, 3, 1\)\)},
                            {\(f\_\(2, 1, 1, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]},
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 1, 2, 1, 1\)\)},
                            {\(f\_\(2, 1, 2, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 1, 2, 2, 1\)\)},
                            {\(f\_\(2, 1, 2, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 1, 2, 3, 1\)\)},
                            {\(f\_\(2, 1, 2, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 2, 1, 1, 1\)\)},
                            {\(f\_\(2, 2, 1, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 2, 1, 2, 1\)\)},
                            {\(f\_\(2, 2, 1, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 2, 1, 3, 1\)\)},
                            {\(f\_\(2, 2, 1, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]},
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 2, 2, 1, 1\)\)},
                            {\(f\_\(2, 2, 2, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 2, 2, 2, 1\)\)},
                            {\(f\_\(2, 2, 2, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 2, 2, 3, 1\)\)},
                            {\(f\_\(2, 2, 2, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 3, 1, 1, 1\)\)},
                            {\(f\_\(2, 3, 1, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 3, 1, 2, 1\)\)},
                            {\(f\_\(2, 3, 1, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 3, 1, 3, 1\)\)},
                            {\(f\_\(2, 3, 1, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]},
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 3, 2, 1, 1\)\)},
                            {\(f\_\(2, 3, 2, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 3, 2, 2, 1\)\)},
                            {\(f\_\(2, 3, 2, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 3, 2, 3, 1\)\)},
                            {\(f\_\(2, 3, 2, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{{{
        Subscript[ f, 1, 1, 1, 1, 1], 
        Subscript[ f, 1, 1, 1, 1, 2]}, {
        Subscript[ f, 1, 1, 1, 2, 1], 
        Subscript[ f, 1, 1, 1, 2, 2]}, {
        Subscript[ f, 1, 1, 1, 3, 1], 
        Subscript[ f, 1, 1, 1, 3, 2]}}, {{
        Subscript[ f, 1, 1, 2, 1, 1], 
        Subscript[ f, 1, 1, 2, 1, 2]}, {
        Subscript[ f, 1, 1, 2, 2, 1], 
        Subscript[ f, 1, 1, 2, 2, 2]}, {
        Subscript[ f, 1, 1, 2, 3, 1], 
        Subscript[ f, 1, 1, 2, 3, 2]}}}, {{{
        Subscript[ f, 1, 2, 1, 1, 1], 
        Subscript[ f, 1, 2, 1, 1, 2]}, {
        Subscript[ f, 1, 2, 1, 2, 1], 
        Subscript[ f, 1, 2, 1, 2, 2]}, {
        Subscript[ f, 1, 2, 1, 3, 1], 
        Subscript[ f, 1, 2, 1, 3, 2]}}, {{
        Subscript[ f, 1, 2, 2, 1, 1], 
        Subscript[ f, 1, 2, 2, 1, 2]}, {
        Subscript[ f, 1, 2, 2, 2, 1], 
        Subscript[ f, 1, 2, 2, 2, 2]}, {
        Subscript[ f, 1, 2, 2, 3, 1], 
        Subscript[ f, 1, 2, 2, 3, 2]}}}, {{{
        Subscript[ f, 1, 3, 1, 1, 1], 
        Subscript[ f, 1, 3, 1, 1, 2]}, {
        Subscript[ f, 1, 3, 1, 2, 1], 
        Subscript[ f, 1, 3, 1, 2, 2]}, {
        Subscript[ f, 1, 3, 1, 3, 1], 
        Subscript[ f, 1, 3, 1, 3, 2]}}, {{
        Subscript[ f, 1, 3, 2, 1, 1], 
        Subscript[ f, 1, 3, 2, 1, 2]}, {
        Subscript[ f, 1, 3, 2, 2, 1], 
        Subscript[ f, 1, 3, 2, 2, 2]}, {
        Subscript[ f, 1, 3, 2, 3, 1], 
        Subscript[ f, 1, 3, 2, 3, 2]}}}}, {{{{
        Subscript[ f, 2, 1, 1, 1, 1], 
        Subscript[ f, 2, 1, 1, 1, 2]}, {
        Subscript[ f, 2, 1, 1, 2, 1], 
        Subscript[ f, 2, 1, 1, 2, 2]}, {
        Subscript[ f, 2, 1, 1, 3, 1], 
        Subscript[ f, 2, 1, 1, 3, 2]}}, {{
        Subscript[ f, 2, 1, 2, 1, 1], 
        Subscript[ f, 2, 1, 2, 1, 2]}, {
        Subscript[ f, 2, 1, 2, 2, 1], 
        Subscript[ f, 2, 1, 2, 2, 2]}, {
        Subscript[ f, 2, 1, 2, 3, 1], 
        Subscript[ f, 2, 1, 2, 3, 2]}}}, {{{
        Subscript[ f, 2, 2, 1, 1, 1], 
        Subscript[ f, 2, 2, 1, 1, 2]}, {
        Subscript[ f, 2, 2, 1, 2, 1], 
        Subscript[ f, 2, 2, 1, 2, 2]}, {
        Subscript[ f, 2, 2, 1, 3, 1], 
        Subscript[ f, 2, 2, 1, 3, 2]}}, {{
        Subscript[ f, 2, 2, 2, 1, 1], 
        Subscript[ f, 2, 2, 2, 1, 2]}, {
        Subscript[ f, 2, 2, 2, 2, 1], 
        Subscript[ f, 2, 2, 2, 2, 2]}, {
        Subscript[ f, 2, 2, 2, 3, 1], 
        Subscript[ f, 2, 2, 2, 3, 2]}}}, {{{
        Subscript[ f, 2, 3, 1, 1, 1], 
        Subscript[ f, 2, 3, 1, 1, 2]}, {
        Subscript[ f, 2, 3, 1, 2, 1], 
        Subscript[ f, 2, 3, 1, 2, 2]}, {
        Subscript[ f, 2, 3, 1, 3, 1], 
        Subscript[ f, 2, 3, 1, 3, 2]}}, {{
        Subscript[ f, 2, 3, 2, 1, 1], 
        Subscript[ f, 2, 3, 2, 1, 2]}, {
        Subscript[ f, 2, 3, 2, 2, 1], 
        Subscript[ f, 2, 3, 2, 2, 2]}, {
        Subscript[ f, 2, 3, 2, 3, 1], 
        Subscript[ f, 2, 3, 2, 3, 2]}}}}}]]], "Output",
  CellLabel->"Out[76]//MatrixForm="]
}, Open  ]],

Cell["\<\
This is the submatrix defined by setting indices {2,4} to {2,2} \
respectively:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtractSubMatrix[ff, {2, 2}, {2, 4}] // MatrixForm\)], "Input",
  CellLabel->"In[77]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(f\_\(1, 2, 1, 2, 1\)\)},
                    {\(f\_\(1, 2, 1, 2, 2\)\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(f\_\(1, 2, 2, 2, 1\)\)},
                    {\(f\_\(1, 2, 2, 2, 2\)\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(f\_\(2, 2, 1, 2, 1\)\)},
                    {\(f\_\(2, 2, 1, 2, 2\)\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(f\_\(2, 2, 2, 2, 1\)\)},
                    {\(f\_\(2, 2, 2, 2, 2\)\)}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{
        Subscript[ f, 1, 2, 1, 2, 1], 
        Subscript[ f, 1, 2, 1, 2, 2]}, {
        Subscript[ f, 1, 2, 2, 2, 1], 
        Subscript[ f, 1, 2, 2, 2, 2]}}, {{
        Subscript[ f, 2, 2, 1, 2, 1], 
        Subscript[ f, 2, 2, 1, 2, 2]}, {
        Subscript[ f, 2, 2, 2, 2, 1], 
        Subscript[ f, 2, 2, 2, 2, 2]}}}]]], "Output",
  CellLabel->"Out[77]//MatrixForm="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{Automatic, 194}, {Automatic, 41}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 48, 0, 36, "SubsectionIcon"],
Cell[1790, 53, 467, 9, 52, "DefinitionBox"],
Cell[2260, 64, 46, 0, 28, "MathCaption"],
Cell[2309, 66, 84, 2, 27, "Input"],
Cell[2396, 70, 61, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2482, 74, 112, 2, 27, "Input"],
Cell[2597, 78, 12037, 247, 147, "Output"]
}, Open  ]],
Cell[14649, 328, 110, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[14784, 335, 108, 2, 27, "Input"],
Cell[14895, 339, 1305, 31, 75, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

