(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     39540,       1292]*)
(*NotebookOutlinePosition[     40423,       1320]*)
(*  CellTagsIndexPosition[     40379,       1316]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Multinomial distribution", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(RandomMultinomial[
              n, {p\_1, \[Ellipsis]}]\), \(gives\ a\ list\ of\ random\ \
integers\ drawn\ from\ the\ \(\(multinomial\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->"RandomMultinomial"]], "DefinitionBox"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Utilities`RandomNumbers`;\)\)], "Input",
  CellLabel->"In[305]:="],

Cell["\<\
This package automatically loads Statistics`DiscreteDistributions`, \
Statistics`ContinuousDistributions` as well.\
\>", "Text"],

Cell["\<\
Here is a sample of 100 from the multinomial, with probabilities \
{0.1,0.3,0.6}\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pp = {0.1, 0.3, 0.6};\)\), "\n", 
    \(RandomMultinomial[100, pp]\)}], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \({12, 32, 56}\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell["Results are given as counts of each of the 3 outcomes", "Text"],

Cell["This generates 1000 random numbers from the multinomial:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tt = Table[RandomMultinomial[100, pp], {1000}];\)\), "\n", 
    \({1000*pp, Plus @@ tt/100 // N} // TableForm\)}], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"100.`", "300.`", "600.`"},
          {"101.680000000000014`", "299.05999999999997`", 
            "599.260000000000037`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[33]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "The built-in function Random[BinomialDistribution[n,p]] is grossly \
inefficient for large ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ": it tabulates n trials of ",
  Cell[BoxData[
      \(TraditionalForm\`Random[] > p\)]],
  ".  RandomMultinomial[n,p] therefore uses RandomCum[] for ",
  Cell[BoxData[
      \(TraditionalForm\`n > 10\^4\)]],
  " (see below).  It should be used even for sampling from the binomial when \
",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is large."
}], "Text"],

Cell["\<\
At the threshold value, the two methods take about the same time:\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pp = {0.1, 0.9};\)\), "\n", 
    \({Timing[RandomMultinomial[10\^4 - 1, pp]], 
      Timing[RandomMultinomial[10\^4 + 1, pp]]}\)}], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \({{0.04999999999999716`\ Second, {1014, 
          8985}}, {0.05000000000001137`\ Second, {938, 9063}}}\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[TextData[{
  "For large ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`RandomMultinomial[n, p]\)]],
  " is much faster:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pp = {0.1, 0.9};\)\), "\n", 
    \({Timing[Random[BinomialDistribution[10\^6, pp // First]]], 
      Timing[RandomMultinomial[10\^6, pp]]}\)}], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \({{4.783333333333331`\ Second, 
        100252}, {0.11666666666667425`\ Second, {99953, 900047}}}\)], "Output",\

  CellLabel->"Out[6]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(RandomMultinomial[{J, 
                K, \[Ellipsis]}, {n\_1, \[Ellipsis]}]\), \(gives\ a\ list\ of\
\ samples\ {{j\_1, \(k\_1\) \[Ellipsis]} \[Ellipsis]}\ taken\ without\ \
replacement\ from\ an\ urn\ containing\ {J, 
                  K, \[Ellipsis]}\ items . \ \ \(\[Sum]\+i j\_i\) = J, \ 
            and\ j\_\(\(i\)\(\ \)\) + \(k\_i\) \[Ellipsis] = n\_i\)},
          {\(RandomMultinomial[{J, K, \[Ellipsis]}, {n\_1, \[Ellipsis]}, 
              Compiled \[Rule] True]\), \(is\ a\ compiled\ version\)}
          }], TraditionalForm]],
  CellTags->"Multinomial sampling wo replacement"]], "DefinitionBox"],

Cell["\<\
This gives samples of size {5, 25, 5,5} from an urn containing {10, \
20, 10} objects:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RandomMultinomial[{10, 20, 10}, {5, 25, 5, 5}] // MatrixForm\)], "Input",\

  CellLabel->"In[306]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "3", "1"},
            {"6", "12", "7"},
            {"1", "3", "1"},
            {"2", "2", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[306]//MatrixForm="]
}, Open  ]],

Cell["\<\
Sampling is assumed to be exhaustive; if it is not, the remainder \
can just be added to the list of sample sizes as a dummy sample.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(MultinomialSamplingProbability[{{j\_1, 
                  k\_1, \[Ellipsis]}, \[Ellipsis]}]\), \(gives\ the\ \
probability\ of\ sampling\ without\ replacement\ a\ set\ of\ numbers\ {{j\_1, 
                  k\_1, \[Ellipsis]}, \[Ellipsis]}\ from\ an\ urn\ containing\
\ {\[Sum]\+i j\_i, \[Sum]\_i\( 
                        k\_i\) \[Ellipsis]}\ of\ each\ \(\(kind\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->"MultinomialSamplingProbability"]], "DefinitionBox"],

Cell[TextData[{
  "Suppose that there are J, K,\[Ellipsis] of each kind in an urn; the total \
number is N.  The probability of taking a sample ",
  Cell[BoxData[
      \(TraditionalForm\`{j\_i, k\_i, \[Ellipsis]}\)]],
  " without replacement is:"
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{\(\(\(J \((J - 1)\) \[Ellipsis] \((J - j\_1 + 1)\) 
                K \((K - 1)\) \[Ellipsis] \((K - k\_1 + 
                    1)\) \[Ellipsis]\)\/\(N \((N - 1)\) \[Ellipsis] \((N - 
                    j\_1 - \(k\_1\) \[Ellipsis] + 
                    1)\)\)\) \(\((j\_1 + \(k\_1\) \
\[Ellipsis])\)!\)\/\(\(j\_1!\) \(k\_1!\) \[Ellipsis]\)\), "=", 
        FractionBox[
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"J"},
                  {\(\(j\_1\) j\_2\)}
                  }], ")"}], 
            RowBox[{"(", GridBox[{
                  {"K"},
                  {\(\(k\_1\) k\_2\)}
                  }], ")"}], "\[Ellipsis]"}], 
          RowBox[{"(", GridBox[{
                {"N"},
                {\(\((j\_1 + \(k\_1\) \[Ellipsis])\)\ \((j\_2 + \(k\_2\) \
\[Ellipsis])\)\)}
                }], ")"}]]}], TextForm]], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`j\_2 = J - j\_1\)]],
  ".  This generalises to a sequence of samples, taken without replacement; \
by convention, the last element in the list is the remainder, which can be \
thought of as a last and exhaustive sample."
}], "Text"],

Cell[TextData[{
  "For example, this is the chance of taking 2 ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  "'s and 2 ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "'s in a sample from an urn containing 5 ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  "'s and ",
  Cell[BoxData[
      \(TraditionalForm\`2\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "'s:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MultinomialSamplingProbability[{{2, 2}, {3, 0}}]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(2\/7\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell[TextData[{
  "These are all the configurations that can be taken in a sample of 4 from \
an urn containing 5 ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  "'s and ",
  Cell[BoxData[
      \(TraditionalForm\`2\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "'s: "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"ex", "=", 
      RowBox[{
        RowBox[{"Table", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"m", "=", 
                RowBox[{"(", GridBox[{
                      {"j1", \(5 - j1\)},
                      {\(4 - j1\), \(j1 - 2\)}
                      }], ")"}]}], 
              ";", \({m, MultinomialSamplingProbability[m]}\)}], 
            ",", \({j1, 2, 4}\)}], "]"}], "//", "TableForm"}]}]], "Input",
  CellLabel->"In[151]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {"2", "3"},
                {"2", "0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], \(2\/7\)},
          {GridBox[{
                {"3", "2"},
                {"1", "1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], \(4\/7\)},
          {GridBox[{
                {"4", "1"},
                {"0", "2"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], \(1\/7\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{{2, 3}, {2, 0}}, 
        Rational[ 2, 7]}, {{{3, 2}, {1, 1}}, 
        Rational[ 4, 7]}, {{{4, 1}, {0, 2}}, 
        Rational[ 1, 7]}}]]], "Output",
  CellLabel->"Out[151]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "That is, one could draw 2 ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  "'s and 2 ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "'s, leaving 3 ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  "'s and no ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "'s, with probability ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(2\/7\)\(,\)\(\ \)\)\)]],
  "and so on.  The total probability of any configuration of samples of {4,3} \
is 1.  RandomMultinomial[] will draw random samples as desired."
}], "Text"],

Cell["This is a table of 1000 random samples:", "MathCaption"],

Cell[BoxData[
    \(\(ss = Table[RandomMultinomial[{5, 2}, {4, 3}], {1000}];\)\)], "Input",
  CellLabel->"In[153]:="],

Cell["Only three configurations are possible", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Union[ss]\)], "Input",
  CellLabel->"In[154]:="],

Cell[BoxData[
    \({{{2, 2}, {3, 0}}, {{3, 1}, {2, 1}}, {{4, 0}, {1, 2}}}\)], "Output",
  CellLabel->"Out[154]="]
}, Open  ]],

Cell["\<\
These are the observed #; expected #; and a G test with \
P=0.19\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(obs = \(Count[ss, #] &\) /@ Union[ss]; 
    exN = 1000*\(Transpose[ex[\([1]\)]]\)[\([2]\)];\), "\n", 
    \(dl = 
      LogLikelihoodTest[obs, exN] // N; {obs, 
        exN // N, {dl, 1 - CDF[ChiSquareDistribution[2], 2  dl]}} // 
      TableForm\)}], "Input",
  CellLabel->"In[155]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"300", "576", "124"},
          {"285.7142857142857`", "571.4285714285714`", 
            "142.85714285714286`"},
          {"1.6728329928539374`", "0.1877145177553705`", "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{300, 576, 124}, {285.71428571428572, 571.42857142857144, 
        142.85714285714286}, {1.6728329928539374, 
        0.18771451775537051}}]]], "Output",
  CellLabel->"Out[156]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "The built-in function ",
  Cell[BoxData[
      \(TraditionalForm\`HypergeometricDistribution[n\_1, j\_1, n\_tot]\)]],
  " can be used in the special case where there are two samples and two kinds \
of object:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(p1 = PDF[HypergeometricDistribution[n, ns, nt], j]\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \(\(Binomial[ns, j]\ Binomial[\(-ns\) + nt, \(-j\) + n]\)\/Binomial[nt, \
n]\)], "Output",
  CellLabel->"Out[63]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(p2 = 
      MultinomialSamplingProbability[{{j, n - j}, {ns - j, 
            nt - ns + j - n}}]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(\(Multinomial[j, \(-j\) + n]\ Multinomial[\(-j\) + ns, j - n - ns + nt]\
\)\/Multinomial[ns, \(-ns\) + nt]\)], "Output",
  CellLabel->"Out[64]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(p1\/p2 // FullSimplify\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[65]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Technical issues", "SubsectionIcon"],

Cell[TextData[{
  "The built in function ",
  Cell[BoxData[
      \(TraditionalForm\`Random[BinomialDistribution[n, p]]\)]],
  " is grossly inefficient for large ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", since it just constructs a list of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " trials of  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(If\)\([\)\(Random[] > p\)\)\)]],
  ",0,1], and then sums the list.  This is both slow, and uses a great deal \
of memory for large ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Timing", "[", 
      FormBox[\(Random[BinomialDistribution[10\^6, 0.3]]\),
        "TraditionalForm"], "]"}]], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \({4.816666666666606`\ Second, 300029}\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell[TextData[{
  "A Poisson or a Gaussian approximation could be used for ",
  Cell[BoxData[
      \(TraditionalForm\`n > 10\^4\)]],
  "(say); a Poisson could be used if n\[VeryThinSpace]p<30 or n\
\[VeryThinSpace]q<30 (say). The Gaussian is fastest."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(n = 10\^4; p = 0.003;\), "\[IndentingNewLine]", 
    \({Timing[Mean[Table[Random[BinomialDistribution[n, p]], {100}]]], 
      Timing[Mean[Table[Random[PoissonDistribution[n\ p]], {100}]]], 
      Timing[Mean[
          Table[Round[
              Random[NormalDistribution[
                  n\ p, \@\(n\ p \((1 - p)\)\)]]], {100}]]]}\)}], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \({{4.75`\ Second, 2961\/100}, {0.7666666666664241`\ Second, 
        3011\/100}, {0.016666666666424135`\ Second, 2959\/100}}\)], "Output",
  CellLabel->"Out[60]="]
}, Open  ]],

Cell[TextData[{
  "This table compares the exact PDF, the Poisson approximatiuon, and the \
Gaussian approximation, at  ",
  Cell[BoxData[
      \(TraditionalForm\`n = 10\^4\)]],
  ", p=0.003.  The ",
  StyleBox["Poisson",
    FontColor->RGBColor[1, 0, 0]],
  " approximation is accurate, but the ",
  StyleBox["Gaussian",
    FontColor->RGBColor[0, 0, 1]],
  " is not, at least in the tails.  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f[j_, n_, p_] := 
        Integrate[
          PDF[NormalDistribution[n\ p, \ \@\(n\ p \((1 - p)\)\)], y], {y, 
            j - 1/2, j + 1/2}];\)\), "\n", 
    \(\(tt = 
        Table[{j, PDF[BinomialDistribution[10000, 0.003], j], 
            PDF[PoissonDistribution[30], j] // N, f[j, 10000, 0.003]}, {j, 
            10, 60}];\)\), "\[IndentingNewLine]", 
    \(\(Show[ListPlot[tt /. {{j_, p_, _, _} \[RuleDelayed] {j, Log[p]}}], 
        ListPlot[tt /. {{j_, _, p_, _} \[RuleDelayed] {j, Log[p]}}, 
          PlotStyle \[Rule] RGBColor[1, 0, 0]], 
        ListPlot[tt /. {{j_, _, _, p_} \[RuleDelayed] {j, Log[p]}}, 
          PlotStyle \[Rule] RGBColor[0, 0, 1]]];\)\)}], "Input",
  CellLabel->"In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.0190476 0.603319 0.0333997 [
[.21429 .59082 -6 -9 ]
[.21429 .59082 6 0 ]
[.40476 .59082 -6 -9 ]
[.40476 .59082 6 0 ]
[.59524 .59082 -6 -9 ]
[.59524 .59082 6 0 ]
[.78571 .59082 -6 -9 ]
[.78571 .59082 6 0 ]
[.97619 .59082 -6 -9 ]
[.97619 .59082 6 0 ]
[.01131 .01882 -30 -4.5 ]
[.01131 .01882 0 4.5 ]
[.01131 .10232 -18 -4.5 ]
[.01131 .10232 0 4.5 ]
[.01131 .18582 -30 -4.5 ]
[.01131 .18582 0 4.5 ]
[.01131 .26932 -18 -4.5 ]
[.01131 .26932 0 4.5 ]
[.01131 .35282 -24 -4.5 ]
[.01131 .35282 0 4.5 ]
[.01131 .43632 -12 -4.5 ]
[.01131 .43632 0 4.5 ]
[.01131 .51982 -24 -4.5 ]
[.01131 .51982 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .60332 m
.21429 .60957 L
s
[(20)] .21429 .59082 0 1 Mshowa
.40476 .60332 m
.40476 .60957 L
s
[(30)] .40476 .59082 0 1 Mshowa
.59524 .60332 m
.59524 .60957 L
s
[(40)] .59524 .59082 0 1 Mshowa
.78571 .60332 m
.78571 .60957 L
s
[(50)] .78571 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(60)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.0619 .60332 m
.0619 .60707 L
s
.1 .60332 m
.1 .60707 L
s
.1381 .60332 m
.1381 .60707 L
s
.17619 .60332 m
.17619 .60707 L
s
.25238 .60332 m
.25238 .60707 L
s
.29048 .60332 m
.29048 .60707 L
s
.32857 .60332 m
.32857 .60707 L
s
.36667 .60332 m
.36667 .60707 L
s
.44286 .60332 m
.44286 .60707 L
s
.48095 .60332 m
.48095 .60707 L
s
.51905 .60332 m
.51905 .60707 L
s
.55714 .60332 m
.55714 .60707 L
s
.63333 .60332 m
.63333 .60707 L
s
.67143 .60332 m
.67143 .60707 L
s
.70952 .60332 m
.70952 .60707 L
s
.74762 .60332 m
.74762 .60707 L
s
.82381 .60332 m
.82381 .60707 L
s
.8619 .60332 m
.8619 .60707 L
s
.9 .60332 m
.9 .60707 L
s
.9381 .60332 m
.9381 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .01882 m
.03006 .01882 L
s
[(-17.5)] .01131 .01882 1 0 Mshowa
.02381 .10232 m
.03006 .10232 L
s
[(-15)] .01131 .10232 1 0 Mshowa
.02381 .18582 m
.03006 .18582 L
s
[(-12.5)] .01131 .18582 1 0 Mshowa
.02381 .26932 m
.03006 .26932 L
s
[(-10)] .01131 .26932 1 0 Mshowa
.02381 .35282 m
.03006 .35282 L
s
[(-7.5)] .01131 .35282 1 0 Mshowa
.02381 .43632 m
.03006 .43632 L
s
[(-5)] .01131 .43632 1 0 Mshowa
.02381 .51982 m
.03006 .51982 L
s
[(-2.5)] .01131 .51982 1 0 Mshowa
.125 Mabswid
.02381 .03552 m
.02756 .03552 L
s
.02381 .05222 m
.02756 .05222 L
s
.02381 .06892 m
.02756 .06892 L
s
.02381 .08562 m
.02756 .08562 L
s
.02381 .11902 m
.02756 .11902 L
s
.02381 .13572 m
.02756 .13572 L
s
.02381 .15242 m
.02756 .15242 L
s
.02381 .16912 m
.02756 .16912 L
s
.02381 .20252 m
.02756 .20252 L
s
.02381 .21922 m
.02756 .21922 L
s
.02381 .23592 m
.02756 .23592 L
s
.02381 .25262 m
.02756 .25262 L
s
.02381 .28602 m
.02756 .28602 L
s
.02381 .30272 m
.02756 .30272 L
s
.02381 .31942 m
.02756 .31942 L
s
.02381 .33612 m
.02756 .33612 L
s
.02381 .36952 m
.02756 .36952 L
s
.02381 .38622 m
.02756 .38622 L
s
.02381 .40292 m
.02756 .40292 L
s
.02381 .41962 m
.02756 .41962 L
s
.02381 .45302 m
.02756 .45302 L
s
.02381 .46972 m
.02756 .46972 L
s
.02381 .48642 m
.02756 .48642 L
s
.02381 .50312 m
.02756 .50312 L
s
.02381 .53652 m
.02756 .53652 L
s
.02381 .55322 m
.02756 .55322 L
s
.02381 .56992 m
.02756 .56992 L
s
.02381 .58662 m
.02756 .58662 L
s
.02381 .00212 m
.02756 .00212 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .23218 Mdot
.04286 .26576 Mdot
.0619 .29643 Mdot
.08095 .32442 Mdot
.1 .34993 Mdot
.11905 .37313 Mdot
.1381 .39418 Mdot
.15714 .4132 Mdot
.17619 .4303 Mdot
.19524 .4456 Mdot
.21429 .45918 Mdot
.23333 .47112 Mdot
.25238 .48151 Mdot
.27143 .49041 Mdot
.29048 .49789 Mdot
.30952 .504 Mdot
.32857 .5088 Mdot
.34762 .51233 Mdot
.36667 .51464 Mdot
.38571 .51578 Mdot
.40476 .51578 Mdot
.42381 .51469 Mdot
.44286 .51253 Mdot
.4619 .50934 Mdot
.48095 .50515 Mdot
.5 .49999 Mdot
.51905 .49388 Mdot
.5381 .48686 Mdot
.55714 .47894 Mdot
.57619 .47015 Mdot
.59524 .46051 Mdot
.61429 .45004 Mdot
.63333 .43877 Mdot
.65238 .4267 Mdot
.67143 .41387 Mdot
.69048 .40028 Mdot
.70952 .38595 Mdot
.72857 .3709 Mdot
.74762 .35515 Mdot
.76667 .3387 Mdot
.78571 .32158 Mdot
.80476 .30379 Mdot
.82381 .28535 Mdot
.84286 .26626 Mdot
.8619 .24655 Mdot
.88095 .22623 Mdot
.9 .2053 Mdot
.91905 .18377 Mdot
.9381 .16167 Mdot
.95714 .13898 Mdot
.97619 .11573 Mdot
1 0 0 r
.02381 .23283 Mdot
.04286 .26634 Mdot
.0619 .29695 Mdot
.08095 .32488 Mdot
.1 .35033 Mdot
.11905 .37349 Mdot
.1381 .39448 Mdot
.15714 .41345 Mdot
.17619 .43051 Mdot
.19524 .44577 Mdot
.21429 .45931 Mdot
.23333 .47122 Mdot
.25238 .48158 Mdot
.27143 .49046 Mdot
.29048 .49791 Mdot
.30952 .504 Mdot
.32857 .50878 Mdot
.34762 .5123 Mdot
.36667 .5146 Mdot
.38571 .51573 Mdot
.40476 .51573 Mdot
.42381 .51464 Mdot
.44286 .51248 Mdot
.4619 .5093 Mdot
.48095 .50512 Mdot
.5 .49997 Mdot
.51905 .49388 Mdot
.5381 .48688 Mdot
.55714 .47898 Mdot
.57619 .47022 Mdot
.59524 .46061 Mdot
.61429 .45018 Mdot
.63333 .43894 Mdot
.65238 .42692 Mdot
.67143 .41412 Mdot
.69048 .40058 Mdot
.70952 .3863 Mdot
.72857 .37131 Mdot
.74762 .35561 Mdot
.76667 .33923 Mdot
.78571 .32216 Mdot
.80476 .30444 Mdot
.82381 .28607 Mdot
.84286 .26706 Mdot
.8619 .24743 Mdot
.88095 .22719 Mdot
.9 .20634 Mdot
.91905 .1849 Mdot
.9381 .16288 Mdot
.95714 .14029 Mdot
.97619 .11714 Mdot
0 0 1 r
.02381 .29312 Mdot
.04286 .31483 Mdot
.0619 .33543 Mdot
.08095 .35492 Mdot
.1 .37329 Mdot
.11905 .39055 Mdot
.1381 .4067 Mdot
.15714 .42173 Mdot
.17619 .43565 Mdot
.19524 .44846 Mdot
.21429 .46015 Mdot
.23333 .47073 Mdot
.25238 .4802 Mdot
.27143 .48855 Mdot
.29048 .49579 Mdot
.30952 .50191 Mdot
.32857 .50692 Mdot
.34762 .51082 Mdot
.36667 .5136 Mdot
.38571 .51527 Mdot
.40476 .51583 Mdot
.42381 .51527 Mdot
.44286 .5136 Mdot
.4619 .51082 Mdot
.48095 .50692 Mdot
.5 .50191 Mdot
.51905 .49579 Mdot
.5381 .48855 Mdot
.55714 .4802 Mdot
.57619 .47073 Mdot
.59524 .46015 Mdot
.61429 .44846 Mdot
.63333 .43565 Mdot
.65238 .42173 Mdot
.67143 .4067 Mdot
.69048 .39055 Mdot
.70952 .37329 Mdot
.72857 .35492 Mdot
.74762 .33543 Mdot
.76667 .31483 Mdot
.78571 .29312 Mdot
.80476 .27029 Mdot
.82381 .24634 Mdot
.84286 .22129 Mdot
.8619 .19512 Mdot
.88095 .16784 Mdot
.9 .13944 Mdot
.91905 .10993 Mdot
.9381 .0793 Mdot
.95714 .04757 Mdot
.97619 .01472 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[55]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0025oo`800?eo
o`008Goo00<007ooOol0o7oo0007Ool30004Ool00`00Oomoo`03Ool00`00Oomoo`02Ool30005Ool0
0`00Oomoo`3lOol000Qoo`03001oogoo00=oo`03001oogoo00Moo`05001oogooOol00004Ool00`00
Oomoo`3dOol201l6Ool000D000=oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo009oo`03
001oogoo0?Aoo`807`Ioo`0027oo00<007ooOol017oo00<007ooOol02Woo00<007ooOol00Woo0P00
oGoo0008Ool00`00Oomoo`05Ool00`00Oomoo`05Ool40005Ool00`00Oomoo`3lOol000Moo`8000=o
o`05001oogooOol00007Ool00`00Oomoo`06Ool00`00Oomoo`3lOol000Qoo`04001oogooOol50007
Ool50004Ool00`00Oomoo`3lOol0025oo`800?eoo`008Goo00<007ooOol0o7oo000QOol00`00Oomo
o`3lOol0025oo`03001oogoo0>moo`807`]oo`008Goo0P00l7oo0P0O2goo000QOol00`00Oomoo`3l
Ool0025oo`03001oogoo0?aoo`008Goo00<007ooOol0o7oo000QOol00`00Oomoo`3lOol0025oo`80
0?eoo`008Goo00<007ooOol0o7oo000QOol00`00Oomoo`3ZOol201l@Ool0025oo`03001oogoo0>Yo
o`807a1oo`008Goo0P00oGoo000QOol00`00Oomoo`3lOol001=oo`<000=oo`<000Eoo`03001oogoo
0?aoo`0057oo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo0?aoo`0037oo1@000goo
00<007ooOol01Goo00<007ooOol00Woo0P00oGoo000DOol00`00Oomoo`05Ool00`00Oomoo`02Ool0
0`00Oomoo`3lOol001Aoo`04001oogooOol40005Ool00`00Oomoo`3UOol201lEOol001=oo`8000=o
o`03001oogoo00Ioo`03001oogoo0>Eoo`807`eoo`8000Ioo`0057oo00@007ooOomoo`D000Aoo`03
001oogoo0?Aoo`9l00Ioo`008Goo0P00mGoo0W`01Woo000QOol00`00Oomoo`3lOol0025oo`03001o
ogoo0?aoo`008Goo00<007ooOol0o7oo000QOol2003QOol201l=Ool2000;Ool0025oo`03001oogoo
0>1oo`807`eoo`9l00]oo`008Goo00<007ooOol0kgoo0W`02goo000QOol00`00Oomoo`3lOol0025o
o`800?eoo`008Goo00<007ooOol0o7oo000QOol00`00Oomoo`3ZOol2000@Ool0025oo`03001oogoo
0>Yoo`9l011oo`008Goo00<007ooOol0fgoo0P0O3Goo0W`047oo000QOol2003LOol201lOOol0025o
o`03001oogoo0?aoo`001goo0`000Woo1@000goo00<007ooOol00Woo0`001Goo00<007ooOol0o7oo
0008Ool00`00Oomoo`02Ool01000Oomoo`001goo00D007ooOomoo`0000Aoo`03001oogoo0>Eoo`9l
01Eoo`001@000goo00<007ooOol00goo00<007ooOol02goo00<007ooOol00Woo0P00iWoo0W`05Goo
0008Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`3lOol000Qoo`05
001oogooOol00003Ool00`00Oomoo`05Ool40005Ool00`00Oomoo`3FOol201lTOol000Moo`8000=o
o`05001oogooOol00007Ool00`00Oomoo`06Ool00`00Oomoo`3FOol201lTOol000Qoo`03001oogoo
009oo`<000Qoo`D000Aoo`800?eoo`008Goo00<007ooOol0h7oo0W`06Woo000QOol00`00Oomoo`3P
Ool2O00JOol0025oo`03001oogoo0?aoo`008Goo00<007ooOol0o7oo000QOol2003BOol201lYOol0
025oo`03001oogoo0=5oo`807`Qoo`9l01moo`008Goo00<007ooOol0fgoo0W`07goo000POol2O03n
Ool0021oo`9l0003001oogoo0?]oo`008Goo00<007ooOol0o7oo000QOol00`00Oomoo`3<Ool201l8
Ool2000TOol0025oo`03001oogoo0<aoo`807`Qoo`9l02Aoo`008Goo0P00egoo0W`097oo000QOol0
0`00Oomoo`3lOol001=oo`<000Aoo`8000Eoo`03001oogoo0?aoo`0057oo00<007ooOol00Woo00@0
07ooOol000Aoo`04001oogooOol2O03>Ool2000YOol000aoo`D000=oo`03001oogoo009oo`04001o
ogoo0004Ool01000Oomoogoo0W`0a7oo0P0O27oo0W`0:Goo000DOol00`00Oomoo`02Ool01000Oomo
o`0017oo0P00b7oo0P0O27oo0W`0:Goo000DOol00`00Oomoo`02Ool01000Oomoo`0017oo00<007oo
Ool0o7oo000COol20004Ool01000Oomoo`0017oo00<007ooOol0o7oo000DOol00`00Oomoo`03Ool2
0005Ool00`00Oomoo`3<Ool2000^Ool0025oo`800<eoo`9l02ioo`0087oo0P0Oa7oo0P0O27oo0W`0
;Woo000POol201l8Ool2O02jOol201lhOol0025oo`03001oogoo00Ioo`9l0?Aoo`008Goo0P00b7oo
0W`0<goo000QOol00`00Oomoo`37Ool2O00cOol0025oo`03001oogoo0?aoo`008Goo00@007ooOomo
o`807kYoo`807ceoo`008Goo00@007ooOomoo`807kYoo`807ceoo`008Goo0P00`goo0W`0>7oo000Q
Ool00`00Oomoo`0;Ool2O02eOol2O00hOol0025oo`03001oogoo00]oo`9l0>moo`008Goo00<007oo
Ool01Woo0P0O/7oo0P0O@Woo000QOol20007Ool201n`Ool201l3Ool2O00mOol0025oo`03001oogoo
0;eoo`9l03eoo`003Woo00<007ooOol00goo00<007ooOol00Woo0`001Goo00<007ooOol0o7oo000>
Ool00`00Oomoo`07Ool01@00Oomoogoo000017oo00<007ooOol047oo0W`0jWoo0006Ool50004Ool0
0`00Oomoo`0:Ool00`00Oomoo`02Ool2000<Ool201l3Ool2O02QOol201m7Ool000moo`03001oogoo
00Yoo`03001oogoo009oo`03001oogoo00]oo`807jIoo`807`=oo`9l049oo`0047oo00<007ooOol0
1Goo10001Goo00<007ooOol0^7oo0W`0@Woo000<Ool01@00Oomoogoo00001goo00<007ooOol01Woo
00<007ooOol0o7oo000<Ool50007Ool50004Ool00`00Oomoo`3lOol0025oo`80015oo`807`=oo`9l
09Moo`807`=oo`9l04Moo`008Goo00<007ooOol047oo0P0O0goo0W`0Ugoo0P0O0goo0W`0Agoo000Q
Ool00`00Oomoo`3lOol0025oo`03001oogoo0?aoo`008Goo0P00[goo0W`0C7oo000QOol00`00Oomo
o`0EOol201nCOol201l2Ool2O01<Ool0025oo`03001oogoo01Eoo`807`=oo`9l08ioo`807e1oo`00
8Goo00<007ooOol06Woo0W`0SWoo0W`0D7oo000QOol2002[Ool2O01@Ool0025oo`03001oogoo01Yo
o`807hUoo`807eEoo`008Goo00<007ooOol06Woo0P0ORGoo0P0OEGoo000QOol00`00Oomoo`0OOol2
O024Ool2O01EOol0025oo`03001oogoo01moo`9l08Aoo`9l05Eoo`008Goo0P0087oo0P0OOgoo0P0O
FWoo000QOol00`00Oomoo`0OOol201moOol201mJOol001Uoo`<000Eoo`03001oogoo02Aoo`9l07Yo
o`9l05Yoo`0067oo00D007ooOomoo`0000Aoo`03001oogoo02Aoo`807gEoo`807emoo`004Woo1@00
1Goo00<007ooOol00Woo0P009Goo0P0OMGoo0P0OGgoo000LOol00`00Oomoo`02Ool00`00Oomoo`2K
Ool2O01OOol001Qoo`@000Eoo`03001oogoo02Uoo`9l0=5oo`0067oo00<007ooOol01Woo00<007oo
Ool0:Goo0P0OJgoo0P0OI7oo000HOol50004Ool2000ZOol201m[Ool201mTOol0025oo`03001oogoo
0?aoo`008Goo00<007ooOol0;Woo0P0OHGoo0P0OJGoo000QOol00`00Oomoo`0^Ool201mQOol201mY
Ool0025oo`03001oogoo08aoo`9l06ioo`008Goo0P00=7oo0P0OEgoo0P0OKWoo000QOol00`00Oomo
o`0cOol201mGOol201m^Ool0025oo`03001oogoo03Qoo`807deoo`807g=oo`008Goo00<007ooOol0
>7oo0P0OCGoo0P0OLgoo000QOol2000nOol201m3Ool201mhOol0025oo`03001oogoo03eoo`807d=o
o`807gQoo`008Goo00<007ooOol0?Goo0W`00goo0P0O>Goo0P0OOGoo000QOol00`00Oomoo`12Ool2
01ldOol2O003Ool201mmOol0025oo`8004=oo`9l00=oo`807bmoo`807h9oo`008Goo00<007ooOol0
Agoo0P0O0Woo0P0O9Woo0P0O0goo0P0OPWoo000<Ool50003Ool00`00Oomoo`02Ool30005Ool00`00
Oomoo`1;Ool201l3Ool201lGOol2O003Ool201l3Ool201n7Ool000eoo`04001oogoo0007Ool01@00
Oomoogoo000017oo00<007ooOol0D7oo0P0O0goo0P0O0goo0P0O0goo0P0O0goo0P0O0goo0P0O0goo
0P0OS7oo0006Ool50003Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`1EOol201l3Ool2
01l3Ool201l3Ool201l3Ool201nAOol000moo`03001oogoo00Yoo`03001oogoo009oo`800?eoo`00
37oo00D007ooOomoo`0000Moo`@000Eoo`03001oogoo0?aoo`0037oo00D007ooOomoo`0000Moo`03
001oogoo00Ioo`03001oogoo0?aoo`003Goo0`0027oo1@0017oo00<007ooOol0o7oo000QOol2003m
Ool0025oo`03001oogoo0?aoo`008Goo00<007ooOol0o7oo000QOol00`00Oomoo`3lOol0025oo`03
001oogoo0?aoo`008Goo0P00oGoo000QOol00`00Oomoo`0XOol50003Ool2000YOol30004Ool2000Y
Ool30003Ool2000YOol30004Ool2000XOol30004Ool20004Ool0025oo`03001oogoo02Uoo`04001o
ogoo0002Ool01000Oomoo`009goo00D007ooOomoo`00009oo`04001oogoo000YOol01@00Oomoogoo
00000Woo00<007ooOol09Goo00D007ooOomoo`00009oo`04001oogoo000VOol01@00Oomoogoo0000
0Woo00@007ooOol000=oo`008Goo00<007ooOol0:Woo00<007ooOol00Woo00@007ooOol002]oo`04
001oogoo0002Ool00`00Oomoo`0TOol50002Ool01000Oomoo`00:goo00@007ooOol0009oo`03001o
ogoo02Aoo`05001oogooOol00002Ool01000Oomoo`000goo000QOol2000/Ool01@00Oomoogoo0000
0Woo00<007ooOol09goo0P000goo00@007ooOol002Ioo`04001oogoo0003Ool01000Oomoo`00:goo
00@007ooOol0009oo`03001oogoo02Aoo`@000=oo`04001oogoo0003Ool0025oo`03001oogoo02Qo
o`05001oogooOol00002Ool01000Oomoo`00:goo00@007ooOol0009oo`03001oogoo02Eoo`03001o
o`0000=oo`04001oogoo000WOol40003Ool01000Oomoo`009Woo00<007ooOol017oo00@007ooOol0
00=oo`008Goo00<007ooOol0:7oo00D007ooOomoo`00009oo`04001oogoo000WOol01@00Oomoogoo
00000Woo00@007ooOol002Qoo`8000=oo`04001oogoo000WOol00`00Oomoo`04Ool01000Oomoo`00
9goo00<007ooOol00goo00@007ooOol000=oo`008Goo00<007ooOol0:Goo0`0017oo0P00:Goo0`00
17oo0P00:Woo00<007ooOol00Woo0P00:7oo1@000goo0P00:Goo0P0017oo0P0017oo000QOol2003m
Ool0025oo`03001oogoo0?aoo`008Goo00<007ooOol0o7oo000QOol00`00Oomoo`3lOol0025oo`03
001oogoo0?aoo`006gooo`001P00000QOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`05Ool0025oo`03001oogoo0?aoo`008Goo
00<007ooOol0o7oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {3.28438, -19.0017, 0.201972, \
0.115183}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tt // TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"10", "0.000014932279260852495`", "0.000015227024875635036`", 
            "0.00009256370564883646`"},
          {"11", "0.00004080609186174426`", "0.000041528249660822824`", 
            "0.0001773368936319584`"},
          {"12", "0.0001022096418272225`", "0.00010382062415205704`", 
            "0.0003286071635007793`"},
          {"13", "0.00023629424486620594`", "0.00023958605573551627`", 
            "0.0005889448156924404`"},
          {"14", "0.000507208186734231`", "0.0005133986908618206`", 
            "0.0010209204497367013`"},
          {"15", "0.0010160443235161546`", "0.0010267973817236413`", 
            "0.0017117053146318063`"},
          {"16", "0.0019079493299226692`", "0.0019252450907318276`", 
            "0.0027757858625344816`"},
          {"17", "0.003371697346736903`", "0.0033974913365855774`", 
            "0.004353743594519111`"},
          {"18", "0.005626822904124793`", "0.005662485560975963`", 
            "0.006604800831770048`"},
          {"19", "0.008895150645986435`", "0.008940766675225205`", 
            "0.009691179719027308`"},
          {"20", "0.013357447131031685`", "0.013411150012837807`", 
            "0.013753513694652495`"},
          {"21", "0.01910120681583267`", "0.019158785732625437`", 
            "0.01887864513835122`"},
          {"22", "0.02607061313237817`", "0.026125616908125593`", 
            "0.025063872153943952`"},
          {"23", "0.03403243353995063`", "0.03407689161929426`", 
            "0.03218442339155189`"},
          {"24", "0.04257040990823565`", "0.042596114524117816`", 
            "0.03997270655170277`"},
          {"25", "0.05111523481378843`", "0.051115337428941386`", 
            "0.04801773420984973`"},
          {"26", "0.0590086953862595`", "0.05897923549493237`", 
            "0.05579047790388974`"},
          {"27", "0.06559152209768775`", "0.06553248388325819`", 
            "0.06269585514535203`"},
          {"28", "0.07029777724748243`", "0.07021337558920521`", 
            "0.06814561657308522`"},
          {"29", "0.07273642666398106`", "0.07263452647159159`", 
            "0.071640297028185`"},
          {"30", "0.07274372219323524`", "0.07263452647159159`", 
            "0.07284457176785482`"},
          {"31", "0.07039715050958247`", "0.07029147723057251`", 
            "0.071640297028185`"},
          {"32", "0.0659907090110984`", "0.06589825990366173`", 
            "0.06814561657308522`"},
          {"33", "0.05997951923248188`", "0.05990750900332883`", 
            "0.06269585514535203`"},
          {"34", "0.052907180499452505`", "0.05285956676764309`", 
            "0.05579047790388974`"},
          {"35", "0.045330817669368986`", "0.04530820008655122`", 
            "0.04801773420984973`"},
          {"36", "0.037756736716421095`", "0.03775683340545935`", 
            "0.03997270655170277`"},
          {"37", "0.030595146898188055`", "0.030613648707129203`", 
            "0.03218442339155189`"},
          {"38", "0.02413710462017481`", "0.024168670031944107`", 
            "0.025063872153943952`"},
          {"39", "0.018552105256244233`", "0.018591284639957007`", 
            "0.01887864513835122`"},
          {"40", "0.013901518590078892`", "0.013943463479967758`", 
            "0.013753513694652495`"},
          {"41", "0.010161640420567985`", "0.010202534253634942`", 
            "0.009691179719027308`"},
          {"42", "0.007250306415563583`", "0.007287524466882102`", 
            "0.006604800831770048`"},
          {"43", "0.00505226502434155`", "0.005084319395499141`", 
            "0.004353743594519111`"},
          {"44", "0.0034402345341047326`", "0.003466581406022141`", 
            "0.0027757858625344816`"},
          {"45", "0.0022902691421963703`", "0.0023110542706814277`", 
            "0.0017117053146318063`"},
          {"46", "0.0014914065660393049`", "0.0015072093069661483`", 
            "0.0010209204497367013`"},
          {"47", "0.0009504339161114349`", "0.00096204849380818`", 
            "0.0005889448156924404`"},
          {"48", "0.0005930083229097988`", "0.0006012803086301125`", 
            "0.0003286071635007793`"},
          {"49", "0.00036241083431508725`", "0.00036813080120210964`", 
            "0.0001773368936319584`"},
          {"50", "0.00021703210906335603`", "0.00022087848072126578`", 
            "0.00009256370564883646`"},
          {"51", "0.00012740984631425992`", "0.0001299285180713328`", 
            "0.00004673065294019853`"},
          {"52", "0.00007335085415750554`", "0.00007495876042576894`", 
            "0.000022818251233608137`"},
          {"53", "0.000041427733984530864`", "0.00004242948703345412`", 
            "0.00001077660995461306`"},
          {"54", "0.000022962313047148582`", "0.000023571937240807843`", 
            "4.92267510012868`*^-6"},
          {"55", "0.00001249474781983805`", "0.000012857420313167913`", 
            "2.174899944973612`*^-6"},
          {"56", "6.6768305130546686`*^-6", "6.887903739197096`*^-6", 
            "9.293865595484742`*^-7"},
          {"57", "3.5049571145972463`*^-6", "3.625212494314261`*^-6", 
            "3.841248293011324`*^-7"},
          {"58", "1.807999269728517`*^-6", "1.8751099108522039`*^-6", 
            "1.5355612636654624`*^-7"},
          {"59", "9.167398163800342`*^-7", "9.534457173824765`*^-7", 
            "5.9371849019831594`*^-8"},
          {"60", "4.5703663563861175`*^-7", "4.7672285869123827`*^-7", 
            "2.220304515562191`*^-8"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[46]//TableForm="]
}, Closed]],

Cell[TextData[{
  "Another strategy is to draw a single uniform random variable, Random[], \
and find where it intersects the cumulative density function. ",
  Cell[BoxData[
      \(TraditionalForm\`CDF[BinomialDistribution[n, p], j]\)]],
  " is efficient for large ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", so this approach is fairly fast.  For example, with ",
  Cell[BoxData[
      \(TraditionalForm\`n = 10\^6, \ p = 0.3\)]],
  ", RandomCum[] takes 0.011s, whereas ",
  "Random[BinomialDistribution[n, p]] takes 4.8s"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Timing[
        RandomCum[CDF[BinomialDistribution[10\^6, 0.3], #] &, 0.3\ 10\^6]], 
      Timing[Random[BinomialDistribution[10\^6, 0.3]]]}\)], "Input",
  CellLabel->"In[109]:="],

Cell[BoxData[
    \({{0.1000000000003638`\ Second, 299625}, {4.800000000000182`\ Second, 
        300319}}\)], "Output",
  CellLabel->"Out[110]="]
}, Open  ]],

Cell[TextData[{
  "The same method works for extreme ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  ".  It is important that p be numerical, since ",
  Cell[BoxData[
      \(CDF[BinomialDistribution[n, p], 0]\)]],
  "  crashes for 0 an integer and ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " large."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(n = 10\^6; p = 10. \^\(-6\);\), "\[IndentingNewLine]", 
    \({Timing[
        RandomCum[CDF[BinomialDistribution[10\^6, 10. \^\(-6\)], #] &, 1]], 
      Timing[Random[BinomialDistribution[10\^6, \ 10\^\(-6\)]]]}\)}], "Input",\

  CellLabel->"In[8]:="],

Cell[BoxData[
    \({{0.`\ Second, 4}, {4.866666666666674`\ Second, 0}}\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{97, Automatic}, {Automatic, 41}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 50, 0, 36, "SubsectionIcon"],
Cell[1792, 53, 295, 6, 50, "DefinitionBox"],
Cell[2090, 61, 46, 0, 28, "MathCaption"],
Cell[2139, 63, 91, 2, 27, "Input"],
Cell[2233, 67, 138, 3, 36, "Text"],
Cell[2374, 72, 111, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2510, 79, 127, 3, 42, "Input"],
Cell[2640, 84, 70, 2, 20, "Output"]
}, Open  ]],
Cell[2725, 89, 69, 0, 22, "Text"],
Cell[2797, 91, 79, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2901, 95, 171, 3, 42, "Input"],
Cell[3075, 100, 372, 11, 35, "Output"]
}, Open  ]],
Cell[3462, 114, 528, 16, 52, "Text"],
Cell[3993, 132, 98, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4116, 139, 187, 4, 57, "Input"],
Cell[4306, 145, 160, 3, 20, "Output"]
}, Open  ]],
Cell[4481, 151, 197, 8, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4703, 163, 199, 4, 57, "Input"],
Cell[4905, 169, 156, 4, 20, "Output"]
}, Open  ]],
Cell[5076, 176, 673, 11, 98, "DefinitionBox"],
Cell[5752, 189, 117, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5894, 196, 121, 3, 27, "Input"],
Cell[6018, 201, 296, 9, 67, "Output"]
}, Open  ]],
Cell[6329, 213, 156, 3, 36, "Text"],
Cell[6488, 218, 537, 9, 64, "DefinitionBox"],
Cell[7028, 229, 259, 6, 36, "Text"],
Cell[7290, 237, 916, 22, 106, "NumberedEquation"],
Cell[8209, 261, 301, 7, 50, "Text"],
Cell[8513, 270, 413, 17, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[8951, 291, 105, 2, 27, "Input"],
Cell[9059, 295, 62, 2, 36, "Output"]
}, Open  ]],
Cell[9136, 300, 308, 12, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[9469, 316, 487, 13, 63, "Input"],
Cell[9959, 331, 1139, 35, 87, "Output"]
}, Open  ]],
Cell[11113, 369, 544, 18, 64, "Text"],
Cell[11660, 389, 62, 0, 28, "MathCaption"],
Cell[11725, 391, 117, 2, 27, "Input"],
Cell[11845, 395, 54, 0, 22, "Text"],

Cell[CellGroupData[{
Cell[11924, 399, 68, 2, 27, "Input"],
Cell[11995, 403, 114, 2, 20, "Output"]
}, Open  ]],
Cell[12124, 408, 88, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[12237, 415, 307, 7, 57, "Input"],
Cell[12547, 424, 580, 14, 51, "Output"]
}, Open  ]],
Cell[13142, 441, 240, 6, 36, "Text"],

Cell[CellGroupData[{
Cell[13407, 451, 108, 2, 27, "Input"],
Cell[13518, 455, 133, 3, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13688, 463, 154, 4, 27, "Input"],
Cell[13845, 469, 165, 3, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14047, 477, 80, 2, 45, "Input"],
Cell[14130, 481, 60, 2, 20, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14239, 489, 42, 0, 36, "SubsectionIcon"],
Cell[14284, 491, 566, 18, 50, "Text"],

Cell[CellGroupData[{
Cell[14875, 513, 171, 4, 28, "Input"],
Cell[15049, 519, 95, 2, 20, "Output"]
}, Open  ]],
Cell[15159, 524, 264, 6, 38, "Text"],

Cell[CellGroupData[{
Cell[15448, 534, 394, 8, 93, "Input"],
Cell[15845, 544, 182, 3, 36, "Output"]
}, Open  ]],
Cell[16042, 550, 407, 12, 54, "Text"],

Cell[CellGroupData[{
Cell[16474, 566, 734, 14, 121, "Input"],
Cell[17211, 582, 14823, 531, 184, 6593, 424, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32071, 1118, 48, 1, 27, "Input"],
Cell[32122, 1121, 5701, 110, 851, "Output"]
}, Closed]],
Cell[37838, 1234, 547, 13, 62, "Text"],

Cell[CellGroupData[{
Cell[38410, 1251, 200, 4, 43, "Input"],
Cell[38613, 1257, 146, 3, 20, "Output"]
}, Open  ]],
Cell[38774, 1263, 328, 11, 36, "Text"],

Cell[CellGroupData[{
Cell[39127, 1278, 273, 6, 58, "Input"],
Cell[39403, 1286, 109, 2, 20, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

