(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     79062,       2667]*)
(*NotebookOutlinePosition[     80800,       2721]*)
(*  CellTagsIndexPosition[     80549,       2710]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Negative binomial likelihoods", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            
            FormBox[\(NegativeBinomialLogLikelihood[{n\_1, \[Ellipsis]}, \
{n\&_, c}]\),
              
              "TraditionalForm"], \(gives\ the\ log\ likelihood\ that\ the\ \
list\ of\ numbers\ \ is\ drawn\ from\ a\ negative\ binomial\ with\ mean\ n\&_\
\ and\ variance/mean\ ratio\ \(\(c\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->"NegativeBinomialLogLikelihood"]], "DefinitionBox",
  CellTags->"NegativeBinomialLogLikelihood"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Utilities`RandomNumbers`;\)\)], "Input",
  CellLabel->"In[305]:="],

Cell["\<\
This package automatically loads Statistics`DiscreteDistributions`, \
Statistics`ContinuousDistributions` as well.\
\>", "Text"],

Cell[TextData[{
  "The negative binomial distribution is defined here in terms of its mean, \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n\&_\)\(,\)\)\)]],
  " and the variance/mean ratio, ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\(\ \ \)\(\(c\^\(\(-n\&_\)/\((c - 1)\)\)\/\(n!\)\) \(\((n\&_\/\(c - 1\
\))\)\_n\) \((\(c - 1\)\/c)\)\^n\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is the observed number, and  ",
  Cell[BoxData[
      \(TraditionalForm\`\((a)\)\_n\)]],
  " is the Pochhammer function ",
  Cell[BoxData[
      \(TraditionalForm\`\((a + n - 1)\) \(\[Ellipsis](a)\)\)]],
  ".  For the special case ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c = 1\)\(,\)\(\ \)\(the\)\(\ \)\)\)]],
  "distribution is Poisson:"
}], "Text"],

Cell[BoxData[
    \(\(n\&_\^n\/\(n!\)\) \[ExponentialE]\^\(-n\&_\)\ \ for\ c = 
      1\)], "NumberedEquation"],

Cell["\<\
NegativeBinomialDistribution[] calculates the log likelihood that a \
list of numbers is drawn from this distribution:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NegativeBinomialLogLikelihood[{10, 20, 30}, {20, 1.2}]\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\(-11.790433392034736`\)\)], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell["The probability density sums to 1:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[
      Exp[NegativeBinomialLogLikelihood[{j}, {20, 1.2}]], {j, 0, 
        100}]\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \(1.0000000000000007`\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell[TextData[{
  "Note that this definition differs from the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function NegativeBinomialDistribution[].  The relation between the \
parameters is:"
}], "Text"],

Cell[BoxData[
    \(NegativeBinomialDistribution[n\&_\/\(c - 1\), 
      1\/c]\)], "NumberedEquation"],

Cell["\<\
However, NegativeBinomialDistribution[] does not allow the full \
range of parameter values that is permitted by \
NegativeBinomialLogLikelihood[].  Also, NegativeBinomialLogLikelihood[] \
efficiently calculates the log likelihood for a list of observations, rather \
than just for one.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            
            FormBox[\(NegativeBinomialLogLikelihood[{n\_1, \[Ellipsis]}, \
{n\&_, c}, Compiled \[Rule] True]\),
              
              "TraditionalForm"], \(gives\ the\ log\ likelihood\ that\ the\ \
list\ of\ numbers\ \ is\ drawn\ from\ a\ negative\ binomial\ with\ mean\ n\&_\
\ and\ variance/mean\ ratio\ \(\(c\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"Compiled"],

Cell["Compiling the code saves time if c>1:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Do[
        tbl[j] = Table[Random[Integer, {10, 20}], {100}], {j, 
          100}];\)\), "\[IndentingNewLine]", 
    \(Timing[
      Sum[NegativeBinomialLogLikelihood[tbl[j], {10, 1.8}, 
          Compiled \[Rule] True], {j, 100}]]\)}], "Input",
  CellLabel->"In[100]:="],

Cell[BoxData[
    \({0.18333333333339397`\ Second, \(-33762.38341520702`\)}\)], "Output",
  CellLabel->"Out[101]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      Sum[NegativeBinomialLogLikelihood[tbl[j], {10, 1.8}], {j, 
          100}]]\)], "Input",
  CellLabel->"In[102]:="],

Cell[BoxData[
    \({0.5500000000001819`\ Second, \(-33762.38341520701`\)}\)], "Output",
  CellLabel->"Out[102]="]
}, Open  ]],

Cell["\<\
For c<1, there is much less saving, because the slowest step is to \
use a hypergeometric function to calculate the normalisation (see \
below):\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Do[
        tbl[j] = Table[Random[Integer, {0, 13}], {100}], {j, 
          100}];\)\), "\[IndentingNewLine]", 
    \(Timing[
      Sum[NegativeBinomialLogLikelihood[tbl[j], {10, 0.2}], {j, 
          100}]]\)}], "Input",
  CellLabel->"In[106]:="],

Cell[BoxData[
    \({1.583333333333485`\ Second, \(-67797.92432567643`\)}\)], "Output",
  CellLabel->"Out[107]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      Sum[NegativeBinomialLogLikelihood[tbl[j], {10, 0.2}, 
          Compiled \[Rule] True], {j, 100}]]\)], "Input",
  CellLabel->"In[108]:="],

Cell[BoxData[
    \({1.333333333333485`\ Second, \(-67797.92432567643`\)}\)], "Output",
  CellLabel->"Out[108]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            FormBox[\(NegativeBinomialLogLikelihood[{n\&_, c}]\),
              
              "TraditionalForm"], \(The\ normalisation\ constant\ required\ \
for\ c < 1. \)}
          }], TraditionalForm]],
  CellTags->"normalisation"]], "DefinitionBox",
  CellTags->"Normalisation"],

Cell[TextData[{
  "Note that for c<1, Eq. 1 may give a negative distribution.  Negative \
values are truncated by the algorithm to -\[Infinity], and the total \
distribution is normalised using ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["NegativeBinomialLogLikelihood",
            "TraditionalForm"], "[", \({n\&_, c}\), "]"}], 
        TraditionalForm]]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Exp[NegativeBinomialLogLikelihood[{4. , 0.2}]]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell[TextData[{
  "The mean and variance are now not quite equal to ",
  Cell[BoxData[
      \(TraditionalForm\`n\&_, \ \(n\&_\) c\)]],
  " for small ",
  Cell[BoxData[
      \(TraditionalForm\`n\&_, \ c\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tt = 
        Table[Exp[NegativeBinomialLogLikelihood[{j}, {4. , 0.22}]], {j, 0, 
              20}] // Chop;\)\), "\n", 
    \(rr = Range[0, 20]; {Plus @@ tt, 
      rr . tt, \((rr - \((rr . tt)\))\)\^2 . tt\/rr . tt}\)}], "Input",
  CellLabel->"In[339]:="],

Cell[BoxData[
    \({1.0000000000000013`, 4.016131304670811`, 
      0.2279684621650717`}\)], "Output",
  CellLabel->"Out[340]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tt = 
        Table[Exp[NegativeBinomialLogLikelihood[{j}, {4. , 0.4}]], {j, 0, 
              20}] // Chop;\)\), "\n", 
    \(rr = Range[0, 20]; {Plus @@ tt, 
      rr . tt, \((rr - \((rr . tt)\))\)\^2 . tt\/rr . tt}\)}], "Input",
  CellLabel->"In[341]:="],

Cell[BoxData[
    \({0.9999999999999996`, 4.002885490764886`, 
      0.4021604780495614`}\)], "Output",
  CellLabel->"Out[342]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tt = 
        Table[Exp[NegativeBinomialLogLikelihood[{j}, {10. , 0.2}]], {j, 0, 
              20}] // Chop;\)\), "\n", 
    \(rr = Range[0, 20]; {Plus @@ tt, 
      rr . tt, \((rr - \((rr . tt)\))\)\^2 . tt\/rr . tt}\)}], "Input",
  CellLabel->"In[343]:="],

Cell[BoxData[
    \({1.0000000000000007`, 10.00760529423789`, 
      0.20227407472058345`}\)], "Output",
  CellLabel->"Out[344]="]
}, Open  ]],

Cell["However, the error is small.", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            FormBox[
              
              FormBox[\(NegativeBinomialLogLikelihood[{n\_1, \[Ellipsis]}, {n\
\&_, c}, Normalised \[Rule] False]\),
                "TraditionalForm"],
              "TraditionalForm"], \(A\ simpler\ version, \ 
            with\ no\ checks\ for\ feasibility\ and\ no\ \
\(\(normalisation\)\(.\)\)\)},
          {
            
            FormBox[\(NegativeBinomialLogLikelihood[{n\_1, \[Ellipsis]}, \
{n\&_, c}, Compiled \[Rule] True, Normalised \[Rule] False]\),
              "TraditionalForm"], \(An\ unn\ ormalised\ version, \ 
            compiled; \ does\ check\ for\ feasibility .. \)}
          }], TraditionalForm]],
  CellTags->"Normalised"]], "DefinitionBox"],

Cell["\<\
By setting Normalised\[Rule]False, the result is not normalised, \
and there is no check that the distribution is positive.  \
\>", "Text"],

Cell["\<\
This allows symbolic manipulation.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NegativeBinomialLogLikelihood[{3, 4, 5}, {nb, c}, 
      Normalised \[Rule] False]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(\(-3\)\ \((4 + nb\/\(\(-1\) + c\))\)\ Log[c] + 3\ Log[nb] + 
      Log[\(-1\) + c + 1\/5\ \((1 - c + nb)\)] + 
      2\ Log[\(-1\) + c + 1\/4\ \((1 - c + nb)\)] + 
      3\ Log[\(-1\) + c + 1\/3\ \((1 - c + nb)\)] + 
      3\ Log[\(-1\) + c + 1\/2\ \((1 - c + nb)\)]\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
      Exp[NegativeBinomialLogLikelihood[{j}, {4, 0.1}, 
            Normalised \[Rule] False]] // Chop, {j, 0, 10}]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \({0.00003593813663804628`, 0.0014375254655218518`, 
      0.022281644715588682`, 0.16339872791431712`, 0.5310458657215307`, 
      0.4248366925772247`, \(-0.35403057714768665`\), 
      0.7080611542953731`, \(-2.035675818599195`\), 
      7.23795846613047`, \(-29.675629711134977`\)}\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell["\<\
The sum of the feasible terms equals the normalisation \
constant:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Sum[
        Exp[NegativeBinomialLogLikelihood[{j}, {4, 0.1}, 
            Normalised \[Rule] False]], {j, 0, 5}], 
      Exp[NegativeBinomialLogLikelihood[{4, 0.1}]]}\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \({1.143036394530821`, 1.1430363945308206`}\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell["\<\
The compiled version does check where values are feasible, but does \
not normalise: that is because normalisation is slow & often \
unnecessary\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
      Exp[NegativeBinomialLogLikelihood[{j}, {4, 0.1}, 
            Normalised \[Rule] False, Compiled \[Rule] True]] // Chop, {j, 0, 
        10}]\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \({0.00003593813663804628`, 0.0014375254655218518`, 
      0.022281644715588682`, 0.16339872791431706`, 0.5310458657215305`, 
      0.4248366925772247`, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(NegativeBinomialLogLikelihood[{{n\_1, \[Ellipsis]}, \
\[Ellipsis]}, {{\[Alpha]\_1, \[Beta]\_1}, \[Ellipsis]}, {n\&_, 
                c}]\), \(gives\ the\ log\ likelihood\ for\ a\ multiplicative\ \
model, \ in\ which\ the\ parameters\ in\ sample\ k\ are\ \(\({\(\[Alpha]\_k\) 
                    n\&_, \(\[Beta]\_k\) c}\)\(.\)\)\)},
          {\(NegativeBinomialLogLikelihood[{{n\_1, \[Ellipsis]}, \
\[Ellipsis]}, {{\[Alpha]\_1, \[Beta]\_1}, \[Ellipsis]}, {n\&_, c}, 
              Compiled \[Rule] 
                True]\), \(is\ a\ compiled\ \(\(version\)\(.\)\)\)},
          {\(NegativeBinomialLogLikelihood[{{n\_1, \[Ellipsis]}, \
\[Ellipsis]}, {{\[Alpha]\_1, \[Beta]\_1}, \[Ellipsis]}, {n\&_, c}, 
              Normalised \[Rule] 
                False]\), \(does\ not\ normalise\ the\ likelihood\ for\ c < 
              1. \)}
          }], TraditionalForm]],
  CellTags->"multiplicative models"]], "DefinitionBox"],

Cell["Here is a list of four samples:", "MathCaption"],

Cell[BoxData[
    \(\(cd = {{27, 30, 26, 24, 29, 25, 23, 18, 20, 17}, {41, 43, 45, 50, 41, 
            46, 42, 42, 46, 41}, {82, 66, 72, 72, 74, 75, 68, 63, 67, 
            62}, {412, 356, 481, 269}};\)\)], "Input",
  CellLabel->"In[4]:="],

Cell["\<\
Here are factors by which the parameters in each list are to be \
multiplied:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Alpha]\[Beta] = \({Mean[#], Variance[#]\/Mean[#]} &\) /@ cd // 
        N\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \({{23.9`, 0.8224081822408182`}, {43.7`, 0.2036613272311213`}, {70.1`, 
        0.5308289744809003`}, {379.5`, 21.186649099692577`}}\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell["This determines the MLE, fitting to all the samples:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      FindMinimum[\(-NegativeBinomialLogLikelihood[
            cd, \[Alpha]\[Beta], {\[ExponentialE]\^z, \[ExponentialE]\^c}]\), \
{z, {\(-0.1\), 0.1}}, {c, {0, 0.5}}]]\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \({3.1833333333332803`\ Second, {108.44760312898867`, {z \[Rule] 
            0.0008391755907866731`, 
          c \[Rule] \(-0.055455412158170514`\)}}}\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell["\<\
This is equivalent to summing likelihoods over all four \
samples:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      FindMinimum[\(-Plus @@ 
            MapThread[
              NegativeBinomialLogLikelihood[#1, #2\ {\[ExponentialE]\^z, \
\[ExponentialE]\^c}] &, {cd, \[Alpha]\[Beta]}]\), {z, {\(-0.1\), 
            0.1}}, {c, {0, 0.5}}]]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \({3.2000000000000455`\ Second, {108.44760312898867`, {z \[Rule] 
            0.0008391755907866731`, 
          c \[Rule] \(-0.055455412158170514`\)}}}\)], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell["\<\
This compiled version of NegativeBinomialLogLikelihood[] is \
somewhat faster than using MapThread[], because compiling MapThread[] is \
inefficient:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      FindMinimum[\(-NegativeBinomialLogLikelihood[
            cd, \[Alpha]\[Beta], {\[ExponentialE]\^z, \[ExponentialE]\^c}, 
            Compiled \[Rule] True, 
            Normalised \[Rule] False]\), {z, {\(-0.1\), 0.1}}, {c, {0, 
            0.5}}]]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \({0.43333333333339397`\ Second, {108.44760301516422`, {z \[Rule] 
            0.0008391797790829661`, 
          c \[Rule] \(-0.05545494735259923`\)}}}\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      FindMinimum[\(-Plus @@ 
            MapThread[
              NegativeBinomialLogLikelihood[#1, #2\ {\[ExponentialE]\^z, \
\[ExponentialE]\^c}, Compiled \[Rule] True, 
                  Normalised \[Rule] 
                    False] &, {cd, \[Alpha]\[Beta]}]\), {z, {\(-0.1\), 
            0.1}}, {c, {0, 0.5}}]]\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \({0.6333333333334394`\ Second, {108.44760301516422`, {z \[Rule] 
            0.0008391797790829661`, 
          c \[Rule] \(-0.05545494735259923`\)}}}\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            FormBox[\(NegativeBinomialMLE[{n\_1, \[Ellipsis]}]\),
              
              "TraditionalForm"], \(gives\ the\ MLE\ and\ log\ likelihood, \ \
{L, {n\&\(\(_\)\(\[NonBreakingSpace]\)\), c}}, \ 
            given\ that\ the\ list\ of\ numbers\ {n\_1, \[Ellipsis]}\ is\ \
drawn\ from\ a\ negative\ binomial\ with\ mean\ n\&_\ and\ variance\/mean = 
              c\)},
          {\(NegativeBinomialMLE[{n\_1, \[Ellipsis]}, 
              FullOutput \[Rule] 
                False]\), \(just\ returns\ {n\&\(\(_\)\(\[NonBreakingSpace]\)\
\), c}\)}
          }], TraditionalForm]],
  CellTags->"NegativeBinomialMLE"]], "DefinitionBox",
  CellTags->"NegativeBinomialMLE"],

Cell[TextData[{
  "This is the best estimate of ",
  Cell[BoxData[
      \(TraditionalForm\`n\&_, \ c\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NegativeBinomialMLE[{10, 20, 30, 40}]\)], "Input",
  CellLabel->"In[443]:="],

Cell[BoxData[
    \({\(-15.321388017959634`\), {25, 5.675858984235089`}}\)], "Output",
  CellLabel->"Out[443]="]
}, Open  ]],

Cell[TextData[{
  "This is the MLE when ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is fixed at 1:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NegativeBinomialMLE[{10, 20, 30, 40}, {None, 1}] // N\)], "Input",
  CellLabel->"In[444]:="],

Cell[BoxData[
    \({\(-20.531322610596543`\), {25.`, 1.`}}\)], "Output",
  CellLabel->"Out[444]="]
}, Open  ]],

Cell[TextData[{
  "There is a loss of log likelihood of 5.21, suggesting a significant excess \
variance over a Poisson distribution ",
  Cell[BoxData[
      \(TraditionalForm\`\((c = 1)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "This is the MLE when the mean is constrained to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n\&_\)\(=\)\)\)]],
  "25:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NegativeBinomialMLE[{10, 20, 30, 40}, {25, None}] // N\)], "Input",
  CellLabel->"In[445]:="],

Cell[BoxData[
    \({\(-15.321388017959634`\), {25.`, 5.675858984235089`}}\)], "Output",
  CellLabel->"Out[445]="]
}, Open  ]],

Cell["This is just the same as NegativeBinomialLogLikelihood[]:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NegativeBinomialMLE[{10, 20, 30, 40}, {25, 5.67586}] // N\)], "Input",
  CellLabel->"In[446]:="],

Cell[BoxData[
    \({\(-15.321388017911005`\), {25.`, 5.67586`}}\)], "Output",
  CellLabel->"Out[446]="]
}, Open  ]],

Cell["\<\
The option FullOutput\[Rule]False suppresses calculation of the \
likelihood; it is slightly faster.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NegativeBinomialMLE[{10, 20, 30, 40}, 
      FullOutput \[Rule] False]\)], "Input",
  CellLabel->"In[447]:="],

Cell[BoxData[
    \({25, 5.675858984235089`}\)], "Output",
  CellLabel->"Out[447]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Timings",
  FontWeight->"Bold"]], "SubsubsectionIcon",
  CellTags->"Timings"],

Cell["\<\
With a single number, normalisation doubles the time.  Compiling \
saves about 30% of the time:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({{Timing[\(Do[
                NegativeBinomialLogLikelihood[{5}, {4, 0.1}, 
                  Normalised \[Rule] 
                    False], {1000}];\)], \[IndentingNewLine]Timing[\(Do[
                NegativeBinomialLogLikelihood[{5}, {4, 
                    0.1}], {1000}];\)]}, {Timing[\(Do[
                NegativeBinomialLogLikelihood[{5}, {4, 0.1}, 
                  Normalised \[Rule] False, 
                  Compiled \[Rule] 
                    True], {1000}];\)], \[IndentingNewLine]Timing[\(Do[
                NegativeBinomialLogLikelihood[{5}, {4, 0.1}, 
                  Compiled \[Rule] True], {1000}];\)]}} // 
      MatrixForm\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1.8333333333333712`\ Second\)},
                    {"Null"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(3.4166666666666288`\ Second\)},
                    {"Null"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(1.3000000000000682`\ Second\)},
                    {"Null"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(2.8333333333332575`\ Second\)},
                    {"Null"}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{
        Times[ 1.8333333333333712, Second], Null}, {
        Times[ 3.4166666666666288, Second], Null}}, {{
        Times[ 1.3000000000000682, Second], Null}, {
        Times[ 2.8333333333332575, Second], Null}}}]]], "Output",
  CellLabel->"Out[31]//MatrixForm="]
}, Open  ]],

Cell["The same pattern is seen for homogeneous arrays of numbers:", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(tt = Array[3 &, {20}]~Join~Array[4 &, {50}]~Join~Array[5 &, {30}]; 
    nt = 100;\), "\[IndentingNewLine]", 
    \({{Timing[\(Do[
                NegativeBinomialLogLikelihood[tt, {4, 0.1}, 
                  Normalised \[Rule] 
                    False], {nt}];\)], \[IndentingNewLine]Timing[\(Do[
                NegativeBinomialLogLikelihood[
                  tt, {4, 0.1}], {nt}];\)]}, {Timing[\(Do[
                NegativeBinomialLogLikelihood[tt, {4, 0.1}, 
                  Normalised \[Rule] False, 
                  Compiled \[Rule] 
                    True], {nt}];\)], \[IndentingNewLine]Timing[\(Do[
                NegativeBinomialLogLikelihood[tt, {4, 0.1}, 
                  Compiled \[Rule] True], {nt}];\)]}} // 
      MatrixForm\)}], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(0.2666666666666515`\ Second\)},
                    {"Null"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(0.39999999999997726`\ Second\)},
                    {"Null"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(0.14999999999997726`\ Second\)},
                    {"Null"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(0.33333333333337123`\ Second\)},
                    {"Null"}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{
        Times[ 0.26666666666665151, Second], Null}, {
        Times[ 0.39999999999997726, Second], Null}}, {{
        Times[ 0.14999999999997726, Second], Null}, {
        Times[ 0.33333333333337123, Second], Null}}}]]], "Output",
  CellLabel->"Out[47]//MatrixForm="]
}, Open  ]],

Cell["\<\
For c>1, and heterogeneous arrays, compilation is very much faster; \
normalising takes little time:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nb = 400; c = 2; 
    tt = RandomArray[
        NegativeBinomialDistribution[nb\/\(c - 1\), 1\/c], {100}]\)], "Input",\

  CellLabel->"In[55]:="],

Cell[BoxData[
    \({390, 402, 424, 414, 377, 387, 380, 386, 345, 394, 397, 399, 402, 441, 
      412, 377, 388, 453, 396, 379, 423, 396, 440, 393, 442, 420, 418, 390, 
      398, 396, 382, 354, 389, 405, 446, 368, 418, 366, 361, 425, 430, 375, 
      343, 436, 398, 361, 398, 413, 332, 377, 384, 399, 426, 380, 455, 361, 
      385, 412, 424, 368, 407, 418, 407, 377, 392, 428, 444, 411, 370, 348, 
      424, 422, 366, 419, 359, 445, 433, 409, 401, 425, 362, 412, 389, 406, 
      392, 396, 416, 411, 419, 408, 408, 377, 406, 394, 367, 396, 357, 391, 
      434, 398}\)], "Output",
  CellLabel->"Out[55]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(nt = 100;\)\), "\[IndentingNewLine]", 
    \({{Timing[\(Do[
                NegativeBinomialLogLikelihood[tt, {nb, c}, 
                  Normalised \[Rule] 
                    False], {nt}];\)], \[IndentingNewLine]Timing[\(Do[
                NegativeBinomialLogLikelihood[
                  tt, {nb, c}], {nt}];\)]}, {Timing[\(Do[
                NegativeBinomialLogLikelihood[tt, {nb, c}, 
                  Normalised \[Rule] False, 
                  Compiled \[Rule] 
                    True], {nt}];\)], \[IndentingNewLine]Timing[\(Do[
                NegativeBinomialLogLikelihood[tt, {nb, c}, 
                  Compiled \[Rule] True], {nt}];\)]}} // 
      MatrixForm\)}], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(6.100000000000136`\ Second\)},
                    {"Null"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(6.099999999999909`\ Second\)},
                    {"Null"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(0.6166666666665606`\ Second\)},
                    {"Null"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(0.7833333333335304`\ Second\)},
                    {"Null"}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{
        Times[ 6.1000000000001364, Second], Null}, {
        Times[ 6.0999999999999091, Second], Null}}, {{
        Times[ 0.61666666666656056, Second], Null}, {
        Times[ 0.78333333333353039, Second], Null}}}]]], "Output",
  CellLabel->"Out[59]//MatrixForm="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NegativeBinomialMLE[] does not allow for normalisation when \
c<1\
\>", "SubsubsectionIcon",
  CellTags->"c<1"],

Cell[TextData[{
  "Note that NegativeBinomialMLE[] does not allow for the complicated \
normalisation that is requiredfor c<1.  Provided that parameters are not \
extreme, this may cause little error.  For  this reason,  ",
  Cell[BoxData[
      \(TraditionalForm\`NegativeBinomialMLE[{n\_1, \[Ellipsis]}]\)]],
  " is not quite equivalent to  maximising NegativeBinomialLogLikelihood[",
  Cell[BoxData[
      \(TraditionalForm\`\(\({n\_1, \[Ellipsis]}, {n\&_, c}\)\(]\)\)\)]],
  " when c<1."
}], "Text"],

Cell["\<\
In this example, NegativeBinomialMLE[] fails, because the best \
estimate (ignorng normalisation) yields a negative distribution.  The \
example, is implausiblke, however, because these values are unlikely to be \
generated by a distribution with narrow variance:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NegativeBinomialMLE[{10, 20, 30, 40}, {None, 0.2}]\)], "Input",
  CellLabel->"In[233]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[\(-\[Infinity]\),
          DirectedInfinity[ -1]], ",", \({25.128923929006298`, 0.2`}\)}], 
      "}"}]], "Output",
  CellLabel->"Out[233]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMinimum[\(-NegativeBinomialLogLikelihood[{10, 20, 30, 40}, {nb, 
            0.2}]\), {nb, {31.9, 32.1}}]\)], "Input",
  CellLabel->"In[236]:="],

Cell[BoxData[
    \({52.10799279892326`, {nb \[Rule] 32.0765726346919`}}\)], "Output",
  CellLabel->"Out[236]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
        NegativeBinomialLogLikelihood[{10, 20, 30, 40}, {nb, 0.2}]\ , {nb, 
          30, 50}];\)\)], "Input",
  CellLabel->"In[234]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55799 0.0506835 1.04382 0.00845367 [
[.08923 .27049 -16 -18 ]
[.08923 .27049 16 0 ]
[.34265 .27049 -16 -18 ]
[.34265 .27049 16 0 ]
[.46936 .27049 -10 -18 ]
[.46936 .27049 10 0 ]
[.59606 .27049 -16 -18 ]
[.59606 .27049 16 0 ]
[.72277 .27049 -10 -18 ]
[.72277 .27049 10 0 ]
[.84948 .27049 -16 -18 ]
[.84948 .27049 16 0 ]
[.97619 .27049 -10 -18 ]
[.97619 .27049 10 0 ]
[.20344 .02938 -39.0625 -9 ]
[.20344 .02938 0 9 ]
[.20344 .11392 -39.0625 -9 ]
[.20344 .11392 0 9 ]
[.20344 .19846 -39.0625 -9 ]
[.20344 .19846 0 9 ]
[.20344 .36753 -31.0625 -9 ]
[.20344 .36753 0 9 ]
[.20344 .45207 -31.0625 -9 ]
[.20344 .45207 0 9 ]
[.20344 .5366 -31.0625 -9 ]
[.20344 .5366 0 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08923 .28299 m
.08923 .28924 L
s
gsave
.08923 .27049 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(32.5) show
1.000 setlinewidth
grestore
.34265 .28299 m
.34265 .28924 L
s
gsave
.34265 .27049 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(37.5) show
1.000 setlinewidth
grestore
.46936 .28299 m
.46936 .28924 L
s
gsave
.46936 .27049 -71 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.59606 .28299 m
.59606 .28924 L
s
gsave
.59606 .27049 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(42.5) show
1.000 setlinewidth
grestore
.72277 .28299 m
.72277 .28924 L
s
gsave
.72277 .27049 -71 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45) show
1.000 setlinewidth
grestore
.84948 .28299 m
.84948 .28924 L
s
gsave
.84948 .27049 -77 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(47.5) show
1.000 setlinewidth
grestore
.97619 .28299 m
.97619 .28924 L
s
gsave
.97619 .27049 -71 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.125 Mabswid
.11457 .28299 m
.11457 .28674 L
s
.13991 .28299 m
.13991 .28674 L
s
.16525 .28299 m
.16525 .28674 L
s
.1906 .28299 m
.1906 .28674 L
s
.24128 .28299 m
.24128 .28674 L
s
.26662 .28299 m
.26662 .28674 L
s
.29196 .28299 m
.29196 .28674 L
s
.3173 .28299 m
.3173 .28674 L
s
.36799 .28299 m
.36799 .28674 L
s
.39333 .28299 m
.39333 .28674 L
s
.41867 .28299 m
.41867 .28674 L
s
.44401 .28299 m
.44401 .28674 L
s
.4947 .28299 m
.4947 .28674 L
s
.52004 .28299 m
.52004 .28674 L
s
.54538 .28299 m
.54538 .28674 L
s
.57072 .28299 m
.57072 .28674 L
s
.62141 .28299 m
.62141 .28674 L
s
.64675 .28299 m
.64675 .28674 L
s
.67209 .28299 m
.67209 .28674 L
s
.69743 .28299 m
.69743 .28674 L
s
.74811 .28299 m
.74811 .28674 L
s
.77346 .28299 m
.77346 .28674 L
s
.7988 .28299 m
.7988 .28674 L
s
.82414 .28299 m
.82414 .28674 L
s
.87482 .28299 m
.87482 .28674 L
s
.90017 .28299 m
.90017 .28674 L
s
.92551 .28299 m
.92551 .28674 L
s
.95085 .28299 m
.95085 .28674 L
s
.06389 .28299 m
.06389 .28674 L
s
.03855 .28299 m
.03855 .28674 L
s
.0132 .28299 m
.0132 .28674 L
s
.25 Mabswid
0 .28299 m
1 .28299 L
s
.21594 .02938 m
.22219 .02938 L
s
gsave
.20344 .02938 -100.062 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(120) show
1.000 setlinewidth
grestore
.21594 .11392 m
.22219 .11392 L
s
gsave
.20344 .11392 -100.062 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(110) show
1.000 setlinewidth
grestore
.21594 .19846 m
.22219 .19846 L
s
gsave
.20344 .19846 -100.062 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.21594 .36753 m
.22219 .36753 L
s
gsave
.20344 .36753 -92.0625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.21594 .45207 m
.22219 .45207 L
s
gsave
.20344 .45207 -92.0625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70) show
1.000 setlinewidth
grestore
.21594 .5366 m
.22219 .5366 L
s
gsave
.20344 .5366 -92.0625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.125 Mabswid
.21594 .04629 m
.21969 .04629 L
s
.21594 .0632 m
.21969 .0632 L
s
.21594 .0801 m
.21969 .0801 L
s
.21594 .09701 m
.21969 .09701 L
s
.21594 .13083 m
.21969 .13083 L
s
.21594 .14773 m
.21969 .14773 L
s
.21594 .16464 m
.21969 .16464 L
s
.21594 .18155 m
.21969 .18155 L
s
.21594 .21536 m
.21969 .21536 L
s
.21594 .23227 m
.21969 .23227 L
s
.21594 .24918 m
.21969 .24918 L
s
.21594 .26609 m
.21969 .26609 L
s
.21594 .2999 m
.21969 .2999 L
s
.21594 .31681 m
.21969 .31681 L
s
.21594 .33371 m
.21969 .33371 L
s
.21594 .35062 m
.21969 .35062 L
s
.21594 .38444 m
.21969 .38444 L
s
.21594 .40134 m
.21969 .40134 L
s
.21594 .41825 m
.21969 .41825 L
s
.21594 .43516 m
.21969 .43516 L
s
.21594 .46897 m
.21969 .46897 L
s
.21594 .48588 m
.21969 .48588 L
s
.21594 .50279 m
.21969 .50279 L
s
.21594 .5197 m
.21969 .5197 L
s
.21594 .55351 m
.21969 .55351 L
s
.21594 .57042 m
.21969 .57042 L
s
.21594 .58732 m
.21969 .58732 L
s
.21594 .60423 m
.21969 .60423 L
s
.21594 .01247 m
.21969 .01247 L
s
.25 Mabswid
.21594 0 m
.21594 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .56882 m
.02504 .57977 L
.02639 .58474 L
.02716 .58665 L
.02788 .58812 L
.02933 .59047 L
.03089 .59241 L
.03371 .59504 L
.03629 .59682 L
.03928 .59841 L
.04254 .59975 L
.04563 .60073 L
.04849 .60146 L
.05113 .60199 L
.05399 .60245 L
.05669 .60277 L
.05918 .603 L
.06143 .60315 L
.0627 .60321 L
.06389 .60326 L
.06515 .60329 L
.0663 .60331 L
.06762 .60332 L
.06887 .60331 L
.07012 .6033 L
.0715 .60327 L
.07219 .60325 L
.07293 .60322 L
.07428 .60316 L
.07689 .60302 L
.07928 .60285 L
.0848 .60235 L
.09061 .60164 L
.10077 .60005 L
.11162 .5979 L
.13117 .59308 L
.17534 .57866 L
.21789 .56126 L
.25883 .54203 L
.30238 .51936 L
.34432 .49571 L
.38465 .47151 L
.42758 .44435 L
.46891 .41699 L
.51284 .38673 L
.55516 .35653 L
.59587 .32661 L
.63918 .29388 L
.68089 .26159 L
.7252 .22648 L
Mistroke
.7679 .19194 L
.80899 .15807 L
.85269 .12144 L
.89477 .08558 L
.93524 .05059 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[234]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{1, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000mOol0
0`00Oomoo`3POol003eoo`03001oogoo0>1oo`00?Goo00<007ooOol0h7oo000mOol2003QOol003eo
o`03001oogoo0=Aoo`8000Yoo`0087oo1@000Woo1P0017oo0`002Goo00<007ooOol0dgoo00<007oo
Ool02Woo000ROol00`00Oomoo`02Ool00`00Oomoo`03Ool01000Oomoo`000goo00<007ooOol01Woo
00<007ooOol0dWoo00<007ooOol02goo000ROol00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomo
o`03Ool00`00Oomoo`05Ool00`00Oomoo`3AOol00`00Oomoo`0<Ool0029oo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00=oo`03001oogoo00Eoo`<00=1oo`03001oogoo00eoo`005Goo2000
1Goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol0
cWoo0P0047oo000ROol00`00Oomoo`06Ool01@00Oomoogoo00001Goo00<007ooOol01Goo00<007oo
Ool0cGoo00<007ooOol047oo000ROol00`00Oomoo`07Ool01000Oomoo`001Goo00<007ooOol01Goo
00<007ooOol0c7oo00<007ooOol04Goo000ROol00`00Oomoo`07Ool01000Oomoo`001Goo00<007oo
Ool01Goo00<007ooOol0bgoo00<007ooOol04Woo000ROol00`00Oomoo`02Ool00`00Oomoo`02Ool0
1000Oomoo`001Goo00<007ooOol01Goo0P00bgoo00<007ooOol04goo000POol30005Ool01000Oomo
o`0017oo00D007ooOomoo`0000Qoo`03001oogoo0<Qoo`8001Ioo`008Woo00<007ooOol017oo0P00
1Woo0`002Goo00<007ooOol0agoo00<007ooOol05Woo000mOol00`00Oomoo`36Ool00`00Oomoo`0G
Ool003eoo`03001oogoo0<Eoo`03001oogoo01Qoo`00?Goo0P00aGoo00<007ooOol06Goo000mOol0
0`00Oomoo`32Ool2000LOol003eoo`03001oogoo0<5oo`03001oogoo01aoo`00?Goo00<007ooOol0
`7oo00<007ooOol07Goo000mOol20030Ool00`00Oomoo`0NOol003eoo`03001oogoo0;ioo`03001o
ogoo01moo`00?Goo00<007ooOol0_7oo0P008Woo000mOol00`00Oomoo`2kOol00`00Oomoo`0ROol0
03eoo`03001oogoo0;Yoo`03001oogoo02=oo`00?Goo0P00^Woo00<007ooOol097oo000mOol00`00
Oomoo`2hOol00`00Oomoo`0UOol0021oo`D000=oo`D000Aoo`<000Uoo`03001oogoo0;Ioo`8002Qo
o`008Woo00<007ooOol01Goo00<007ooOol00goo00D007ooOomoo`0000Qoo`03001oogoo0;Eoo`03
001oogoo02Qoo`008Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
1Goo00<007ooOol0]7oo00<007ooOol0:Goo000ROol00`00Oomoo`05Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`05Ool3002cOol00`00Oomoo`0ZOol001Eoo`P000Eoo`03001oogoo00Eo
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo0;9oo`03001oogoo02]o
o`008Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo00<007oo
Ool0/7oo0P00;Woo000ROol00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`05Ool00`00Oomoo`2_Ool00`00Oomoo`0^Ool0029oo`03001oogoo00Eoo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo00Eoo`03001oogoo0:ioo`03001oogoo02moo`008Woo00<007ooOol0
1Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo0P00[Woo00<007ooOol0<7oo000P
Ool30005Ool30005Ool01@00Oomoogoo000027oo00<007ooOol0[7oo00<007ooOol0<Goo000ROol0
0`00Oomoo`05Ool00`00Oomoo`04Ool30009Ool00`00Oomoo`2[Ool00`00Oomoo`0bOol003eoo`03
001oogoo0:Yoo`03001oogoo03=oo`00?Goo00<007ooOol0ZGoo00<007ooOol0=7oo000mOol2002Y
Ool00`00Oomoo`0eOol003eoo`03001oogoo0:Moo`03001oogoo03Ioo`00?Goo00<007ooOol0YWoo
00<007ooOol0=goo000mOol00`00Oomoo`2TOol2000jOol003eoo`800:Aoo`03001oogoo03Yoo`00
?Goo00<007ooOol0XWoo00<007ooOol0>goo000mOol00`00Oomoo`2POol2000nOol003eoo`03001o
ogoo09moo`03001oogoo03ioo`00?Goo00<007ooOol0WWoo00<007ooOol0?goo000mOol2002MOol2
0012Ool003eoo`03001oogoo09]oo`03001oogoo049oo`0087oo1@0017oo0`001Goo0`002Goo00<0
07ooOol0VWoo00<007ooOol0@goo000ROol00`00Oomoo`03Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000Qoo`03001oogoo09Qoo`8004Ioo`008Woo00<007ooOol00Woo00<007ooOol00goo00<0
07oo00001Goo00<007ooOol01Goo00<007ooOol0Ugoo00<007ooOol0AWoo000ROol00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`05Ool3002FOol00`00Oomoo`17Ool001Eo
o`P000Eoo`03001oogoo009oo`03001oogoo00=oo`03001oo`0000Eoo`03001oogoo00Eoo`03001o
ogoo09Eoo`03001oogoo04Qoo`008Woo00<007ooOol00Woo00<007ooOol00goo00<007oo00001Goo
00<007ooOol01Goo00<007ooOol0U7oo00<007ooOol0BGoo000ROol00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Ool00005Ool00`00Oomoo`05Ool00`00Oomoo`2BOol2001<Ool0029oo`03001oogoo
009oo`03001oogoo00=oo`03001oo`0000Eoo`03001oogoo00Eoo`03001oogoo095oo`03001oogoo
04aoo`008Woo00<007ooOol00Woo00<007ooOol00goo00<007oo00001Goo00<007ooOol01Goo0P00
TGoo00<007ooOol0CGoo000POol30005Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Qoo`03
001oogoo08moo`03001oogoo04ioo`008Woo00<007ooOol017oo0`001Goo0`002Goo00<007ooOol0
SWoo00<007ooOol0Cgoo000;Ool40004Ool60003Ool00`00Ool00004000JOol00`00Oomoo`0COol4
0007Ool00`00Oomoo`03Ool00`00Ool00004000GOol00`00Oomoo`02Ool3000FOol00`00Oomoo`06
0003Ool00`00Ool00004000GOol00`00Ool00005000FOol00`00Oomoo`03Ool00`00Oomoo`03Ool0
0`00Ool00004000BOol50005Ool30006Ool000moo`05001oogooOol00005Ool00`00Oomoo`07Ool0
0`00Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0DOol0
1@00Oomoogoo00000goo00<007ooOol04goo00@007ooOol000Eoo`03001oogoo00Moo`03001oogoo
01Aoo`8000Ioo`03001oogoo01=oo`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo01Aoo`05
001oogooOol00003Ool00`00Oomoo`03Ool0011oo`05001oogooOol0000?Ool00`00Oomoo`0FOol2
000IOol00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`0COol01000Oomoo`001Goo00<007oo
Ool04Woo00D007ooOomoo`0000moo`03001oogoo01=oo`03001oogoo00Ioo`03001oogoo019oo`03
001oogoo00=oo`03001oogoo00]oo`03001oogoo01Aoo`03001oo`0000Eoo`03001oogoo009oo`00
47oo00<007ooOol00Woo00<007ooOol037oo00<007ooOol05Woo00<007ooOol067oo00<007ooOol0
17oo00<007ooOol02Woo00<007ooOol03Woo2@001Goo00<007ooOol03Goo20000Woo00<007ooOol0
37oo00<007ooOol03Woo20001Woo00<007ooOol03Goo200017oo00<007ooOol02Woo00<007ooOol0
57oo00<007oo00001Goo00<007ooOol00Woo000@Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00
Oomoo`0FOol00`00Oomoo`0HOol00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0>Ool00`00
Oomoo`02Ool01000Oomoo`001Goo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol02goo00<007ooOol03Woo00H007ooOol007oo0008Ool00`00Oomoo`0=Ool00`00Oomoo`02
Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0DOol00`00Ool00005Ool00`00Oomoo`02
Ool000eoo`<000Moo`03001oogoo00Yoo`03001oogoo01Ioo`03001oogoo01Eoo`<000Moo`03001o
ogoo00Yoo`03001oogoo00moo`05001oogooOol00002Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool0
1@00Oomoogoo00001Woo00<007ooOol02Woo00<007ooOol03goo0P000Woo00<007ooOol01Woo00<0
07ooOol03Woo00D007ooOomoo`0000Ioo`03001oogoo00Yoo`03001oogoo01Aoo`03001oo`0000Eo
o`03001oogoo009oo`003Woo00<007ooOol01goo00<007ooOol027oo00<007ooOol05goo0P005goo
00<007ooOol01goo00<007ooOol027oo00<007ooOol04Goo00@007ooOol0009oo`03001oogoo00=o
o`03001oogoo00moo`04001oogoo0007Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Ool00002
Ool00`00Oomoo`05Ool00`00Oomoo`0@Ool01000Oomoo`001goo00<007ooOol027oo00<007ooOol0
57oo00@007ooOol000Eoo`03001oogoo009oo`003goo00<007ooOol01Woo00<007ooOol017oo1000
6Woo00<007ooOol05goo00<007ooOol01Woo00<007ooOol017oo10005Goo00<007oo00000Woo00<0
07ooOol00goo00<007ooOol047oo00<007oo00001goo00<007ooOol017oo10004Goo00L007ooOomo
o`00Ool00003Ool4000DOol00`00Ool00007Ool00`00Oomoo`04Ool4000COol40003Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool000]oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Oomoo`0KOol00`00Oomoo`0COol01@00Oomoogoo00000goo00<007ooOol00Woo00<007oo
Ool017oo00<007ooOol05goo0P000Woo00<007ooOol00goo00<007ooOol04Goo0P000Woo00<007oo
Ool00Woo00<007ooOol017oo00<007ooOol04Goo00<007ooOol00goo0P000goo00<007ooOol05Woo
0P000Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol057oo00<007ooOol017oo00<007oo
Ool00goo00<007ooOol00Woo000;Ool01@00Oomoogoo000017oo00@007ooOol000Qoo`03001oogoo
01Yoo`03001oogoo01=oo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00
Oomoo`0FOol20003Ool01@00Oomoogoo000057oo0P000goo00@007ooOol000Qoo`03001oogoo00mo
o`03001oogoo00Aoo`8000Aoo`03001oogoo01Eoo`8000=oo`03001oogoo009oo`03001oogoo00Ao
o`03001oogoo01Aoo`03001oogoo00Aoo`05001oogooOol00005Ool000aoo`<000Ioo`8000Uoo`D0
01Qoo`03001oogoo01Aoo`<000Eoo`H000Ioo`D001Eoo`03001oogoo009oo`<001Ioo`03001oogoo
009oo`8000Uoo`D000]oo`8000Qoo`03001oogoo009oo`D001Aoo`04001oogooOol60006Ool5000B
Ool50003Ool30006Ool003eoo`80081oo`03001oogoo05ioo`00?Goo00<007ooOol0OWoo00<007oo
Ool0Ggoo000mOol00`00Oomoo`1lOol2001ROol003eoo`03001oogoo07]oo`03001oogoo069oo`00
?Goo00<007ooOol0NWoo00<007ooOol0Hgoo003o000M0004Ool000=oo`03001oogoo00Aoo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo00Qoo`006Goo00<007ooOol08Goo00<007ooOol08Goo
00<007ooOol08Goo00<007ooOol08Goo00<007ooOol02Woo00<007ooOol057oo00<007ooOol08Goo
00<007ooOol08Goo00<007ooOol027oo000mOol00`00Oomoo`1dOol2001ZOol003eoo`03001oogoo
07=oo`03001oogoo06Yoo`00?Goo0P00Lgoo00<007ooOol0Jgoo000mOol00`00Oomoo`1`Ool2001^
Ool003eoo`03001oogoo06moo`03001oogoo06ioo`00?Goo00<007ooOol0KWoo00<007ooOol0Kgoo
000mOol00`00Oomoo`1/Ool2001bOol003eoo`8006aoo`03001oogoo079oo`00?Goo00<007ooOol0
JWoo00<007ooOol0Lgoo000mOol00`00Oomoo`1XOol2001fOol003eoo`03001oogoo06Moo`03001o
ogoo07Ioo`00?Goo0P00Igoo00<007ooOol0Mgoo000mOol00`00Oomoo`1TOol2001jOol003eoo`03
001oogoo06=oo`03001oogoo07Yoo`00?Goo00<007ooOol0HWoo00<007ooOol0Ngoo000mOol00`00
Oomoo`1POol2001nOol003eoo`80061oo`03001oogoo07ioo`00?Goo00<007ooOol0GWoo00<007oo
Ool0Ogoo000YOol30005Ool30009Ool00`00Oomoo`1LOol20022Ool002Qoo`05001oogooOol00003
Ool01@00Oomoogoo000027oo00<007ooOol0Fgoo00<007ooOol0PWoo000WOol00`00Oomoo`03Ool0
0`00Ool00005Ool00`00Oomoo`05Ool00`00Oomoo`1IOol20025Ool002Moo`03001oogoo00=oo`03
001oo`0000Eoo`03001oogoo00Eoo`<005Qoo`03001oogoo08Eoo`007Goo20000goo00D007ooOomo
o`00009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo05Ioo`8008Qoo`00:Goo0`000goo
00<007ooOol00goo00<007ooOol01Goo00<007ooOol0EGoo00<007ooOol0R7oo000XOol01@00Oomo
ogoo00000Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol0Dgoo0P00Rgoo000WOol00`00
Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`05Ool00`00Oomoo`1BOol00`00Oomoo`2;Ool002Mo
o`03001oogoo00=oo`03001oo`0000Eoo`03001oogoo00Eoo`80055oo`8008ioo`00:7oo00D007oo
Oomoo`0000=oo`05001oogooOol00008Ool00`00Oomoo`1?Ool00`00Oomoo`2>Ool002Uoo`<000Eo
o`<000Uoo`03001oogoo04ioo`03001oogoo08moo`00?Goo00<007ooOol0C7oo0P00TWoo000mOol0
0`00Oomoo`1;Ool00`00Oomoo`2BOol003eoo`8004]oo`03001oogoo09=oo`00?Goo00<007ooOol0
B7oo0P00UWoo000mOol00`00Oomoo`17Ool00`00Oomoo`2FOol003eoo`03001oogoo04Ioo`03001o
ogoo09Moo`00?Goo0P00AGoo0P00VWoo000mOol00`00Oomoo`13Ool00`00Oomoo`2JOol003eoo`03
001oogoo045oo`8009eoo`00?Goo00<007ooOol0@7oo00<007ooOol0WGoo000mOol00`00Oomoo`0n
Ool2002POol003eoo`8003ioo`03001oogoo0:1oo`00?Goo00<007ooOol0>goo0P00Xgoo000ZOol0
0`00Oomoo`04Ool30009Ool00`00Oomoo`0jOol00`00Oomoo`2SOol002Yoo`03001oogoo00=oo`05
001oogooOol00008Ool00`00Oomoo`0hOol2002VOol002Yoo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo00Eoo`03001oogoo03Ioo`800:Qoo`00:goo00D007ooOomoo`0000Eoo`03001oogoo
00Eoo`<003Eoo`03001oogoo0:Qoo`007Goo20001Woo00D007ooOomoo`0000Eoo`03001oogoo00Eo
o`03001oogoo03=oo`800:]oo`00:goo00D007ooOomoo`0000Eoo`03001oogoo00Eoo`03001oogoo
035oo`800:eoo`00;7oo00@007ooOol000Eoo`03001oogoo00Eoo`03001oogoo031oo`03001oogoo
0:eoo`00;7oo00@007ooOol000Eoo`03001oogoo00Eoo`03001oogoo02ioo`800;1oo`009goo00<0
07ooOol00Woo00@007ooOol000Eoo`03001oogoo00Eoo`8002eoo`800;9oo`00:7oo00<007ooOol0
0Woo00@007ooOol000=oo`03001oogoo00Ioo`03001oogoo02Yoo`800;Aoo`00:7oo1P000goo0`00
2Goo00<007ooOol0:Goo00<007ooOol0]7oo000mOol00`00Oomoo`0WOol2002gOol003eoo`03001o
ogoo02Eoo`800;Uoo`00?Goo0P009Goo00<007ooOol0^Goo000mOol00`00Oomoo`0ROol2002lOol0
03eoo`03001oogoo021oo`800;ioo`00?Goo00<007ooOol07Woo0P00`7oo000mOol2000NOol00`00
Oomoo`30Ool003eoo`03001oogoo01]oo`800<=oo`00?Goo00<007ooOol06Goo0P00aGoo000mOol0
0`00Oomoo`0HOol00`00Oomoo`35Ool003eoo`03001oogoo01Ioo`800<Qoo`00?Goo0P005Goo0P00
bWoo000mOol00`00Oomoo`0BOol2003<Ool002Uoo`<000Eoo`<000Uoo`03001oogoo011oo`800<io
o`00:7oo00D007ooOomoo`0000=oo`05001oogooOol00008Ool00`00Oomoo`0>Ool2003@Ool002Mo
o`03001oogoo00=oo`03001oo`0000Eoo`03001oogoo00Eoo`03001oogoo00aoo`800=9oo`009goo
00<007ooOol00goo00<007oo00001Goo00<007ooOol01Goo0`002Woo0P00e7oo000MOol80002Ool0
0`00Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`05Ool00`00Oomoo`08Ool2003FOol002Moo`80
00=oo`04001oogoo0005Ool00`00Oomoo`05Ool00`00Oomoo`06Ool2003HOol002Moo`03001oo`00
008000=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Aoo`800=Yoo`00:7oo00<007oo
Ool017oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo0P00g7oo000XOol00`00Oomo
o`04Ool00`00Oomoo`03Ool00`00Oomoo`05Ool200000goo0000003NOol002Uoo`8000Eoo`05001o
ogooOol00008Ool3003POol002]oo`<000=oo`<000Qoo`800>9oo`00>Goo0`0000=oo`00Ool0hGoo
0006Ool00`00Oomoo`0^Ool20004Ool00`00Oomoo`3POol000Ioo`03001oogoo02aoo`8000Ioo`80
0>5oo`001goo00<007ooOol0:7oo0`0027oo00<007ooOol0h7oo0007Ool00`00Oomoo`0VOol2000;
Ool00`00Oomoo`3POol000Moo`03001oogoo02=oo`<000eoo`03001oogoo0>1oo`001goo00<007oo
Ool087oo0`0047oo0P00hGoo0007Ool2000NOol3000COol00`00Oomoo`3POol000Qoo`03001oogoo
01Moo`D001Ioo`03001oogoo0>1oo`002Goo0`004Woo10006goo00<007ooOol0h7oo000<Ool3000:
Ool5000OOol00`00Oomoo`3POol000moo`X002Aoo`800>5oo`00?Goo00<007ooOol0h7oo000mOol0
0`00Oomoo`3POol003eoo`03001oogoo0>1oo`00?Goo00<007ooOol0h7oo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {30.7395, -123.941, \
0.0695332, 0.416882}}]
}, Open  ]],

Cell[TextData[{
  "Note the constraint that ",
  Cell[BoxData[
      \(TraditionalForm\`Max[n] < n\&_\/\(1 - c\)\)]]
}], "Text"],

Cell["\<\
If numbers which are lkiekely to be produced by a distribution with \
c<<1 are used, the deiscrepancy is slight:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NegativeBinomialMLE[{10, 11, 12, 13}, {None, 0.1}]\)], "Input",
  CellLabel->"In[239]:="],

Cell[BoxData[
    \({\(-6.050666367017494`\), {11.466314165314177`, 0.1`}}\)], "Output",
  CellLabel->"Out[239]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMinimum[\(-NegativeBinomialLogLikelihood[{10, 11, 12, 13}, {nb, 
            0.1}]\), {nb, {11.2, 11.7}}]\)], "Input",
  CellLabel->"In[241]:="],

Cell[BoxData[
    \({6.045338691033197`, {nb \[Rule] 11.524839882387106`}}\)], "Output",
  CellLabel->"Out[241]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
        NegativeBinomialLogLikelihood[{10, 11, 12, 13}, {nb, 0.1}]\ , {nb, 
          10, 15}];\)\)], "Input",
  CellLabel->"In[240]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.42628 0.226831 0.897278 0.0486258 [
[.2957 .49577 -10 -18 ]
[.2957 .49577 10 0 ]
[.52253 .49577 -10 -18 ]
[.52253 .49577 10 0 ]
[.74936 .49577 -10 -18 ]
[.74936 .49577 10 0 ]
[.97619 .49577 -10 -18 ]
[.97619 .49577 10 0 ]
[.05637 .02201 -31.0625 -9 ]
[.05637 .02201 0 9 ]
[.05637 .11927 -31.0625 -9 ]
[.05637 .11927 0 9 ]
[.05637 .21652 -31.0625 -9 ]
[.05637 .21652 0 9 ]
[.05637 .31377 -31.0625 -9 ]
[.05637 .31377 0 9 ]
[.05637 .41102 -31.0625 -9 ]
[.05637 .41102 0 9 ]
[.05637 .60552 -23.0625 -9 ]
[.05637 .60552 0 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2957 .50827 m
.2957 .51452 L
s
gsave
.2957 .49577 -71 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.52253 .50827 m
.52253 .51452 L
s
gsave
.52253 .49577 -71 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
1.000 setlinewidth
grestore
.74936 .50827 m
.74936 .51452 L
s
gsave
.74936 .49577 -71 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
1.000 setlinewidth
grestore
.97619 .50827 m
.97619 .51452 L
s
gsave
.97619 .49577 -71 -22 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.125 Mabswid
.11423 .50827 m
.11423 .51202 L
s
.1596 .50827 m
.1596 .51202 L
s
.20496 .50827 m
.20496 .51202 L
s
.25033 .50827 m
.25033 .51202 L
s
.34106 .50827 m
.34106 .51202 L
s
.38643 .50827 m
.38643 .51202 L
s
.4318 .50827 m
.4318 .51202 L
s
.47716 .50827 m
.47716 .51202 L
s
.56789 .50827 m
.56789 .51202 L
s
.61326 .50827 m
.61326 .51202 L
s
.65863 .50827 m
.65863 .51202 L
s
.70399 .50827 m
.70399 .51202 L
s
.79473 .50827 m
.79473 .51202 L
s
.84009 .50827 m
.84009 .51202 L
s
.88546 .50827 m
.88546 .51202 L
s
.93082 .50827 m
.93082 .51202 L
s
.0235 .50827 m
.0235 .51202 L
s
.25 Mabswid
0 .50827 m
1 .50827 L
s
.06887 .02201 m
.07512 .02201 L
s
gsave
.05637 .02201 -92.0625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18) show
1.000 setlinewidth
grestore
.06887 .11927 m
.07512 .11927 L
s
gsave
.05637 .11927 -92.0625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
1.000 setlinewidth
grestore
.06887 .21652 m
.07512 .21652 L
s
gsave
.05637 .21652 -92.0625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
1.000 setlinewidth
grestore
.06887 .31377 m
.07512 .31377 L
s
gsave
.05637 .31377 -92.0625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.06887 .41102 m
.07512 .41102 L
s
gsave
.05637 .41102 -92.0625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.06887 .60552 m
.07512 .60552 L
s
gsave
.05637 .60552 -84.0625 -13 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 26 translate 1 -1 scale
63.000 17.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.062 17.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.06887 .04633 m
.07262 .04633 L
s
.06887 .07064 m
.07262 .07064 L
s
.06887 .09495 m
.07262 .09495 L
s
.06887 .14358 m
.07262 .14358 L
s
.06887 .16789 m
.07262 .16789 L
s
.06887 .1922 m
.07262 .1922 L
s
.06887 .24083 m
.07262 .24083 L
s
.06887 .26514 m
.07262 .26514 L
s
.06887 .28946 m
.07262 .28946 L
s
.06887 .33808 m
.07262 .33808 L
s
.06887 .36239 m
.07262 .36239 L
s
.06887 .38671 m
.07262 .38671 L
s
.06887 .43533 m
.07262 .43533 L
s
.06887 .45965 m
.07262 .45965 L
s
.06887 .48396 m
.07262 .48396 L
s
.06887 .53259 m
.07262 .53259 L
s
.06887 .5569 m
.07262 .5569 L
s
.06887 .58121 m
.07262 .58121 L
s
.25 Mabswid
.06887 0 m
.06887 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .32202 m
.02524 .40609 L
.0265 .43254 L
.02787 .45108 L
.02932 .46504 L
.03067 .47529 L
.03364 .49237 L
.03689 .50605 L
.0428 .52405 L
.04856 .53681 L
.05391 .54617 L
.06601 .56198 L
.07277 .56868 L
.07891 .57383 L
.09005 .58146 L
.10183 .58767 L
.11474 .59285 L
.12662 .59643 L
.13791 .59899 L
.14412 .60009 L
.15001 .60097 L
.15548 .60164 L
.16143 .60223 L
.16683 .60264 L
.17184 .60293 L
.17472 .60306 L
.17736 .60316 L
.18025 .60323 L
.18171 .60326 L
.1833 .60329 L
.18472 .6033 L
.186 .60331 L
.18748 .60332 L
.18888 .60332 L
.19017 .60331 L
.19137 .6033 L
.19268 .60329 L
.19407 .60327 L
.19698 .60321 L
.2001 .60312 L
.20575 .6029 L
.21246 .60255 L
.2186 .60215 L
.22429 .60171 L
.22593 .60157 L
.22747 .60143 L
.22886 .60112 L
.23035 .60074 L
.24125 .5978 L
.26595 .58994 L
Mistroke
.31484 .5705 L
.36193 .54842 L
.40721 .52532 L
.45541 .49625 L
.50181 .46267 L
.55113 .42504 L
.59864 .38782 L
.64435 .35081 L
.69297 .3057 L
.7398 .2609 L
.78481 .21723 L
.83275 .17069 L
.87889 .12197 L
.92794 .06821 L
.97519 .01583 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[240]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo000ROol00`00Oomoo`3kOol0029oo`03001oogoo0?]oo`008Woo00<0
07ooOol0ngoo000>Ool50004Ool30008Ool00`00Oomoo`3kOol0011oo`03001oogoo00=oo`05001o
ogooOol00007Ool00`00Oomoo`3_Ool2000:Ool0011oo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo0>moo`03001oogoo00Uoo`0047oo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol017oo0`00kWoo00<007ooOol02Woo0003Ool80005Ool00`00Oomoo`03Ool01@00
Oomoogoo00001goo00<007ooOol0kGoo00<007ooOol02goo000@Ool00`00Oomoo`04Ool30008Ool0
0`00Oomoo`3/Ool00`00Oomoo`0<Ool0011oo`03001oogoo00=oo`05001oogooOol00007Ool00`00
Oomoo`3[Ool00`00Oomoo`0=Ool0011oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Ao
o`03001oogoo0>Yoo`03001oogoo00ioo`0047oo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool017oo00<007ooOol0jGoo00<007ooOol03goo000>Ool30005Ool01@00Oomoogoo00001goo00<0
07ooOol0jGoo00<007ooOol03goo000@Ool00`00Oomoo`04Ool30008Ool2003YOol00`00Oomoo`0@
Ool0029oo`03001oogoo0>Moo`03001oogoo015oo`008Woo00<007ooOol0iWoo00<007ooOol04Woo
000ROol00`00Oomoo`3UOol00`00Oomoo`0COol0029oo`03001oogoo0>Aoo`03001oogoo01Aoo`00
8Woo00<007ooOol0hgoo00<007ooOol05Goo000ROol2003TOol00`00Oomoo`0EOol0029oo`03001o
ogoo0>9oo`03001oogoo01Ioo`008Woo00<007ooOol0hGoo00<007ooOol05goo000ROol00`00Oomo
o`3POol00`00Oomoo`0HOol0029oo`03001oogoo0=moo`03001oogoo01Uoo`008Woo00<007ooOol0
gWoo00<007ooOol06Woo000ROol00`00Oomoo`3MOol00`00Oomoo`0KOol0029oo`800=eoo`03001o
ogoo01aoo`008Woo00<007ooOol0fgoo00<007ooOol07Goo000ROol00`00Oomoo`3JOol00`00Oomo
o`0NOol000ioo`D000Aoo`<000Qoo`03001oogoo0=Uoo`03001oogoo01moo`0047oo00<007ooOol0
0goo00D007ooOomoo`0000Moo`03001oogoo0=Qoo`03001oogoo021oo`0047oo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol017oo00<007ooOol0egoo00<007ooOol08Goo000@Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool3003FOol00`00Oomoo`0ROol000=oo`P000Eoo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo0=Eoo`03001oogoo02=oo`00
47oo00<007ooOol00Woo0P000goo00<007ooOol01Goo00<007ooOol0eGoo00<007ooOol08goo000@
Ool00`00Oomoo`02Ool00`00Ool000020008Ool00`00Oomoo`3DOol00`00Oomoo`0TOol0011oo`03
001oogoo00=oo`03001oogoo00Uoo`03001oogoo0==oo`03001oogoo02Eoo`0047oo00<007ooOol0
0goo00<007ooOol02Goo00<007ooOol0dWoo00<007ooOol09Woo000>Ool30006Ool20009Ool00`00
Oomoo`3AOol00`00Oomoo`0WOol0011oo`03001oogoo00Ioo`<000Ioo`800=5oo`03001oogoo02Qo
o`008Woo00<007ooOol0cgoo00<007ooOol0:Goo000ROol00`00Oomoo`3>Ool00`00Oomoo`0ZOol0
029oo`03001oogoo0<eoo`03001oogoo02]oo`008Woo00<007ooOol0c7oo00<007ooOol0;7oo000R
Ool00`00Oomoo`3;Ool00`00Oomoo`0]Ool0029oo`800<]oo`03001oogoo02ioo`008Woo00<007oo
Ool0b7oo0P00<Goo000ROol00`00Oomoo`37Ool00`00Oomoo`0aOol0029oo`03001oogoo0<Ioo`03
001oogoo039oo`008Woo00<007ooOol0aGoo00<007ooOol0<goo000ROol00`00Oomoo`34Ool00`00
Oomoo`0dOol0029oo`03001oogoo0<=oo`03001oogoo03Eoo`008Woo0P00`goo00<007ooOol0=Woo
000ROol00`00Oomoo`31Ool00`00Oomoo`0gOol0029oo`03001oogoo0<1oo`03001oogoo03Qoo`00
3Woo1@001goo00<007ooOol01Goo00<007ooOol0_goo00<007ooOol0>Goo000@Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool00`00Oomoo`2nOol00`00Oomoo`0jOol0011oo`03001oogoo00Moo`03001o
ogoo00Eoo`03001oogoo0;eoo`03001oogoo03]oo`0047oo00<007ooOol00Woo20001Goo0`00_7oo
00<007ooOol0?7oo0003Ool80005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool0
0`00Oomoo`2kOol00`00Oomoo`0mOol0011oo`03001oogoo00=oo`05001oogooOol00007Ool00`00
Oomoo`2jOol00`00Oomoo`0nOol0011oo`03001oogoo00Aoo`04001oogoo0007Ool00`00Oomoo`2i
Ool00`00Oomoo`0oOol0011oo`03001oogoo00Eoo`03001oo`0000Moo`03001oogoo0;Qoo`03001o
ogoo041oo`0047oo00<007ooOol01Woo0P001goo00<007ooOol0]goo00<007ooOol0@Goo000>Ool3
0008Ool20007Ool00`00Oomoo`2fOol00`00Oomoo`12Ool0011oo`03001oogoo00Moo`03001oogoo
00Eoo`800;Ioo`03001oogoo04=oo`008Woo00<007ooOol0]7oo00<007ooOol0A7oo000ROol00`00
Oomoo`2cOol00`00Oomoo`15Ool0029oo`03001oogoo0;9oo`03001oogoo04Ioo`008Woo00<007oo
Ool0/Goo00<007ooOol0Agoo000ROol00`00Oomoo`2`Ool00`00Oomoo`18Ool0029oo`800;1oo`03
001oogoo04Uoo`008Woo00<007ooOol0[Woo00<007ooOol0BWoo000ROol00`00Oomoo`2]Ool00`00
Oomoo`1;Ool0029oo`03001oogoo0:aoo`03001oogoo04aoo`008Woo00<007ooOol0Zgoo00<007oo
Ool0CGoo000ROol00`00Oomoo`2ZOol00`00Oomoo`1>Ool0029oo`03001oogoo0:Uoo`03001oogoo
04moo`008Woo0P00ZGoo00<007ooOol0D7oo000ROol00`00Oomoo`2WOol00`00Oomoo`1AOol0029o
o`03001oogoo0:Ioo`03001oogoo059oo`003Woo1@000Woo1P001goo00<007ooOol0YGoo00<007oo
Ool0Dgoo000@Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`2SOol2
001FOol0011oo`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo0:9oo`03001oogoo05Ioo`00
47oo00<007ooOol017oo00<007ooOol027oo0`00XGoo00<007ooOol0Egoo0003Ool80005Ool00`00
Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`2POol00`00Oomoo`1HOol0011oo`03001oogoo00=o
o`04001oogoo0008Ool00`00Oomoo`2OOol00`00Oomoo`1IOol0011oo`03001oogoo00=oo`05001o
ogooOol00007Ool00`00Oomoo`2NOol00`00Oomoo`1JOol0011oo`03001oogoo00=oo`05001oogoo
Ool00007Ool00`00Oomoo`2MOol00`00Oomoo`1KOol0011oo`03001oogoo009oo`8000=oo`03001o
ogoo00Eoo`03001oogoo09aoo`03001oogoo05aoo`003Woo0`001Goo00@007ooOol000Qoo`03001o
ogoo09]oo`03001oogoo05eoo`0047oo00<007ooOol00goo0`002Goo0P00Vgoo00<007ooOol0GWoo
000FOol00`00Oomoo`09Ool00`00Oomoo`2IOol00`00Oomoo`1OOol001Ioo`03001oogoo00Uoo`03
001oogoo09Qoo`03001oogoo061oo`005Woo00<007ooOol02Goo00<007ooOol0UWoo0P00Hgoo000F
Ool00`00Oomoo`09Ool00`00Oomoo`2EOol00`00Oomoo`1SOol001Ioo`03001oogoo00Uoo`03001o
ogoo09Aoo`03001oogoo06Aoo`005Woo00<007ooOol02Goo0P00U7oo00<007ooOol0IGoo000FOol0
0`00Oomoo`09Ool00`00Oomoo`2BOol00`00Oomoo`1VOol001Ioo`03001oogoo00Uoo`03001oogoo
091oo`8006Uoo`005Woo00<007ooOol02Goo00<007ooOol0Sgoo00<007ooOol0JGoo000FOol00`00
Oomoo`09Ool00`00Oomoo`2>Ool00`00Oomoo`1ZOol001Ioo`03001oogoo00Uoo`03001oogoo08eo
o`03001oogoo06]oo`005Woo00<007ooOol02Goo00<007ooOol0S7oo00<007ooOol0K7oo000FOol0
0`00Oomoo`09Ool2002;Ool2001_Ool001Ioo`03001oogoo00Uoo`03001oogoo08Uoo`03001oogoo
06moo`005Woo00<007ooOol02Goo00<007ooOol0R7oo00<007ooOol0L7oo000>Ool50003Ool40008
Ool00`00Oomoo`26Ool2001cOol0011oo`03001oogoo00=oo`05001oogooOol00007Ool00`00Oomo
o`25Ool00`00Oomoo`1cOol0011oo`03001oogoo009oo`8000Aoo`03001oogoo00Aoo`03001oogoo
08Aoo`03001oogoo07Aoo`0047oo00<007ooOol00Woo0P0017oo00<007ooOol017oo0`00Pgoo00<0
07ooOol0MGoo0003Ool80005Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`04Ool00`00Oomoo`21
Ool2001hOol0011oo`03001oogoo009oo`8000Aoo`03001oogoo00Aoo`03001oogoo081oo`03001o
ogoo07Qoo`0047oo00<007ooOol00Woo00<007oo00000goo00<007ooOol017oo00<007ooOol0Ogoo
00<007ooOol0NGoo000@Ool00`00Oomoo`02Ool00`00Ool00003Ool00`00Oomoo`04Ool00`00Oomo
o`1mOol2001lOol0011oo`03001oogoo009oo`03001oo`0000=oo`03001oogoo00Aoo`03001oogoo
07aoo`03001oogoo07aoo`003Woo0`001Goo0P000Woo00<007ooOol01Goo00<007ooOol0Ngoo00<0
07ooOol0OGoo000@Ool00`00Oomoo`04Ool30008Ool2001jOol20020Ool001Moo`03001oogoo00Qo
o`03001oogoo07Qoo`03001oogoo081oo`005goo00<007ooOol027oo00<007ooOol0Mgoo00<007oo
Ool0PGoo000GOol00`00Oomoo`08Ool00`00Oomoo`1fOol00`00Oomoo`22Ool001Moo`03001oogoo
00Qoo`03001oogoo03=oo`D0009oo`H002moo`/0039oo`D000Moo`03001oogoo02ioo`D0009oo`D0
00Ioo`005goo00<007ooOol027oo00<007ooOol0=Goo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol0;Woo00<007oo00001Woo00<007ooOol0<Goo00<007ooOol01goo00<007ooOol0<7oo00<0
07ooOol01goo00<007ooOol00goo000GOol00`00Oomoo`08Ool2000fOol00`00Oomoo`03Ool00`00
Oomoo`0cOol20008Ool00`00Oomoo`0`Ool00`00Oomoo`07Ool00`00Oomoo`0`Ool00`00Oomoo`08
Ool00`00Oomoo`02Ool001Moo`03001oogoo00Qoo`03001oogoo03Eoo`03001oogoo00Aoo`03001o
ogoo035oo`8000Uoo`03001oogoo031oo`03001oogoo009oo`P0031oo`03001oogoo00Qoo`03001o
ogoo009oo`005goo00<007ooOol027oo00<007ooOol0=Goo00<007ooOol01Goo00<007ooOol0;goo
00<007oo00002Goo00<007ooOol0<7oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0<7oo
00<007ooOol027oo00<007ooOol00Woo000HOol00`00Oomoo`07Ool00`00Oomoo`0eOol00`00Oomo
o`06Ool00`00Oomoo`0/Ool20002Ool00`00Oomoo`04Ool3000cOol00`00Oomoo`03Ool01@00Oomo
ogoo0000<Woo00<007ooOol027oo00<007ooOol00Woo000HOol00`00Oomoo`07Ool00`00Oomoo`0e
Ool00`00Oomoo`07Ool00`00Oomoo`0ZOol00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`0b
Ool00`00Oomoo`04Ool01000Oomoo`00<Woo00<007ooOol01goo00<007ooOol00goo000HOol00`00
Oomoo`07Ool00`00Oomoo`0eOol00`00Oomoo`07Ool00`00Oomoo`0XOol20005Ool00`00Oomoo`06
Ool00`00Oomoo`0aOol00`00Oomoo`05Ool00`00Ool0000bOol00`00Oomoo`03Ool40006Ool001Qo
o`03001oogoo00Moo`03001oogoo03Eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Mo
o`03001oogoo00Eoo`03001oogoo009oo`05001oogooOol0000cOol00`00Oomoo`06Ool2000bOol0
0`00Oomoo`03Ool00`00Oomoo`07Ool001Qoo`03001oogoo00Moo`8003Aoo`<000Eoo`04001oogoo
000YOol00`00Oomoo`04Ool30004Ool01@00Oomoogoo0000<Goo0`0027oo0P00<7oo0`001Woo00<0
07ooOol01Woo000HOol00`00Oomoo`07Ool00`00Oomoo`0eOol00`00Oomoo`04Ool2000XOol20009
Ool00`00Oomoo`03Ool3000dOol00`00Oomoo`07Ool00`00Oomoo`0`Ool00`00Oomoo`04Ool50004
Ool001Qoo`03001oogoo00Moo`03001oogoo06Eoo`03001oogoo09=oo`0067oo00<007ooOol01goo
00<007ooOol0Hgoo0P00UWoo000IOol00`00Oomoo`06Ool00`00Oomoo`1ROol00`00Oomoo`2FOol0
01Uoo`03001oogoo00Ioo`03001oogoo061oo`8009Uoo`003gooo`003P0017oo000FOol01@00Oomo
ogoo00001goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo0P002goo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
2Woo00<007ooOol027oo000JOol00`00Oomoo`05Ool00`00Oomoo`0jOol00`00Oomoo`0NOol2000I
Ool00`00Oomoo`0jOol00`00Oomoo`0jOol00`00Oomoo`08Ool001Yoo`03001oogoo00Eoo`03001o
ogoo05Uoo`800:1oo`006goo00<007ooOol017oo00<007ooOol0F7oo00<007ooOol0X7oo000KOol0
0`00Oomoo`04Ool00`00Oomoo`1FOol2002SOol001]oo`03001oogoo00Aoo`03001oogoo05Aoo`80
0:Eoo`0077oo00<007ooOol00goo0P00Dgoo0P00Ygoo000LOol00`00Oomoo`03Ool00`00Oomoo`1@
Ool2002YOol001eoo`03001oogoo009oo`03001oogoo04ioo`800:]oo`007Woo00D007ooOomoo`00
04ioo`800:eoo`007Woo00D007ooOomoo`0004aoo`800:moo`007goo00@007ooOol004Yoo`800;5o
o`0087oo00@007oo000004Moo`800;=oo`008Goo0P00AWoo0P00]Goo000ROol00`00Oomoo`12Ool2
002gOol0029oo`80045oo`800;Uoo`008Woo00<007oo0000?Woo0P00^goo000ROol00`00Oomoo`02
000iOol3002mOol0029oo`03001oogoo009oo`03001oogoo03=oo`<00<1oo`008Woo0P0017oo0`00
<7oo0P00`goo000ROol00`00Oomoo`06Ool2000[Ool30035Ool0029oo`03001oogoo00Qoo`03001o
ogoo02Eoo`<00<Qoo`005goo0`0027oo00<007ooOol02Goo0`008Goo0`00bgoo000FOol01@00Oomo
ogoo00001goo00<007ooOol037oo1@006Goo0`00cWoo000EOol00`00Oomoo`03Ool00`00Oomoo`04
Ool00`00Oomoo`0AOolI003AOol001Eoo`03001oogoo00=oo`03001oogoo00Aoo`<00?]oo`002goo
20000Woo00<007ooOol00goo00<007ooOol017oo00<007ooOol0ngoo000EOol20003Ool00`00Oomo
o`05Ool00`00Oomoo`3kOol001Eoo`03001oo`00008000Qoo`03001oogoo0?]oo`005Woo00<007oo
Ool0ogoo27oo000FOol00`00Oomoo`3oOol8Ool001Moo`800?moo`Qoo`006Goo0`00ogoo1Goo003o
OolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {10.4327, -18.8047, \
0.0164885, 0.0769158}}]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{678, 620},
WindowMargins->{{137, Automatic}, {Automatic, 41}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "NegativeBinomialLogLikelihood"->{
    Cell[1797, 53, 524, 12, 52, "DefinitionBox",
      CellTags->"NegativeBinomialLogLikelihood"]},
  "Compiled"->{
    Cell[4925, 164, 481, 11, 50, "DefinitionBox",
      CellTags->"Compiled"]},
  "Normalisation"->{
    Cell[7148, 243, 346, 9, 38, "DefinitionBox",
      CellTags->"Normalisation"]},
  "NegativeBinomialMLE"->{
    Cell[17267, 571, 744, 16, 94, "DefinitionBox",
      CellTags->"NegativeBinomialMLE"]},
  "Timings"->{
    Cell[20177, 684, 101, 2, 24, "SubsubsectionIcon",
      CellTags->"Timings"]},
  "c<1"->{
    Cell[27328, 872, 121, 4, 20, "SubsubsectionIcon",
      CellTags->"c<1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"NegativeBinomialLogLikelihood", 79916, 2688},
  {"Compiled", 80032, 2691},
  {"Normalisation", 80133, 2694},
  {"NegativeBinomialMLE", 80244, 2697},
  {"Timings", 80351, 2700},
  {"c<1", 80445, 2703}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 55, 0, 36, "SubsectionIcon"],
Cell[1797, 53, 524, 12, 52, "DefinitionBox",
  CellTags->"NegativeBinomialLogLikelihood"],
Cell[2324, 67, 46, 0, 28, "MathCaption"],
Cell[2373, 69, 91, 2, 27, "Input"],
Cell[2467, 73, 138, 3, 22, "Text"],
Cell[2608, 78, 262, 9, 22, "Text"],
Cell[2873, 89, 153, 2, 50, "NumberedEquation"],
Cell[3029, 93, 438, 14, 36, "Text"],
Cell[3470, 109, 111, 2, 45, "NumberedEquation"],
Cell[3584, 113, 149, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3758, 120, 111, 2, 27, "Input"],
Cell[3872, 124, 82, 2, 20, "Output"]
}, Open  ]],
Cell[3969, 129, 57, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4051, 133, 141, 4, 27, "Input"],
Cell[4195, 139, 77, 2, 20, "Output"]
}, Open  ]],
Cell[4287, 144, 217, 6, 24, "Text"],
Cell[4507, 152, 102, 2, 45, "NumberedEquation"],
Cell[4612, 156, 310, 6, 50, "Text"],
Cell[4925, 164, 481, 11, 50, "DefinitionBox",
  CellTags->"Compiled"],
Cell[5409, 177, 60, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[5494, 181, 294, 7, 42, "Input"],
Cell[5791, 190, 115, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5943, 197, 148, 4, 27, "Input"],
Cell[6094, 203, 114, 2, 20, "Output"]
}, Open  ]],
Cell[6223, 208, 175, 4, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[6423, 216, 270, 7, 42, "Input"],
Cell[6696, 225, 113, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6846, 232, 171, 4, 27, "Input"],
Cell[7020, 238, 113, 2, 20, "Output"]
}, Open  ]],
Cell[7148, 243, 346, 9, 38, "DefinitionBox",
  CellTags->"Normalisation"],
Cell[7497, 254, 408, 11, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[7930, 269, 103, 2, 27, "Input"],
Cell[8036, 273, 59, 2, 20, "Output"]
}, Open  ]],
Cell[8110, 278, 233, 8, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[8368, 290, 281, 6, 59, "Input"],
Cell[8652, 298, 129, 3, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8818, 306, 280, 6, 59, "Input"],
Cell[9101, 314, 129, 3, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9267, 322, 281, 6, 59, "Input"],
Cell[9551, 330, 130, 3, 20, "Output"]
}, Open  ]],
Cell[9696, 336, 44, 0, 22, "Text"],
Cell[9743, 338, 770, 18, 84, "DefinitionBox"],
Cell[10516, 358, 149, 3, 22, "Text"],
Cell[10668, 363, 65, 2, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[10758, 369, 139, 3, 27, "Input"],
Cell[10900, 374, 324, 6, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11261, 385, 180, 4, 27, "Input"],
Cell[11444, 391, 341, 6, 33, "Output"]
}, Open  ]],
Cell[11800, 400, 97, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[11922, 407, 226, 5, 42, "Input"],
Cell[12151, 414, 100, 2, 20, "Output"]
}, Open  ]],
Cell[12266, 419, 168, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[12459, 427, 212, 5, 42, "Input"],
Cell[12674, 434, 224, 4, 20, "Output"]
}, Open  ]],
Cell[12913, 441, 988, 17, 118, "DefinitionBox"],
Cell[13904, 460, 54, 0, 28, "MathCaption"],
Cell[13961, 462, 241, 4, 42, "Input"],
Cell[14205, 468, 108, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[14338, 475, 133, 3, 44, "Input"],
Cell[14474, 480, 189, 3, 20, "Output"]
}, Open  ]],
Cell[14678, 486, 75, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[14778, 490, 235, 5, 27, "Input"],
Cell[15016, 497, 209, 4, 20, "Output"]
}, Open  ]],
Cell[15240, 504, 97, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[15362, 511, 294, 7, 42, "Input"],
Cell[15659, 520, 209, 4, 20, "Output"]
}, Open  ]],
Cell[15883, 527, 180, 4, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[16088, 535, 321, 7, 57, "Input"],
Cell[16412, 544, 209, 4, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16658, 553, 383, 9, 57, "Input"],
Cell[17044, 564, 208, 4, 20, "Output"]
}, Open  ]],
Cell[17267, 571, 744, 16, 94, "DefinitionBox",
  CellTags->"NegativeBinomialMLE"],
Cell[18014, 589, 131, 5, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[18170, 598, 96, 2, 27, "Input"],
Cell[18269, 602, 112, 2, 20, "Output"]
}, Open  ]],
Cell[18396, 607, 129, 5, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[18550, 616, 112, 2, 27, "Input"],
Cell[18665, 620, 99, 2, 20, "Output"]
}, Open  ]],
Cell[18779, 625, 211, 6, 22, "Text"],
Cell[18993, 633, 160, 5, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[19178, 642, 113, 2, 27, "Input"],
Cell[19294, 646, 114, 2, 20, "Output"]
}, Open  ]],
Cell[19423, 651, 82, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[19530, 656, 116, 2, 27, "Input"],
Cell[19649, 660, 104, 2, 20, "Output"]
}, Open  ]],
Cell[19768, 665, 131, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[19924, 672, 129, 3, 27, "Input"],
Cell[20056, 677, 84, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20177, 684, 101, 2, 24, "SubsubsectionIcon",
  CellTags->"Timings"],
Cell[20281, 688, 126, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[20432, 695, 710, 14, 72, "Input"],
Cell[21145, 711, 1153, 27, 67, "Output"]
}, Open  ]],
Cell[22313, 741, 84, 1, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[22422, 746, 813, 16, 87, "Input"],
Cell[23238, 764, 1160, 27, 67, "Output"]
}, Open  ]],
Cell[24413, 794, 131, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[24569, 801, 165, 5, 42, "Input"],
Cell[24737, 808, 608, 9, 72, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25382, 822, 741, 15, 87, "Input"],
Cell[26126, 839, 1153, 27, 67, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[27328, 872, 121, 4, 20, "SubsubsectionIcon",
  CellTags->"c<1"],
Cell[27452, 878, 503, 10, 50, "Text"],
Cell[27958, 890, 287, 5, 36, "Text"],

Cell[CellGroupData[{
Cell[28270, 899, 109, 2, 27, "Input"],
Cell[28382, 903, 215, 6, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28634, 914, 168, 3, 27, "Input"],
Cell[28805, 919, 112, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28954, 926, 164, 4, 27, "Input"],
Cell[29121, 932, 27035, 941, 184, 13741, 772, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[56171, 1876, 128, 4, 37, "Text"],
Cell[56302, 1882, 136, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[56463, 1889, 109, 2, 27, "Input"],
Cell[56575, 1893, 114, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56726, 1900, 168, 3, 27, "Input"],
Cell[56897, 1905, 114, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57048, 1912, 164, 4, 27, "Input"],
Cell[57215, 1918, 21807, 744, 185, 10974, 605, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

