(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     23718,        522]*)
(*NotebookOutlinePosition[     24602,        550]*)
(*  CellTagsIndexPosition[     24558,        546]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Negative Hypergeometric Distribution", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(NegativeHypergeometricDistribution[n, 
              p, \[Alpha]]\), \(\(gives\)\(\ \)\(the\)\(\ \
\)\(distribution\)\(\ \)\(obtained\)\(\ \)\(by\)\(\ \)\(binomial\)\(\ \
\)\(sampling\)\(\ \)\(from\)\(\ \)\(an\)\(\ \)\(underlying\)\(\ \)\(Beta\)\(\ \
\)\(distribution\)\(\ \)\(with\)\(\ \)\(mean\)\(\ \)\(p\)\(\ \)\(and\)\(\ \
\)\(variance\)\(\ \)\(\(\(p\[VeryThinSpace]q\)\/\(\[Alpha] + 
                      1\)\) . \ \ Range\)\(\ \)\(is\)\(\ \)\(0\)\(\ \
\)\(to\)\(\ \)\(\(n\)\(.\)\)\(\ \)\)}
          }], TraditionalForm]],
  CellTags->"NegativeHypergeometricDistribution"]], "DefinitionBox"],

Cell[TextData[{
  "This distribution is a generalisation of HypergeometricDistribution[",
  StyleBox["n,nsucc,ntot",
    FontSlant->"Italic"],
  "], but allows for non-integer parameters.  Note that the parameters ",
  StyleBox["p",
    FontSlant->"Italic"],
  ", \[Alpha], which describe the mean and variance, are given differently \
from HypergeometricDistribution[] and BetaDistribution[]."
}], "Text"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Utilities`RandomNumbers`;\)\)], "Input",
  CellLabel->"In[305]:="],

Cell["\<\
This package automatically loads Statistics`DiscreteDistributions`, \
Statistics`ContinuousDistributions` as well.\
\>", "Text"],

Cell["\<\
All the usual functions that operate on distributions are \
defined:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(?? NegativeHypergeometricDistribution\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \("NegativeHypergeometricDistribution[n,p,\[Alpha]] gives the \
distribution obtained by binomial sampling from an underlying Beta \
distribution with mean p and variance \!\(\(p\[VeryThinSpace]q\)\/\(\[Alpha] \
+ 1\)\)."\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      StyleBox[\(Utilities`RandomNumbers`Private`PDF[
            NegativeHypergeometricDistribution[
              Utilities`RandomNumbers`Private`n_, \ 
              Utilities`RandomNumbers`Private`p_, \ 
              Utilities`RandomNumbers`Private`\[Alpha]_], \ 
            Utilities`RandomNumbers`Private`i_]\  ^:= \ \((Pochhammer[
                    Utilities`RandomNumbers`Private`\[Alpha]*
                      Utilities`RandomNumbers`Private`p, \ 
                    Utilities`RandomNumbers`Private`i]*
                  Pochhammer[
                    Utilities`RandomNumbers`Private`\[Alpha]*\((1\  - \ 
                          Utilities`RandomNumbers`Private`p)\), \ 
                    Utilities`RandomNumbers`Private`n\  - \ 
                      Utilities`RandomNumbers`Private`i])\)/
              Pochhammer[Utilities`RandomNumbers`Private`\[Alpha], \ 
                Utilities`RandomNumbers`Private`n]*
            Binomial[Utilities`RandomNumbers`Private`n, \ 
              Utilities`RandomNumbers`Private`i]\n\ \n
        Utilities`RandomNumbers`Private`CDF[
            NegativeHypergeometricDistribution[
              Utilities`RandomNumbers`Private`n_, \ 
              Utilities`RandomNumbers`Private`p_, \ 
              Utilities`RandomNumbers`Private`\[Alpha]_], \ 
            Utilities`RandomNumbers`Private`i_]\  ^:= \ 
          Module[{Utilities`RandomNumbers`Private`j, \ 
              Utilities`RandomNumbers`Private`t\  = \ 
                Pochhammer[
                    Utilities`RandomNumbers`Private`\[Alpha]*\((1\  - \ 
                          Utilities`RandomNumbers`Private`p)\), \ 
                    Utilities`RandomNumbers`Private`n]/
                  Pochhammer[Utilities`RandomNumbers`Private`\[Alpha], \ 
                    Utilities`RandomNumbers`Private`n]}, \ 
            Utilities`RandomNumbers`Private`t\  + \ 
              Sum[Utilities`RandomNumbers`Private`t\  = \ 
                  Utilities`RandomNumbers`Private`t*\((Utilities`\
RandomNumbers`Private`\[Alpha]*Utilities`RandomNumbers`Private`p\  + \ 
                          Utilities`RandomNumbers`Private`j\  - \ 
                          1)\)/\((Utilities`RandomNumbers`Private`\[Alpha]*\((\
1\  - \ Utilities`RandomNumbers`Private`p)\)\  + \ 
                          Utilities`RandomNumbers`Private`n\  - \ 
                          Utilities`RandomNumbers`Private`j)\)*\((Utilities`\
RandomNumbers`Private`n\  - \ Utilities`RandomNumbers`Private`j\  + \ 1)\)/
                      Utilities`RandomNumbers`Private`j, \ \
{Utilities`RandomNumbers`Private`j, \ 1, \ 
                  Utilities`RandomNumbers`Private`i}]]\n\ \n
        Utilities`RandomNumbers`Private`Quantile[
            NegativeHypergeometricDistribution[
              Utilities`RandomNumbers`Private`n_Integer, \ 
              Utilities`RandomNumbers`Private`p_, \ 
              Utilities`RandomNumbers`Private`\[Alpha]_], \ 
            Utilities`RandomNumbers`Private`q_]\  ^:= \ 
          Module[{Utilities`RandomNumbers`Private`i, \ 
              Utilities`RandomNumbers`Private`s}, \ 
            If[Utilities`RandomNumbers`Private`q\  <= \ 0, \ 0, \ 
              If[Utilities`RandomNumbers`Private`q\  >= \ 1, \ 
                Utilities`RandomNumbers`Private`n, \ 
                If[Utilities`RandomNumbers`Private`q\  < \ 
                    Utilities`RandomNumbers`Private`CDF[
                      NegativeHypergeometricDistribution[
                        Utilities`RandomNumbers`Private`n, \ 
                        Utilities`RandomNumbers`Private`p, \ 
                        Utilities`RandomNumbers`Private`\[Alpha]], \ 
                      Quotient[Utilities`RandomNumbers`Private`n, \ 2]], \ 
                  Utilities`RandomNumbers`Private`i\  = \ 0; \ 
                  Utilities`RandomNumbers`Private`s\  = \ 0; \ 
                  While[Utilities`RandomNumbers`Private`s\  += \ 
                      Utilities`RandomNumbers`Private`PDF[
                        NegativeHypergeometricDistribution[
                          Utilities`RandomNumbers`Private`n, \ 
                          Utilities`RandomNumbers`Private`p, \ 
                          Utilities`RandomNumbers`Private`\[Alpha]], \ 
                        Utilities`RandomNumbers`Private`i]; \ 
                    Utilities`RandomNumbers`Private`s\  < \ 
                      Utilities`RandomNumbers`Private`q, \ 
                    Utilities`RandomNumbers`Private`i\  += \ 1]; \ 
                  Utilities`RandomNumbers`Private`i, \ 
                  Utilities`RandomNumbers`Private`i\  = \ 
                    Utilities`RandomNumbers`Private`n; \ 
                  Utilities`RandomNumbers`Private`s\  = \ 1; \ 
                  While[Utilities`RandomNumbers`Private`s\  -= \ 
                      Utilities`RandomNumbers`Private`PDF[
                        NegativeHypergeometricDistribution[
                          Utilities`RandomNumbers`Private`n, \ 
                          Utilities`RandomNumbers`Private`p, \ 
                          Utilities`RandomNumbers`Private`\[Alpha]], \ 
                        Utilities`RandomNumbers`Private`i]; \ 
                    Utilities`RandomNumbers`Private`s\  >= \ 
                      Utilities`RandomNumbers`Private`q, \ 
                    Utilities`RandomNumbers`Private`i\  -= \ 1]; \ 
                  Utilities`RandomNumbers`Private`i]]]]\n\ \n
        Utilities`RandomNumbers`Private`Mean[
            NegativeHypergeometricDistribution[
              Utilities`RandomNumbers`Private`n_, \ 
              Utilities`RandomNumbers`Private`p_, \ 
              Utilities`RandomNumbers`Private`\[Alpha]_]]\  ^:= \ 
          Utilities`RandomNumbers`Private`n*
            Utilities`RandomNumbers`Private`p\n\ \n
        Utilities`RandomNumbers`Private`Variance[
            NegativeHypergeometricDistribution[
              Utilities`RandomNumbers`Private`n_, \ 
              Utilities`RandomNumbers`Private`p_, \ 
              Utilities`RandomNumbers`Private`\[Alpha]_]]\  ^:= \ 
          Utilities`RandomNumbers`Private`n*
            Utilities`RandomNumbers`Private`p*\((1\  - \ 
                Utilities`RandomNumbers`Private`p)\)*\((Utilities`\
RandomNumbers`Private`n\  + \ 
                  Utilities`RandomNumbers`Private`\[Alpha])\)/\((1\  + \ 
                  Utilities`RandomNumbers`Private`\[Alpha])\)\n\ \n
        Utilities`RandomNumbers`Private`StandardDeviation[
            NegativeHypergeometricDistribution[
              Utilities`RandomNumbers`Private`n_, \ 
              Utilities`RandomNumbers`Private`p_, \ 
              Utilities`RandomNumbers`Private`\[Alpha]_]]\  ^:= \ 
          Sqrt[Utilities`RandomNumbers`Private`n*
              Utilities`RandomNumbers`Private`p*\((1\  - \ 
                  Utilities`RandomNumbers`Private`p)\)*\((Utilities`\
RandomNumbers`Private`n\  + \ 
                    Utilities`RandomNumbers`Private`\[Alpha])\)/\((1\  + \ 
                    Utilities`RandomNumbers`Private`\[Alpha])\)]\n\ \n
        Utilities`RandomNumbers`Private`Skewness[
            NegativeHypergeometricDistribution[
              Utilities`RandomNumbers`Private`n_, \ 
              Utilities`RandomNumbers`Private`p_, \ 
              Utilities`RandomNumbers`Private`\[Alpha]_], \ 
            Utilities`RandomNumbers`Private`t_]\  ^:= \ 
          Utilities`RandomNumbers`Private`n*
            Utilities`RandomNumbers`Private`p*\((1\  - \ 
                Utilities`RandomNumbers`Private`p)\)*\((1\  - \ 
                2*Utilities`RandomNumbers`Private`p)\)*\(\((\((Utilities`\
RandomNumbers`Private`n\  + \ 
                        Utilities`RandomNumbers`Private`\[Alpha])\)*\((2*
                          Utilities`RandomNumbers`Private`n\  + \ 
                        Utilities`RandomNumbers`Private`\[Alpha])\))\)/\((\((\
1\  + \ Utilities`RandomNumbers`Private`\[Alpha])\)*\((2\  + \ 
                        Utilities`RandomNumbers`Private`\[Alpha])\))\)\)/
              Utilities`RandomNumbers`Private`StandardDeviation[
                  NegativeHypergeometricDistribution[
                    Utilities`RandomNumbers`Private`n, \ 
                    Utilities`RandomNumbers`Private`p, \ 
                    Utilities`RandomNumbers`Private`\[Alpha]]]^3\n\ \n
        Utilities`RandomNumbers`Private`Kurtosis[
            NegativeHypergeometricDistribution[
              Utilities`RandomNumbers`Private`n_, \ 
              Utilities`RandomNumbers`Private`p_, \ 
              Utilities`RandomNumbers`Private`\[Alpha]_]]\  ^:= \ 
          Utilities`RandomNumbers`Private`n*
            Utilities`RandomNumbers`Private`p*\((1\  - \ 
                Utilities`RandomNumbers`Private`p)\)*\((\((Utilities`\
RandomNumbers`Private`n\  + \ 
                        Utilities`RandomNumbers`Private`\[Alpha])\)/\((\((1\  \
+ \ Utilities`RandomNumbers`Private`\[Alpha])\)*\((2\  + \ 
                            Utilities`RandomNumbers`Private`\[Alpha])\)*\((3\ \
 + \ Utilities`RandomNumbers`Private`\[Alpha])\))\)*\((6*
                        Utilities`RandomNumbers`Private`n^2\  + \ \((6*
                              Utilities`RandomNumbers`Private`n\  - \ 1)\)*
                        Utilities`RandomNumbers`Private`\[Alpha]\  + \ 
                      Utilities`RandomNumbers`Private`\[Alpha]^2\  - \ \((18*
                              Utilities`RandomNumbers`Private`n^2\  - \ 
                            3*Utilities`RandomNumbers`Private`n*\((Utilities`\
RandomNumbers`Private`n\  - \ 6)\)*
                              Utilities`RandomNumbers`Private`\[Alpha]\  - \ 
                            3*\((Utilities`RandomNumbers`Private`n\  - \ 2)\)*
                              Utilities`RandomNumbers`Private`\[Alpha]^2)\)*
                        Utilities`RandomNumbers`Private`p*\((1\  - \ 
                            Utilities`RandomNumbers`Private`p)\))\))\)/
              Utilities`RandomNumbers`Private`Variance[
                  NegativeHypergeometricDistribution[
                    Utilities`RandomNumbers`Private`n, \ 
                    Utilities`RandomNumbers`Private`p, \ 
                    Utilities`RandomNumbers`Private`\[Alpha]]]^2\n\ \n
        Utilities`RandomNumbers`Private`KurtosisExcess[
            NegativeHypergeometricDistribution[
              Utilities`RandomNumbers`Private`n_, \ 
              Utilities`RandomNumbers`Private`p_, \ 
              Utilities`RandomNumbers`Private`\[Alpha]_]]\  ^:= \ 
          Utilities`RandomNumbers`Private`Kurtosis[
              NegativeHypergeometricDistribution[
                Utilities`RandomNumbers`Private`n, \ 
                Utilities`RandomNumbers`Private`p, \ 
                Utilities`RandomNumbers`Private`\[Alpha]]]\  - \ 3\n\ \n
        Utilities`RandomNumbers`Private`ExpectedValue[
            Utilities`RandomNumbers`Private`f_, \ 
            NegativeHypergeometricDistribution[
              Utilities`RandomNumbers`Private`n_, \ 
              Utilities`RandomNumbers`Private`p_, \ 
              Utilities`RandomNumbers`Private`\[Alpha]_]]\  ^:= \ 
          Module[{Utilities`RandomNumbers`Private`i}, \ 
            Sum[Utilities`RandomNumbers`Private`f[
                  Utilities`RandomNumbers`Private`i]*
                Utilities`RandomNumbers`Private`PDF[
                  NegativeHypergeometricDistribution[
                    Utilities`RandomNumbers`Private`n, \ 
                    Utilities`RandomNumbers`Private`p, \ 
                    Utilities`RandomNumbers`Private`\[Alpha]], \ 
                  Utilities`RandomNumbers`Private`i], \ \
{Utilities`RandomNumbers`Private`i, \ 0, \ 
                Utilities`RandomNumbers`Private`n}]]\n\ \n
        Utilities`RandomNumbers`Private`ExpectedValue[
            Utilities`RandomNumbers`Private`f_, \ 
            NegativeHypergeometricDistribution[
              Utilities`RandomNumbers`Private`n_, \ 
              Utilities`RandomNumbers`Private`p_, \ 
              Utilities`RandomNumbers`Private`\[Alpha]_], \ 
            Utilities`RandomNumbers`Private`x_]\  ^:= \ 
          Module[{Utilities`RandomNumbers`Private`i}, \ 
            Together[
              Sum[\((Utilities`RandomNumbers`Private`f\  /. \ 
                      Utilities`RandomNumbers`Private`x\  -> \ 
                        Utilities`RandomNumbers`Private`i)\)*
                  Utilities`RandomNumbers`Private`PDF[
                    NegativeHypergeometricDistribution[
                      Utilities`RandomNumbers`Private`n, \ 
                      Utilities`RandomNumbers`Private`p, \ 
                      Utilities`RandomNumbers`Private`\[Alpha]], \ 
                    Utilities`RandomNumbers`Private`i], \ \
{Utilities`RandomNumbers`Private`i, \ 0, \ 
                  Utilities`RandomNumbers`Private`n}]]]\n\ \n
        Utilities`RandomNumbers`Private`CharacteristicFunction[
            NegativeHypergeometricDistribution[
              Utilities`RandomNumbers`Private`n_, \ 
              Utilities`RandomNumbers`Private`p_, \ 
              Utilities`RandomNumbers`Private`\[Alpha]_], \ 
            Utilities`RandomNumbers`Private`t_]\  ^:= \ \((Gamma[
                  Utilities`RandomNumbers`Private`\[Alpha]]*
                Gamma[Utilities`RandomNumbers`Private`n\  + \ 
                    Utilities`RandomNumbers`Private`\[Alpha]\  - \ 
                    Utilities`RandomNumbers`Private`p*
                      Utilities`RandomNumbers`Private`\[Alpha]]*
                HypergeometricPFQ[{\(-Utilities`RandomNumbers`Private`n\), \ 
                    Utilities`RandomNumbers`Private`p*
                      Utilities`RandomNumbers`Private`\[Alpha]}, \ {1\  - \ 
                      Utilities`RandomNumbers`Private`n\  - \ 
                      Utilities`RandomNumbers`Private`\[Alpha]\  + \ 
                      Utilities`RandomNumbers`Private`p*
                        Utilities`RandomNumbers`Private`\[Alpha]}, \ 
                  Exp[I*Utilities`RandomNumbers`Private`t]])\)/\((Gamma[\((1\ \
 - \ Utilities`RandomNumbers`Private`p)\)*
                    Utilities`RandomNumbers`Private`\[Alpha]]*
                Gamma[Utilities`RandomNumbers`Private`n\  + \ 
                    Utilities`RandomNumbers`Private`\[Alpha]])\)\n\ \n
        Random[
            NegativeHypergeometricDistribution[
              Utilities`RandomNumbers`Private`n_, \ 
              Utilities`RandomNumbers`Private`p_, \ 
              Utilities`RandomNumbers`Private`\[Alpha]_]]\  ^:= \ 
          Random[BinomialDistribution[Utilities`RandomNumbers`Private`n, \ 
              Random[BetaDistribution[
                  Utilities`RandomNumbers`Private`\[Alpha]*
                    Utilities`RandomNumbers`Private`p, \ 
                  Utilities`RandomNumbers`Private`\[Alpha]*\((1\  - \ 
                        Utilities`RandomNumbers`Private`p)\)]]]]\n\ \n
        NegativeHypergeometricDistribution /: \ 
          Utilities`RandomNumbers`Private`RandomArray[
            NegativeHypergeometricDistribution[
              Utilities`RandomNumbers`Private`n_, \ 
              Utilities`RandomNumbers`Private`p_, \ 
              Utilities`RandomNumbers`Private`\[Alpha]_], \ 
            Utilities`RandomNumbers`Private`dims_List]\  := \ 
          Array[Random[
                NegativeHypergeometricDistribution[
                  Utilities`RandomNumbers`Private`n, \ 
                  Utilities`RandomNumbers`Private`p, \ 
                  Utilities`RandomNumbers`Private`\[Alpha]]]\  &\ , \ 
            Utilities`RandomNumbers`Private`dims]\),
        ShowStringCharacters->True,
        NumberMarks->True],
      InputForm[ 
        Definition[ NegativeHypergeometricDistribution]],
      Editable->True,
      AutoDelete->True]], "Print"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Domain[NegativeHypergeometricDistribution[n, p, \[Alpha]]]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(Range[0, n]\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PDF[NegativeHypergeometricDistribution[n, p, \[Alpha]], i]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(\(Binomial[n, i]\ Pochhammer[\((1 - p)\)\ \[Alpha], \(-i\) + n]\ \
Pochhammer[p\ \[Alpha], i]\)\/Pochhammer[\[Alpha], n]\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rr = 
      RandomArray[
        NegativeHypergeometricDistribution[10, 0.2, 2.2], {100}]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \({0, 0, 0, 3, 9, 3, 6, 2, 0, 1, 3, 1, 0, 0, 0, 5, 2, 0, 5, 0, 0, 1, 1, 
      4, 1, 0, 3, 2, 2, 6, 1, 0, 3, 1, 0, 0, 2, 0, 5, 0, 2, 0, 0, 0, 0, 0, 5, 
      5, 0, 3, 3, 0, 0, 1, 0, 0, 2, 0, 0, 0, 0, 0, 0, 1, 4, 4, 0, 4, 3, 3, 5, 
      2, 1, 4, 2, 1, 1, 0, 0, 7, 2, 9, 0, 5, 5, 5, 1, 0, 4, 6, 4, 6, 1, 2, 3, 
      0, 0, 5, 0, 0}\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[{i, 
          100  PDF[NegativeHypergeometricDistribution[10, 0.2, 2.2], i], 
          Count[rr, i]}, {i, 0, 10}] // TableForm\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0", "40.854913003628237`", "41"},
          {"1", "16.706470001483666`", "14"},
          {"2", "11.0920005747555494`", "11"},
          {"3", "8.23880712401934189`", "10"},
          {"4", "6.39144573280881722`", "7"},
          {"5", "5.03751817520790634`", "10"},
          {"6", "3.96471337863585269`", "4"},
          {"7", "3.06515656163444294`", "1"},
          {"8", "2.27441138482981308`", "0"},
          {"9", "1.54557424218708057`", "2"},
          {"10", "0.828989820809434085`", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[13]//TableForm="]
}, Open  ]],

Cell[TextData[{
  "The j'th derivative of the CharacteristicFunction[] at t=0 gives ",
  Cell[BoxData[
      \(TraditionalForm\`\((I)\)\^j\)]],
  " times the j'th moment.  The j'th derivative of \
Log[CharacteristicFunction[]] at t=0 gives ",
  Cell[BoxData[
      \(TraditionalForm\`\((I)\)\^j\)]],
  " times the j'th cumulant."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(cf = 
      CharacteristicFunction[
        NegativeHypergeometricDistribution[10, 0.2, 2.2], t]\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \(0.408549130036282548`\ \((1 + 0.408921933085501887`\ E\^\(I\ t\) + 
          0.271497349015783973`\ E\^\(2\ I\ t\) + 
          0.201660131384631036`\ E\^\(3\ I\ t\) + 
          0.156442524605087456`\ E\^\(4\ I\ t\) + 
          0.123302628860341334`\ E\^\(5\ I\ t\) + 
          0.0970437356771205372`\ E\^\(6\ I\ t\) + 
          0.0750254090949167196`\ E\^\(7\ I\ t\) + 
          0.0556704498337280995`\ E\^\(8\ I\ t\) + 
          0.0378308048789584017`\ E\^\(9\ I\ t\) + 
          0.0202910680714413249`\ E\^\(10\ I\ t\))\)\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({\(-I\)\ D[cf, t] /. t -> 0, 
      Mean[NegativeHypergeometricDistribution[10, 0.2, 2.2]]}\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({2.00000000000000399`, 2.`}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({\((\(-I\))\)\^2\ D[Log[cf], {t, 2}] /. t -> 0, 
      Variance[NegativeHypergeometricDistribution[10, 0.2, 2.2]]}\)], "Input",\

  CellLabel->"In[21]:="],

Cell[BoxData[
    \({6.1000000000000023`, 6.10000000000000053`}\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({\(\((\(-I\))\)\^4\ D[Log[cf], {t, 4}]\)\/\((\((\(-I\))\)\^2\ \
D[Log[cf], {t, 2}])\)\^\(\(2\)\(\ \)\) /. t -> 0, 
      KurtosisExcess[
        NegativeHypergeometricDistribution[10, 0.2, 2.2]]}\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \({0.80911547468923608`, 0.809115474689244607`}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{129, Automatic}, {Automatic, 21}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 62, 0, 36, "SubsectionIcon"],
Cell[1804, 53, 661, 11, 70, "DefinitionBox"],
Cell[2468, 66, 406, 9, 54, "Text"],
Cell[2877, 77, 46, 0, 28, "MathCaption"],
Cell[2926, 79, 91, 2, 27, "Input"],
Cell[3020, 83, 138, 3, 36, "Text"],
Cell[3161, 88, 99, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3285, 95, 94, 2, 27, "Input"],
Cell[3382, 99, 252, 4, 50, "Print"],
Cell[3637, 105, 15825, 271, 2540, "Print"]
}, Closed]],

Cell[CellGroupData[{
Cell[19499, 381, 115, 2, 23, "Input"],
Cell[19617, 385, 69, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19723, 392, 115, 2, 27, "Input"],
Cell[19841, 396, 178, 3, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20056, 404, 147, 4, 27, "Input"],
Cell[20206, 410, 387, 6, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20630, 421, 192, 4, 42, "Input"],
Cell[20825, 427, 748, 19, 179, "Output"]
}, Open  ]],
Cell[21588, 449, 341, 9, 40, "Text"],

Cell[CellGroupData[{
Cell[21954, 462, 154, 4, 27, "Input"],
Cell[22111, 468, 591, 11, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22739, 484, 149, 3, 27, "Input"],
Cell[22891, 489, 86, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23014, 496, 174, 4, 43, "Input"],
Cell[23191, 502, 102, 2, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23330, 509, 253, 5, 70, "Input"],
Cell[23586, 516, 104, 2, 20, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

