(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9889,        334]*)
(*NotebookOutlinePosition[     12473,        412]*)
(*  CellTagsIndexPosition[     12061,        395]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Utilities`Numbering`", "SubsectionIcon"],

Cell[TextData[{
  "This package contains functions which find all the tags of a specified \
style, and which generate automatically numbered links",
  StyleBox[" to them.",
    InitializationCell->True]
}], "Text"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"findTags[style]\\\\\\\"\\\
\", \\\"MR\\\"]\\) \"\>", "\<\"gives a list of all the tags of equations of \
this style \"\>"},
                {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"eqLink[tag]\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", "\<\"makes an automatically numbered link to the cell \
with this tag  \"\>"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"SA.8.7", "7.2", "FindTags", "NumberedLink"}],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Utilities`Numbering`;\)\)], "Input",
  CellLabel->"In[3]:=",
  AspectRatioFixed->False],

Cell[TextData[{
  "NOTE:",
  StyleBox["  These functions may not work when evaluated from within the \
Help Browser.  They should do so if the help notebook is pened directly \
(Utilities:Documentation:English:NumberingDocumentation.nb).",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  StyleBox["In case of problems, see ",
    FontWeight->"Plain"],
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Manipulating notebooks"},
    ButtonStyle->"AddOnsLink"],
  StyleBox[".",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["Finding tags", "SubsubsectionIcon",
  CellTags->"Finding tags"],

Cell["\<\
This sets up a list of the tags of all three numbered equations in \
this notebook.  \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ts = FindTags["\<NumberedEquation\>"]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \({"f eqn", "psi eqn", "psi soln"}\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[TextData[{
  "Note that the scheme ONLY works if each numbered equation has one distinct \
cell tag.  This tag should ",
  StyleBox["describe",
    FontSlant->"Italic"],
  " the equation - it is confusing to call it \"equation 1\", say, since the \
numbering may well change."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Setting up links to a list of tags", "SubsubsectionIcon",
  CellTags->"Setting up links to a list of tags"],

Cell["\<\
This sets up cells containing links to each equation; the first tag \
is used if there are several.  These can be pasted as necessary; they will \
maintain the correct numbering automatically.\
\>", "Text"],

Cell[BoxData[
    \(\(Scan[NumberedLink, FindTags["\<NumberedEquation\>"]];\)\)], "Input",
  CellLabel->"In[5]:="],

Cell[TextData[{
  "f eqn",
  "   ",
  ButtonBox["(",
    ButtonData:>"f eqn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "f eqn"],
  ButtonBox[")",
    ButtonData:>"f eqn",
    ButtonStyle->"Hyperlink"]
}],
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "psi eqn",
  "   ",
  ButtonBox["(",
    ButtonData:>"psi eqn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "psi eqn"],
  ButtonBox[")",
    ButtonData:>"psi eqn",
    ButtonStyle->"Hyperlink"]
}],
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "psi soln",
  "   ",
  ButtonBox["(",
    ButtonData:>"psi soln",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "psi soln"],
  ButtonBox[")",
    ButtonData:>"psi soln",
    ButtonStyle->"Hyperlink"]
}],
  GeneratedCell->True,
  CellAutoOverwrite->True],

Cell[TextData[{
  "These cells can be merged to save space.  They can also be pasted into a \
separate notebook so that they can be inserted as required into a long \
document.  However, they must be generated within the desired notebook. Also, \
note that hyperlinks should only be pasted between notebooks in the same \
folder (see ",
  ButtonBox["Bugs",
    ButtonData:>{"Bugs", "Pasting hyperlinks"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Bugs"],
  ")."
}], "Text"],

Cell["\<\
Note that (for obscure reasons) the active elements are the \
brackets, not the number. The cell tag is displayed at bottom left when the \
pointer goes over it.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Some numbered equations", "SubsubsectionIcon"],

Cell[BoxData[
    \(f[t] = \[Alpha] + \[Beta]t\)], "NumberedEquation",
  CellFrame->False,
  CellTags->"f eqn"],

Cell[BoxData[
    \(\[PartialD]\ \[Psi]\/\[PartialD]t = f[t] \[Psi]\)], "NumberedEquation",
  CellFrame->False,
  CellTags->"psi eqn"],

Cell[TextData[{
  "Equation  ",
  ButtonBox["(",
    ButtonData:>"psi eqn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "psi eqn"],
  ButtonBox[")",
    ButtonData:>"psi eqn",
    ButtonStyle->"Hyperlink"],
  " depends on the function defined in Eq. ",
  " ",
  ButtonBox["(",
    ButtonData:>"f eqn",
    ButtonStyle->"Hyperlink"],
  
  CounterBox["NumberedEquation", "f eqn"],
  ButtonBox[")",
    ButtonData:>"f eqn",
    ButtonStyle->"Hyperlink"],
  ".  Its solution is:"
}], "Text"],

Cell[BoxData[
    \(\[Psi][t] = 
      C\ Exp[\[Alpha]\[VeryThinSpace]t + \[Beta]t\^2\/2]\)], \
"NumberedEquation",
  CellFrame->False,
  CellTags->"psi soln"],

Cell["To make a link to a \"NumberedFigure\", use:", "Text"],

Cell[BoxData[
    RowBox[{"NumberedLink", "[", 
      RowBox[{"\"\<\!\(\*
StyleBox[\\\"figure\\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\*
StyleBox[\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\)\!\(\*
StyleBox[\\\"tag\\\",\\nFontSlant->\\\"Italic\\\"]\)\>\"", ",", 
        "\"\<NumberedFigure\>\""}], "]"}]], "Input"],

Cell["To make links to all the figures in a notebook, use:", "Text"],

Cell[TextData[StyleBox[" \
Scan[NumberedLink[#,\"NumberedFigure\"]&,FindTags[\"NumberedFigure\"]].  ", \
"Input"]], "Text"],

Cell["The same applies to \"NumberedTable\".", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Aesthetics", "SubsubsectionIcon",
  CellTags->"Aesthetics"],

Cell["\<\
The links may appear in an odd style (eg as \"Headings\"); just \
select them and type \[CloverLeaf]7 to change to Text style.  It is also \
convenient to merge them (\[CloverLeaf]M).\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Saving the links", "SubsubsectionIcon",
  CellTags->"Saving the links"],

Cell[TextData[{
  "It can be helpful to paste the links made using Scan[NumberedLink[...]] \
into a new notebook, which can then be kept open alongside the main notebook. \
 Links can then be pasted across as necessary.  \nOne problem is then that \
the links will not be numbered in the new notebook, because that does not \
contain the equations.  A simple trick is to evaluate:\n",
  Cell[BoxData[
      \(NotebookFind[SelectedNotebook[], "\<NumberedEquation\>", All, 
        CellStyle]; \)], "Input",
    CellLabel->"In[4]:=",
    FontFamily->"Times"],
  StyleBox["\n",
    FontWeight->"Bold"],
  "which selects all the numbered equations.  Copy and paste these into the \
new notebook, and the numbering will be displayed.  However, be careful that \
the sets of equations in the two notebooks correspond - otherwise the \
numbering will be awry."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Notes", "SubsubsectionIcon",
  CellTags->"Notes"],

Cell["\<\
Ideally, one would set up either NumberedLink[] on a palette, so as \
to be able to click & paste links in where required.  However, I have not \
found how to paste objects into text cells: that is why NumberedLink[] \
produces a whole cell containing the object.  
Another limitation is that automatically numbered objects can only appear in \
text cells, and so the links cannot be displayed more compactly as a table.  \
However, one can merge the set of cells that is produced to compress them.
The number itself cannot be the active link, because it is a \"value display \
object\" - that is why the brackets on either side make the link.\
\>", "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{886, 722},
WindowMargins->{{Automatic, 85}, {Automatic, 6}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "SA.8.7"->{
    Cell[2005, 60, 669, 15, 57, "Text",
      CellTags->{"SA.8.7", "7.2", "FindTags", "NumberedLink"}]},
  "7.2"->{
    Cell[2005, 60, 669, 15, 57, "Text",
      CellTags->{"SA.8.7", "7.2", "FindTags", "NumberedLink"}]},
  "FindTags"->{
    Cell[2005, 60, 669, 15, 57, "Text",
      CellTags->{"SA.8.7", "7.2", "FindTags", "NumberedLink"}]},
  "NumberedLink"->{
    Cell[2005, 60, 669, 15, 57, "Text",
      CellTags->{"SA.8.7", "7.2", "FindTags", "NumberedLink"}]},
  "Finding tags"->{
    Cell[3427, 106, 69, 1, 24, "SubsubsectionIcon",
      CellTags->"Finding tags"]},
  "Setting up links to a list of tags"->{
    Cell[4172, 137, 113, 1, 24, "SubsubsectionIcon",
      CellTags->"Setting up links to a list of tags"]},
  "f eqn"->{
    Cell[6252, 219, 111, 3, 28, "NumberedEquation",
      CellTags->"f eqn"]},
  "psi eqn"->{
    Cell[6366, 224, 134, 3, 44, "NumberedEquation",
      CellTags->"psi eqn"]},
  "psi soln"->{
    Cell[7016, 252, 159, 5, 47, "NumberedEquation",
      CellTags->"psi soln"]},
  "Aesthetics"->{
    Cell[7842, 280, 65, 1, 24, "SubsubsectionIcon",
      CellTags->"Aesthetics"]},
  "Saving the links"->{
    Cell[8154, 292, 77, 1, 20, "SubsubsectionIcon",
      CellTags->"Saving the links"]},
  "Notes"->{
    Cell[9136, 317, 55, 1, 20, "SubsubsectionIcon",
      CellTags->"Notes"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"SA.8.7", 10718, 355},
  {"7.2", 10834, 358},
  {"FindTags", 10955, 361},
  {"NumberedLink", 11080, 364},
  {"Finding tags", 11205, 367},
  {"Setting up links to a list of tags", 11333, 370},
  {"f eqn", 11455, 373},
  {"psi eqn", 11549, 376},
  {"psi soln", 11646, 379},
  {"Aesthetics", 11746, 382},
  {"Saving the links", 11854, 385},
  {"Notes", 11957, 388}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 46, 0, 36, "SubsectionIcon"],
Cell[1788, 53, 214, 5, 22, "Text"],
Cell[2005, 60, 669, 15, 57, "Text",
  CellTags->{"SA.8.7", "7.2", "FindTags", "NumberedLink"}],
Cell[2677, 77, 46, 0, 28, "MathCaption"],
Cell[2726, 79, 112, 3, 26, "Input"],
Cell[2841, 84, 298, 7, 38, "Text"],
Cell[3142, 93, 260, 9, 23, "Text"],

Cell[CellGroupData[{
Cell[3427, 106, 69, 1, 24, "SubsubsectionIcon",
  CellTags->"Finding tags"],
Cell[3499, 109, 116, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3640, 116, 94, 2, 26, "Input"],
Cell[3737, 120, 90, 2, 20, "Output"]
}, Open  ]],
Cell[3842, 125, 293, 7, 38, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4172, 137, 113, 1, 24, "SubsubsectionIcon",
  CellTags->"Setting up links to a list of tags"],
Cell[4288, 140, 216, 4, 22, "Text"],
Cell[4507, 146, 114, 2, 26, "Input"],
Cell[4624, 150, 280, 13, 22, InheritFromParent],
Cell[4907, 165, 288, 13, 22, InheritFromParent],
Cell[5198, 180, 292, 13, 22, InheritFromParent],
Cell[5493, 195, 479, 11, 37, "Text"],
Cell[5975, 208, 185, 4, 22, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6197, 217, 52, 0, 24, "SubsubsectionIcon"],
Cell[6252, 219, 111, 3, 28, "NumberedEquation",
  CellTags->"f eqn"],
Cell[6366, 224, 134, 3, 44, "NumberedEquation",
  CellTags->"psi eqn"],
Cell[6503, 229, 510, 21, 22, "Text"],
Cell[7016, 252, 159, 5, 47, "NumberedEquation",
  CellTags->"psi soln"],
Cell[7178, 259, 60, 0, 22, "Text"],
Cell[7241, 261, 310, 6, 26, "Input"],
Cell[7554, 269, 68, 0, 22, "Text"],
Cell[7625, 271, 123, 2, 25, "Text"],
Cell[7751, 275, 54, 0, 22, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7842, 280, 65, 1, 24, "SubsubsectionIcon",
  CellTags->"Aesthetics"],
Cell[7910, 283, 207, 4, 22, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8154, 292, 77, 1, 20, "SubsubsectionIcon",
  CellTags->"Saving the links"],
Cell[8234, 295, 865, 17, 116, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9136, 317, 55, 1, 20, "SubsubsectionIcon",
  CellTags->"Notes"],
Cell[9194, 320, 667, 10, 94, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

