(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7622,        237]*)
(*NotebookOutlinePosition[      8797,        275]*)
(*  CellTagsIndexPosition[      8683,        268]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Summing products", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(ProductSum[V, 
              n]\), \(gives\ the\ sum\ of\ all\ products\ of\ n\ distinct\ \
elements\ of\ \(\(V\)\(.\)\)\)},
          {\(ProductSum[V1, V2, n1, n2]\), \(\(\ \)\(is\ also\ defined; \ 
            it\ is\ just\ ProductSum[V\_1, n\_1] ProductSum[V\_2, n\_2]\)\)},
          {\(\(ProductSum[n]\)[
              U]\), \(is\ a\ compiled\ version\ \((n < 7)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"ProductSum"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(<< Utilities`SetManipulation`\)], "Input",
  CellLabel->"In[27]:="],

Cell["\<\
This is the sum of products of all distinct pairs of {x,y,z}: \
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ProductSum[{x, y, z}, 2]\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \(x\ y + x\ z + y\ z\)], "Output",
  CellLabel->"Out[62]="]
}, Open  ]],

Cell["\<\
This is the product of all distinct triples of {a,b,c,d} and all \
distinct pairs of {x,y,z}:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ProductSum[{a, b, c, d}, {x, y, z}, 3, 2] // Factor\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \(\((a\ b\ c + a\ b\ d + a\ c\ d + b\ c\ d)\)\ \((x\ y + x\ z + 
          y\ z)\)\)], "Output",
  CellLabel->"Out[63]="]
}, Open  ]],

Cell["\<\
The compiled version is much faster, but only takes lists of \
numerical values:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Timing[ProductSum[Range[10] // N, 6]], 
        Timing[\(ProductSum[6]\)[Range[10] // N]]} // TableForm\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\(0.08333333333331439`\ Second\), "3.41693`*^6"},
          {\(0.`\ Second\), "3.41693`*^6"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[18]//TableForm="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(ProductSum[{{\[Alpha]\_1, \[Ellipsis]\[Alpha]\_n}, {\[Beta]\_1, \
\[Ellipsis]\[Beta]\_n}}, {a, 
                b}]\), \(gives\ \(\[Sum]\ \[Product]\+\(i \[Element] A\)\
\[Alpha]\_i\ \(\[Product]\+\(j \[Element] B\)\[Beta]\_j . \ \ The\ products\ \
are\ over\ sets\ A\)\), \ B\ of\ distinct\ elements, \ 
            and\ the\ sum\ is\ over\ all\ such\ sets; \ 
            generalises\ to\ arbitrarily\ many\ \(\(sets\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"ProductSum over sets"],

Cell["\<\
This generates the sum  of all products involving 2 \[Alpha]'s and \
2 \[Beta]'s, each with distinct indices:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ProductSum[{{\[Alpha]\_1, \[Alpha]\_2, \[Alpha]\_3, \[Alpha]\_4, \
\[Alpha]\_5}, {\[Beta]\_1, \[Beta]\_2, \[Beta]\_3, \[Beta]\_4, \[Beta]\_5}}, \
{2, 2}]\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \(\[Alpha]\_4\ \[Alpha]\_5\ \((\[Beta]\_1\ \[Beta]\_2 + \[Beta]\_1\ \
\[Beta]\_3 + \[Beta]\_2\ \[Beta]\_3)\) + \[Alpha]\_3\ \[Alpha]\_5\ \((\[Beta]\
\_1\ \[Beta]\_2 + \[Beta]\_1\ \[Beta]\_4 + \[Beta]\_2\ \[Beta]\_4)\) + \
\[Alpha]\_2\ \[Alpha]\_5\ \((\[Beta]\_1\ \[Beta]\_3 + \[Beta]\_1\ \[Beta]\_4 \
+ \[Beta]\_3\ \[Beta]\_4)\) + \[Alpha]\_1\ \[Alpha]\_5\ \((\[Beta]\_2\ \
\[Beta]\_3 + \[Beta]\_2\ \[Beta]\_4 + \[Beta]\_3\ \[Beta]\_4)\) + \[Alpha]\_3\
\ \[Alpha]\_4\ \((\[Beta]\_1\ \[Beta]\_2 + \[Beta]\_1\ \[Beta]\_5 + \
\[Beta]\_2\ \[Beta]\_5)\) + \[Alpha]\_2\ \[Alpha]\_4\ \((\[Beta]\_1\ \
\[Beta]\_3 + \[Beta]\_1\ \[Beta]\_5 + \[Beta]\_3\ \[Beta]\_5)\) + \[Alpha]\_1\
\ \[Alpha]\_4\ \((\[Beta]\_2\ \[Beta]\_3 + \[Beta]\_2\ \[Beta]\_5 + \
\[Beta]\_3\ \[Beta]\_5)\) + \[Alpha]\_2\ \[Alpha]\_3\ \((\[Beta]\_1\ \
\[Beta]\_4 + \[Beta]\_1\ \[Beta]\_5 + \[Beta]\_4\ \[Beta]\_5)\) + \[Alpha]\_1\
\ \[Alpha]\_3\ \((\[Beta]\_2\ \[Beta]\_4 + \[Beta]\_2\ \[Beta]\_5 + \
\[Beta]\_4\ \[Beta]\_5)\) + \[Alpha]\_1\ \[Alpha]\_2\ \((\[Beta]\_3\ \
\[Beta]\_4 + \[Beta]\_3\ \[Beta]\_5 + \[Beta]\_4\ \[Beta]\_5)\)\)], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell["\<\
A zero index is interpreted as omitting the corresponding \
set:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ProductSum[{{\[Alpha]\_1, \[Alpha]\_2, \[Alpha]\_3, \[Alpha]\_4, \
\[Alpha]\_5}, {\[Beta]\_1, \[Beta]\_2, \[Beta]\_3, \[Beta]\_4, \[Beta]\_5}}, \
{2, 0}]\)], "Input",
  CellLabel->"In[100]:="],

Cell[BoxData[
    \(\[Alpha]\_1\ \[Alpha]\_2 + \[Alpha]\_1\ \[Alpha]\_3 + \[Alpha]\_2\ \
\[Alpha]\_3 + \[Alpha]\_1\ \[Alpha]\_4 + \[Alpha]\_2\ \[Alpha]\_4 + \
\[Alpha]\_3\ \[Alpha]\_4 + \[Alpha]\_1\ \[Alpha]\_5 + \[Alpha]\_2\ \
\[Alpha]\_5 + \[Alpha]\_3\ \[Alpha]\_5 + \[Alpha]\_4\ \[Alpha]\_5\)], "Output",\

  CellLabel->"Out[100]="]
}, Open  ]],

Cell[TextData[{
  "There are ",
  Cell[BoxData[
      \(TraditionalForm\`\(5!\)\/\(\(2!\) \(2!\) \(1!\)\)\)]],
  "terms in this expression:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[Expand[%]]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \(30\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[TextData[{
  "In general, there are ",
  Cell[BoxData[
      \(TraditionalForm\`\(n!\)\/\(\(a!\) \(b!\) \(\((n - a - b)\)!\)\)\)]],
  "terms."
}], "Text"],

Cell[TextData[{
  "This is used by ",
  ButtonBox["EstimatingMoments[]",
    ButtonData:>{"Estimating the matrix", "EstimateMoments"},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"EstimatingMoments[]"],
  " in ",
  StyleBox["Multilocus`EstimatingD`",
    FontSlant->"Italic"],
  "; the expectation of expressions of this form over a set of genotype \
frequencies is a simple function of the moments ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(a, b\)\)]],
  "."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{1043, 639},
WindowMargins->{{48, Automatic}, {Automatic, 14}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "ProductSum"->{
    Cell[1784, 53, 513, 10, 74, "DefinitionBox",
      CellTags->"ProductSum"]},
  "ProductSum over sets"->{
    Cell[3809, 129, 581, 10, 60, "DefinitionBox",
      CellTags->"ProductSum over sets"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"ProductSum", 8457, 258},
  {"ProductSum over sets", 8566, 261}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 42, 0, 36, "SubsectionIcon"],
Cell[1784, 53, 513, 10, 74, "DefinitionBox",
  CellTags->"ProductSum"],
Cell[2300, 65, 46, 0, 28, "MathCaption"],
Cell[2349, 67, 87, 2, 26, "Input"],
Cell[2439, 71, 95, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2559, 78, 82, 2, 26, "Input"],
Cell[2644, 82, 77, 2, 20, "Output"]
}, Open  ]],
Cell[2736, 87, 124, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2885, 94, 109, 2, 26, "Input"],
Cell[2997, 98, 139, 3, 20, "Output"]
}, Open  ]],
Cell[3151, 104, 111, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3287, 111, 162, 3, 26, "Input"],
Cell[3452, 116, 342, 10, 53, "Output"]
}, Open  ]],
Cell[3809, 129, 581, 10, 60, "DefinitionBox",
  CellTags->"ProductSum over sets"],
Cell[4393, 141, 140, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[4558, 148, 211, 4, 26, "Input"],
Cell[4772, 154, 1154, 16, 35, "Output"]
}, Open  ]],
Cell[5941, 173, 95, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6061, 180, 212, 4, 26, "Input"],
Cell[6276, 186, 335, 6, 20, "Output"]
}, Open  ]],
Cell[6626, 195, 159, 5, 34, "MathCaption"],

Cell[CellGroupData[{
Cell[6810, 204, 75, 2, 26, "Input"],
Cell[6888, 208, 61, 2, 20, "Output"]
}, Open  ]],
Cell[6964, 213, 159, 5, 29, "Text"],
Cell[7126, 220, 480, 14, 24, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

