(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     13353,        353]*)
(*NotebookOutlinePosition[     14236,        381]*)
(*  CellTagsIndexPosition[     14192,        377]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Drawing random numbers from a specified distribution", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(RandomCum[CDF[#] &, 
              j0]\), \(generates\ a\ random\ number\ from\ the\ discrete\ \
distribution\ whose\ cumulative\ distribution\ is\ given\ by\ CDF[
                j], \ \ \(\(defined\)\(\ \)\(as\)\(\ \)\(the\)\(\ \
\)\(probability\)\(\ \)\(of\)\(\ \)\(going\)\(\ \)\(from\)\(\ \)\(0\)\(\ \
\)\(to\)\(\ \)\(j\)\(\ \)\(inclusive . \ \ j0\)\(\ \)\(is\)\(\ \)\(an\)\(\ \)\
\(initial\)\(\ \)\(guess . \ \ Range\)\(\ \)\(is\)\(\ \)\(0\)\(\ \)\(to\)\(\ \
\)\(\(\[Infinity]\)\(.\)\)\(\ \)\)\)},
          {\(RandomCum[{F\_0, \[Ellipsis]}, 
              j0]\), \(uses\ a\ faster\ compiled\ version, \ 
            given\ a\ pre - calculated\ CDF\)},
          {\(\(\ \)\(RandomCum[CDF[#] &, j0, 
              x]\)\), \(generates\ the\ integer\ appropriate\ to\ \
\(\(x\)\(.\)\)\)}
          }], TraditionalForm]],
  CellTags->"RandomCum"]], "DefinitionBox"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Utilities`RandomNumbers`;\)\)], "Input",
  CellLabel->"In[305]:="],

Cell["\<\
This package automatically loads Statistics`DiscreteDistributions`, \
Statistics`ContinuousDistributions` as well.\
\>", "Text"],

Cell["\<\
In the following example, random Poisson variables are generated.  \
Of course, Random[PoissonDistribution[\[Lambda]]] would be easier to use in \
this case; but RandomCum[] gives a general method for novel \
distributions.\
\>", "Text"],

Cell["This is the cumulative distribution of a Poisson:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[CDF[PoissonDistribution[1.5], j], {j, 0, 10}]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \({0.223130160148429812`, 0.557825400371074753`, 0.808846830538058192`, 
      0.934357545621549867`, 0.981424063777859245`, 0.995544019224752041`, 
      0.999074008086475373`, 0.999830434271130208`, 0.999972264180753178`, 
      0.999995902499023614`, 0.999999448246764188`}\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell["\<\
This generates 1000 random numbers drawn from that \
distribution:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tt = 
      Table[RandomCum[CDF[PoissonDistribution[1.5], #] &, 
          1], {1000}]\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \({2, 1, 2, 1, 1, 1, 1, 1, 1, 0, 1, 3, 0, 1, 3, 2, 5, 3, 1, 1, 1, 0, 0, 
      3, 2, 1, 1, 2, 1, 0, 3, 1, 2, 0, 2, 1, 2, 2, 2, 3, 2, 3, 1, 1, 1, 2, 1, 
      1, 1, 1, 0, 3, 1, 0, 1, 1, 1, 2, 2, 0, 3, 0, 3, 0, 0, 1, 1, 2, 2, 1, 0, 
      1, 1, 1, 4, 1, 4, 1, 2, 3, 1, 1, 0, 3, 2, 1, 0, 2, 1, 0, 2, 3, 2, 2, 2, 
      2, 1, 1, 2, 1, 1, 0, 4, 1, 0, 2, 3, 2, 1, 1, 2, 3, 3, 0, 4, 0, 0, 1, 1, 
      1, 2, 0, 2, 0, 0, 0, 2, 2, 0, 1, 2, 0, 2, 0, 0, 1, 2, 5, 0, 1, 2, 1, 3, 
      3, 3, 1, 1, 2, 2, 0, 2, 4, 2, 2, 3, 2, 4, 2, 3, 1, 0, 2, 2, 0, 2, 0, 3, 
      0, 2, 4, 2, 1, 0, 2, 4, 1, 1, 4, 0, 2, 1, 1, 1, 1, 1, 2, 2, 1, 2, 1, 2, 
      0, 3, 1, 0, 2, 3, 3, 0, 0, 1, 3, 0, 1, 6, 1, 2, 3, 2, 3, 0, 2, 0, 1, 1, 
      1, 0, 2, 1, 3, 1, 4, 1, 2, 3, 0, 0, 1, 3, 2, 1, 1, 0, 2, 0, 3, 0, 1, 2, 
      1, 3, 2, 1, 2, 1, 2, 0, 2, 2, 2, 3, 1, 2, 4, 1, 3, 1, 0, 1, 3, 1, 2, 2, 
      1, 2, 0, 1, 3, 0, 1, 1, 0, 1, 2, 1, 2, 3, 3, 0, 3, 1, 2, 2, 0, 3, 5, 0, 
      2, 0, 4, 2, 2, 0, 2, 1, 2, 1, 3, 6, 3, 2, 5, 5, 4, 1, 1, 1, 4, 1, 1, 0, 
      1, 1, 1, 1, 2, 1, 2, 3, 0, 2, 3, 3, 1, 0, 3, 4, 1, 3, 2, 2, 1, 1, 1, 1, 
      4, 0, 4, 0, 0, 2, 1, 0, 0, 5, 1, 1, 3, 2, 1, 1, 1, 4, 2, 2, 0, 2, 1, 0, 
      1, 1, 1, 0, 0, 2, 1, 2, 4, 2, 4, 1, 0, 3, 2, 0, 2, 4, 2, 1, 1, 1, 1, 1, 
      0, 3, 2, 1, 0, 0, 1, 1, 0, 1, 1, 0, 0, 2, 5, 3, 1, 2, 0, 1, 0, 0, 3, 0, 
      4, 1, 0, 2, 3, 0, 2, 0, 2, 1, 0, 0, 2, 4, 0, 1, 1, 1, 3, 3, 0, 0, 4, 3, 
      1, 3, 3, 0, 1, 3, 1, 4, 2, 1, 1, 2, 3, 1, 1, 1, 2, 4, 1, 2, 1, 2, 1, 2, 
      0, 3, 2, 2, 2, 0, 1, 2, 0, 3, 0, 3, 1, 1, 2, 1, 2, 2, 1, 2, 1, 2, 3, 5, 
      1, 3, 1, 1, 1, 3, 4, 2, 1, 5, 3, 2, 0, 1, 0, 1, 1, 3, 2, 1, 0, 0, 3, 1, 
      4, 0, 1, 0, 1, 1, 2, 2, 0, 1, 2, 3, 3, 3, 1, 2, 1, 0, 2, 0, 0, 4, 4, 1, 
      1, 2, 1, 1, 3, 1, 3, 2, 2, 5, 0, 3, 4, 0, 2, 1, 2, 0, 2, 0, 1, 0, 3, 2, 
      0, 1, 1, 1, 1, 4, 2, 2, 1, 4, 1, 2, 2, 3, 3, 1, 5, 3, 0, 1, 2, 2, 0, 2, 
      1, 1, 2, 1, 0, 1, 0, 2, 2, 1, 2, 3, 0, 2, 3, 1, 0, 2, 3, 0, 1, 5, 2, 1, 
      0, 1, 3, 1, 3, 0, 2, 2, 0, 1, 4, 2, 0, 3, 0, 1, 4, 0, 1, 0, 1, 0, 2, 2, 
      1, 1, 2, 1, 1, 1, 0, 2, 1, 0, 0, 0, 0, 0, 0, 2, 1, 0, 3, 1, 2, 0, 0, 3, 
      1, 1, 1, 1, 3, 4, 1, 2, 2, 3, 0, 2, 1, 2, 5, 4, 0, 2, 0, 1, 1, 2, 4, 1, 
      4, 0, 1, 0, 0, 0, 1, 1, 1, 1, 0, 2, 4, 1, 0, 2, 2, 4, 0, 0, 1, 1, 0, 2, 
      1, 1, 1, 2, 1, 0, 1, 1, 4, 2, 0, 2, 0, 1, 3, 0, 1, 1, 2, 4, 3, 4, 2, 1, 
      1, 2, 0, 2, 0, 2, 3, 1, 0, 3, 2, 2, 0, 2, 4, 1, 4, 1, 0, 2, 0, 1, 1, 1, 
      1, 2, 1, 1, 1, 4, 1, 0, 0, 0, 2, 1, 5, 1, 3, 0, 0, 0, 2, 1, 7, 2, 0, 0, 
      1, 0, 2, 2, 0, 0, 0, 1, 3, 0, 1, 4, 3, 2, 2, 3, 3, 2, 4, 1, 3, 2, 2, 1, 
      1, 2, 0, 2, 1, 1, 3, 0, 1, 1, 1, 0, 1, 1, 3, 1, 2, 4, 3, 2, 2, 0, 0, 1, 
      1, 1, 0, 3, 0, 0, 0, 2, 2, 3, 2, 2, 0, 1, 3, 1, 1, 1, 5, 2, 2, 0, 3, 0, 
      1, 2, 2, 0, 1, 1, 1, 1, 2, 2, 2, 2, 2, 1, 3, 1, 0, 0, 3, 3, 1, 3, 0, 2, 
      0, 1, 1, 2, 2, 2, 2, 1, 0, 0, 4, 1, 1, 2, 0, 0, 1, 2, 0, 1, 4, 3, 0, 1, 
      3, 2, 3, 3, 0, 3, 0, 2, 0, 3, 0, 0, 2, 0, 0, 3, 0, 1, 4, 2, 1, 1, 3, 0, 
      1, 3, 4, 0, 0, 0, 3, 2, 0, 0, 2, 2, 1, 0, 1, 2, 1, 2, 1, 0, 0, 0, 2, 4, 
      2, 0, 2, 2, 1, 0, 3, 0, 1, 6, 1, 1, 3, 3, 3, 3, 2, 1, 1, 2, 1, 0, 2, 3, 
      2, 3, 7, 0, 1, 2, 0, 3, 3, 2, 3, 1, 4, 3, 5, 1, 1, 2, 2, 2, 3, 1, 4, 3, 
      0, 1, 4, 3, 3, 2, 3, 3, 0, 0, 0, 1, 0, 1, 0, 0, 2}\)], "Output",
  CellLabel->"Out[18]="]
}, Closed]],

Cell["These fit the appropriate distribution.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ett = 
      Table[1000*PDF[PoissonDistribution[1.5], j], {j, 0, 10}]\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({223.130160148429812`, 334.695240222644718`, 251.021430166983527`, 
      125.510715083491763`, 47.0665181563094137`, 14.1199554468928241`, 
      3.52998886172320602`, 0.756426184654972644`, 0.141829909622807388`, 
      0.0236383182704678995`, 0.00354574774057018471`}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Statistics`DataManipulation`;\)\), "\n", 
    \({ett, Frequencies[tt]} // TableForm\)}], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"223.130160148429812`", "334.695240222644718`", 
            "251.021430166983527`", "125.510715083491763`", 
            "47.0665181563094137`", "14.1199554468928241`", 
            "3.52998886172320602`", "0.756426184654972644`", 
            "0.141829909622807388`", "0.0236383182704678995`", 
            "0.00354574774057018471`"},
          {GridBox[{
                {"227"},
                {"0"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"315"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"241"},
                {"2"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"138"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"58"},
                {"4"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"16"},
                {"5"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"3"},
                {"6"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"2"},
                {"7"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{223.13016014842981, 334.69524022264471, 251.02143016698352,
         125.51071508349176, 47.066518156309414, 14.119955446892824, 
        3.529988861723206, 0.75642618465497269, 0.14182990962280739, 
        0.0236383182704679, 0.0035457477405701847}, {{227, 0}, {315, 1}, {241,
         2}, {138, 3}, {58, 4}, {16, 5}, {3, 6}, {2, 7}}}]]], "Output",
  CellLabel->"Out[21]//TableForm="]
}, Open  ]],

Cell["\<\
RandomCum[] can be much faster than the built-in routines, if the \
CDF is constructed once and then used many times.  RandomArray[] does not \
seem to use this shortcut.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ct = 
        Table[CDF[PoissonDistribution[10. ], j], {j, 0, 
            40}];\)\), "\[IndentingNewLine]", 
    \({Timing[\(Table[
            RandomCum[ct\[LeftDoubleBracket]# + 1\[RightDoubleBracket] &, 
              10], {1000}];\)], 
      Timing[\(RandomArray[PoissonDistribution[10. ], 1000];\)]}\)}], "Input",\

  CellLabel->"In[131]:="],

Cell[BoxData[
    \({{1.1666666666667425`\ Second, Null}, {4.533333333333303`\ Second, 
        Null}}\)], "Output",
  CellLabel->"Out[132]="]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`RandomCum[{F\_0, \[Ellipsis]}, j\_0]\)]],
  " uses a compiled version which ismuch faster, given a precalculated table \
of the CDF:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Timing[\(Table[
            RandomCum[ct\[LeftDoubleBracket]# + 1\[RightDoubleBracket] &, 
              10], {1000}];\)], \[IndentingNewLine]Timing[\(Table[
            RandomCum[ct, 10], {1000}];\)]}\)], "Input",
  CellLabel->"In[133]:="],

Cell[BoxData[
    \({{1.183333333333394`\ Second, Null}, {0.16666666666674246`\ Second, 
        Null}}\)], "Output",
  CellLabel->"Out[133]="]
}, Open  ]],

Cell["\<\
Using a sensible initial guess for the random variable (here, 10 \
for PoissonDistribution[10]) makes a slight saving:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Timing[\(Table[
            RandomCum[ct\[LeftDoubleBracket]# + 1\[RightDoubleBracket] &, 
              10], {1000}];\)], 
      Timing[\(Table[
            RandomCum[ct\[LeftDoubleBracket]# + 1\[RightDoubleBracket] &, 
              1], {1000}];\)]}\)], "Input",
  CellLabel->"In[163]:="],

Cell[BoxData[
    \({{1.316666666666606`\ Second, Null}, {1.5166666666664241`\ Second, 
        Null}}\)], "Output",
  CellLabel->"Out[163]="]
}, Open  ]],

Cell["\<\
It is important that the table cover the whole probability \
distibution - otherwise an error will be returned.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(1 - ct // Last\)], "Input",
  CellLabel->"In[164]:="],

Cell[BoxData[
    \(1.7774670624248756`*^-13\)], "Output",
  CellLabel->"Out[164]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
WindowSize->{799, 527},
WindowMargins->{{Automatic, 99}, {Automatic, 81}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 78, 0, 36, "SubsectionIcon"],
Cell[1820, 53, 930, 17, 106, "DefinitionBox"],
Cell[2753, 72, 46, 0, 28, "MathCaption"],
Cell[2802, 74, 91, 2, 26, "Input"],
Cell[2896, 78, 138, 3, 22, "Text"],
Cell[3037, 83, 247, 5, 36, "Text"],
Cell[3287, 90, 72, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3384, 94, 108, 2, 26, "Input"],
Cell[3495, 98, 332, 5, 35, "Output"]
}, Open  ]],
Cell[3842, 106, 97, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3964, 113, 144, 4, 26, "Input"],
Cell[4111, 119, 3346, 43, 470, "Output"]
}, Closed]],
Cell[7472, 165, 62, 0, 18, "MathCaption"],

Cell[CellGroupData[{
Cell[7559, 169, 127, 3, 26, "Input"],
Cell[7689, 174, 329, 5, 20, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8055, 184, 148, 3, 42, "Input"],
Cell[8206, 189, 2748, 75, 59, "Output"]
}, Open  ]],
Cell[10969, 267, 194, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[11188, 275, 370, 9, 58, "Input"],
Cell[11561, 286, 142, 3, 20, "Output"]
}, Open  ]],
Cell[11718, 292, 202, 5, 22, "Text"],

Cell[CellGroupData[{
Cell[11945, 301, 261, 5, 42, "Input"],
Cell[12209, 308, 143, 3, 20, "Output"]
}, Open  ]],
Cell[12367, 314, 142, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[12534, 321, 311, 7, 42, "Input"],
Cell[12848, 330, 142, 3, 20, "Output"]
}, Open  ]],
Cell[13005, 336, 135, 3, 22, "Text"],

Cell[CellGroupData[{
Cell[13165, 343, 73, 2, 26, "Input"],
Cell[13241, 347, 84, 2, 22, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

