(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12315,        327]*)
(*NotebookOutlinePosition[     13197,        355]*)
(*  CellTagsIndexPosition[     13153,        351]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Set manipulation: overview", "SubsectionIcon"],

Cell["\<\
This package contains various routines that are useful for \
manipulating the sets of indices used to represent systems of many \
genes.\
\>", "Text"],

Cell[TextData[{
  "These are particularly useful when the sets represent sets of genes: see \
the ",
  ButtonBox["Multilocus algebra",
    ButtonData:>{"Introduction to multilocus algebra", None},
    ButtonStyle->"AddOnsLink",
    ButtonNote->"Multilocus algebra"],
  " package"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(Repeat[U, n]\), 
            StyleBox[\(gives\ the\ list\ U, \ repeated\ n\ times\),
              AutoIndent->False,
              FontWeight->"Plain"]},
          {
            StyleBox[\(ExtractRepeat[U]\),
              FontWeight->"Plain"], 
            RowBox[{
              
              StyleBox[\(gives\ a\ list\ of\ the\ repeated\ elements\ in\ U\),
                
                AutoIndent->False,
                FontWeight->"Plain"], 
              StyleBox[",",
                AutoIndent->False,
                FontWeight->"Plain"], 
              StyleBox[" ",
                AutoIndent->False,
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox["in",
                  AutoIndent->False,
                  FontWeight->"Plain"], 
                StyleBox[" ",
                  AutoIndent->False,
                  FontWeight->"Plain"], 
                StyleBox["the",
                  AutoIndent->False,
                  FontWeight->"Plain"], 
                StyleBox[" ",
                  AutoIndent->False,
                  FontWeight->"Plain"], 
                StyleBox["form",
                  AutoIndent->False,
                  FontWeight->"Plain"], 
                StyleBox[" ",
                  AutoIndent->False,
                  FontWeight->"Plain"], 
                RowBox[{
                  StyleBox["{",
                    FontWeight->"Plain"], 
                  RowBox[{
                    RowBox[{
                      StyleBox["{",
                        AutoIndent->False,
                        FontWeight->"Plain"], 
                      RowBox[{
                        SubscriptBox[
                          StyleBox["U",
                            AutoIndent->False,
                            FontWeight->"Plain"], "2"], 
                        StyleBox[",",
                          FontWeight->"Plain"], 
                        StyleBox["3",
                          FontWeight->"Plain"]}], 
                      StyleBox["}",
                        FontWeight->"Plain"]}], 
                    StyleBox[",",
                      FontWeight->"Plain"], 
                    StyleBox["..",
                      FontWeight->"Plain"]}], 
                  StyleBox["}",
                    FontWeight->"Plain"]}]}]}]},
          {\(\(Locations[S, 
              U]\)\(\ \)\), \(lists\ the\ positions\ of\ elements\ of\ U\ \
within\ S\)},
          {
            StyleBox[\(TakeAway[U, V]\ or\ U\[Backslash]V\),
              FontWeight->"Plain"], 
            
            StyleBox[\(\(\ \)\(gives\ the\ set\ U, \ 
              minus\ elements\ V . \ \ Not\ the\ same\ as\ Complement[U, 
                  V]\)\),
              FontWeight->"Plain"]},
          {\(Join[U, 
                V]\ or\ U\[Vee]V\), \(joins\ U\ with\ V . \ \ Not\ the\ same\ \
as\ U \[Union] \(\(V\)\(.\)\)\)},
          {\(ExactIntersection[U, 
                V]\ or\ U\[Wedge]V\), \(gives\ those\ elements\ that\ appear\ \
in\ both\ U\ and\ V . \ \ Not\ the\ same\ as\ U \[Intersection] \
\(\(V\)\(.\)\)\)},
          {
            RowBox[{
              StyleBox[\(AddUp[x, e, U]\),
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox["or",
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              RowBox[{
                UnderscriptBox[
                  StyleBox["\[Sum]",
                    FontWeight->"Plain"], \(e \[Element] U\)], "x"}]}], 
            
            StyleBox[\(gives\ the\ sum\ of\ x\ over\ all\ e\ in\ the\ list\ U \
. \ Thus, \ AddUp[f[e, z], e, {i, j, k}]\ gives\ f[i, z] + f[j, z] + 
                f[k, z]\),
              FontWeight->"Plain"]},
          {\(AddUp[x, e\_1, U\_1, e\_2, U\_2]\), \(is\ also\ defined\)},
          {
            RowBox[{
              StyleBox[\(TimesUp[x, e, U]\),
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox["or",
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              RowBox[{
                UnderscriptBox[
                  StyleBox["\[Product]",
                    FontWeight->"Plain"], \(e \[Element] U\)], "x"}]}], 
            
            StyleBox[\(gives\ the\ product\ of\ x\ over\ all\ e\ in\ the\ \
list\ U . \ Thus, \ 
              TimesUp[f[e, z], e, {i, j, k}]\ gives\ f[i, z] f[j, z] 
                f[k, z]\),
              FontWeight->"Plain"]},
          {\(TimesUp[x, e\_1, U\_1, e\_2, U\_2]\), \(is\ also\ defined\)},
          {
            StyleBox[\(Subsets[U]\),
              FontWeight->"Plain"], 
            
            StyleBox[\(gives\ a\ list\ of\ all\ subsets\ of\ U, \ 
              including\ {}\ and\ U\),
              AutoIndent->False,
              FontWeight->"Plain"]},
          {
            StyleBox[\(Subsets[U, i]\),
              FontWeight->"Plain"], 
            StyleBox[\(gi  ves\ subsets\ of\ length\ i\),
              FontWeight->"Plain"]},
          {
            RowBox[{
              StyleBox["Subsets",
                FontWeight->"Plain"], 
              StyleBox["[",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox["U",
                  FontWeight->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                SubscriptBox[
                  StyleBox["i",
                    FontWeight->"Plain"], "0"], ",", \(i\_1\)}], 
              StyleBox["]",
                FontWeight->"Plain"]}], 
            RowBox[{
              StyleBox[\(gi  ves\),
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox["subsets",
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox["of",
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox["length",
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              SubscriptBox[
                StyleBox["i",
                  FontWeight->"Plain"], "0"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox["to",
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              SubscriptBox[
                StyleBox["i",
                  FontWeight->"Plain"], "1"]}]},
          {\(SplitSet[
              U, {n\_1, \(n\_2\) \[Ellipsis]}]\), \(splits\ the\ set\ U\ into\
\ successive\ sets\ of\ length\ n\_1, \ \(n\_2\) \[Ellipsis]\)},
          {\(PartitionSet[U]\), \(gives\ all\ partitions\ of\ the\ set\ U\)},
          {\(PartitionSet[U, 
              j]\), \(gives\ all\ partitions\ of\ U\ into\ j\ elements\)},
          {\(PartitionSet[U, 
              Ordered \[Rule] 
                True]\), \(gives\ only\ partitions\ which\ respect\ the\ \
order\ of\ the\ elements\ in\ U\)},
          {\(StandardPartition[
              P]\), \(gives\ the\ standard\ form\ for\ partition\ P\)},
          {\(StandardPartitionQ[
              P]\), \(returns\ True\ if\ P\ is\ in\ the\ standard\ form\)},
          {\(NumberOfSetPartitions[
              n]\), \(gives\ the\ number\ of\ ways\ in\ which\ a\ set\ of\ n\ \
elements\ can\ be\ partitioned\)},
          {\(SamplePartition[{x, \ 
                y, \[Ellipsis]}]\), \(describes\ the\ structure\ of\ a\ \
sample\ of\ k\ objects, \ 
            by\ listing\ which\ of\ the\ k\ are\ \(\(equal\)\(.\)\)\)},
          {\(NumberOfSamplePartitions[P, 
              n]\), \(is\ the\ number\ of\ ways\ k\ items\ can\ be\ \
sampledwith\ replacement\ from\ a\ population\ of\ n\ objects, \ 
            so\ as\ to\ match\ the\ structure\ \(\(P\)\(.\)\)\)},
          {\(Lumpings[\[DoubleStruckCapitalP]]\), \(gives\ all\ the\ ways\ in\
\ which\ the\ elements\ of\ the\ partition\ \[DoubleStruckCapitalP]\ can\ be\ \
merged\)},
          {\(SetOfCombinations[{{a\_1, b\_1}, {a\_2, b\_2, 
                  c\_2}, \[Ellipsis]}]\), \(lists\ all\ the\ combinations\ of\
\ elements, \ {{a\_1, a\_2, \[Ellipsis]}, {a\_1, b\_1, \[Ellipsis]}}\)},
          {\(ConfigurationSet[{n1, n2\[Ellipsis]}, 
              k]\), \(lists\ all\ the\ distinct\ ways\ of\ combining\ the\ \
{n1, n2, \[Ellipsis]}\ objects\ into\ k\ sets\)},
          {
            StyleBox["Symmetrise",
              FontWeight->"Plain"], 
            
            StyleBox[\(is\ a\ rule\ which\ replaces\ f[
                  U]\ by\ the\ standard\ ordering\ of\ U\),
              FontWeight->"Plain"]},
          {\(ProductSum[V, 
              n]\), \(gives\ the\ sum\ of\ all\ products\ of\ n\ distinct\ \
elements\ of\ \(\(V\)\(.\)\)\)},
          {\(ProductSum[V\_1, V\_2, n\_1, n\_2]\), \(is\ also\ defined; \ 
            it\ is\ just\ ProductSum[V\_1, n\_1] ProductSum[V\_2, n\_2]\)},
          {\(\(ProductSum[n]\)[
              U]\), \(is\ a\ compiled\ version\ \((n < 7)\)\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(<< Utilities`SetManipulation`; \)], "Input",
  CellLabel->"In[1]:="],

Cell[TextData[{
  "Note: ",
  StyleBox["This package uses a few functions from \
DiscreteMath`Combinatorica` - for example, Subsets[].  There is a minor ",
    FontWeight->"Plain"],
  ButtonBox["bug",
    ButtonData:>{"Bugs", "Clashes between packages"},
    ButtonStyle->"AddOnsLink"],
  StyleBox[" in ",
    FontWeight->"Plain"],
  StyleBox["Mathematica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[", such that the same name is used for functions in \
DiscreteMath`Combinatorica` and other packages.",
    FontWeight->"Plain"]
}], "Text",
  FontWeight->"Bold"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{1011, 684},
WindowMargins->{{0, Automatic}, {Automatic, 1}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 52, 0, 36, "SubsectionIcon"],
Cell[1794, 53, 160, 4, 22, "Text"],
Cell[1957, 59, 291, 8, 23, "Text"],
Cell[2251, 69, 9323, 230, 590, "DefinitionBox"],
Cell[11577, 301, 46, 0, 28, "MathCaption"],
Cell[11626, 303, 88, 2, 27, "Input"],
Cell[11717, 307, 582, 17, 38, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

