(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4748,        103]*)
(*NotebookOutlinePosition[      5659,        132]*)
(*  CellTagsIndexPosition[      5615,        128]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Example data", "SubsectionIcon"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Utilities`StructuredModels`;\)\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
These data come from an experiment which investiagted variation in \
viability of lines of flies carrying different chromosomes, and reared at \
different densities (courtesy of Linda Partridge & Michael Gardner).  The \
array gives the numbers of flies emerging from each vial.  It is indexed by \
line, replicate, density, and vial.  There were 10 lines (carrying different \
chromosomes); 2 replicate cages for each line; 4 density treatments; and 5 \
sample vials for each treatment at densities 1, 2, 3, and 2 sample vials at \
density 4.  The four density treatments were set up with approximately 30, \
60, 90 and \"many\" eggs. \
\>", "Text"],

Cell[BoxData[
    \(\(dd = {{{{27, 29, 24, 27, 29}, {54, 48, 60, 58, 49}, {57, 59, 62, 53, 
                59}, {336, 342}}, {{24, 29, 26, 33, 26}, {47, 46, 45, 47, 
                42}, {51, 56, 55, 63, 58}, {241, 221}}}, {{{24, 23, 28, 29, 
                27}, {52, 47, 51, 56, 55}, {68, 66, 66, 89, 73}, {259, 
                297}}, {{27, 23, 27, 31, 28}, {52, 60, 49, 45, 47}, {66, 76, 
                68, 74, 68}, {239, 205}}}, {{{29, 25, 24, 14, 23}, {48, 45, 
                55, 41, 47}, {65, 74, 46, 72, 73}, {227, 133}}, {{21, 22, 33, 
                23, 18}, {48, 50, 45, 53, 53}, {47, 64, 71, 72, 63}, {223, 
                170}}}, {{{20, 12, 24, 21, 19}, {46, 47, 33, 32, 34}, {61, 
                56, 61, 57, 62}, {258, 256}}, {{15, 18, 25, 17, 22}, {38, 28, 
                43, 24, 40}, {73, 46, 51, 54, 62}, {143, 99}}}, {{{29, 27, 
                28, 23, 27}, {57, 49, 44, 49, 50}, {69, 68, 69, 60, 
                54}, {131, 197}}, {{29, 20, 26, 26, 25}, {46, 51, 34, 50, 
                49}, {73, 76, 68, 82, 68}, {147, 126}}}, {{{20, 23, 24, 22, 
                20}, {47, 44, 49, 47, 54}, {72, 66, 65, 73, 62}, {132, 
                107}}, {{29, 23, 22, 30, 27}, {44, 49, 44, 47, 54}, {74, 68, 
                55, 70, 61}, {114, 183}}}, {{{24, 26, 28, 27, 27}, {50, 62, 
                53, 54, 39}, {67, 73, 67, 83, 69}, {201, 230}}, {{29, 29, 28, 
                25, 28}, {59, 55, 49, 54, 55}, {86, 76, 85, 77, 68}, {242, 
                239}}}, {{{29, 27, 27, 25, 28}, {58, 54, 52, 54, 53}, {84, 
                82, 80, 79, 78}, {323, 267}}, {{29, 28, 28, 30, 26}, {53, 57, 
                53, 56, 57}, {78, 81, 88, 77, 88}, {348, 345}}}, {{{27, 26, 
                28, 28, 30}, {52, 58, 51, 53, 66}, {78, 85, 77, 69, 
                91}, {117, 275}}, {{28, 27, 24, 29, 27}, {60, 62, 54, 57, 
                60}, {86, 82, 88, 80, 76}, {253, 291}}}, {{{23, 22, 26, 28, 
                25}, {52, 51, 46, 56, 57}, {83, 86, 73, 72, 74}, {217, 
                241}}, {{32, 22, 27, 25, 27}, {44, 60, 52, 59, 52}, {85, 90, 
                77, 84, 71}, {159, 137}}}};\)\)], "Input",
  CellLabel->"In[6]:="]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{572, 668},
WindowMargins->{{17, Automatic}, {Automatic, 16}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 38, 0, 36, "SubsectionIcon"],
Cell[1780, 53, 46, 0, 28, "MathCaption"],
Cell[1829, 55, 92, 2, 27, "Input"],
Cell[1924, 59, 660, 10, 92, "Text"],
Cell[2587, 71, 2145, 29, 312, "Input"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

