(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7125,        208]*)
(*NotebookOutlinePosition[      8219,        243]*)
(*  CellTagsIndexPosition[      8127,        237]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Estimating initial parameters", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{"StructuredInitialParameters", "[", 
              StyleBox[\(data, vars, model, f\),
                FontSlant->"Italic"], 
              "]"}], \(supplies\ arrays\ of\ initial\ parameter\ values\ \
which\ are\ constructed\ using\ the\ function\ \(\(f[data]\)\(.\)\)\)},
          {
            RowBox[{"StructuredInitialParameters", "[", 
              
              StyleBox[\(data, 
                vars, {model\_1, \[Ellipsis]}, {f\_1, \[Ellipsis]}\),
                FontSlant->"Italic"], 
              StyleBox["]",
                
                FontSlant->
                  "Italic"]}], \(supplies\ a\ list\ for\ several\ \
\(\(parameters\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"StructuredInitialParameters"],

Cell["This loads the package", "MathCaption"],

Cell[BoxData[
    \(\(<< Utilities`StructuredModels`;\)\)], "Input",
  CellLabel->"In[1]:="],

Cell[TextData[{
  "This supplies arrays which are estimated from the Log[Mean[",
  StyleBox["data",
    FontSlant->"Italic"],
  "]]:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StructuredInitialParameters[dd, {line, rep, density}, {density, line}, 
      N[Log[Mean[#]]] &]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \({4.225372824628505`, {\(-0.9886570816319735`\), \(-0.31394999927239153`\
\), 0.029246484128814032`, 1.1534871246347187`}, {0.06548943626350034`, 
        0.07031065894095256`, \(-0.09397807810980119`\), \
\(-0.20370437930965224`\), \(-0.1374212027926669`\), \
\(-0.19113218647610974`\), 0.057807975408743495`, 0.22829024306597834`, 
        0.10960844635532219`, 0.004033820858331261`}}\)], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell[TextData[{
  "The data array is flattened out to classes corresponding to the model \
elements, and ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " mapped onto the flattened array.  The first element is ",
  Cell[BoxData[
      \(TraditionalForm\`f[data]\)]],
  "; the second is ",
  Cell[BoxData[
      \(TraditionalForm\`{f[data\_\(d = 1\)], \[Ellipsis]}\)]],
  ", and so on.  Here, ",
  Cell[BoxData[
      \(TraditionalForm\`f[]\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`Log[Mean[]]\)]],
  ", and so these values are the logs of the arithmetic means of the various \
classes.  As a final step, the overall ",
  Cell[BoxData[
      FormBox[
        RowBox[{"value", " ", 
          RowBox[{"f", "[", 
            StyleBox["data",
              FontSlant->"Italic"], "]"}]}], TraditionalForm]]],
  " is subtracted from each effect, as a normalisation.  Note that this \
normalisation differs from that used in StructuredLogLikelihood[]."
}], "Text"],

Cell[TextData[{
  "This supplies a pair of arrays, one calculated as Log[Mean[",
  StyleBox["data",
    FontSlant->"Italic"],
  "]], the other as ",
  Cell[BoxData[
      FormBox[
        RowBox[{"Log", "[", 
          FractionBox[
            RowBox[{"Variance", "[", 
              StyleBox["data",
                FontSlant->"Italic"], "]"}], 
            RowBox[{"Mean", "[", 
              StyleBox["data",
                FontSlant->"Italic"], "]"}]]}], TraditionalForm]]],
  "]:"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StructuredInitialParameters[
      dd, {line, rep, 
        density}, {{density, {rep, line}}, {density}}, {N[Log[Mean[#]]] &, 
        N[Log[Variance[#]\/Mean[#]]] &}]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \({{4.225372824628505`, {\(-0.9886570816319735`\), \
\(-0.31394999927239153`\), 0.029246484128814032`, 
          1.1534871246347187`}, {{0.16616723708324965`, 
            0.11919624751047575`, \(-0.11064910006975204`\), \
\(-0.05643021428110018`\), \(-0.12030168466776114`\), \
\(-0.2266326031188659`\), 0.014683548774988786`, 0.18564134691862844`, 
            0.04061557486837142`, 
            0.057807975408743495`}, {\(-0.04647087437834152`\), 
            0.018911884884510677`, \(-0.07758042796299147`\), \
\(-0.37647757123491266`\), \(-0.15483891110012316`\), \(-0.15684896202814702`\
\), 0.09914931556518525`, 0.26919436973691013`, 
            0.17414696749289327`, \(-0.05279714943121849`\)}}}, \
{4.0420266021919184`, {\(-4.572208444604204`\), \(-3.9613072604925708`\), \
\(-3.5407499510532627`\), \(-0.8658099558721903`\)}}}\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell["\<\
Note that using Mean[Log[data]] gives a substantially different \
result:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StructuredInitialParameters[dd, {line, rep, density}, {density, line}, 
      N[Mean[Log[#]]] &]\)], "Input",
  CellLabel->"In[434]:="],

Cell[BoxData[
    \({3.9684402997789507`, {\(-0.7451104230071612`\), \
\(-0.06943969770549074`\), 0.2740023645391232`, 
        1.351369390433828`}, {0.0033524469385484146`, 
        0.05667089822016669`, \(-0.07431964606889974`\), \
\(-0.2509415852869581`\), \(-0.04604521268485673`\), \
\(-0.09192751756807471`\), 0.07460471724941042`, 0.1571196333656073`, 
        0.12170788220171813`, 0.04977838363333875`}}\)], "Output",
  CellLabel->"Out[434]="]
}, Open  ]],

Cell["\<\
Now, estimates are based on the aruthmetic mean of Log[data], equal \
to the Log of the geometric mean.\
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{572, 668},
WindowMargins->{{17, Automatic}, {Automatic, 16}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "StructuredInitialParameters"->{
    Cell[1797, 53, 841, 20, 84, "DefinitionBox",
      CellTags->"StructuredInitialParameters"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"StructuredInitialParameters", 8004, 230}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 55, 0, 36, "SubsectionIcon"],
Cell[1797, 53, 841, 20, 84, "DefinitionBox",
  CellTags->"StructuredInitialParameters"],
Cell[2641, 75, 45, 0, 28, "MathCaption"],
Cell[2689, 77, 92, 2, 27, "Input"],
Cell[2784, 81, 152, 5, 30, "MathCaption"],

Cell[CellGroupData[{
Cell[2961, 90, 154, 3, 27, "Input"],
Cell[3118, 95, 445, 7, 33, "Output"]
}, Open  ]],
Cell[3578, 105, 977, 27, 78, "Text"],
Cell[4558, 134, 505, 16, 74, "MathCaption"],

Cell[CellGroupData[{
Cell[5088, 154, 226, 5, 64, "Input"],
Cell[5317, 161, 896, 15, 72, "Output"]
}, Open  ]],
Cell[6228, 179, 104, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6357, 186, 155, 3, 27, "Input"],
Cell[6515, 191, 452, 8, 46, "Output"]
}, Open  ]],
Cell[6982, 202, 127, 3, 22, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

