(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     18257,        425]*)
(*NotebookOutlinePosition[     19459,        464]*)
(*  CellTagsIndexPosition[     19343,        457]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Internal functions", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(StructuredModel[
              vars, {model}]\), \(replaces\ the\ variable\ names\ by\ their\ \
position\ in\ the\ array\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"StructuredModel"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Utilities`StructuredModels`;\)\)], "Input",
  CellLabel->"In[1]:="],

Cell["This describes the structure of the model:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StructuredModel[{line, rep, 
        density}, {{density, {rep, line}}}]\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \({{{3}, {2, 1}}}\)], "Output",
  CellLabel->"Out[49]="]
}, Open  ]],

Cell["A list of models can also be given:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StructuredModel[{line, rep, 
        density}, {{density}, {density, {rep, line}}}]\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \({{{3}}, {{3}, {2, 1}}}\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell["\<\
Note that {density,{rep,line}} is equivalent to \
{{density},{rep,line}}; the correct replacement is made by StructuredModel[].\
\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(StructuredArray[data, vars, 
              model]\), \(creates\ a\ transposed\ array\ with\ a\ structure\ \
appropriate\ to\ the\ \(\(model\)\(.\)\)\)}
          }], TraditionalForm]]]], "DefinitionBox",
  CellTags->"StructuredArray"],

Cell["This is a five-dimensional array:", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ff = Array[f\_## &, {2, 3, 2, 3, 2}]; ff // MatrixForm\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 1, 1, 1, 1\)\)},
                            {\(f\_\(1, 1, 1, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 1, 1, 2, 1\)\)},
                            {\(f\_\(1, 1, 1, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 1, 1, 3, 1\)\)},
                            {\(f\_\(1, 1, 1, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]},
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 1, 2, 1, 1\)\)},
                            {\(f\_\(1, 1, 2, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 1, 2, 2, 1\)\)},
                            {\(f\_\(1, 1, 2, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 1, 2, 3, 1\)\)},
                            {\(f\_\(1, 1, 2, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 2, 1, 1, 1\)\)},
                            {\(f\_\(1, 2, 1, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 2, 1, 2, 1\)\)},
                            {\(f\_\(1, 2, 1, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 2, 1, 3, 1\)\)},
                            {\(f\_\(1, 2, 1, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]},
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 2, 2, 1, 1\)\)},
                            {\(f\_\(1, 2, 2, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 2, 2, 2, 1\)\)},
                            {\(f\_\(1, 2, 2, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 2, 2, 3, 1\)\)},
                            {\(f\_\(1, 2, 2, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 3, 1, 1, 1\)\)},
                            {\(f\_\(1, 3, 1, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 3, 1, 2, 1\)\)},
                            {\(f\_\(1, 3, 1, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 3, 1, 3, 1\)\)},
                            {\(f\_\(1, 3, 1, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]},
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 3, 2, 1, 1\)\)},
                            {\(f\_\(1, 3, 2, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 3, 2, 2, 1\)\)},
                            {\(f\_\(1, 3, 2, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(1, 3, 2, 3, 1\)\)},
                            {\(f\_\(1, 3, 2, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 1, 1, 1, 1\)\)},
                            {\(f\_\(2, 1, 1, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 1, 1, 2, 1\)\)},
                            {\(f\_\(2, 1, 1, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 1, 1, 3, 1\)\)},
                            {\(f\_\(2, 1, 1, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]},
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 1, 2, 1, 1\)\)},
                            {\(f\_\(2, 1, 2, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 1, 2, 2, 1\)\)},
                            {\(f\_\(2, 1, 2, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 1, 2, 3, 1\)\)},
                            {\(f\_\(2, 1, 2, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 2, 1, 1, 1\)\)},
                            {\(f\_\(2, 2, 1, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 2, 1, 2, 1\)\)},
                            {\(f\_\(2, 2, 1, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 2, 1, 3, 1\)\)},
                            {\(f\_\(2, 2, 1, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]},
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 2, 2, 1, 1\)\)},
                            {\(f\_\(2, 2, 2, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 2, 2, 2, 1\)\)},
                            {\(f\_\(2, 2, 2, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 2, 2, 3, 1\)\)},
                            {\(f\_\(2, 2, 2, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 3, 1, 1, 1\)\)},
                            {\(f\_\(2, 3, 1, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 3, 1, 2, 1\)\)},
                            {\(f\_\(2, 3, 1, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 3, 1, 3, 1\)\)},
                            {\(f\_\(2, 3, 1, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]},
                    {
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 3, 2, 1, 1\)\)},
                            {\(f\_\(2, 3, 2, 1, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 3, 2, 2, 1\)\)},
                            {\(f\_\(2, 3, 2, 2, 2\)\)}
                            }], "\[NoBreak]", ")"}], 
                      RowBox[{"(", "\[NoBreak]", GridBox[{
                            {\(f\_\(2, 3, 2, 3, 1\)\)},
                            {\(f\_\(2, 3, 2, 3, 2\)\)}
                            }], "\[NoBreak]", ")"}]}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{{{
        Subscript[ f, 1, 1, 1, 1, 1], 
        Subscript[ f, 1, 1, 1, 1, 2]}, {
        Subscript[ f, 1, 1, 1, 2, 1], 
        Subscript[ f, 1, 1, 1, 2, 2]}, {
        Subscript[ f, 1, 1, 1, 3, 1], 
        Subscript[ f, 1, 1, 1, 3, 2]}}, {{
        Subscript[ f, 1, 1, 2, 1, 1], 
        Subscript[ f, 1, 1, 2, 1, 2]}, {
        Subscript[ f, 1, 1, 2, 2, 1], 
        Subscript[ f, 1, 1, 2, 2, 2]}, {
        Subscript[ f, 1, 1, 2, 3, 1], 
        Subscript[ f, 1, 1, 2, 3, 2]}}}, {{{
        Subscript[ f, 1, 2, 1, 1, 1], 
        Subscript[ f, 1, 2, 1, 1, 2]}, {
        Subscript[ f, 1, 2, 1, 2, 1], 
        Subscript[ f, 1, 2, 1, 2, 2]}, {
        Subscript[ f, 1, 2, 1, 3, 1], 
        Subscript[ f, 1, 2, 1, 3, 2]}}, {{
        Subscript[ f, 1, 2, 2, 1, 1], 
        Subscript[ f, 1, 2, 2, 1, 2]}, {
        Subscript[ f, 1, 2, 2, 2, 1], 
        Subscript[ f, 1, 2, 2, 2, 2]}, {
        Subscript[ f, 1, 2, 2, 3, 1], 
        Subscript[ f, 1, 2, 2, 3, 2]}}}, {{{
        Subscript[ f, 1, 3, 1, 1, 1], 
        Subscript[ f, 1, 3, 1, 1, 2]}, {
        Subscript[ f, 1, 3, 1, 2, 1], 
        Subscript[ f, 1, 3, 1, 2, 2]}, {
        Subscript[ f, 1, 3, 1, 3, 1], 
        Subscript[ f, 1, 3, 1, 3, 2]}}, {{
        Subscript[ f, 1, 3, 2, 1, 1], 
        Subscript[ f, 1, 3, 2, 1, 2]}, {
        Subscript[ f, 1, 3, 2, 2, 1], 
        Subscript[ f, 1, 3, 2, 2, 2]}, {
        Subscript[ f, 1, 3, 2, 3, 1], 
        Subscript[ f, 1, 3, 2, 3, 2]}}}}, {{{{
        Subscript[ f, 2, 1, 1, 1, 1], 
        Subscript[ f, 2, 1, 1, 1, 2]}, {
        Subscript[ f, 2, 1, 1, 2, 1], 
        Subscript[ f, 2, 1, 1, 2, 2]}, {
        Subscript[ f, 2, 1, 1, 3, 1], 
        Subscript[ f, 2, 1, 1, 3, 2]}}, {{
        Subscript[ f, 2, 1, 2, 1, 1], 
        Subscript[ f, 2, 1, 2, 1, 2]}, {
        Subscript[ f, 2, 1, 2, 2, 1], 
        Subscript[ f, 2, 1, 2, 2, 2]}, {
        Subscript[ f, 2, 1, 2, 3, 1], 
        Subscript[ f, 2, 1, 2, 3, 2]}}}, {{{
        Subscript[ f, 2, 2, 1, 1, 1], 
        Subscript[ f, 2, 2, 1, 1, 2]}, {
        Subscript[ f, 2, 2, 1, 2, 1], 
        Subscript[ f, 2, 2, 1, 2, 2]}, {
        Subscript[ f, 2, 2, 1, 3, 1], 
        Subscript[ f, 2, 2, 1, 3, 2]}}, {{
        Subscript[ f, 2, 2, 2, 1, 1], 
        Subscript[ f, 2, 2, 2, 1, 2]}, {
        Subscript[ f, 2, 2, 2, 2, 1], 
        Subscript[ f, 2, 2, 2, 2, 2]}, {
        Subscript[ f, 2, 2, 2, 3, 1], 
        Subscript[ f, 2, 2, 2, 3, 2]}}}, {{{
        Subscript[ f, 2, 3, 1, 1, 1], 
        Subscript[ f, 2, 3, 1, 1, 2]}, {
        Subscript[ f, 2, 3, 1, 2, 1], 
        Subscript[ f, 2, 3, 1, 2, 2]}, {
        Subscript[ f, 2, 3, 1, 3, 1], 
        Subscript[ f, 2, 3, 1, 3, 2]}}, {{
        Subscript[ f, 2, 3, 2, 1, 1], 
        Subscript[ f, 2, 3, 2, 1, 2]}, {
        Subscript[ f, 2, 3, 2, 2, 1], 
        Subscript[ f, 2, 3, 2, 2, 2]}, {
        Subscript[ f, 2, 3, 2, 3, 1], 
        Subscript[ f, 2, 3, 2, 3, 2]}}}}}]]], "Output",
  CellLabel->"Out[2]//MatrixForm="]
}, Open  ]],

Cell["\<\
The array consists of elements indexed by four variables \
{v1,v2,v3,v4}; each element is a list.  This gives a flattened tw-dimensional \
array, approdiate for a model with two components.  \
\>", "Text"],

Cell["\<\
The first index now corresponds to v2, and the second to {v1,v4}.\
\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StructuredArray[ff, {v1, v2, v3, v4}, {v2, {v1, v4}}]\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \({{{f\_\(1, 1, 1, 1, 1\), f\_\(1, 1, 1, 1, 2\), f\_\(1, 1, 2, 1, 1\), 
          f\_\(1, 1, 2, 1, 2\)}, {f\_\(1, 1, 1, 2, 1\), f\_\(1, 1, 1, 2, 2\), 
          f\_\(1, 1, 2, 2, 1\), f\_\(1, 1, 2, 2, 2\)}, {f\_\(1, 1, 1, 3, 1\), 
          f\_\(1, 1, 1, 3, 2\), f\_\(1, 1, 2, 3, 1\), 
          f\_\(1, 1, 2, 3, 2\)}, {f\_\(2, 1, 1, 1, 1\), f\_\(2, 1, 1, 1, 2\), 
          f\_\(2, 1, 2, 1, 1\), f\_\(2, 1, 2, 1, 2\)}, {f\_\(2, 1, 1, 2, 1\), 
          f\_\(2, 1, 1, 2, 2\), f\_\(2, 1, 2, 2, 1\), 
          f\_\(2, 1, 2, 2, 2\)}, {f\_\(2, 1, 1, 3, 1\), f\_\(2, 1, 1, 3, 2\), 
          f\_\(2, 1, 2, 3, 1\), 
          f\_\(2, 1, 2, 3, 2\)}}, {{f\_\(1, 2, 1, 1, 1\), 
          f\_\(1, 2, 1, 1, 2\), f\_\(1, 2, 2, 1, 1\), 
          f\_\(1, 2, 2, 1, 2\)}, {f\_\(1, 2, 1, 2, 1\), f\_\(1, 2, 1, 2, 2\), 
          f\_\(1, 2, 2, 2, 1\), f\_\(1, 2, 2, 2, 2\)}, {f\_\(1, 2, 1, 3, 1\), 
          f\_\(1, 2, 1, 3, 2\), f\_\(1, 2, 2, 3, 1\), 
          f\_\(1, 2, 2, 3, 2\)}, {f\_\(2, 2, 1, 1, 1\), f\_\(2, 2, 1, 1, 2\), 
          f\_\(2, 2, 2, 1, 1\), f\_\(2, 2, 2, 1, 2\)}, {f\_\(2, 2, 1, 2, 1\), 
          f\_\(2, 2, 1, 2, 2\), f\_\(2, 2, 2, 2, 1\), 
          f\_\(2, 2, 2, 2, 2\)}, {f\_\(2, 2, 1, 3, 1\), f\_\(2, 2, 1, 3, 2\), 
          f\_\(2, 2, 2, 3, 1\), 
          f\_\(2, 2, 2, 3, 2\)}}, {{f\_\(1, 3, 1, 1, 1\), 
          f\_\(1, 3, 1, 1, 2\), f\_\(1, 3, 2, 1, 1\), 
          f\_\(1, 3, 2, 1, 2\)}, {f\_\(1, 3, 1, 2, 1\), f\_\(1, 3, 1, 2, 2\), 
          f\_\(1, 3, 2, 2, 1\), f\_\(1, 3, 2, 2, 2\)}, {f\_\(1, 3, 1, 3, 1\), 
          f\_\(1, 3, 1, 3, 2\), f\_\(1, 3, 2, 3, 1\), 
          f\_\(1, 3, 2, 3, 2\)}, {f\_\(2, 3, 1, 1, 1\), f\_\(2, 3, 1, 1, 2\), 
          f\_\(2, 3, 2, 1, 1\), f\_\(2, 3, 2, 1, 2\)}, {f\_\(2, 3, 1, 2, 1\), 
          f\_\(2, 3, 1, 2, 2\), f\_\(2, 3, 2, 2, 1\), 
          f\_\(2, 3, 2, 2, 2\)}, {f\_\(2, 3, 1, 3, 1\), f\_\(2, 3, 1, 3, 2\), 
          f\_\(2, 3, 2, 3, 1\), f\_\(2, 3, 2, 3, 2\)}}}\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell["\<\
StructuredArray[] could be used to find log likelihoods for \
structured models in a simple way.  However, it cannot be used when different \
models are fitted to different parameters, and so is not taken further.\
\>", \
"Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{572, 668},
WindowMargins->{{17, Automatic}, {Automatic, 16}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "StructuredModel"->{
    Cell[1786, 53, 269, 6, 37, "DefinitionBox",
      CellTags->"StructuredModel"]},
  "StructuredArray"->{
    Cell[2993, 101, 297, 6, 50, "DefinitionBox",
      CellTags->"StructuredArray"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"StructuredModel", 19124, 447},
  {"StructuredArray", 19232, 450}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 44, 0, 36, "SubsectionIcon"],
Cell[1786, 53, 269, 6, 37, "DefinitionBox",
  CellTags->"StructuredModel"],
Cell[2058, 61, 46, 0, 28, "MathCaption"],
Cell[2107, 63, 92, 2, 27, "Input"],
Cell[2202, 67, 65, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2292, 71, 130, 3, 27, "Input"],
Cell[2425, 76, 74, 2, 20, "Output"]
}, Open  ]],
Cell[2514, 81, 58, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[2597, 85, 141, 3, 27, "Input"],
Cell[2741, 90, 81, 2, 20, "Output"]
}, Open  ]],
Cell[2837, 95, 153, 4, 36, "Text"],
Cell[2993, 101, 297, 6, 50, "DefinitionBox",
  CellTags->"StructuredArray"],
Cell[3293, 109, 56, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[3374, 113, 111, 2, 27, "Input"],
Cell[3488, 117, 12036, 247, 147, "Output"]
}, Open  ]],
Cell[15539, 367, 215, 4, 36, "Text"],
Cell[15757, 373, 98, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[15880, 380, 111, 2, 27, "Input"],
Cell[15994, 384, 1993, 30, 133, "Output"]
}, Open  ]],
Cell[18002, 417, 239, 5, 36, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

