(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11339,        342]*)
(*NotebookOutlinePosition[     12223,        370]*)
(*  CellTagsIndexPosition[     12179,        366]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Variance components", "SubsectionIcon"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(VarianceComponents[
              m]\), \(gives\ the\ variance\ components\ associated\ with\ the\
\ matrix\ m, \ 
            in\ the\ form\ {{v\_1, \(v\_\(\(2\)\(,\)\)\) \[Ellipsis]}, {\(v\_\
\(2, 3\)\) \[Ellipsis]}, {\(v\_\(i, j, k\)\) \[Ellipsis]} \[Ellipsis]}\)}
          }], TraditionalForm]]]], "DefinitionBox"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`VarianceComponents[m]\)]],
  " gives the components of variance for the matrix.  "
}], "Text"],

Cell["This loads the package:", "MathCaption"],

Cell[BoxData[
    \(\(<< Utilities`Matrices`;\)\)], "Input",
  CellLabel->"In[9]:="],

Cell["\<\
In this example, the values are a sum of row and column effects, \
and so there is no interaction variance:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"VarianceComponents", "[", 
      RowBox[{"(", GridBox[{
            {\(-1\), "2", "3", "0"},
            {"0", "3", "4", "1"},
            {"1", "4", "5", "2"}
            }], ")"}], "]"}]], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \({{0}, {1, 10\/3}, {0}}\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell[TextData[{
  "Values are given as a list of zero'th, first, second\[Ellipsis] order \
components.  Thus, the first element is the variance of the main effect \
(always zero); the second, the variances of each of the first-order effects; \
the third, the variances of each of the second-order effects; and so on.  The \
order of the elements in the ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "'th order list  in the same order as in ",
  Cell[BoxData[
      \(TraditionalForm\`Subsets[{1, 2, 3  \[Ellipsis]}, k]\)]],
  ".  For example, second order elements are ordered as ",
  Cell[BoxData[
      \(TraditionalForm\`{v\_\(1, 2\), \ v\_\(1, 3\), \[Ellipsis], 
        v\_\(2, 3\), v\_\(2, 4\), \[Ellipsis]}\)]],
  "."
}], "Text"],

Cell[TextData[{
  "In this example of a fourth-order matrix, there are additive effects of ",
  Cell[BoxData[
      \(TraditionalForm\`{i, j, k}\)]],
  ", and interactions ",
  Cell[BoxData[
      \(TraditionalForm\`j\[Times]l\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i\[Times]j\[Times]k\)]],
  ":"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tn = 
      Table[i + 2  j + 3  k + l*j + i*j*k, {i, 2}, {j, 3}, {k, 4}, {l, 3}]; 
    tn // MatrixForm\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"8", "9", "10"},
                    {"12", "13", "14"},
                    {"16", "17", "18"},
                    {"20", "21", "22"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"12", "14", "16"},
                    {"17", "19", "21"},
                    {"22", "24", "26"},
                    {"27", "29", "31"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"16", "19", "22"},
                    {"22", "25", "28"},
                    {"28", "31", "34"},
                    {"34", "37", "40"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"10", "11", "12"},
                    {"15", "16", "17"},
                    {"20", "21", "22"},
                    {"25", "26", "27"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"15", "17", "19"},
                    {"22", "24", "26"},
                    {"29", "31", "33"},
                    {"36", "38", "40"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"20", "23", "26"},
                    {"29", "32", "35"},
                    {"38", "41", "44"},
                    {"47", "50", "53"}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{{8, 9, 10}, {12, 13, 14}, {16, 17, 18}, {20, 21, 22}}, {{
        12, 14, 16}, {17, 19, 21}, {22, 24, 26}, {27, 29, 31}}, {{16, 19, 
        22}, {22, 25, 28}, {28, 31, 34}, {34, 37, 40}}}, {{{10, 11, 12}, {15, 
        16, 17}, {20, 21, 22}, {25, 26, 27}}, {{15, 17, 19}, {22, 24, 26}, {
        29, 31, 33}, {36, 38, 40}}, {{20, 23, 26}, {29, 32, 35}, {38, 41, 
        44}, {47, 50, 53}}}}]]], "Output",
  CellLabel->"Out[23]//MatrixForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(VarianceComponents[tn]\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \({{0}, {18, 961\/16, 60, 4}, {5\/4, 10\/7, 0, 45\/22, 1\/2, 0}, {5\/23, 
        0, 0, 0}, {0}}\)], "Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell["\<\
These components correspond to the same order as in \
Subsets[]:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Subsets[{i, j, k, l}]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \({{}, {i}, {j}, {k}, {l}, {i, j}, {i, k}, {i, l}, {j, k}, {j, l}, {k, 
        l}, {i, j, k}, {i, j, l}, {i, k, l}, {j, k, l}, {i, j, k, 
        l}}\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell[TextData[{
  "There is an additive effect of ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  ", induced by the higher-order term ",
  Cell[BoxData[
      \(TraditionalForm\`l\[Times]j\)]],
  ".  Similarly, there are pairwise interactions  ",
  Cell[BoxData[
      \(TraditionalForm\`i\[Times]j\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i\[Times]k\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j\[Times]k\)]],
  " induced by ",
  Cell[BoxData[
      \(TraditionalForm\`i\[Times]j\[Times]k\)]],
  ".  There is no four way interaction."
}], "Text"],

Cell["\<\
VarianceComponents[] can be slow for four or more dimensions.\
\>", \
"Text"],

Cell[TextData[{
  "Variances are calculated using the unbiased estimator, ",
  Cell[BoxData[
      FormBox[
        FractionBox[
          FormBox[\(\[Sum]x\_i\%2\),
            "TraditionalForm"], \(n - 1\)], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(VarianceComponents[m, 
              Table \[Rule] 
                True]\), \(lists\ the\ components\ at\ each\ \(\(level\)\(.\)\
\)\)}
          }], TraditionalForm]],
  CellTags->"Table"]], "DefinitionBox"],

Cell["\<\
The original values are represented as a sum of components; the \
variances are the variances of each of the arrays.  \
\>", "Text"],

Cell["This lists the components at each level:  ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(VarianceComponents[tn, Table \[Rule] True]\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \({{49\/2}, {{\(-3\), 3}, {\(-\(31\/4\)\), 0, 31\/4}, {\(-9\), \(-3\), 3, 
          9}, {\(-2\), 0, 
          2}}, {{{5\/4, 0, \(-\(5\/4\)\)}, {\(-\(5\/4\)\), 0, 5\/4}}, {{3\/2, 
            1\/2, \(-\(1\/2\)\), \(-\(3\/2\)\)}, {\(-\(3\/2\)\), \
\(-\(1\/2\)\), 1\/2, 3\/2}}, {{0, 0, 0}, {0, 0, 0}}, {{9\/4, 
            3\/4, \(-\(3\/4\)\), \(-\(9\/4\)\)}, {0, 0, 0, 
            0}, {\(-\(9\/4\)\), \(-\(3\/4\)\), 3\/4, 9\/4}}, {{1, 
            0, \(-1\)}, {0, 0, 0}, {\(-1\), 0, 1}}, {{0, 0, 0}, {0, 0, 
            0}, {0, 0, 0}, {0, 0, 
            0}}}, {{{{\(-\(3\/4\)\), \(-\(1\/4\)\), 1\/4, 3\/4}, {0, 0, 0, 
              0}, {3\/4, 1\/4, \(-\(1\/4\)\), \(-\(3\/4\)\)}}, {{3\/4, 
              1\/4, \(-\(1\/4\)\), \(-\(3\/4\)\)}, {0, 0, 0, 
              0}, {\(-\(3\/4\)\), \(-\(1\/4\)\), 1\/4, 3\/4}}}, {{{0, 0, 
              0}, {0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 
              0}}}, {{{0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}}, {{0, 0, 
              0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}}}, {{{0, 0, 0}, {0, 0, 
              0}, {0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 
              0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
              0}}}}, {{{{{0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}}, {{0, 0, 
                0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 
                0}, {0, 0, 0}, {0, 0, 0}}}, {{{0, 0, 0}, {0, 0, 0}, {0, 0, 
                0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 0}, {0, 0, 
                0}}}}}}\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell[TextData[{
  "The original value ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(1, 2, 1, 2\)\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`z\^0 + z\_\(1; 1\)\%1 + z\_\(2; 2\)\%1 + 
        z\_\(1; 1\)\%1 + 
        z\_\(2; 2\)\%1 + \(z\_\(1, 2; 1, 2\)\%2\) \[Ellipsis]\)]],
  "."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {\(VarianceComponents[m, {\[Alpha], \[Beta]\[Ellipsis]}, 
              Table \[Rule] 
                True]\), \(lists\ the\ components\ for\ levels\ {\[Alpha], \
\[Beta]\[Ellipsis]}\)}
          }], TraditionalForm]],
  CellTags->"Table"]], "DefinitionBox"],

Cell["\<\
This lists the pairwise interactions involving dimensions 1 & \
3:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(VarianceComponents[tn, {1, 3}, Table \[Rule] True]\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \({{3\/2, 
        1\/2, \(-\(1\/2\)\), \(-\(3\/2\)\)}, {\(-\(3\/2\)\), \(-\(1\/2\)\), 
        1\/2, 3\/2}}\)], "Output",
  CellLabel->"Out[27]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 626},
WindowMargins->{{Automatic, 178}, {12, Automatic}},
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 45, 0, 36, "SubsectionIcon"],
Cell[1787, 53, 382, 7, 64, "DefinitionBox"],
Cell[2172, 62, 151, 4, 22, "Text"],
Cell[2326, 68, 46, 0, 28, "MathCaption"],
Cell[2375, 70, 84, 2, 27, "Input"],
Cell[2462, 74, 138, 3, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[2625, 81, 251, 7, 58, "Input"],
Cell[2879, 90, 81, 2, 36, "Output"]
}, Open  ]],
Cell[2975, 95, 743, 16, 78, "Text"],
Cell[3721, 113, 330, 11, 42, "MathCaption"],

Cell[CellGroupData[{
Cell[4076, 128, 161, 4, 42, "Input"],
Cell[4240, 134, 2142, 48, 131, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6419, 187, 80, 2, 27, "Input"],
Cell[6502, 191, 153, 3, 36, "Output"]
}, Open  ]],
Cell[6670, 197, 95, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[6790, 204, 79, 2, 27, "Input"],
Cell[6872, 208, 207, 4, 33, "Output"]
}, Open  ]],
Cell[7094, 215, 575, 20, 36, "Text"],
Cell[7672, 237, 87, 3, 22, "Text"],
Cell[7762, 242, 247, 8, 39, "Text"],
Cell[8012, 252, 272, 7, 37, "DefinitionBox"],
Cell[8287, 261, 142, 3, 36, "Text"],
Cell[8432, 266, 65, 0, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[8522, 270, 100, 2, 27, "Input"],
Cell[8625, 274, 1640, 25, 290, "Output"]
}, Open  ]],
Cell[10280, 302, 308, 10, 25, "Text"],
Cell[10591, 314, 319, 7, 50, "DefinitionBox"],
Cell[10913, 323, 97, 3, 28, "MathCaption"],

Cell[CellGroupData[{
Cell[11035, 330, 108, 2, 27, "Input"],
Cell[11146, 334, 165, 4, 36, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

