(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10863,        273]*)
(*NotebookOutlinePosition[     11774,        302]*)
(*  CellTagsIndexPosition[     11730,        298]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(\(BeginPackage["\<Utilities`Hyperlinks`\>"];\)\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell["Public parts", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
FindHyperlinks[] finds all hyperlinks within the selected notebook, \
and lists their targets.  For each occurrence, the result is specified as \
{hyperlink name,{filename,cell tag}}.  If the cell tag is not specified, the \
last element is None.  Note that filename is represented in a form usable by \
FrontEndExecute[FrontEnd`NotebookLocate[filename]]\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(FindHyperlinks::usage = "\<FindHyperlinks[] finds all hyperlinks \
within the selected notebook, and lists their targets.  For each occurrence, \
the result is specified as {hyperlink name,{filename,cell tag}}.  If the cell \
tag is not specified, the last element is None.  Note that filename is \
represented in a form usable by \
FrontEndExecute[FrontEnd`NotebookLocate[filename]]. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
FindIndexTag[filename] looks up the IndexTag defined for this file \
in the appropriate BrowserCategories.m file.  This allows conversion between \
standard hyperlinks (which refer to files by their names) and Add-ons \
hyperlinks, which refer to files by their index tags.  the file name must be \
specified\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(FindIndexTag::usage = "\<FindIndexTag[filename] looks up the IndexTag \
defined for this file in the appropriate BrowserCategories.m file.  This \
allows conversion between standard hyperlinks (which refer to files by their \
names) and Add-ons hyperlinks, which refer to files by their index tags.  The \
file name must be specified in a form usable by the Front End.\>";\)\)], \
"Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ConvertHyperlinkToAddOnsLink[] finds all hyperlinks within the \
selected notebook, and changes them to the style AddOnsLink.  This requires \
that the target file name be converted to the IndexTag, which must be \
specified in BrowserCategories.m. The new version is created as an untitled \
notebook; this should be given a HelpBrowser style sheet.\
\>", \
"Subsubsection"],

Cell[BoxData[
    \(\(ConvertHyperlinkToAddOnsLink::usage = \
"\<ConvertHyperlinkToAddOnsLink[] finds all hyperlinks within the selected \
notebook, and changes them to the style AddOnsLink.  This requires that the \
target file name be converted to the IndexTag, which must be specified in \
BrowserCategories.m. The new version is created as an untitled notebook; this \
should be given a HelpBrowser style sheet.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Private parts", "Subsection"],

Cell[BoxData[
    \(\(Begin["\<Utilities`Hyperlinks`Private`\>"];\)\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell["\<\
FindHyperlinks[] finds all hyperlinks within the selected notebook, \
and lists their targets.  For each occurrence, the result is specified as \
{hyperlink name,{filename,cell tag}}.  If the cell tag is not specified, the \
last element is None.  Note that filename is represented in a form usable by \
FrontEndExecute[FrontEnd`NotebookLocate[filename]]\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(FindHyperlinks[] := 
        Module[\[IndentingNewLine]{nb = SelectedNotebook[], expr, 
            ps}, \[IndentingNewLine]SelectionMove[nb, \ All, \ 
            Notebook]; \[IndentingNewLine]expr = 
            NotebookRead[nb]; \[IndentingNewLine]ps = 
            Position[expr, 
              ButtonStyle \[Rule] "\<Hyperlink\>"]; \
\[IndentingNewLine]\(\((Extract[expr, \ Drop[#, \(-1\)]] /. 
                  ButtonBox[name_, ___, 
                      ButtonData \[RuleDelayed] 
                        fn_, ___] \[RuleDelayed] {name, fn})\) &\) /@ 
            ps];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
FindIndexTag[filename] looks up the IndexTag defined for this file \
in the appropriate BrowserCategories.m file.  This allows conversion between \
standard hyperlinks (which refer to files by their names) and Add-ons \
hyperlinks, which refer to files by their index tags.  the file name must be \
specified\
\>", "Subsubsection"],

Cell[BoxData[{
    \(\(FindIndexTag::noFile = "\<No file `1` found in \
BrowserCategories.m\>";\)\), "\[IndentingNewLine]", 
    \(\(FindIndexTag::noBrowserCategories = "\<No BrowserCategories.m found \
with file `1`\>";\)\), "\[IndentingNewLine]", 
    \(\(FindIndexTag::manyFiles = "\<Several files `1` found in \
BrowserCategories.m\>";\)\), "\[IndentingNewLine]", 
    \(\(FindIndexTag::noIndexTags = "\<No IndexTag found for `1` in \
BrowserCategories.m\>";\)\), "\[IndentingNewLine]", 
    \(\(FindIndexTag::defectiveFileName = "\<File name `1` is in the wrong \
form\>";\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FindIndexTag[fn_] := 
        Module[{bfn, xx, ps, ps2, expr, nb, nb0, res, 
            ss}, \[IndentingNewLine]If[
            Not[\((Head[fn] === FrontEnd`FileName)\) || \((Head[fn] === 
                    String)\)], \[IndentingNewLine]Message[
              FindIndexTag::defectiveFileName, 
              fn]; "\<\>", \[IndentingNewLine]bfn = 
              If[Head[fn] === 
                  String, \[IndentingNewLine]"\<BrowserCategories.m\>", \
\[IndentingNewLine]fn /. 
                  FrontEnd`FileName[dir_, _, opts___] \[Rule] 
                    FrontEnd`FileName[dir, "\<BrowserCategories.m\>", 
                      opts]]; \[IndentingNewLine]nb0 = 
              SelectedNotebook[]; \[IndentingNewLine]ss = 
              FrontEndExecute[
                FrontEnd`NotebookLocate[{bfn, 
                    None}]]; \[IndentingNewLine]nb = 
              SelectedNotebook[]; \[IndentingNewLine]If[
              nb === nb0, \[IndentingNewLine]Message[
                FindIndexTag::noBrowserCategories, 
                fn]; "\<\>", \[IndentingNewLine]SelectionMove[nb, All, 
                Notebook]; \[IndentingNewLine]expr = 
                ToExpression[
                  First[NotebookRead[nb]]]; \[IndentingNewLine]NotebookClose[
                nb]; SetSelectedNotebook[nb0]; \[IndentingNewLine]ps = 
                Position[expr, 
                  fn /. FrontEnd`FileName[_, x_, ___] \[RuleDelayed] 
                      x]; \[IndentingNewLine]If[
                Length[ps] < 1, \[IndentingNewLine]Message[
                  FindIndexTag::noFile, fn]; "\<\>", \[IndentingNewLine]If[
                  Length[ps] > 1, 
                  Message[FindIndexTag::manyFiles, 
                    fn]; "\<\>", \[IndentingNewLine]xx = 
                    Extract[expr, 
                      Drop[First[ps], \(-1\)]]; \[IndentingNewLine]If[
                    Length[xx] \[NotEqual] 4, \[IndentingNewLine]Message[
                      FindIndexTag::noIndexTags, 
                      fn]; "\<\>", \
\[IndentingNewLine]xx\[LeftDoubleBracket]3, 
                      2\[RightDoubleBracket]]]]]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ConvertHyperlinkToAddOnsLink[] finds all hyperlinks within the \
selected notebook, and changes them to the style AddOnsLink.  This requires \
that the target file name be converted to the IndexTag, which must be \
specified in BrowserCategories.m. The new version is created as an untitled \
notebook; this should be given a HelpBrowser style sheet.\
\>", \
"Subsubsection"],

Cell[BoxData[
    \(\(ConvertHyperlinkToAddOnsLink[] := 
        Module[\[IndentingNewLine]{nb = SelectedNotebook[], expr, 
            exprNew}, \[IndentingNewLine]SelectionMove[nb, \ All, \ 
            Notebook]; \[IndentingNewLine]expr = 
            NotebookRead[nb]; \[IndentingNewLine]exprNew = 
            expr /. \[IndentingNewLine]{ButtonBox[name_, a___, 
                    ButtonData \[RuleDelayed] {fn_, ct_}, b___, 
                    ButtonStyle \[Rule] "\<Hyperlink\>", 
                    c___] \[RuleDelayed] \
\[IndentingNewLine]Check[\((ButtonBox[name, a, 
                        ButtonData \[RuleDelayed] 
                          Evaluate[{FindIndexTag[fn], ct}], b, 
                        ButtonStyle \[Rule] "\<AddOnsLink\>", 
                        ButtonNote \[Rule] name, 
                        c])\), \[IndentingNewLine]ButtonBox[name, a, 
                      ButtonData \[RuleDelayed] {fn, ct}, b, 
                      ButtonStyle \[Rule] "\<Hyperlink\>", 
                      c]]}; \[IndentingNewLine]NotebookPut[
            Notebook[{exprNew}]]; \[IndentingNewLine] (*\ 
            unclear\ that\ the\ {}\ should\ be\ included\ above\
*) \[IndentingNewLine]exprNew];\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ending", "Subsection"],

Cell["\<\
End[];
\
\>", "Input",
  InitializationCell->True],

Cell["EndPackage[];", "Input",
  InitializationCell->True]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->Automatic,
WindowSize->{745, 647},
WindowMargins->{{Automatic, 6}, {Automatic, 18}},
StyleDefinitions -> "Default.nb",
MacintoshSystemPageSetup->"\<\
00h0001804P000000b02<?oaonl3>@91H`85N0?N0@00005X0FP000003j0:l001
0@00I00100000@0200000BL?00400000000000000000010000000000000@0?ne
oj/@7@]500P1000000000000000001T1\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 134, 3, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[1876, 56, 34, 0, 46, "Subsection"],

Cell[CellGroupData[{
Cell[1935, 60, 387, 6, 74, "Subsubsection"],
Cell[2325, 68, 454, 7, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[2816, 80, 341, 6, 60, "Subsubsection"],
Cell[3160, 88, 439, 7, 107, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[3636, 100, 385, 7, 74, "Subsubsection"],
Cell[4024, 109, 462, 7, 123, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4535, 122, 35, 0, 46, "Subsection"],
Cell[4573, 124, 135, 3, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[4733, 131, 387, 6, 74, "Subsubsection"],
Cell[5123, 139, 642, 13, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5802, 157, 341, 6, 60, "Subsubsection"],
Cell[6146, 165, 621, 11, 107, "Input",
  InitializationCell->True],
Cell[6770, 178, 2192, 41, 379, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8999, 224, 385, 7, 60, "Subsubsection"],
Cell[9387, 233, 1259, 22, 235, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10695, 261, 28, 0, 46, "Subsection"],
Cell[10726, 263, 60, 4, 42, "Input",
  InitializationCell->True],
Cell[10789, 269, 58, 1, 27, "Input",
  InitializationCell->True]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

