(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     65954,       1883]*)
(*NotebookOutlinePosition[    104944,       3193]*)
(*  CellTagsIndexPosition[    104900,       3189]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(\(BeginPackage["\<Utilities`SetManipulation`\>", \
{"\<Utilities`Notation`\>", "\<DiscreteMath`Combinatorica`\>"}];\)\)], "Input",\

  PageWidth->PaperWidth,
  InitializationCell->True,
  AspectRatioFixed->False],

Cell["This closes the Notation Palette, for tidiness:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"NotebookClose", "[", 
        InterpretationBox[\(NotebookObject[\[LeftSkeleton]"\<Notation Palette\
\>"\[RightSkeleton]]\),
          NotebookObject[ 
            FrontEndObject[ 
              LinkObject[ "Mathematica 4", 1, 1]], 47]], "]"}], 
      ";"}]], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[" Usage statements", "Subsection",
  Evaluatable->False,
  InitializationCell->True,
  AspectRatioFixed->False],

Cell[CellGroupData[{

Cell["Separate", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Separate::usage = \*"\"\<Separate is a rule which replaces \
{i,j,\!\(\(i\^*\)\),\!\(k\^\[Dagger]\)} by {{i,j},{i},{k}}. Also applies to \
diploids: {i,j,OverHat[k],SuperDagger[OverHat[n]]} is converted to \
{{{i,j},{},{}},{{k},{},{n}}}.  Obsolete function.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Combine", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Combine::usage = \*"\"\<Combine is a rule which replaces \
{{i,j},{i},{k}} by  {i,j, \!\(\(i\^*\)\), \!\(k\^\[Dagger]\)}. Extends to \
diploids.  Obsolete function.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ReplaceRepeatedSpecial[expr,rules] or expr||.rules applies rules \
repeatedly until there is no further change.  Evaluates rules inside AddUp[] \
and TimesUp[]\
\>", "Subsubsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(ReplaceRepeatedSpecial::usage\), "=", 
        "\"\<ReplaceRepeatedSpecial[expr,rules] or expr||.rules applies \
\!\(\*
StyleBox[\\\"rules\\\",\\nFontSlant->\\\"Italic\\\"]\) repeatedly until there \
is no further change.  Evaluates rules inside AddUp[] and TimesUp[]\>\""}], 
      ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ReplaceAllSpecial[expr,rules] or expr|.rules applies rules, \
evaluating them inside AddUp[] and TimesUp[]\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(ReplaceAllSpecial::usage\), "=", 
        "\"\<ReplaceAllSpecial[expr,rules] or expr|.rules applies \!\(\*
StyleBox[\\\"rules\\\",\\nFontSlant->\\\"Italic\\\"]\), evaluating them \
inside AddUp[] and TimesUp[]\>\""}], ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Repeat, ExtractRepeat", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Repeat::usage = "\<Repeat[U,n] gives the list U, repeated n times\>";\
\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ExtractRepeat::usage = "\<ExtractRepeat[U] gives a list of the \
repeated elements in U\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["TakeAway", "Subsubsection"],

Cell[BoxData[
    \(\(TakeAway::usage = "\<TakeAway[U,V] or U\[Backslash]V gives the set U, \
minus elements V. Note that this is not the same as Complement[U,V] if U \
contains repeated elements.  (\[Backslash] is entered as \
\[AliasIndicator]\\[AliasIndicator])\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ExactIntersection[U,V] gives those elements that appear in both U \
and V.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(ExactIntersection::usage = "\<ExactIntersection[U,V] or U\[Wedge]V \
gives those elements that appear in both U and V. (\[Wedge] is entered as \
\[AliasIndicator]^\[AliasIndicator]).\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Join is now represented by \[Vee]", "Subsubsection"],

Cell[BoxData[
    \(\(Join::usage = 
        StringJoin[
          Join::usage, "\< list1\[Vee]list2 has the same effect.  (The \
character \[Vee] is input as \[AliasIndicator]v\[AliasIndicator]).\>"];\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
PatternFree is an option for FlattenList that determines whether \
elements may themselves contain a pattern\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(PatternFree::usage = "\<PatternFree is an option for FlattenList that \
determines whether elements may themselves contain a pattern\>";\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
FlattenList[list,pattern] produces a new list, containing those \
elements of list that match pattern.  This can be used to partly flatten a \
nested list.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(FlattenList::usage = "\<FlattenList[list,pattern] produces a new \
list, containing those elements of list that match pattern.  This can be used \
to partly flatten a nested list.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AddUp", "Subsubsection"],

Cell[BoxData[
    \(\(AddUp::usage = \*"\"\<AddUp[x,e,U] or \!\(\[Sum]\+\(\(\(e\)\(\\\\\\\\\
\)\)\\\\\\\ \\\\\\\  \[Element] \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \
\)\(U\)\)\)\)x gives the sum of x over all e in the list U. Thus, \
AddUp[f[e,z],e,{i,j,k}] gives f[i,z]+f[j,z]+f[k,z]. AddUp[x,{\!\(e\_1\),\!\(e\
\_2\)\[Ellipsis]},{\!\(U\_1\),\!\(U\_2\),\[Ellipsis]}] is also defined - it \
gives the multiple sum over \!\(e\_1\),\!\(e\_2\).  All the \!\(e\_i\) must \
be distinct.  AddUp[x,e,U,Subsets->True] or \!\(\[Sum]\+\(\(\(e\)\(\\\\\\\\\)\
\)\\\\\\\ \\\\\\\  \[SubsetEqual] \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(U\)\)\)\
\)x gives the sum of x over all distinct subsets of U.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["TimesUp", "Subsubsection"],

Cell[BoxData[
    \(\(TimesUp::usage = \*"\"\<TimesUp[x,e,U] or \!\(\[Product]\+\(e\\\\\\\  \
\[Element] \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(U\)\)\)\)x gives the product \
of x over all e in the list U. Thus, TimesUp[f[e,z],e,{i,j,k}] gives \
f[i,z]f[j,z]f[k,z]. TimesUp[x,{\!\(e\_1\),\!\(e\_2\)\[Ellipsis]},{\!\(U\_1\),\
\!\(U\_2\),\[Ellipsis]}] is also defined - it gives multiple sum over \
\!\(e\_1\),\!\(e\_2\).  All the \!\(e\_i\) must be distinct. \
TimesUp[x,e,U,Subsets->True] or \!\(\[Product]\+\(\(\(e\)\(\\\\\\\\\)\)\\\\\\\
\ \\\\\\\  \[SubsetEqual] \\\\\\\ \(\(\\\\\\\\\)\(\\\\\\\ \)\(U\)\)\)\)x \
gives the product of x over all distinct subsets of U.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(SimplifyAddUp[
          expr]\ simplifies\ expressions\ involving\ AddUp[]\ or\ \[Sum]\+\(i \
\[Element] U\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(SimplifyAddUp::usage = \*"\"\<SimplifyAddUp[expr] simplifies \
expressions involving AddUp[] or \!\(\[Sum]\+\(i\\\\\\\  \[Element] \\\\\\\ U\
\)\)\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SimplifyAddUpQ[expr] returns True if expr is in the standard form \
generated by SimplifyAddUp.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(SimplifyAddUpQ::usage = "\<SimplifyAddUpQ[expr] returns True if expr \
is in the standard form generated by SimplifyAddUp.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Subsets", "Subsubsection"],

Cell[BoxData[
    \(\(Subsets::usage = "\<Subsets[U] gives a list of all subsets of U, \
including {} and U. Subsets[U,i] gives subsets of length i. \
Subsets[U,imin,imax] gives subsets of length imin to imax.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Symmetrise", "Subsubsection"],

Cell[BoxData[
    \(\(Symmetrise::usage = "\<Symmetrise[f] is a rule which replaces f[U] by \
the standard ordering\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Locations[S,U] lists the positions of elements of U within S", \
"Subsubsection"],

Cell[BoxData[
    \(\(Locations::usage = "\<Locations[S,U] lists the positions of elements \
of U within S.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ProductSum[V,n] gives the sum of all products of distinct elements \
of V.  ProductSum[V1,V2,n1,n2] is also defined.  ProductSum[n][u] is a \
compiled version; defined only up to ProductSum[5]\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(ProductSum::usage = \*"\"\<ProductSum[V,n] gives the sum of all \
products of distinct elements of V. ProductSum[V1,V2,n1,n2] is also defined; \
it is just ProductSum[V1,n1]ProductSum[V2,n2].  ProductSum[n][u] is a \
compiled version; gets slow to calculate for the first time for n>8. \
ProductSum[{{\!\(\[Alpha]\_1\),\[Ellipsis]},{\!\(\[Beta]\_1\),\[Ellipsis]}},{\
a,b}] generates A, B of distinct elements, and the sum is over all such sets. \
\>\"";\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(ProductSumExpression[c, 
            k]\ gives\ an\ expression\ for\ ProductSum[u, 
            k]\ in\ terms\ of\ c[k] = \[Sum]\_i u\_i\%k\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(ProductSumExpression::usage = \*"\"\<ProductSumExpression[c,k] gives \
an expression for ProductSum[u,k] in terms of c[k]=\!\(\[Sum]\_i\)\!\(u\_i\%k\
\).  Used to set up ProductSum[n]\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    StyleBox[\(\(ProductSumVector[
            n]\)[\[Delta]p\/p]\ is\ a\ compiled\ routine\ which\ returns\ the\
\ vector\ of\ ProductSum[j], \ 
      given\ the\ vector\ of\ \(\[Delta]p\/p\) . \ \ Defined\ up\ to\ order\ \
5\),
      FontFamily->"Times"]]]], "Subsubsection"],

Cell[BoxData[
    \(\(ProductSumVector::usage = \*"\"\<ProductSumVector[n][\!\(\[Delta]p\/p\
\)] is a compiled routine which returns the vector of ProductSum[j], given \
the vector of \!\(\[Delta]p\/p\). Defined up to order 5\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SortByHead", "Subsubsection"],

Cell[BoxData[
    \(\(SortByHead::usage = \*"\"\<SortByHead[{\!\(e\_1\),\[Ellipsis]}] sorts \
the \!\(e\_i\) such that all lists appear at the beginning. SortByHead[{\!\(e\
\_1\),\[Ellipsis]},h] does the same for arbitrary head.  Reverse\[Rule]True \
puts the lists (or whatever) at the end.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SetPartition[U] lists all the ways in which the set U can be \
partitioned.  For example, SetPartition[{a,b,c}] gives \
{{{a,b,c}},{{a,b},{c}},\[Ellipsis],{{a},{b},{c}}}. SetPartition[U,m] lists \
all the ways of partitioning U into m parts. OBSOLETE\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(SetPartition::usage = "\<SetPartition[U] lists all the ways in which \
the set U can be partitioned.  For example, SetPartition[{a,b,c}] gives \
{{{a,b,c}},{{a,b},{c}},\[Ellipsis],{{a},{b},{c}}}. SetPartition[U,m] lists \
all the ways of partitioning U into m parts.  The same function is now \
carried out by PartitionList, which is rather more general.\>";\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfSetPartitions[n] gives the number of distinct partitions of \
a set of n elements.  NumberOfSetPartitions[n,m] gives the number of distinct \
partitions of a set of n elements into m parts.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(NumberOfSetPartitions::usage = "\<NumberOfSetPartitions[n] gives the \
number of distinct partitions of a set of n elements.  \
NumberOfSetPartitions[n,m] gives the number of distinct partitions of a set \
of n elements into m parts. \>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(SamplePartition[{x\_1, \[Ellipsis], 
            x\_k}]\ describes\ the\ structure\ of\ a\ sample\ of\ k\ objects, \
\ by\ listing\ which\ of\ the\ k\ are\ equal . \ \ For\ example, \ 
      SamplePartition[{a, b, c, a, 
            c}]\ gives\ \(\({{2}, {1, 4}, {3, 5}}\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(SamplePartition::usage = \*"\"\<SamplePartition[{\!\(x\_1\),\
\[Ellipsis],\!\(x\_k\)}] describes the structure of a sample of k objects, by \
listing which of the k are equal.  For example, SamplePartition[{a,b,c,a,c}] \
gives {{2},{1,4},{3,5}}.\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfSamplePartitions[P,n] gives the number of ways k objects \
can be sampled with replacement from a population of n objects, so as to \
match the structure P\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(NumberOfSamplePartitions::usage = "\<NumberOfSamplePartitions[P,n] \
gives the number of ways k objects can be sampled with replacement from a \
population of n objects, so as to match the structure P\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
AddTag[{{x,y},{z}}] gives a flattened list, \
{Tag[x,1],Tag[y,1],Tag[z,2]} with elements which are tagged so as to retain \
information about the original structure. AddTag[{{{x,y}},{{z}}},3] acts at a \
lower level.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(AddTag::usage = "\<AddTag[{{x,y},{z}}] gives a flattened list, \
{Tag[x,1],Tag[y,1],Tag[z,2]} with elements which are tagged so as to retain \
information about the original structure. AddTag[{{{x,y}},{{z}}},3] acts at a \
lower level.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
RemoveTag is used by ToPopulationCumulants[] and \
ToPopulationMoments[]\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(RemoveTag::usage = "\<RemoveTag[{Tag[x,1],Tag[y,2],Tag[z,1]}] gives \
{{x,z},{y}}. RemoveTag[{Tag[x,1],Tag[y,2],Tag[z,1]},3] gives \
{{{x},{z}},{{y}}}\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Tag[elem,pos] tags elements of a set with their position.", \
"Subsubsection"],

Cell[BoxData[
    \(\(Tag::usage = "\<Tag[elem,pos] tags elements of a set with their \
position.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SplitSet", "Subsubsection"],

Cell[BoxData[
    \(\(SplitSet::usage = \
\*"\"\<SplitSet[U,{\!\(n\_1\),\!\(n\_2\),\[Ellipsis]}] splits the set U into \
successive lists of length \!\(n\_1\),\[Ellipsis].\>\"";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PartitionSet", "Subsubsection"],

Cell[BoxData[
    \(\(PartitionSet::usage = "\<PartitionSet[U] gives all partitions of the \
set U - possibly a very large set.  PartitionSet[U,n] gives all partititions \
into n sets. EmptySets\[Rule]True includes empty sets.  \
Permutations\[Rule]True pools permutations.  Ordered\[Rule]True specifies \
that partitions must respect the given order of elements.  \
PartitionSet[n,opts] stores the canonical form for PartitionSet[{1,2\
\[Ellipsis]n},opts].\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Ordered", "Subsubsection"],

Cell[BoxData[
    \(\(Ordered::usage = "\<Ordered is an option for PartitionSet which \
specifies that the order of the elements must be respected.\>";\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Permutations", "Subsubsection"],

Cell[BoxData[
    \(\(Permutations::usage = 
        Permutations::usage <> "\<.  Permutations is an option for \
PartitionSet which specifies that all permutations are given.\>";\)\)], \
"Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["EmptySets", "Subsubsection"],

Cell[BoxData[
    \(\(EmptySets::usage = "\<EmptySets is an option for PartitionSet which \
specifies that empty sets {} are included.\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\[EmptySet] denotes missing data", "Subsubsection"],

Cell[BoxData[
    \(\(\[EmptySet]::usage = "\<\[EmptySet] denotes an empty set,or missing \
data\>";\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["SetOfCombinations", "Subsubsection"],

Cell[BoxData[
    \(\(SetOfCombinations::usage = "\<SetOfCombinations[{{a1,b1},{a2,b2,c2},\
\[Ellipsis]}] lists all possible combinations of the sets: \
{{a1,a2,\[Ellipsis]},{a1,b2,\[Ellipsis]}\[Ellipsis]}.  \
SetOfCombinations[{{a,b,..},n}] lists all possible combinations of n \
elements, using a single set: \
{{a,a,\[Ellipsis]},{a,b,\[Ellipsis]},\[Ellipsis]}.  SetOfCombinations[n] \
gives the set of binary integers with n digits. Stores results.  Equivalent \
to HaploidTypes[].\>";\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["StandardPartitionQ", "Subsubsection"],

Cell[BoxData[
    \(\(StandardPartitionQ::usage = "\<StandardPartitionQ[P] returns True if \
P is a partition of {1,2\[Ellipsis]n} in standard order\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["StandardPartition", "Subsubsection"],

Cell[BoxData[
    \(\(StandardPartition::usage = "\<StandardPartition[P] returns the \
standard form for the partition.\>";\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["ConfigurationSet", "Subsubsection"],

Cell[BoxData[
    \(\(ConfigurationSet::usage = "\<ConfigurationSet[{n1,n2\[Ellipsis]},k] \
lists all distinct ways of combining the {n1,n2\[Ellipsis]} objects into k \
sets. ConfigurationSet[{n1,n2\[Ellipsis]}]  lists all configurations from k=1 \
up.  ConfigurationSet[{{a1,b1\[Ellipsis]},{a2,b2\[Ellipsis]}\[Ellipsis]},k] \
does the same for definite sets {a1,b1\[Ellipsis]}\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Private parts", "Subsection"],

Cell[BoxData[
    \(\(Begin["\<Utilities`SetManipulation`Private`\>"];\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["\<\
ReplaceAllSpecial[expr,rules] or expr|.rules applies rules, \
evaluating them inside AddUp[] and TimesUp[]\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(ReplaceAllSpecial[f_, 
          r_] := \((\(\(f /. {AddUp \[Rule] au, TimesUp \[Rule] tu}\) /. 
              r\) /. {au \[Rule] AddUp, tu \[Rule] TimesUp})\);\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(e_ | \(\(.\)\(r_\)\)\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          TagBox[\(Utilities`SetManipulation`ReplaceAllSpecial[e_, r_]\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ReplaceRepeatedSpecial[expr,rules] or expr||.rules applies rules \
repeatedly until there is no further change.  Evaluates rules inside AddUp[] \
and TimesUp[]\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(ReplaceRepeatedSpecial[f_, 
          r_] := \((\(\(f /. {AddUp \[Rule] au, TimesUp \[Rule] tu}\) //. 
              r\) /. {au \[Rule] AddUp, tu \[Rule] TimesUp})\);\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"Notation", "[", 
        RowBox[{
          TagBox[\(e_ || \(\(.\)\(r_\)\)\),
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], " ", 
          "\[DoubleLongLeftRightArrow]", " ", 
          
          TagBox[\(Utilities`SetManipulation`ReplaceRepeatedSpecial[e_, r_]\),
            
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"]}], "]"}], ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Repeat", "Subsubsection"],

Cell[BoxData[{
    \(\(Repeat[U_List, 0] := {};\)\), "\n", 
    \(\(Repeat[U_List, 1] := U;\)\), "\n", 
    \(\(Repeat[U_List, n_Integer] := 
        Join[Repeat[U, n - 1], U] /; n > 1;\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ExtractRepeat", "Subsubsection"],

Cell[BoxData[
    \(\(ExtractRepeat[U_List] := 
        DeleteCases[Map[{#, Count[U, #]} &, Union[U]], {_, 1}];\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["AddUp", "Subsubsection"],

Cell[BoxData[
    \(\(Attributes[AddUp] = {HoldFirst};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[AddUp] = {Subsets \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(AddUp[f_, e_?\((\(! ListQ[#]\) &)\), U_List, 
          opts___Rule] := \[IndentingNewLine]Module[{sf = 
              Evaluate[\(Subsets /. {opts}\) /. 
                  Options[AddUp]]}, \[IndentingNewLine]If[
            sf, \[IndentingNewLine]ReleaseHold[
              AddUp[f, e, 
                Union[Sort /@ Subsets[U]]]], \[IndentingNewLine]ReleaseHold[
              Plus @@ \(\((\((Hold[f] /. e \[RuleDelayed] #1)\) &)\) /@ 
                  U\)]]];\)\), "\n", 
    \(\(AddUp[f_, {}, {}, opts___Rule] := 
        ReleaseHold[f];\)\), "\[IndentingNewLine]", 
    \(\(AddUp[x_, e_List, U : {___, _List, ___}, 
          opts___Rule] := \[IndentingNewLine]Module[{tu = Transpose[{U, e}], 
            Ue1, y}, \[IndentingNewLine]Ue1 = 
            First[Cases[tu, {List[___], _}]]; \[IndentingNewLine]y = 
            AddUp[x, Ue1\[LeftDoubleBracket]2\[RightDoubleBracket], 
              Ue1\[LeftDoubleBracket]1\[RightDoubleBracket], 
              opts]; \[IndentingNewLine]ReleaseHold[
            AddUp[Evaluate[y], 
              Evaluate[
                e\[Backslash]{Ue1\[LeftDoubleBracket]2\[RightDoubleBracket]}],\
 Evaluate[U\[Backslash]{Ue1\[LeftDoubleBracket]1\[RightDoubleBracket]}], 
              opts]]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[\(\[Sum]\+\(x_ \[Element] U_\)f_\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Utilities`SetManipulation`AddUp[f_, x_, U_]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[\(\[Sum]\+\(x_ \[SubsetEqual] U_\)f_\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Utilities`SetManipulation`AddUp[f_, x_, U_, 
            Subsets \[Rule] True]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["TimesUp", "Subsubsection"],

Cell[BoxData[
    \(\(Attributes[TimesUp] = {HoldFirst};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Options[TimesUp] = {Subsets \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(TimesUp[f_, e_?\((\(! ListQ[#]\) &)\), U_List, opts___Rule] := 
        Module[{sf = 
              Evaluate[\(Subsets /. {opts}\) /. 
                  Options[TimesUp]]}, \[IndentingNewLine]If[
            sf, \[IndentingNewLine]ReleaseHold[
              TimesUp[f, e, 
                Union[Sort /@ Subsets[U]]]], \[IndentingNewLine]ReleaseHold[
              Times @@ \(\((Hold[f] /. e \[RuleDelayed] #1 &)\) /@ 
                  U\)]]];\)\), "\n", 
    \(\(TimesUp[f_, {}, {}, opts___Rule] := 
        ReleaseHold[f];\)\), "\[IndentingNewLine]", 
    \(\(TimesUp[x_, e_List, U : {___, _List, ___}, 
          opts___Rule] := \[IndentingNewLine]Module[{tu = Transpose[{U, e}], 
            Ue1, y}, \[IndentingNewLine]Ue1 = 
            First[Cases[tu, {List[___], _}]]; \[IndentingNewLine]y = 
            TimesUp[x, Ue1\[LeftDoubleBracket]2\[RightDoubleBracket], 
              Ue1\[LeftDoubleBracket]1\[RightDoubleBracket], 
              opts]; \[IndentingNewLine]ReleaseHold[
            TimesUp[Evaluate[y], 
              Evaluate[
                e\[Backslash]{Ue1\[LeftDoubleBracket]2\[RightDoubleBracket]}],\
 Evaluate[U\[Backslash]{Ue1\[LeftDoubleBracket]1\[RightDoubleBracket]}], 
              opts]]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[\(\[Product]\+\(x_ \[Element] U_\)f_\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Utilities`SetManipulation`TimesUp[f_, x_, U_]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{"Notation", "[", 
      RowBox[{
        TagBox[\(\[Product]\+\(x_ \[SubsetEqual] U_\)f_\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], " ", 
        "\[DoubleLongLeftRightArrow]", " ", 
        TagBox[\(Utilities`SetManipulation`TimesUp[f_, x_, U_, 
            Subsets \[Rule] True]\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"]}], "]"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(SimplifyAddUp[
          expr]\ simplifies\ expressions\ involving\ AddUp[]\ or\ \[Sum]\+\(i \
\[Element] U\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[{
    \(\(SimplifyAddUp[a_ + b_] := \[IndentingNewLine]SimplifyAddUp[a] + 
          SimplifyAddUp[b];\)\), "\[IndentingNewLine]", 
    \(\(SimplifyAddUp[a___*\((b_ + c_)\)] := \[IndentingNewLine]SimplifyAddUp[
          a\ b + a\ c];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(SimplifyAddUp[\((b_ + c_)\)\^n_Integer] \
:= \[IndentingNewLine]SimplifyAddUp[
          Expand[\((b + c)\)\^n]];\)\), "\[IndentingNewLine]", 
    \(\(SimplifyAddUp[
          a___*\((b_ + c_)\)\^n_Integer] := \[IndentingNewLine]SimplifyAddUp[
          Expand[a \((b + c)\)\^n]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SimplifyAddUp[
          a_] := \[IndentingNewLine]SimplifyAddUp[
            a /. {AddUp[x_, i_?\((\(! ListQ[#]\) &)\), S_, 
                    opts___Rule] \[Rule] AddUp[\ x, {i}, {S}, opts]}] /; 
          Not[FreeQ[a, 
              AddUp[_, _?\((\(! ListQ[#]\) &)\), _, ___Rule]]];\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(SimplifyAddUp[\((a___?\((FreeQ[#, AddUp] &)\))\)*
            AddUp[b_, e_List, S_, 
              opts___Rule]] := \[IndentingNewLine]SimplifyAddUp[
          AddUp[a\ b, e, S, opts]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(SimplifyAddUp[
          AddUp[AddUp[b_, i_?\((\(! ListQ[#]\) &)\), S2_, o2___Rule], 
            e1_List, S1_, o1___Rule]] := \[IndentingNewLine]SimplifyAddUp[
          AddUp[AddUp[b, {i}, {S2}, o2], e1, S1, 
            o1]];\)\), "\[IndentingNewLine]", 
    \(\(SimplifyAddUp[
          AddUp[AddUp[b_, e2_List, S2_, o2___Rule], e1_List, S1_, 
            o1___Rule]] := \[IndentingNewLine]If[
          Intersection[e1, e2] === {} && 
            o1 === o2, \[IndentingNewLine]SimplifyAddUp[
            AddUp[\ b, Evaluate[e1\[Vee]e2], Evaluate[S1\[Vee]S2], 
              o1]], \[IndentingNewLine]If[Not[Intersection[e1, e2] === {}], 
            Message[SimplifyAddUp::indexclash, Intersection[e1, e2], 
              AddUp[AddUp[b, e2, s2, o2], e1, s1, 
                o1]]]; \[IndentingNewLine]If[
            Not[o1 === o2], \[IndentingNewLine]Message[
              SimplifyAddUp::optionclash, o1, o2, 
              AddUp[AddUp[b, e2, s2, o2], e1, s1, o1]]]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SimplifyAddUp[
          c___*AddUp[a_, e1_List, S1_, o1___Rule]*
            AddUp[b_, e2_List, S2_, 
              o2___Rule]] := \[IndentingNewLine]Module[{int = 
              Intersection[e1, e2], en, 
            rl}, \[IndentingNewLine]en[x_] := \(en[x] = 
              Unique[x]\); \[IndentingNewLine]rl = \(\((# \[Rule] 
                    en[#])\) &\) /@ int; \[IndentingNewLine]If[
            o1 === o2, \[IndentingNewLine]SimplifyAddUp[
              c*AddUp[Evaluate[\((a /. rl)\) b], 
                  Evaluate[\((\((e1 /. rl)\)\[Vee]e2)\)], 
                  Evaluate[S1\[Vee]S2], o1]], \[IndentingNewLine]Message[
              SimplifyAddUp::optionclash, o1, o2, 
              AddUp[AddUp[b, e2, s2, o2], e1, s1, o1]]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SimplifyAddUp[
          c___*AddUp[a_, e_List, S_, opts___Rule]\^n_Integer] \
:= \[IndentingNewLine]Module[{en, an, rl, k}, \[IndentingNewLine]en = 
            Table[Unique /@ e, {n}]; \[IndentingNewLine]rl[j_] := 
            Table[e\[LeftDoubleBracket]k\[RightDoubleBracket] \[Rule] 
                en\[LeftDoubleBracket]j, k\[RightDoubleBracket], {k, 
                Length[e]}]; \[IndentingNewLine]SimplifyAddUp[
            c*AddUp[Evaluate[Product[a /. rl[k], {k, n}]], 
                Evaluate[en // Flatten], Evaluate[Repeat[S, n]], 
                opts]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SimplifyAddUp[
          AddUp[a_, e_List, S_, opts___Rule]\^n_Integer] \
:= \[IndentingNewLine]Module[{en, an, rl, k}, \[IndentingNewLine]en = 
            Table[Unique /@ e, {n}]; \[IndentingNewLine]rl[j_] := 
            Table[e\[LeftDoubleBracket]k\[RightDoubleBracket] \[Rule] 
                en\[LeftDoubleBracket]j, k\[RightDoubleBracket], {k, 
                Length[e]}]; \[IndentingNewLine]SimplifyAddUp[
            AddUp[Evaluate[Product[a /. rl[k], {k, n}]], 
              Evaluate[en // Flatten], Evaluate[Repeat[S, n]], 
              opts]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SimplifyAddUp[
          AddUp[a_?\((FreeQ[#, AddUp] &)\), e_List, S_, 
            opts___Rule]] := \[IndentingNewLine]AddUp[a, e, S, 
          opts];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SimplifyAddUp[a_?\((FreeQ[#, AddUp] &)\)] := a;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(SimplifyAddUp::indexclash = "\<Clash of dummy indices `1` in \
`2`\>";\)\), "\[IndentingNewLine]", 
    \(\(SimplifyAddUp::optionclash = "\<Clash of options `1`,`2` in `3`\>";\)\
\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SimplifyAddUpQ[expr] returns True if expr is in the standard form \
generated by SimplifyAddUp.\
\>", "Subsubsection"],

Cell[BoxData[
    \(SimplifyAddUpQ[a_ + b_] := SimplifyAddUpQ[a] \[And] SimplifyAddUpQ[b]; 
    SimplifyAddUpQ[expr_] := 
      FreeQ[expr, AddUp] \[Or] 
        MatchQ[expr, 
          AddUp[_?\((FreeQ[#, AddUp] &)\), _List, _List, 
            opts___Rule]];\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SortByHead", "Subsubsection"],

Cell[BoxData[
    \(\(Options[SortByHead] = {Reverse \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(SortByHead[s_List, opts___Rule] := 
        SortByHead[s, List, opts];\)\), "\[IndentingNewLine]", 
    \(\(SortByHead[s_List, h_, opts___Rule] := 
        Module[{r = \(Reverse /. {opts}\) /. 
                Options[SortByHead]}, \[IndentingNewLine]Sort[s, 
            If[Head[#1] === h, \[IndentingNewLine]If[
                  Head[#2] === 
                    List, \[IndentingNewLine]OrderedQ[{#1, #2}], \
\[IndentingNewLine]\(! r\)], \[IndentingNewLine]If[
                  Head[#2] === 
                    h, \[IndentingNewLine]r, \[IndentingNewLine]OrderedQ[{#1, \
#2}]]] &]];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ExactIntersection[U,V] gives those elements that appear in both U \
and V.\
\>", "Subsubsection"],

Cell[BoxData[{
    \(\(ExactIntersection[{a___, x_, b___}, {c___, x_, d___}] := 
        Prepend[ExactIntersection[{a, b}, {c, d}], x];\)\), "\n", 
    \(\(ExactIntersection[a_List, b_List] := 
        If[Intersection[a, b] == {}, {}, 
          ExactIntersection[a, b]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"InfixNotation", "[", 
        RowBox[{
          TagBox["\[Wedge]",
            NotationBoxTag,
            TagStyle->"NotationTemplateStyle"], ",", "ExactIntersection"}], 
        "]"}], ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Join is now represented by \[Vee]", "Subsubsection"],

Cell[BoxData[
    RowBox[{"InfixNotation", "[", 
      RowBox[{
        TagBox["\[Vee]",
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", "Join"}], "]"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["TakeAway", "Subsubsection"],

Cell[BoxData[{
    \(\(TakeAway[U_List, {}] := U;\)\), "\n", 
    \(\(TakeAway[U_List, {v_}] := 
        Drop[U, \(Position[U, 
                v]\)\[LeftDoubleBracket]1\[RightDoubleBracket]] /; 
          Complement[{v}, U] == {};\)\), "\n", 
    \(\(TakeAway[U_List, V_List] := 
        TakeAway[TakeAway[U, Take[V, 1]], Drop[V, 1]] /; 
          Complement[V, U] == {};\)\), "\n", 
    \(\(TakeAway[U_List, W__List, V_List] := 
        TakeAway[TakeAway[U, W], V];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{"InfixNotation", "[", 
      RowBox[{
        TagBox["\[Backslash]",
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], ",", 
        "Utilities`SetManipulation`TakeAway"}], "]"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
FlattenList[list,pattern] produces a new list, containing those \
elements of list that match pattern.  This can be used to partly flatten a \
nested list.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(Options[FlattenList] = {PatternFree \[Rule] True};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(FlattenList[l_List, p_, opts___Rule] := \t
        DeleteCases[
          If[\(PatternFree /. {opts}\) /. 
              Options[FlattenList], \n\t\ \ \ \ Select[
              FlattenList[l, p, 
                PatternFree \[Rule] 
                  False], \(! MemberQ[#, \ p]\) &], \n\t\t\(Extract[
                  l, #] &\) /@ Position[l, p]], {}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Subsets", "Subsubsection"],

Cell[BoxData[
    \(\(Unprotect[Subsets];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Subsets[U_List, 0] := KSubsets[U, 0]; 
    Subsets[U_List, k_Integer?Positive] := KSubsets[U, k]; 
    Subsets[U_List, j_Integer, k_Integer] := 
      Flatten[\(KSubsets[U, #] &\) /@ Range[j, k], 1];\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Protect[Subsets];\)\)], "Input",
  InitializationCell->True],

Cell["The previous code is given below:", "Text"],

Cell[BoxData[{
    \(\(Subsets[U_List] := Subsets[U, 0, Length[U]];\)\), "\n", 
    \(\(Subsets[U_List, 0] := {{}};\)\), "\n", 
    \(\(Subsets[U_List, 1] := \(({#1} &)\) /@ U;\)\), "\n", 
    \(\(Subsets[U_List, j0_Integer, j1_Integer] := 
        Module[{j}, 
          Flatten[Table[Subsets[U, j], {j, j0, j1}], 1]];\)\), "\n", 
    \(\(Subsets[U_List, i_Integer] := 
        Module[{jj, s = {}, w = Subsets[U, i - 1], nw, dw, 
            er = ExtractRepeat[U]}, \n\t\tIf[
            er === {}, \n\t\t\t\((Do[
                dw = w\[LeftDoubleBracket]jj\[RightDoubleBracket]; 
                nw = TakeAway[U, dw]; 
                s = Join[s, \((Sort[Append[dw, #1]] &)\) /@ nw], {jj, 1, 
                  Length[w]}]; Union[s])\), 
            Subsets[Append[TakeAway[U, {er[\([1, 1]\)]}], 
                  tg[er[\([1, 1]\)]]], i] /. tg[x_] -> x]];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Symmetrise", "Subsubsection"],

Cell[BoxData[
    \(\(Symmetrise[
          f_] := {f[
              U_?\((\((ListQ[#] && Not[OrderedQ[#]])\) &)\)] \[RuleDelayed] 
            f[Sort[U]]};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Locations[S,U] lists the positions of elements of U within S", \
"Subsubsection"],

Cell[BoxData[
    \(\(Locations[S_List, U_List] := 
        Map[\(Position[S, #]\)\[LeftDoubleBracket]1\[RightDoubleBracket] &, 
          U];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
ProductSum[V,n] gives the sum of all products of distinct elements \
of V.  ProductSum[V1,V2,n1,n2] is also defined.  ProductSum[n][u] is a \
compiled version; defined only up to ProductSum[5]\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(ProductSum[U_List, n_Integer] := 
        Apply[Plus, Map[Apply[Times, #] &, Subsets[U, n]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ProductSum[U1_List, U2_List, n1_Integer, n2_Integer] := 
        Apply[Plus, 
          Map[Apply[Times, #] &, 
            Flatten[Outer[Join, Subsets[U1, n1], Subsets[U2, n2], 1], 
              1]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ProductSum[{\[Alpha]_List, \[Beta]_List}, {a_Integer, 
            b_Integer}] := \n\t
        Module[{n = Length[\[Alpha]], ss, i}, \n\t\ ss = 
            Subsets[Range[n], 
              a]; \n\ \ Sum[\((Times @@ 
                  Part[\[Alpha], 
                    ss\[LeftDoubleBracket]
                      i\[RightDoubleBracket]])\) \((Plus @@ \((\(\((Times @@ 
                            Part[\[Beta], #])\) &\) /@ 
                      Subsets[
                        Complement[Range[n], 
                          ss\[LeftDoubleBracket]i\[RightDoubleBracket]], 
                        b])\))\), {i, Length[ss]}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ProductSum[{a_List}, {j_Integer}] := ProductSum[a, j];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ProductSum[{a_List, b__List}, {j_Integer, k__Integer}] := 
        Module[{rn = 
              Range[Length[
                  a]]}, \[IndentingNewLine]Plus @@ \((\(\((\((Times @@ 
                          a\[LeftDoubleBracket]#\[RightDoubleBracket])\) 
                      ProductSum[
                        Transpose[\(Transpose[{b}]\)\[LeftDoubleBracket]
                            Complement[
                              rn, #]\[RightDoubleBracket]]\ , {k}])\) &\) /@ 
                Subsets[rn, j])\)];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ProductSum[
          k_Integer] := \[IndentingNewLine]\(ProductSum[
            k] = \[IndentingNewLine]Module[{pr, f, u}, \[IndentingNewLine]u = 
              Array[f, 
                k]; \[IndentingNewLine]Compile[{{z, _Real, 
                  1}}, \[IndentingNewLine]\((pr /. \(Solve[
                        Eliminate[
                          Append[
                            Table[Plus @@ \((u\^j)\) \[Equal] 
                                ProductVector[z, j], {j, 1, k}], 
                            pr == Times @@ u], u], pr]\)[\([1]\)])\) // 
                Evaluate, {{ProductVector[_, _], _Real}}]]\);\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["ProductSum (specific code)", "Subsubsection"],

Cell[BoxData[
    \(\(ProductSum[0] = 1 &;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ProductSum[1] = 
        Module[{u}, \n\t\tCompile[{{u, _Real, 1}}, Plus @@ u]];\)\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(\(ProductSum[2] = 
        Module[{u}, \n\t\tCompile[{{u, _Real, 
                1}}, \((\((Plus @@ u)\)\^2 - Plus @@ \((u\^2)\))\)/
              2]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ProductSum[3] = 
        Module[{u, 
            pl}, \n\t\tCompile[{{u, _Real, 
                1}}, \((pl = \((Plus @@ u)\); \((pl\^3 - 
                    3  pl \((Plus @@ \((u\^2)\))\) + 2  Plus @@ \((u\^3)\))\)/
                6)\), {{pl, _Real}}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ProductSum[4] = 
        Module[{u, pl1, 
            pl2}, \n\t\tCompile[{{u, _Real, 1}}, \((pl1 = \((Plus @@ u)\); 
              pl2 = \((Plus @@ \(u\^2\))\); \((pl1\^4 - 6\ pl1\^2\ pl2 + 
                    3\ pl2\^2 + 8  pl1\ \((Plus @@ \((u\^3)\))\) - 
                    6\ \((Plus @@ \((u\^4)\))\))\)/
                24)\), {{pl1, _Real}, {pl2, _Real}}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ProductSum[5] = 
        Module[{u, pl1, 
            pl2}, \n\t\tCompile[{{u, _Real, 1}}, \((pl1 = \((Plus @@ u)\); 
              pl2 = \((Plus @@ \((u\^2)\))\); \ \((pl1\^5 - 
                    10\ \(pl1\^3\) pl2 + 15\ pl1\ pl2\^2 + 
                    20\ \((pl1\^2 - pl2)\)\ \((Plus @@ \((u\^3)\))\) - 
                    30\ pl1\ \((Plus @@ \((u\^4)\))\) + 
                    24\ \((Plus @@ \((u\^5)\))\))\)/
                120)\), {{pl1, _Real}, {pl2, _Real}}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ProductSum[6] = 
        Module[{u, pl1, pl2, 
            pl3}, \n\t\tCompile[{{u, _Real, 
                1}}, \[IndentingNewLine]pl1 = \((Plus @@ u)\); 
            pl2 = \((Plus @@ \((u\^2)\))\); 
            pl3 = \((Plus @@ \((u\^3)\))\); \ \((pl1\^6 - 15\ pl1\^4\ pl2 + 
                  45\ pl1\^2\ pl2\^2 - 15\ pl2\^3 + 40\ pl1\^3\ pl3 - 
                  120\ pl1\ pl2\ pl3 + 40\ pl3\^2 + 
                  90\ \((pl2 - pl1\^2\ )\) \((Plus @@ \((u\^4)\))\) + 
                  144\ pl1 \((Plus @@ \((u\^5)\))\)\  - 
                  120\ \((Plus @@ \((u\^6)\))\))\)/
              720, {{pl1, _Real}, {pl2, _Real}, {pl3, _Real}}]];\)\)], "Input",\

  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(ProductSumExpression[c, 
            k]\ gives\ an\ expression\ for\ ProductSum[u, 
            k]\ in\ terms\ of\ c[k] = \[Sum]\_i u\_i\%k\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(ProductSumExpression[cc_, k_] := 
        Module[{pr, j, u, f}, \n\t
          u = StandardSet[k, 
              f]; \[IndentingNewLine]pr /. \(Solve[
                Eliminate[
                  Append[Table[Plus @@ \((u\^j)\) == cc[j], {j, 1, k}], 
                    pr == Times @@ u], u], pr]\)[\([1]\)]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ProductVectorCompiled", "Subsubsection"],

Cell[BoxData[{
    \(\(ProductVectorCompiled = 
        Compile[{{u, _Real, 
              1}, {k, _Integer}}, \[IndentingNewLine]Plus @@ \
\((u\^k)\)];\)\), "\n", 
    \(\(ProductVector[u_List, k_Integer] := 
        ProductVectorCompiled[u, k];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["working", "Subsubsection"],

Cell[BoxData[
    \(\(<< Utilities`SetManipulation`;\)\)], "Input"],

Cell[BoxData[
    \(ProductSum // Clear\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(ProductSum[8]\)[{0.1, 0.2, 0.3, 0.4, 0.1, 0.2, 0.3, 0.4, 0.1, 
          0.2, 0.3, 0.4}]]\)], "Input"],

Cell[BoxData[
    \({0.`\ Second, 0.004244279999999999`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[ProductSum[9]]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(475.66666666666674`\ Second\), ",", 
        TagBox[\(CompiledFunction[{z}, \(\(1\/362880\)\((ProductVector[z, \
1]\^9 - 36\ ProductVector[z, 1]\^7\ ProductVector[z, 2] + 
                378\ ProductVector[z, 1]\^5\ ProductVector[z, 2]\^2 - 
                1260\ ProductVector[z, 1]\^3\ ProductVector[z, 2]\^3 + 
                945\ ProductVector[z, 1]\ ProductVector[z, 2]\^4 + 
                168\ ProductVector[z, 1]\^6\ ProductVector[z, 3] - 
                2520\ ProductVector[z, 1]\^4\ ProductVector[z, 
                    2]\ ProductVector[z, 3] + 
                7560\ ProductVector[z, 1]\^2\ ProductVector[z, 2]\^2\ \
ProductVector[z, 3] - 2520\ ProductVector[z, 2]\^3\ ProductVector[z, 3] + 
                3360\ ProductVector[z, 1]\^3\ ProductVector[z, 3]\^2 - 
                10080\ ProductVector[z, 1]\ ProductVector[z, 
                    2]\ ProductVector[z, 3]\^2 + 
                2240\ ProductVector[z, 3]\^3 - 
                756\ ProductVector[z, 1]\^5\ ProductVector[z, 4] + 
                7560\ ProductVector[z, 1]\^3\ ProductVector[z, 
                    2]\ ProductVector[z, 4] - 
                11340\ ProductVector[z, 
                    1]\ ProductVector[z, 2]\^2\ ProductVector[z, 4] - 
                15120\ ProductVector[z, 1]\^2\ ProductVector[z, 
                    3]\ ProductVector[z, 4] + 
                15120\ ProductVector[z, 2]\ ProductVector[z, 
                    3]\ ProductVector[z, 4] + 
                11340\ ProductVector[z, 1]\ ProductVector[z, 4]\^2 + 
                3024\ ProductVector[z, 1]\^4\ ProductVector[z, 5] - 
                18144\ ProductVector[z, 1]\^2\ ProductVector[z, 
                    2]\ ProductVector[z, 5] + 
                9072\ ProductVector[z, 2]\^2\ ProductVector[z, 5] + 
                24192\ ProductVector[z, 1]\ ProductVector[z, 
                    3]\ ProductVector[z, 5] - 
                18144\ ProductVector[z, 4]\ ProductVector[z, 5] - 
                10080\ ProductVector[z, 1]\^3\ ProductVector[z, 6] + 
                30240\ ProductVector[z, 1]\ ProductVector[z, 
                    2]\ ProductVector[z, 6] - 
                20160\ ProductVector[z, 3]\ ProductVector[z, 6] + 
                25920\ ProductVector[z, 1]\^2\ ProductVector[z, 7] - 
                25920\ ProductVector[z, 2]\ ProductVector[z, 7] - 
                45360\ ProductVector[z, 1]\ ProductVector[z, 8] + 
                40320\ ProductVector[z, 9])\)\), "-CompiledCode-"]\),
          False,
          Editable->False]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      ProductSum[{0.1, 0.2, 0.3, 0.4, 0.1, 0.2, 0.3, 0.4, 0.1, 0.2, 0.3, 
          0.4}, 8]]\)], "Input"],

Cell[BoxData[
    \({0.14999999999999147`\ Second, 0.004244280000000008`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(ProductSum[8]\)[{0.1, 0.2, 0.3, 0.4, 0.1, 0.2, 0.3, 0.4, 0.1, 
          0.2, 0.3, 0.4}]]\)], "Input"],

Cell[BoxData[
    \({0.`\ Second, 0.6369`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    StyleBox[\(\(ProductSumVector[
            n]\)[\[Delta]p\/p]\ is\ a\ compiled\ routine\ which\ returns\ the\
\ vector\ of\ prodSum[j], \ 
      given\ the\ vector\ of\ \(\[Delta]p\/p\) . \ \ Defined\ up\ to\ order\ \
6\),
      "Subsubsection"]]]], "Subsubsection"],

Cell[BoxData[
    \(\(ProductSumVector[n_Integer] := \(ProductSumVector[n] = 
          Compile[{{u, _Real, 1}}, 
            Table[\(ProductSum[j]\)[u], {j, 0, 
                n}], {{\(ProductSum[_]\)[_], _Real}}]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
SetPartition[U] lists all the ways in which the set U can be \
partitioned.  For example, SetPartition[{a,b,c}] gives \
{{{a,b,c}},{{a,b},{c}},\[Ellipsis],{{a},{b},{c}}}. SetPartition[U,m] lists \
all the ways of partitioning U into m parts. OBSOLETE\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(SetPartition[U_List] := 
        Flatten[\(SetPartition[U, #] &\) /@ Range[1, Length[U]], 
          1];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(SetPartition[U_List, 1] := {{U}};\)\), "\[IndentingNewLine]", 
    \(SetPartition[U_List, 
        n_Integer] := {List /@ U} /; \((Length[U] \[Equal] n)\); 
    SetPartition[U_List, 
        n_Integer] := {} /; \((\((n > Length[U])\) || \((n < 
                1)\))\);\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SetPartition[U_List, n_Integer] := 
        Module[{V = Drop[U, 1], 
            e = U\[LeftDoubleBracket]1\[RightDoubleBracket], spv, 
            j}, \[IndentingNewLine]spv = 
            SetPartition[V, n]; \[IndentingNewLine]Sort /@ 
              Flatten[Append[\(Table[
                        ReplacePart[#, 
                          Sort[Append[#\[LeftDoubleBracket]
                                j\[RightDoubleBracket], e]], j], {j, n}] &\) /@ 
                    spv, \(Sort[Append[#, {e}]] &\) /@ 
                    SetPartition[V, n - 1]], 1] /; \((1 < n < 
                Length[U])\)];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfSetPartitions[n] gives the number of distinct partitions of \
a set of n elements.  NumberOfSetPartitions[n,m] gives the number of distinct \
partitions of a set of n elements into m parts.\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(NumberOfSetPartitions[n_Integer] := 
        Module[{m}, 
          Sum[NumberOfSetPartitions[n, m], {m, 1, n}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(NumberOfSetPartitions[n_Integer, 1] := 
        1;\)\), "\[IndentingNewLine]", 
    \(NumberOfSetPartitions[n_Integer, n_Integer] := 1; 
    NumberOfSetPartitions[n_Integer, m_Integer] := 
      0 /; \((\((m > n)\) || \((m < 1)\))\);\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NumberOfSetPartitions[n_Integer, m_Integer] := 
        NumberOfSetPartitions[n - 1, m] m + 
            NumberOfSetPartitions[n - 1, m - 1] /; \((1 < m < 
              n)\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(SamplePartition[{x\_1, \[Ellipsis], 
            x\_k}]\ describes\ the\ structure\ of\ a\ sample\ of\ k\ objects, \
\ by\ listing\ which\ of\ the\ k\ are\ equal . \ \ For\ example, \ 
      SamplePartition[{a, b, c, a, 
            c}]\ gives\ \(\({{2}, {1, 4}, {3, 5}}\)\(.\)\)\),
      FontFamily->"Times"]], "Subsubsection"],

Cell[BoxData[
    \(\(SamplePartition[U_List] := 
        Sort[\(Sort[Flatten[Position[U, #]]] &\) /@ Union[U]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
NumberOfSamplePartitions[P,n] gives the number of ways k objects \
can be sampled with replacement from a population of n objects, so as to \
match the structure P\
\>", "Subsubsection"],

Cell[BoxData[{
    \( (*recursive\ algorithm*) \
\[IndentingNewLine]\(NumberOfSamplePartitions[{}, n_] := 
        1;\)\), "\[IndentingNewLine]", 
    \(\(NumberOfSamplePartitions[{1}, n_] := n;\)\), "\[IndentingNewLine]", 
    \(\(NumberOfSamplePartitions[P_List, n_] := 
        Module[{fp = Flatten[P], k, dp}, \[IndentingNewLine]k = 
            Length[fp]; \[IndentingNewLine]If[
            Sort[fp] \[Equal] Range[k], \[IndentingNewLine]dp = 
              DeleteCases[
                DeleteCases[P, k, 
                  2], {}]; \[IndentingNewLine]NumberOfSamplePartitions[dp, 
                n]*\[IndentingNewLine]If[
                MatchQ[P, {___List, \ {k}, ___List}], \[IndentingNewLine]n - 
                  Length[dp], \[IndentingNewLine]1], \
\[IndentingNewLine]Message[NumberOfSamplePartitions : notpart, P, k]; 
            P]];\)\)}], "Input"],

Cell[BoxData[
    \(\(NumberOfSamplePartitions[P_, n_] := 
        Module[{fp = Flatten[P], k}, \[IndentingNewLine]k = 
            Length[fp]; \[IndentingNewLine]If[
            Sort[fp] \[Equal] Range[k], \[IndentingNewLine]Pochhammer[
              n - Length[P] + 1, Length[P]], \[IndentingNewLine]Message[
              NumberOfSamplePartitions : notpart, P, k]; P]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NumberOfSamplePartitions::notpart = "\<`1` is not a valid description \
of a partition of `2` objects\>";\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
AddTag[{{x,y},{z}}] gives a flattened list, \
{Tag[x,1],Tag[y,1],Tag[z,2]} with elements which are tagged so as to retain \
information about the original structure. AddTag[{{{x,y}},{{z}}},3] acts at a \
lower level.\
\>", "Subsubsection"],

Cell[BoxData[{
    \(\(AddTag[U_List] := AddTag[U, 2];\)\), "\[IndentingNewLine]", 
    \(\(AddTag[U_List, l_] := 
        Flatten[MapIndexed[
            Tag[#1, #2\[LeftDoubleBracket]1\[RightDoubleBracket]] &, 
            U, {l}]];\)\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
RemoveTag is used by ToPopulationCumulants[] and \
ToPopulationMoments[]\
\>", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[{
    \(\(RemoveTag[z : {Tag[_, _] ... }, 
          l_Integer] := \({#} &\) /@ 
            RemoveTag[z, l - 1] /; \((l > 2)\);\)\), "\[IndentingNewLine]", 
    \(\(RemoveTag[z : {Tag[_, _] ... }] := 
        RemoveTag[z, 2];\)\), "\[IndentingNewLine]", 
    \(\(RemoveTag[{}, 2] := {};\)\), "\[IndentingNewLine]", 
    \(\(RemoveTag[z : {Tag[_, _] .. }, 
          2] := \[IndentingNewLine]Module[{nn = 
              Max[z /. {Tag[_, j_] \[Rule] j}], aa}, \n
          aa = Array[{} &, 
              nn]; \[IndentingNewLine]Scan[\((aa = 
                  Insert[aa, #\[LeftDoubleBracket]1\[RightDoubleBracket], {#\
\[LeftDoubleBracket]2\[RightDoubleBracket], \(-1\)}])\) &, z]; 
          aa];\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Separate", "Subsubsection"],

Cell[TextData[{
  "Note that it is essential to specify OverHat[] etc as global variables, to \
match the representation of ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\&^\)\)]],
  "."
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Separate", "=", "\[IndentingNewLine]", 
        RowBox[{"{", 
          RowBox[{"U_List", "\[RuleDelayed]", 
            RowBox[{"If", "[", 
              
              RowBox[{\(FreeQ[U, Global`OverHat[_]]\), ",", 
                "\[IndentingNewLine]", \(Module[{c\[Dagger] = 
                        Cases[U, Global`SuperDagger[_]], 
                      cs = Cases[U, Global`SuperStar[_]]}, {TakeAway[U, cs, 
                        c\[Dagger]], cs /. {Global`SuperStar[x_] \[Rule] x}, 
                      c\[Dagger] /. {Global`SuperDagger[x_] \[Rule] 
                            x}}] /. {a_List, b_List, {}} \[Rule] {a, b}\), 
                ",", 
                RowBox[{"Module", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{"ch", "=", 
                        RowBox[{"Cases", "[", 
                          RowBox[{"U", ",", 
                            TagBox[
                              
                              StyleBox[\(Global`OverHat[_] | 
                                  Global`SuperStar[Global`OverHat[_]] | 
                                  Global`SuperDagger[Global`OverHat[_]]\),
                                ShowSpecialCharacters->False,
                                ShowStringCharacters->True,
                                NumberMarks->True],
                              FullForm]}], "]"}]}], "}"}], ",", 
                    "\[IndentingNewLine]", \({TakeAway[U, ch] /. 
                          Separate, \(ch /. {Global`OverHat[x_] -> x}\) /. 
                          Separate} /. \n\t\t{{a_List, b_List, {}}, {c_List, 
                            d_List, {}}} -> {{a, b}, {c, d}}\)}], "]"}]}], 
              "]"}]}], "}"}]}], ";"}]], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Combine", "Subsubsection"],

Cell[BoxData[
    \(\(com = {{U_List, V_List} \[RuleDelayed] 
            Join[U, Map[Global`SuperStar[#] &, V]], \n\t\t\t\t{U_List, 
              V_List, W_List} \[RuleDelayed] 
            Join[U, Map[Global`SuperStar[#] &, V], 
              Map[Global`SuperDagger[#] &, W]]};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Combine = {{U_List, V_List, 
              W_List} \[RuleDelayed] \(({U, V, W} /. com)\), \n{U_List, 
              V_List} \[RuleDelayed] 
            If[Depth[U] == 2, \[IndentingNewLine]{U, V} /. com, 
              Join[U /. com, \(\(Map[Global`OverHat[#] &, V, {2}] /. 
                      Global`OverHat[{}] -> {}\) /. 
                    com\) //. {a___, {}, b___} -> {a, b}]]};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SplitSet", "Subsubsection"],

Cell[BoxData[
    \(\(SplitSet::sumJ = "\<List of lengths `1` does not match the # of \
elements in `2`\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SplitSet[U_List, jl : {___Integer}] := 
        Module[{bb}, \[IndentingNewLine]If[
            Plus @@ jl \[NotEqual] Length[U], \[IndentingNewLine]Message[
              SplitSet::sumJ, jl, U]; 
            U, \[IndentingNewLine]bb = 
              Drop[FoldList[Plus, 0, jl], 
                1]; \[IndentingNewLine]\(Take[U, #] &\) /@ 
              Transpose[{bb - jl + 1, bb}]]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["PartitionSet", "Subsubsection"],

Cell[BoxData[
    \(\(Options[PartitionSet] = {EmptySets \[Rule] False, 
          Permutations \[Rule] False, Ordered \[Rule] False};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(PartitionSet::negJ = "\<# of sets specified, `1`, must be positive.\>"; 
    PartitionSet::bigJ = "\<# of sets specified, `1`, must not be greater \
than the number of elements, `2`.\>";\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PartitionSet[U_List, j_Integer, 
          opts___Rule] := \[IndentingNewLine]PartitionSet[Length[U], j, 
            opts] /. {a_Integer \[RuleDelayed] 
              U\[LeftDoubleBracket]a\[RightDoubleBracket]};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(PartitionSet[n_Integer, 
          opts___Rule] := \(PartitionSet[n, 
            opts] = \[IndentingNewLine]Flatten[\(PartitionSet[n, #, 
                  opts] &\) /@ Range[n], 1]\);\)\), "\[IndentingNewLine]", 
    \(\(PartitionSet[U_List, 
          opts___Rule] := \[IndentingNewLine]Flatten[\(PartitionSet[U, #, 
                opts] &\) /@ Range[Length[U]], 1];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(PartitionSet[n_Integer, j_Integer, 
          opts___Rule] := \(PartitionSet[n, j, 
            opts] = \[IndentingNewLine]Module[{pp, a, b, 
              rn = Range[n], \[IndentingNewLine]eQ = \(EmptySets /. {opts}\) /. 
                  Options[
                    PartitionSet], \[IndentingNewLine]pQ = \(Permutations /. \
{opts}\) /. Options[
                    PartitionSet], \[IndentingNewLine]oQ = \(Ordered /. \
{opts}\) /. Options[PartitionSet], tl}, \[IndentingNewLine]tl = 
              If[j \[LessEqual] 1, \[IndentingNewLine]If[j < 1, 
                  Message[PartitionSet::negJ, 
                    j]]; {{rn}}, \[IndentingNewLine]If[
                  j \[GreaterEqual] n, \[IndentingNewLine]If[j > n, 
                    Message[PartitionSet::bigJ, j, n]]; {List /@ 
                      Range[n]}, \[IndentingNewLine]If[
                    j \[Equal] 2, \[IndentingNewLine]Sort[
                      Union[Sort /@ 
                          If[oQ, \[IndentingNewLine]\({Take[rn, #], 
                                  Drop[rn, #]} &\) /@ 
                              Range[n - 
                                  If[eQ, 0, 1]], \[IndentingNewLine]\((\({#, 
                                    rn\[Backslash]#} &\) /@ 
                                Subsets[rn, 0, 
                                  Quotient[n, 
                                    2]])\)]]], \[IndentingNewLine]pp = 
                      PartitionSet[n, j - 1, opts]; \[IndentingNewLine]Sort[
                      Union[Sort /@ 
                          Flatten[
                            Table[If[
                                Length[
                                    pp\[LeftDoubleBracket]b, 
                                      a\[RightDoubleBracket]] < 
                                  2, {}, \(\((Take[
                                        pp\[LeftDoubleBracket]
                                        b\[RightDoubleBracket], 
                                        a - 1]\[Vee]#\[Vee]Drop[
                                        pp\[LeftDoubleBracket]
                                        b\[RightDoubleBracket], a])\) &\) /@ 
                                  PartitionSet[
                                    pp\[LeftDoubleBracket]b, 
                                      a\[RightDoubleBracket], 2, opts]], {a, 
                                j - 1}, {b, Length[pp]}], 
                            2]]]]]]; \[IndentingNewLine]tl = 
              DeleteCases[tl, {}]; \[IndentingNewLine]tl = 
              If[eQ, tl, 
                DeleteCases[tl, {___, {}, ___}]]; \[IndentingNewLine]tl = 
              If[pQ, Flatten[Permutations /@ tl, 1], tl]]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["SetOfCombinations", "Subsubsection"],

Cell[BoxData[
    \(\(SetOfCombinations[{}, ___] := {};\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SetOfCombinations[
          g_List] := \(SetOfCombinations[g] = \[IndentingNewLine]Flatten[
            Apply[Outer, Prepend[g, List]], Length[g] - 1]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SetOfCombinations[{g_List, 
            n_Integer}] := \(SetOfCombinations[{g, n}] = 
          SetOfCombinations[Table[g, {n}]]\);\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SetOfCombinations[n_Integer] := \(SetOfCombinations[n] = 
          SetOfCombinations[{{0, 1}, n}]\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["StandardPartitionQ", "Subsubsection"],

Cell[BoxData[
    \(\(StandardPartitionQ[
          P : {__List}] := \((StandardPartition[P] === P)\);\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["StandardPartition", "Subsubsection"],

Cell[BoxData[
    \(\(StandardPartition[P : {___List}] := 
        Module[{ss = Sort[Length /@ P]}, \[IndentingNewLine]SplitSet[
            Range[Plus @@ ss], ss]];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ConfigurationSet", "Subsubsection"],

Cell["\<\
It would be far more efficient to derive the set version  from the \
integer version\
\>", "Text"],

Cell[BoxData[
    \(\(ConfigurationSet[n : {_Integer ... }, k_Integer] := 
        Module[{cl}, \[IndentingNewLine]cl = 
            Sequence @@ \((\(Compositions[#, k] &\) /@ 
                  n)\); \[IndentingNewLine]DeleteCases[
            Union[Flatten[Outer[Sort[Transpose[{##}]] &, cl, 1], 
                Length[n] - 1]], {___, {0\  .. }, ___}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ConfigurationSet[s : {_List ... }, k_Integer] := 
        Module[{cl}, \[IndentingNewLine]cl = 
            Sequence @@ \((\(\((Union[\((\(PartitionSet[
                                Join[#, Array[\[EmptySet] &, k]], k, 
                                Permutations \[Rule] 
                                  True] /. {\[EmptySet] .. } \[RuleDelayed] \
{}\) //. {{x___, \[EmptySet], y___} \[RuleDelayed] {x, y}})\)])\) &\) /@ 
                  s)\); \[IndentingNewLine]DeleteCases[
            Union[Flatten[Outer[Sort[Transpose[{##}]] &, cl, 1], 
                Length[s] - 1]], {___, {{} .. }, ___}]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ConfigurationSet[s : {_List ... }] := 
        Flatten[\(ConfigurationSet[s, #] &\) /@ Range[Length[Flatten[s, 1]]], 
          1];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ConfigurationSet[n : {_Integer ... }] := 
        Flatten[\(ConfigurationSet[n, #] &\) /@ Range[Plus @@ n], 
          1];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ending", "Subsubsection"],

Cell[BoxData[{
    \(\(End[];\)\), "\n", 
    \(\(EndPackage[];\)\)}], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{641, 708},
WindowMargins->{{Automatic, 62}, {Automatic, -4}},
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->8],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    Hyphenation->True,
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "EnhancedPrintout"],
    StyleMenuListing->None,
    FontFamily->"Futura",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5N`?N0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000201T1T0000000@000
00000000004000000000000000010000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 232, 6, 59, "Input",
  InitializationCell->True],
Cell[1952, 57, 63, 0, 30, "Text"],
Cell[2018, 59, 338, 9, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2381, 72, 116, 3, 46, "Subsection",
  Evaluatable->False,
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2522, 79, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[2606, 83, 328, 5, 93, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[2971, 93, 80, 2, 28, "Subsubsection",
  Evaluatable->False],
Cell[3054, 97, 235, 4, 61, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3326, 106, 192, 4, 44, "Subsubsection"],
Cell[3521, 112, 370, 8, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3928, 125, 167, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[4098, 131, 305, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4440, 142, 94, 2, 28, "Subsubsection",
  Evaluatable->False],
Cell[4537, 146, 136, 3, 27, "Input",
  InitializationCell->True],
Cell[4676, 151, 156, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[4869, 159, 33, 0, 28, "Subsubsection"],
Cell[4905, 161, 311, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5253, 171, 107, 3, 28, "Subsubsection"],
Cell[5363, 176, 251, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5651, 185, 58, 0, 28, "Subsubsection"],
Cell[5712, 187, 246, 6, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5995, 198, 141, 3, 28, "Subsubsection"],
Cell[6139, 203, 203, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[6379, 212, 188, 4, 44, "Subsubsection"],
Cell[6570, 218, 248, 4, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[6855, 227, 30, 0, 28, "Subsubsection"],
Cell[6888, 229, 723, 10, 162, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[7648, 244, 32, 0, 28, "Subsubsection"],
Cell[7683, 246, 714, 10, 162, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8434, 261, 187, 4, 43, "Subsubsection"],
Cell[8624, 267, 217, 4, 76, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[8878, 276, 128, 3, 28, "Subsubsection"],
Cell[9009, 281, 191, 3, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9237, 289, 32, 0, 28, "Subsubsection"],
Cell[9272, 291, 256, 4, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9565, 300, 35, 0, 28, "Subsubsection"],
Cell[9603, 302, 162, 3, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[9802, 310, 87, 1, 28, "Subsubsection"],
Cell[9892, 313, 154, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[10083, 321, 225, 4, 44, "Subsubsection"],
Cell[10311, 327, 518, 8, 139, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[10866, 340, 217, 4, 48, "Subsubsection"],
Cell[11086, 346, 254, 4, 67, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[11377, 355, 305, 6, 61, "Subsubsection"],
Cell[11685, 363, 274, 4, 116, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[11996, 372, 35, 0, 28, "Subsubsection"],
Cell[12034, 374, 340, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[12411, 384, 283, 5, 60, "Subsubsection"],
Cell[12697, 391, 425, 7, 123, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[13159, 403, 230, 4, 44, "Subsubsection"],
Cell[13392, 409, 303, 5, 87, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[13732, 419, 357, 6, 46, "Subsubsection"],
Cell[14092, 427, 316, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[14445, 437, 196, 4, 44, "Subsubsection"],
Cell[14644, 443, 269, 4, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[14950, 452, 249, 5, 44, "Subsubsection"],
Cell[15202, 459, 304, 5, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[15543, 469, 133, 4, 28, "Subsubsection",
  InitializationCell->True],
Cell[15679, 475, 219, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[15935, 484, 84, 1, 28, "Subsubsection"],
Cell[16022, 487, 144, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[16203, 495, 33, 0, 28, "Subsubsection"],
Cell[16239, 497, 220, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[16496, 506, 37, 0, 28, "Subsubsection"],
Cell[16536, 508, 504, 8, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[17077, 521, 32, 0, 28, "Subsubsection"],
Cell[17112, 523, 196, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[17345, 532, 37, 0, 28, "Subsubsection"],
Cell[17385, 534, 224, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[17646, 544, 34, 0, 28, "Subsubsection"],
Cell[17683, 546, 181, 3, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[17901, 554, 57, 0, 28, "Subsubsection"],
Cell[17961, 556, 143, 3, 27, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[18141, 564, 42, 0, 42, "Subsubsection"],
Cell[18186, 566, 531, 9, 139, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[18754, 580, 43, 0, 42, "Subsubsection"],
Cell[18800, 582, 195, 3, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[19032, 590, 42, 0, 28, "Subsubsection"],
Cell[19077, 592, 166, 3, 59, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[19280, 600, 41, 0, 42, "Subsubsection"],
Cell[19324, 602, 424, 6, 107, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[19797, 614, 35, 0, 30, "Subsection"],
Cell[19835, 616, 113, 2, 27, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[19973, 622, 167, 4, 42, "Subsubsection",
  InitializationCell->True],
Cell[20143, 628, 227, 5, 43, "Input",
  InitializationCell->True],
Cell[20373, 635, 451, 11, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[20861, 651, 192, 4, 44, "Subsubsection"],
Cell[21056, 657, 233, 5, 43, "Input",
  InitializationCell->True],
Cell[21292, 664, 481, 13, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[21810, 682, 31, 0, 28, "Subsubsection"],
Cell[21844, 684, 229, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[22110, 694, 38, 0, 28, "Subsubsection"],
Cell[22151, 696, 156, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[22344, 705, 30, 0, 28, "Subsubsection"],
Cell[22377, 707, 97, 2, 27, "Input",
  InitializationCell->True],
Cell[22477, 711, 106, 2, 27, "Input",
  InitializationCell->True],
Cell[22586, 715, 1300, 24, 203, "Input",
  InitializationCell->True],
Cell[23889, 741, 415, 10, 44, "Input",
  InitializationCell->True],
Cell[24307, 753, 454, 11, 64, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[24798, 769, 32, 0, 28, "Subsubsection"],
Cell[24833, 771, 99, 2, 27, "Input",
  InitializationCell->True],
Cell[24935, 775, 108, 2, 27, "Input",
  InitializationCell->True],
Cell[25046, 779, 1288, 24, 203, "Input",
  InitializationCell->True],
Cell[26337, 805, 421, 10, 44, "Input",
  InitializationCell->True],
Cell[26761, 817, 460, 11, 84, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[27258, 833, 187, 4, 43, "Subsubsection"],
Cell[27448, 839, 291, 5, 75, "Input",
  InitializationCell->True],
Cell[27742, 846, 347, 7, 85, "Input",
  InitializationCell->True],
Cell[28092, 855, 354, 8, 91, "Input",
  InitializationCell->True],
Cell[28449, 865, 250, 5, 59, "Input",
  InitializationCell->True],
Cell[28702, 872, 1040, 19, 219, "Input",
  InitializationCell->True],
Cell[29745, 893, 808, 15, 187, "Input",
  InitializationCell->True],
Cell[30556, 910, 636, 11, 128, "Input",
  InitializationCell->True],
Cell[31195, 923, 625, 11, 112, "Input",
  InitializationCell->True],
Cell[31823, 936, 217, 5, 59, "Input",
  InitializationCell->True],
Cell[32043, 943, 112, 2, 27, "Input",
  InitializationCell->True],
Cell[32158, 947, 244, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[32439, 957, 128, 3, 28, "Subsubsection"],
Cell[32570, 962, 301, 7, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[32908, 974, 35, 0, 28, "Subsubsection"],
Cell[32946, 976, 111, 2, 27, "Input",
  InitializationCell->True],
Cell[33060, 980, 655, 13, 171, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[33752, 998, 107, 3, 28, "Subsubsection"],
Cell[33862, 1003, 315, 6, 75, "Input",
  InitializationCell->True],
Cell[34180, 1011, 274, 8, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[34491, 1024, 58, 0, 28, "Subsubsection"],
Cell[34552, 1026, 220, 6, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[34809, 1037, 33, 0, 28, "Subsubsection"],
Cell[34845, 1039, 511, 11, 123, "Input",
  InitializationCell->True],
Cell[35359, 1052, 265, 7, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[35661, 1064, 188, 4, 44, "Subsubsection"],
Cell[35852, 1070, 115, 2, 27, "Input",
  InitializationCell->True],
Cell[35970, 1074, 419, 9, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[36426, 1088, 32, 0, 28, "Subsubsection"],
Cell[36461, 1090, 84, 2, 27, "Input",
  InitializationCell->True],
Cell[36548, 1094, 260, 5, 75, "Input",
  InitializationCell->True],
Cell[36811, 1101, 82, 2, 27, "Input",
  InitializationCell->True],
Cell[36896, 1105, 49, 0, 30, "Text"],
Cell[36948, 1107, 875, 16, 235, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[37860, 1128, 35, 0, 28, "Subsubsection"],
Cell[37898, 1130, 199, 5, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[38134, 1140, 87, 1, 28, "Subsubsection"],
Cell[38224, 1143, 185, 4, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[38446, 1152, 225, 4, 44, "Subsubsection"],
Cell[38674, 1158, 158, 3, 43, "Input",
  InitializationCell->True],
Cell[38835, 1163, 267, 6, 59, "Input",
  InitializationCell->True],
Cell[39105, 1171, 696, 14, 107, "Input",
  InitializationCell->True],
Cell[39804, 1187, 119, 2, 27, "Input",
  InitializationCell->True],
Cell[39926, 1191, 580, 11, 107, "Input",
  InitializationCell->True],
Cell[40509, 1204, 689, 13, 194, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[41235, 1222, 51, 0, 42, "Subsubsection"],
Cell[41289, 1224, 85, 2, 27, "Input",
  InitializationCell->True],
Cell[41377, 1228, 147, 4, 43, "Input",
  InitializationCell->True],
Cell[41527, 1234, 215, 5, 49, "Input",
  InitializationCell->True],
Cell[41745, 1241, 321, 7, 87, "Input",
  InitializationCell->True],
Cell[42069, 1250, 431, 8, 107, "Input",
  InitializationCell->True],
Cell[42503, 1260, 541, 10, 127, "Input",
  InitializationCell->True],
Cell[43047, 1272, 713, 14, 147, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[43797, 1291, 217, 4, 48, "Subsubsection"],
Cell[44017, 1297, 375, 8, 101, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[44429, 1310, 46, 0, 28, "Subsubsection"],
Cell[44478, 1312, 290, 7, 83, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[44805, 1324, 32, 0, 28, "Subsubsection"],
Cell[44840, 1326, 67, 1, 27, "Input"],
Cell[44910, 1329, 52, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[44987, 1334, 131, 2, 59, "Input"],
Cell[45121, 1338, 70, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45228, 1344, 54, 1, 27, "Input"],
Cell[45285, 1347, 2581, 43, 495, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47903, 1395, 134, 3, 59, "Input"],
Cell[48040, 1400, 87, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48164, 1406, 131, 2, 59, "Input"],
Cell[48298, 1410, 56, 1, 26, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[48403, 1417, 298, 6, 75, "Subsubsection"],
Cell[48704, 1425, 261, 5, 75, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[49002, 1435, 283, 5, 60, "Subsubsection"],
Cell[49288, 1442, 169, 4, 43, "Input",
  InitializationCell->True],
Cell[49460, 1448, 334, 7, 59, "Input",
  InitializationCell->True],
Cell[49797, 1457, 671, 13, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[50505, 1475, 230, 4, 44, "Subsubsection"],
Cell[50738, 1481, 178, 4, 43, "Input",
  InitializationCell->True],
Cell[50919, 1487, 298, 6, 59, "Input",
  InitializationCell->True],
Cell[51220, 1495, 240, 5, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[51497, 1505, 357, 6, 46, "Subsubsection"],
Cell[51857, 1513, 155, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[52049, 1521, 196, 4, 44, "Subsubsection"],
Cell[52248, 1527, 866, 16, 219, "Input"],
Cell[53117, 1545, 415, 7, 91, "Input",
  InitializationCell->True],
Cell[53535, 1554, 170, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[53742, 1562, 249, 5, 44, "Subsubsection"],
Cell[53994, 1569, 278, 6, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[54309, 1580, 133, 4, 42, "Subsubsection",
  InitializationCell->True],
Cell[54445, 1586, 755, 15, 139, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[55237, 1606, 33, 0, 28, "Subsubsection"],
Cell[55273, 1608, 199, 6, 31, "Text"],
Cell[55475, 1616, 1825, 35, 251, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[57337, 1656, 32, 0, 28, "Subsubsection"],
Cell[57372, 1658, 323, 6, 75, "Input",
  InitializationCell->True],
Cell[57698, 1666, 453, 8, 107, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[58188, 1679, 33, 0, 28, "Subsubsection"],
Cell[58224, 1681, 150, 3, 43, "Input",
  InitializationCell->True],
Cell[58377, 1686, 450, 9, 91, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[58864, 1700, 37, 0, 28, "Subsubsection"],
Cell[58904, 1702, 177, 3, 43, "Input",
  InitializationCell->True],
Cell[59084, 1707, 247, 4, 75, "Input",
  InitializationCell->True],
Cell[59334, 1713, 278, 5, 43, "Input",
  InitializationCell->True],
Cell[59615, 1720, 437, 8, 91, "Input",
  InitializationCell->True],
Cell[60055, 1730, 2750, 48, 411, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[62842, 1783, 42, 0, 28, "Subsubsection"],
Cell[62887, 1785, 98, 2, 27, "Input",
  InitializationCell->True],
Cell[62988, 1789, 219, 4, 43, "Input",
  InitializationCell->True],
Cell[63210, 1795, 196, 4, 43, "Input",
  InitializationCell->True],
Cell[63409, 1801, 166, 3, 43, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[63612, 1809, 43, 0, 28, "Subsubsection"],
Cell[63658, 1811, 145, 3, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[63840, 1819, 42, 0, 28, "Subsubsection"],
Cell[63885, 1821, 208, 4, 59, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[64130, 1830, 41, 0, 28, "Subsubsection"],
Cell[64174, 1832, 108, 3, 30, "Text"],
Cell[64285, 1837, 399, 7, 107, "Input",
  InitializationCell->True],
Cell[64687, 1846, 672, 11, 187, "Input",
  InitializationCell->True],
Cell[65362, 1859, 196, 4, 43, "Input",
  InitializationCell->True],
Cell[65561, 1865, 187, 4, 43, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[65785, 1874, 31, 0, 42, "Subsubsection"],
Cell[65819, 1876, 107, 3, 43, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

