(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    169425,       2523]*)
(*NotebookOutlinePosition[    187903,       2943]*)
(*  CellTagsIndexPosition[    187771,       2935]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Beginnings", "Subsection",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[BoxData[{
    \(\(BeginPackage\ [\ "\<PackageSaver`\>", \
"\<Utilities`Notation`\>"];\)\), "\n", 
    \(\(Begin\ @\ "\<`Private`\>";\)\)}], "Input",
  CellLabel->"In[7]:=  (16:01:37 on 4/9/01)",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[ScriptI]\[ScriptN]\[ScriptD]\[ScriptE]\[ScriptN]\[ScriptT]\[ScriptI]\
\[ScriptN]\[ScriptG]\[ScriptCapitalN]\[ScriptE]\[ScriptW]\[ScriptCapitalL]\
\[ScriptI]\[ScriptN]\[ScriptE] = "\<\[IndentingNewLine]\>";\)\)], "Input",
  CellLabel->"In[9]:=  (16:01:37 on 4/9/01)",
  InitializationCell->True],

Cell["Box and Character Querying and Manipulation Functions", "Subsection",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell["\<\
definition of isolatingBoxes and nonIsolatingBoxes and \
mutableIsolatingBoxes\
\>", "Subsubsection",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[TextData[{
  StyleBox["isolatingBoxes", "MR"],
  " are the box structures that isolate the grouping nature and precedence \
nature of the internals of the box."
}], "CommentText",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[BoxData[
    \(\(isolatingBoxes\  = \ \n\t\ \ \((ButtonBox\  | \ FormBox\  | 
            FractionBox\  | \ FrameBox\  | \ GridBox\ \  | 
            RowBox\  | \n\t\t\ \ RadicalBox\  | SqrtBox\ \ )\);\)\)], "Input",\

  CellLabel->"In[10]:=  (16:01:37 on 4/9/01)",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[TextData[{
  StyleBox["nonIsolatingBoxes", "MR"],
  " are the box structures that do not isolate the grouping nature and \
precedence nature of the internals of the box."
}], "CommentText",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[BoxData[
    \(\(nonIsolatingBoxes\  = \n\ \ \ \((\ \ AdjustmentBox\  | ErrorBox\  | \ 
            StyleBox\  | \ SubscriptBox\  | 
            SuperscriptBox\  | \n\t\t\t\ SubsuperscriptBox\  | 
            UnderscriptBox\  | \ OverscriptBox\  | 
            UnderoverscriptBox)\);\)\)], "Input",
  CellLabel->"In[11]:=  (16:01:37 on 4/9/01)",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[TextData[{
  StyleBox["mutableIsolatingBoxes", "MR"],
  " are the box structures that possibly change the grouping nature and \
precedence nature of the internals of the box."
}], "CommentText",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["mutableIsolatingBoxes",
          "MR"], " ", "=", "\n", "   ", \((TagBox\  | InterpretationBox)\)}], 
      ";"}]], "Input",
  CellLabel->"In[12]:=  (16:01:37 on 4/9/01)",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"allTheBoxes", " ", "=", " ", 
        RowBox[{
        "nonIsolatingBoxes", " ", "|", " ", "isolatingBoxes", " ", "|", " ", 
          StyleBox["mutableIsolatingBoxes",
            "MR"]}]}], ";"}]], "Input",
  CellLabel->"In[13]:=  (16:01:37 on 4/9/01)",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell["boxStructureQ", "Subsubsection",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[TextData[{
  StyleBox["boxStructureQ", "MR"],
  " tests an expression to see if its head is a known box."
}], "CommentText",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[BoxData[
    RowBox[{\(boxStructureQ\ @\ \(nonIsolatingBoxes\ @\ \[ScriptA]\[ScriptR]\
\[ScriptG]\[ScriptS]___\) := \ True\), ";", 
      "\n", \(boxStructureQ\ @\ \(isolatingBoxes\ @\ \[ScriptA]\[ScriptR]\
\[ScriptG]\[ScriptS]___\) := \ True\), ";", "\n", 
      RowBox[{
        RowBox[{"boxStructureQ", " ", "@", " ", 
          RowBox[{
            StyleBox["mutableIsolatingBoxes",
              "MR\.7f"], " ", "@", " ", 
            "\[ScriptA]\[ScriptR]\[ScriptG]\[ScriptS]___"}]}], ":=", " ", 
        "True"}], ";", "\n", \(boxStructureQ\ @\ _ := \ False\), 
      ";"}]], "Input",
  CellLabel->"In[14]:=  (16:01:37 on 4/9/01)",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[TextData[{
  StyleBox["boxStructureQ", "MR"],
  " expects only one argument."
}], "CommentText",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[BoxData[
    \(\(\[ScriptE]\[ScriptR]\[ScriptR]\[ScriptO]\[ScriptR]\  : 
          boxStructureQ[___]\ \  := 
        With[{\[ScriptN]\[ScriptU]\[ScriptM]\  = 
              heldLength\ @\ \[ScriptE]\[ScriptR]\[ScriptR]\[ScriptO]\
\[ScriptR]}, \ $Failed\  /; \n\t\ \ \ \ \ \[ScriptN]\[ScriptU]\[ScriptM]\  \
\[NotEqual] \ 1\  \[And] 
              Message[boxStructureQ::argx, 
                HoldForm\ @\ boxStructureQ, \[ScriptN]\[ScriptU]\[ScriptM], 
                1]];\)\)], "Input",
  CellLabel->"In[15]:=  (16:01:37 on 4/9/01)",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell["whiteSpaceQ", "Subsubsection",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[TextData[{
  StyleBox["whiteSpaceQ", "MR"],
  " tests to see if the given string can be considered white space."
}], "CommentText",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[BoxData[
    \(whiteSpaceQ\ @\ \[ScriptS]\[ScriptT]\[ScriptR]\[ScriptI]\[ScriptN]\
\[ScriptG]_String\  := \n\t\ \ DeleteCases[
          Characters\ @\ \[ScriptS]\[ScriptT]\[ScriptR]\[ScriptI]\[ScriptN]\
\[ScriptG], \n\t\ \ \ \((\ "\<\t\>"\  | \ "\<\n\>"\  | \ "\< \>"\ \  | \ "\<\
\[InvisibleSpace]\>"\  | \ "\<\[VeryThinSpace]\>"\  | \ "\<\[ThinSpace]\>"\  \
| \ "\<\[MediumSpace]\>"\  | \ "\<\[ThickSpace]\>"\  | \ "\<\
\[NegativeVeryThinSpace]\>"\  | \ "\<\[NegativeThinSpace]\>"\  | \[ScriptI]\
\[ScriptN]\[ScriptD]\[ScriptE]\[ScriptN]\[ScriptT]\[ScriptI]\[ScriptN]\
\[ScriptG]\[ScriptCapitalN]\[ScriptE]\[ScriptW]\[ScriptCapitalL]\[ScriptI]\
\[ScriptN]\[ScriptE] | \ \n\t\t\t\ \ \ "\<\[NegativeMediumSpace]\>"\  | \ "\<\
\[NegativeThickSpace]\>"\  | \ "\<\n\>"\  | \ "\<\[NoBreak]\>"\  | \ "\<\
\[NonBreakingSpace]\>"\  | \ "\<\[Continuation]\>"\  | \ "\<\[SpaceIndicator]\
\>"\  | \ "\<\[RoundSpaceIndicator]\>"\ \  | \ "\<\[AlignmentMarker]\>"\  | \ \
"\<\>")\)]\  === \ {}\)], "Input",
  CellLabel->"In[16]:=  (16:01:37 on 4/9/01)",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[BoxData[
    \(whiteSpaceQ\ @\ \[ScriptO]\[ScriptT]\[ScriptH]\[ScriptE]\[ScriptR]___\  \
:= \ False\)], "Input",
  CellLabel->"In[17]:=  (16:01:37 on 4/9/01)",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell["notWhiteSpaceQ", "Subsubsection",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[TextData[{
  StyleBox["notWhiteSpaceQ", "MR"],
  " tests to see if the given string is not considered white space."
}], "CommentText",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[BoxData[
    \(notWhiteSpaceQ\ @\ \[ScriptA]\[ScriptN]\[ScriptY]_\  := 
      Not\ @\ \(whiteSpaceQ\ @\ \[ScriptA]\[ScriptN]\[ScriptY]\)\)], "Input",
  CellLabel->"In[18]:=  (16:01:37 on 4/9/01)",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell["stripStylingBoxes", "Subsubsection",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[TextData[{
  StyleBox["StripStylingBoxes", "MR"],
  " will remove any ",
  StyleBox["styleBoxes", "MR"],
  ", ",
  StyleBox["AdjustmentBoxes", "MR"],
  " or ",
  StyleBox["FrameBoxes", "MR"],
  " from an expressions. Note that properly we should look inside the \
TagBoxes to see whether or not striping of style boxes is enabled there but \
we skip this step, since it gets a bit hairy. (Although highly possible.)"
}], "CommentText",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[BoxData[{
    \(SetAttributes[stripStylingBoxes, HoldAll]\), "\n", 
    \(stripStylingBoxes\ @
        StyleBox[\[ScriptB]\[ScriptO]\[ScriptX]\[ScriptE]\[ScriptS]_, \
\[ScriptS]\[ScriptT]\[ScriptY]\[ScriptL]\[ScriptE]\[ScriptS]___]\ \ \ \ \ \ \ \
 := \ stripStylingBoxes\ @\ \
\[ScriptB]\[ScriptO]\[ScriptX]\[ScriptE]\[ScriptS]\), "\n", 
    \(stripStylingBoxes\ @
        AdjustmentBox[\[ScriptB]\[ScriptO]\[ScriptX]\[ScriptE]\[ScriptS]_, \
\[ScriptS]\[ScriptT]\[ScriptY]\[ScriptL]\[ScriptE]\[ScriptS]___]\ \  := 
      stripStylingBoxes\ @\ \
\[ScriptB]\[ScriptO]\[ScriptX]\[ScriptE]\[ScriptS]\), "\n", 
    \(stripStylingBoxes\ @
        FrameBox[\[ScriptB]\[ScriptO]\[ScriptX]\[ScriptE]\[ScriptS]_, \
\[ScriptS]\[ScriptT]\[ScriptY]\[ScriptL]\[ScriptE]\[ScriptS]___]\ \ \ \ \ \ \ \
 := \ stripStylingBoxes\ @\ \
\[ScriptB]\[ScriptO]\[ScriptX]\[ScriptE]\[ScriptS]\), "\n", 
    \(stripStylingBoxes\ @\ \(TagBox\ @\ \[ScriptB]\[ScriptO]\[ScriptX]\
\[ScriptE]\[ScriptS]___\)\ \ \ \ \ \ \ \ \ \ \ \ \ \  := 
      TagBox\ @\ \[ScriptB]\[ScriptO]\[ScriptX]\[ScriptE]\[ScriptS]\), "\
\[IndentingNewLine]", 
    \(stripStylingBoxes\ @\ _?whiteSpaceQ\ \ \ \ \ \ \ \ \ \ \ \ \ \  := 
      Sequence[]\), "\n", 
    \(stripStylingBoxes\ @\ \(RowBox\ @\ \[ScriptB]\[ScriptO]\[ScriptX]\
\[ScriptE]\[ScriptS]___\)\ \ \ \ \ \ \ \ \ \ \ \ \ \  := 
      RowBox\ [stripStylingBoxes\  /@ \ \[ScriptB]\[ScriptO]\[ScriptX]\
\[ScriptE]\[ScriptS]]\), "\[IndentingNewLine]", 
    \(stripStylingBoxes\ @\ \(BoxData\ @\ \[ScriptB]\[ScriptO]\[ScriptX]\
\[ScriptE]\[ScriptS]_List\)\ \ \ \ \ \ \ \ \ \ \ \ \ \  := 
      BoxData\ [
        stripStylingBoxes\  /@ \ \[ScriptB]\[ScriptO]\[ScriptX]\[ScriptE]\
\[ScriptS]]\), "\[IndentingNewLine]", 
    \(stripStylingBoxes\ @\ \(BoxData\ @\ \[ScriptB]\[ScriptO]\[ScriptX]\
\[ScriptE]\[ScriptS]_\)\ \ \ \ \ \ \ \ \ \ \ \ \ \  := 
      BoxData\ \ @\ \(stripStylingBoxes\ @\ \[ScriptB]\[ScriptO]\[ScriptX]\
\[ScriptE]\[ScriptS]\)\), "\n", 
    \(stripStylingBoxes\ @\ \(\[ScriptA]_\ @\ \[ScriptA]\[ScriptR]\[ScriptG]\
\[ScriptS]__\)\  /; 
        boxStructureQ[\ \[ScriptA]\ @\ \[ScriptA]\[ScriptR]\[ScriptG]\
\[ScriptS]]\ \  := \ \[ScriptA]\  @@ \ \((stripStylingBoxes\  /@ \ \
{\[ScriptA]\[ScriptR]\[ScriptG]\[ScriptS]})\)\), "\n", 
    \(stripStylingBoxes\ @\ {\[ScriptA]\[ScriptR]\[ScriptG]\[ScriptS]__} := 
      stripStylingBoxes\  /@ \ {\[ScriptA]\[ScriptR]\[ScriptG]\[ScriptS]}\), \
"\n", 
    \(stripStylingBoxes\ @\ \[ScriptA]_\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \  := \ \[ScriptA]\)}], "Input",
  CellLabel->"In[19]:=  (16:01:37 on 4/9/01)",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[TextData[{
  StyleBox["stripStylingBoxes", "MR"],
  " expects only one argument."
}], "CommentText",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[BoxData[
    \(\[ScriptE]\[ScriptR]\[ScriptR]\[ScriptO]\[ScriptR]\  : 
        stripStylingBoxes[___]\ \  := 
      With[{\[ScriptN]\[ScriptU]\[ScriptM]\  = 
            heldLength\ @\ \
\[ScriptE]\[ScriptR]\[ScriptR]\[ScriptO]\[ScriptR]}, \ $Failed\  /; \n\t\ \ \ \
\ \ \[ScriptN]\[ScriptU]\[ScriptM]\  \[NotEqual] \ 1\  \[And] 
            Message[stripStylingBoxes::argx, 
              HoldForm\ @\ stripStylingBoxes, \[ScriptN]\[ScriptU]\[ScriptM], 
              1]]\)], "Input",
  CellLabel->"In[31]:=  (16:01:37 on 4/9/01)",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell["File Manipulation Functions", "Subsection",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell["Locate the correct notebook", "Subsubsection",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell["Get the correct notebook.", "CommentText"],

Cell[BoxData[
    \(LocateNotebookThroughFE[] := 
      Module[{\[ScriptCapitalN]\[ScriptO]\[ScriptT]\[ScriptE]\[ScriptB]\
\[ScriptO]\[ScriptO]\[ScriptK]\[ScriptS] = 
            Notebooks[]}, \n\t\tFrontEndTokenExecute["\<Open\>"]; \n\t\tIf[
          Complement[
              Notebooks[], \[ScriptCapitalN]\[ScriptO]\[ScriptT]\[ScriptE]\
\[ScriptB]\[ScriptO]\[ScriptO]\[ScriptK]\[ScriptS]] === {}, 
          SelectedNotebook[], \(Complement[
              Notebooks[], \[ScriptCapitalN]\[ScriptO]\[ScriptT]\[ScriptE]\
\[ScriptB]\[ScriptO]\[ScriptO]\[ScriptK]\[ScriptS]]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket], \n\t\t\ \ \ \ \ \ \ Message[
            LocateNotebookThroughFE::notebookAlreadyOpen]]]\)], "Input",
  CellLabel->"In[32]:=  (16:01:37 on 4/9/01)",
  InitializationCell->True],

Cell[BoxData[
    \(\(LocateNotebookThroughFE::notebookAlreadyOpen = "\<To get the notebook \
reference into Mathematica the notebook must be closed before running \
LocateNotebookThroughFE.\>";\)\)], "Input",
  CellLabel->"In[33]:=  (16:01:38 on 4/9/01)",
  InitializationCell->True],

Cell[BoxData[{
    \(\(\[ScriptN]\[ScriptO]\[ScriptT]\[ScriptE]\[ScriptB]\[ScriptO]\[ScriptO]\
\[ScriptK]\[ScriptCapitalT]\[ScriptO]\[ScriptCapitalC]\[ScriptO]\[ScriptN]\
\[ScriptV]\[ScriptE]\[ScriptR]\[ScriptT] = 
        LocateNotebookThroughFE[];\)\), "\n", 
    \(\(SetOptions[\[ScriptN]\[ScriptO]\[ScriptT]\[ScriptE]\[ScriptB]\
\[ScriptO]\[ScriptO]\[ScriptK]\[ScriptCapitalT]\[ScriptO]\[ScriptCapitalC]\
\[ScriptO]\[ScriptN]\[ScriptV]\[ScriptE]\[ScriptR]\[ScriptT], 
        Visible -> False];\)\)}], "Input",
  CellLabel->"In[34]:=  (16:01:38 on 4/9/01)",
  InitializationCell->True],

Cell[BoxData[
    \(\({\[ScriptF]\[ScriptI]\[ScriptL]\[ScriptE]\[ScriptCapitalP]\[ScriptA]\
\[ScriptT]\[ScriptH], \[ScriptF]\[ScriptI]\[ScriptL]\[ScriptE]\
\[ScriptCapitalN]\[ScriptA]\[ScriptM]\[ScriptE]}\  = \ \({#[\([1]\)], #[\([2]\
\)]} &\)\ ["\<FileName\>"\  /. 
            NotebookInformation\ @\ \[ScriptN]\[ScriptO]\[ScriptT]\[ScriptE]\
\[ScriptB]\[ScriptO]\[ScriptO]\[ScriptK]\[ScriptCapitalT]\[ScriptO]\
\[ScriptCapitalC]\[ScriptO]\[ScriptN]\[ScriptV]\[ScriptE]\[ScriptR]\[ScriptT]]\
;\)\)], "Input",
  CellLabel->"In[36]:=  (16:01:42 on 4/9/01)",
  InitializationCell->True],

Cell["Start Write", "Subsubsection",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell["Open the file and write out a header.", "CommentText"],

Cell[BoxData[
    \(\(\[ScriptN]\[ScriptE]\[ScriptW]\[ScriptCapitalF]\[ScriptI]\[ScriptL]\
\[ScriptE]\[ScriptCapitalN]\[ScriptA]\[ScriptM]\[ScriptE]\  = 
        StringDrop[
            StringJoin\ @
              DeleteCases[
                Characters\ @\ \[ScriptF]\[ScriptI]\[ScriptL]\[ScriptE]\
\[ScriptCapitalN]\[ScriptA]\[ScriptM]\[ScriptE], _?
                  DigitQ], \(-2\)] <> "\<m\>";\)\)], "Input",
  CellLabel->"In[37]:=  (16:01:42 on 4/9/01)",
  InitializationCell->True],

Cell[BoxData[{
    \(\(\[ScriptS]\[ScriptT]\[ScriptR]\[ScriptM]\  = 
        OpenWrite\ @
          ToFileName[\[ScriptF]\[ScriptI]\[ScriptL]\[ScriptE]\[ScriptCapitalP]\
\[ScriptA]\[ScriptT]\[ScriptH], \[ScriptN]\[ScriptE]\[ScriptW]\
\[ScriptCapitalF]\[ScriptI]\[ScriptL]\[ScriptE]\[ScriptCapitalN]\[ScriptA]\
\[ScriptM]\[ScriptE]];\)\), "\n", 
    \(\(WriteString[\[ScriptS]\[ScriptT]\[ScriptR]\[ScriptM], \n\t\ \ \ \ \ "\
\<(* \>"\n\t\t\t <> 
          StringDrop[\[ScriptF]\[ScriptI]\[ScriptL]\[ScriptE]\[ScriptCapitalN]\
\[ScriptA]\[ScriptM]\[ScriptE], \(-2\)] <> "\<m\>"\n\t\t\  <> \ "\< :  Jason \
Harris,  \>"\ \n\t\t\t <> 
          ToString\ @
            StringForm["\<`3`/`2`/`1`\>", 
              Sequence\  @@ 
                Take[\ \ Date[], 
                  3]]\n\t\t\t <> "\<       *)\n\>"];\)\), "\n", 
    \(\(WriteString[\[ScriptS]\[ScriptT]\[ScriptR]\[ScriptM], "\<(* This file \
is machine generated from \>" <> \ \[ScriptF]\[ScriptI]\[ScriptL]\[ScriptE]\
\[ScriptCapitalN]\[ScriptA]\[ScriptM]\[ScriptE]\  <> "\<*)\n\>"];\)\), "\n", 
    \(\(WriteString[\[ScriptS]\[ScriptT]\[ScriptR]\[ScriptM], "\<(* It is not \
intended to be read by humans.  *)\n\>"];\)\), "\n", 
    \(\(WriteString[\[ScriptS]\[ScriptT]\[ScriptR]\[ScriptM], "\<(* Please \
consult the source file \>" <> \ \[ScriptF]\[ScriptI]\[ScriptL]\[ScriptE]\
\[ScriptCapitalN]\[ScriptA]\[ScriptM]\[ScriptE]\  <> "\<. *)\n\n\>"];\)\)}], \
"Input",
  CellLabel->"In[38]:=  (16:01:42 on 4/9/01)",
  InitializationCell->True],

Cell["Expression Writing Machinary", "Subsubsection",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[TextData[{
  "Handle writing out Compound expressions on new lines and have a special \
treatment for statments contating a Notation statement. i.e. write them out \
in full form. Everything else can be safely written out in input form (Modulo \
bugs in the linear syntax handler of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " that I don't know about.)"
}], "CommentText"],

Cell[BoxData[{
    \(\(writeOutExpression\ @\ \(HoldComplete\ @\ \(CompoundExpression\ @\ \
\[ScriptE]\[ScriptX]\[ScriptP]\[ScriptR]\[ScriptS]___\)\)\  := \n\t
        writeOutExpression\  /@ \ \(List\  @@ 
            Thread[HoldComplete\ @\ \(HoldComplete\ @\ \[ScriptE]\[ScriptX]\
\[ScriptP]\[ScriptR]\[ScriptS]\), HoldComplete]\);\)\n\), "\n", 
    \(\(writeOutExpression\ @
          HoldComplete\ [\[ScriptF]\[ScriptI]\[ScriptR]\[ScriptS]\[ScriptT]_, \
\[ScriptR]\[ScriptE]\[ScriptS]\[ScriptT]__]\  := \n\t
        writeOutExpression\  /@ \ \(List\  @@ 
            Thread[HoldComplete\ @
                HoldComplete[\ \[ScriptF]\[ScriptI]\[ScriptR]\[ScriptS]\
\[ScriptT], \[ScriptR]\[ScriptE]\[ScriptS]\[ScriptT]], 
              HoldComplete]\);\)\)}], "Input",
  CellLabel->"In[43]:=  (16:01:43 on 4/9/01)",
  InitializationCell->True],

Cell[BoxData[{
    \(\(writeOutExpression\ @\ \ \(HoldComplete\ @\ Null\)\  := 
        NothingToWrite;\)\), "\n", 
    \(\(writeOutExpression\ @\ \ \
\[ScriptE]\[ScriptX]\[ScriptP]\[ScriptR]_HoldComplete\  /; \(! FreeQ[\ \
\[ScriptE]\[ScriptX]\[ScriptP]\[ScriptR], 
              NotationBoxTag, {0, \[Infinity]}]\)\  := 
        writeOutHeldString\ @\ \(ToString@\ \(FullForm\ @\ \[ScriptE]\
\[ScriptX]\[ScriptP]\[ScriptR]\)\);\)\), "\n", 
    \(\(writeOutExpression\ @\ \
\[ScriptE]\[ScriptX]\[ScriptP]\[ScriptR]_HoldComplete\  := 
        writeOutHeldString\ @
          ToString[\ \[ScriptE]\[ScriptX]\[ScriptP]\[ScriptR], InputForm, 
            CharacterEncoding -> "\<PrintableASCII\>"];\)\)}], "Input",
  CellLabel->"In[45]:=  (16:01:43 on 4/9/01)",
  InitializationCell->True],

Cell[BoxData[
    \(\(writeOutHeldString\ @\ \[ScriptS]\[ScriptT]\[ScriptR]\[ScriptI]\
\[ScriptN]\[ScriptG]_String := 
        WriteString[\[ScriptS]\[ScriptT]\[ScriptR]\[ScriptM], 
          StringTake[\[ScriptS]\[ScriptT]\[ScriptR]\[ScriptI]\[ScriptN]\
\[ScriptG], \ {14, \ \(-2\)}], \ "\<;\n\>"];\)\)], "Input",
  CellLabel->"In[48]:=  (16:01:43 on 4/9/01)",
  InitializationCell->True],

Cell["Multi MakeExpression Machinary", "Subsubsection",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[TextData[{
  "Handle writing out Compound expressions on new lines and have a special \
treatment for statments contating a Notation statement. i.e. write them out \
in full form. Everything else can be safely written out in input form (Modulo \
bugs in the linear syntax handler of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " that I don't know about.)"
}], "CommentText"],

Cell[BoxData[{
    \(\(multiMakeAndWriteExpression\ @\ \(BoxData\ @\ {\[ScriptE]\[ScriptX]\
\[ScriptP]\[ScriptR]_RowBox, \[ScriptR]\[ScriptE]\[ScriptS]\[ScriptT]___}\) \
:= \[IndentingNewLine]\((writeOutExpression\ @\ \(stripedMakeExpression\ @\ \
\[ScriptE]\[ScriptX]\[ScriptP]\[ScriptR]\); 
          multiMakeAndWriteExpression\ @\ \(BoxData\ @\ {\[ScriptR]\[ScriptE]\
\[ScriptS]\[ScriptT]}\))\);\)\), "\n", 
    \(multiMakeAndWriteExpression\ @\ \(BoxData\ @\ {"\<\n\>" | \ \[ScriptI]\
\[ScriptN]\[ScriptD]\[ScriptE]\[ScriptN]\[ScriptT]\[ScriptI]\[ScriptN]\
\[ScriptG]\[ScriptCapitalN]\[ScriptE]\[ScriptW]\[ScriptCapitalL]\[ScriptI]\
\[ScriptN]\[ScriptE], \ rest___}\)\  := 
      multiMakeAndWriteExpression\ @\ \(BoxData\ @\ {rest}\)\), "\n", 
    \(\(multiMakeAndWriteExpression\ @\ \(BoxData\ @\ \[ScriptE]\[ScriptX]\
\[ScriptP]\[ScriptR]_RowBox\) := \((\(writeOutExpression\ @\ \
\(stripedMakeExpression\ @\ \[ScriptE]\[ScriptX]\[ScriptP]\[ScriptR]\);\))\);\
\)\), "\n", 
    \(\(multiMakeAndWriteExpression\ @\ \(BoxData\ @\ {}\) := 
        Null;\)\), "\n", 
    \(multiMakeAndWriteExpression\ @\ \(BoxData\ @\ {\[ScriptO]\[ScriptT]\
\[ScriptH]\[ScriptE]\[ScriptR]___}\)\  := $Failed /; 
        Print["\<encountered unexpected thing: \>", {\[ScriptO]\[ScriptT]\
\[ScriptH]\[ScriptE]\[ScriptR]}]\)}], "Input",
  CellLabel->"In[49]:=  (16:01:43 on 4/9/01)",
  InitializationCell->True],

Cell[BoxData[
    \(stripedMakeExpression\ @\ \[ScriptE]\[ScriptX]\[ScriptP]\[ScriptR]_\  \
:= \ MakeExpression\ @\ \((\[ScriptE]\[ScriptX]\[ScriptP]\[ScriptR] //. \
{RowBox[{"\<(*\>", _, "\<*)\>"}] \[Rule] 
                Sequence[], "\<\r\>" \[Rule] "\<\n\>"})\)\)], "Input",
  CellLabel->"In[54]:=  (16:01:43 on 4/9/01)",
  InitializationCell->True],

Cell["Multi MakeExpression Machinary", "Subsubsection",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell[TextData[{
  "Handle writing out Compound expressions on new lines and have a special \
treatment for statments contating a Notation statement. i.e. write them out \
in full form. Everything else can be safely written out in input form (Modulo \
bugs in the linear syntax handler of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " that I don't know about.)"
}], "CommentText"],

Cell[BoxData[{
    \(\(multiMakeAndEvalExpression\ @\ \(BoxData\ @\ {\[ScriptE]\[ScriptX]\
\[ScriptP]\[ScriptR]_RowBox, \[ScriptR]\[ScriptE]\[ScriptS]\[ScriptT]___}\) \
:= \[IndentingNewLine]\((Identity\  @@ 
            stripedMakeExpression\ @\ \
\[ScriptE]\[ScriptX]\[ScriptP]\[ScriptR]; 
          multiMakeAndEvalExpression\ @\ \(BoxData\ @\ {\[ScriptR]\[ScriptE]\
\[ScriptS]\[ScriptT]}\))\);\)\), "\n", 
    \(multiMakeAndEvalExpression\ @\ \(BoxData\ @\ {"\<\n\>" | \ \[ScriptI]\
\[ScriptN]\[ScriptD]\[ScriptE]\[ScriptN]\[ScriptT]\[ScriptI]\[ScriptN]\
\[ScriptG]\[ScriptCapitalN]\[ScriptE]\[ScriptW]\[ScriptCapitalL]\[ScriptI]\
\[ScriptN]\[ScriptE], \ rest___}\)\  := 
      multiMakeAndEvalExpression\ @\ \(BoxData\ @\ {rest}\)\), "\n", 
    \(\(multiMakeAndEvalExpression\ @\ \(BoxData\ @\ \[ScriptE]\[ScriptX]\
\[ScriptP]\[ScriptR]_RowBox\) := \((\(Identity\  @@ 
              stripedMakeExpression\ @\ \[ScriptE]\[ScriptX]\[ScriptP]\
\[ScriptR];\))\);\)\), "\n", 
    \(\(multiMakeAndEvalExpression\ @\ \(BoxData\ @\ {}\) := 
        Null;\)\), "\n", 
    \(multiMakeAndEvalExpression\ @\ \(BoxData\ @\ {\[ScriptO]\[ScriptT]\
\[ScriptH]\[ScriptE]\[ScriptR]___}\)\  := $Failed /; 
        Print["\<encountered unexpected thing: \>", {\[ScriptO]\[ScriptT]\
\[ScriptH]\[ScriptE]\[ScriptR]}]\)}], "Input",
  CellLabel->"In[55]:=  (16:01:43 on 4/9/01)",
  InitializationCell->True],

Cell["\<\
Step through the notebook and convert each cell and write it out to \
the file\
\>", "Subsubsection"],

Cell[BoxData[{
    \(\(SelectionMove[\[ScriptN]\[ScriptO]\[ScriptT]\[ScriptE]\[ScriptB]\
\[ScriptO]\[ScriptO]\[ScriptK]\[ScriptCapitalT]\[ScriptO]\[ScriptCapitalC]\
\[ScriptO]\[ScriptN]\[ScriptV]\[ScriptE]\[ScriptR]\[ScriptT], \ Before, 
        Notebook];\)\), "\n", 
    \(\(SelectionMove[\[ScriptN]\[ScriptO]\[ScriptT]\[ScriptE]\[ScriptB]\
\[ScriptO]\[ScriptO]\[ScriptK]\[ScriptCapitalT]\[ScriptO]\[ScriptCapitalC]\
\[ScriptO]\[ScriptN]\[ScriptV]\[ScriptE]\[ScriptR]\[ScriptT], \ Next, 
        Cell];\)\), "\n", 
    \(\(While[\((\[ScriptS]\[ScriptE]\[ScriptL]\[ScriptE]\[ScriptC]\[ScriptT]\
\[ScriptI]\[ScriptO]\[ScriptN]\  = 
              NotebookRead[\[ScriptN]\[ScriptO]\[ScriptT]\[ScriptE]\[ScriptB]\
\[ScriptO]\[ScriptO]\[ScriptK]\[ScriptCapitalT]\[ScriptO]\[ScriptCapitalC]\
\[ScriptO]\[ScriptN]\[ScriptV]\[ScriptE]\[ScriptR]\[ScriptT]])\)\  =!= \ {}, \
\[IndentingNewLine]If[
          MatchQ[\[ScriptS]\[ScriptE]\[ScriptL]\[ScriptE]\[ScriptC]\[ScriptT]\
\[ScriptI]\[ScriptO]\[ScriptN], 
            Cell[_, \ "\<Input\>", \
\[ScriptO]\[ScriptP]\[ScriptT]\[ScriptS]___] /; \[Not] MemberQ[{\[ScriptO]\
\[ScriptP]\[ScriptT]\[ScriptS]}, 
                  Evaluatable \[Rule] 
                    False]], \[IndentingNewLine]multiMakeAndEvalExpression\ @\
\ \(stripStylingBoxes\ @\ \(Evaluate\ @\ \(First\ @\ \[ScriptS]\[ScriptE]\
\[ScriptL]\[ScriptE]\[ScriptC]\[ScriptT]\[ScriptI]\[ScriptO]\[ScriptN]\)\)\); \
\[IndentingNewLine]If[
            MatchQ[\[ScriptS]\[ScriptE]\[ScriptL]\[ScriptE]\[ScriptC]\
\[ScriptT]\[ScriptI]\[ScriptO]\[ScriptN], 
              Cell[_, \ "\<Input\>", \ ___, 
                InitializationCell\  \[Rule] 
                  True, ___]], \[IndentingNewLine]multiMakeAndWriteExpression\
\ @\ \(stripStylingBoxes\ @\ \(Evaluate\ @\ \(First\ @\ \[ScriptS]\[ScriptE]\
\[ScriptL]\[ScriptE]\[ScriptC]\[ScriptT]\[ScriptI]\[ScriptO]\[ScriptN]\)\)\); \
\[IndentingNewLine]WriteString[\[ScriptS]\[ScriptT]\[ScriptR]\[ScriptM], \ \
"\<\n\>"]]]; \[IndentingNewLine]SelectionMove[\[ScriptN]\[ScriptO]\[ScriptT]\
\[ScriptE]\[ScriptB]\[ScriptO]\[ScriptO]\[ScriptK]\[ScriptCapitalT]\[ScriptO]\
\[ScriptCapitalC]\[ScriptO]\[ScriptN]\[ScriptV]\[ScriptE]\[ScriptR]\[ScriptT],\
 \ Next, \ Cell];];\)\)}], "Input",
  CellLabel->"In[60]:=  (16:01:43 on 4/9/01)",
  InitializationCell->True],

Cell[BoxData[
    \(\(Close[\[ScriptS]\[ScriptT]\[ScriptR]\[ScriptM]];\)\)], "Input",
  CellLabel->"In[63]:=  (16:02:45 on 4/9/01)",
  InitializationCell->True],

Cell["Endings", "Subsection",
  CellTags->{"3.0 Code", "4.0 Code"}],

Cell["EndPackage.", "Subsubsection"],

Cell[BoxData[{
    \(\(End[];\)\), "\n", 
    \(\(EndPackage[];\)\)}], "Input",
  CellLabel->"In[64]:=  (16:02:45 on 4/9/01)",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Play[Sin[1000\/\(t + 0.1\)], {t, \(-1\), 1}];\)\)], "Input",
  CellLabel->"In[66]:=  (16:02:45 on 4/9/01)",
  CellTags->"Play"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
8192 16384 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[66]:=  (16:02:46 on 4/9/01)",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oo`008@0000000`00
Oomoo`3oOolMOol100000003001oogoo05eoo`X000Ioo`<00003Ool0000000H00003Ool0000000P0
0003Ool007oo00<00004Ool007ooOol20007Ool:001kOol100000003001oogoo05Qooa0000Eoo`<0
0003Ool0000001T00004Ool000000005Ool@001gOol100000003001oogoo05AooaD000=oo`@00003
Ool0000001T00003Ool00000008000AooaD0079oo`40000000<007ooOol0CWoo6`000goo100000Ao
o`00001ooad000=ooa/006eoo`40000000<007ooOol0AWoo90000Woo9P0000=oo`000000100000=o
o`0000007000I7oo0@0000000`00Oomoo`0iOolZ00000goo0000000400000goo0000000J00000goo
0000000400001Goo00000000Ool01`0000Aoo`00001oobL005Moo`40000000<007ooOol06goo=`00
00=oo`000000AP0000=oo`000000A000>Woo0@0000000`00Ool0001H00000goo0000000k00001Goo
00000000Ool0P0000Goo0@0000000`00Ool0002S00000goo0000001e0001Ool100000003001oogoo
01aood@00003Ool0000000<00003Ool0000002H00003Ool0000000P00003Ool0000004@003]oo`40
000000<007ooOol0>Goo8`0000=oo`0000001P0000=oo`0000002P0000=oo`0000007@0000=oo`00
00003P0000=oo`0000007P00F7oo0@0000000`00Oomoo`16OolF00000goo0000000;0002Ool60000
0goo0000000D00000goo0000000600000goo0000000R001UOol100000003001oogoo04ioo`h00003
Ool0000000X000=oo`P00003Ool0000000d00003Ool0000000X000=ooa/006eoo`40000000<007oo
0000E7oo5@000goo100000=oo`0000002@0000Moo`00000007oo001oo`0900000goo000000020004
Ool800000goo0000000:001bOol100000003001oogoo05Uoo`l000Eoo`<00003Ool0000001T00003
Ool00000008000Eoo`800003Ool0000000X007Moo`40000000<007ooOol0G7oo2`001Woo0`0000Ao
o`00001ooa000003Ool0000000D0009oo`8000Moo`X007]oo`40000000<007ooOol0ogoo7Goo0@00
003o000Q00000003001oogoo0?mooaeoo`40000000<007oo0000DP0000=oo`0000008@0000=oo`00
0000100000=oo`0000002`0000=oo`000000S@000Goo0@0000000`00Ool0000300001Goo00000000
Ool01P0000=oo`00Ool010000Woo100000Aoo`00001oo`T00003Ool0000000800006Ool007ooOol0
07oo0`000Woo3P0000Eoo`00Ool007oo00800007Ool00000Ool007oo00000Woo00@007oo001oo`H0
0004Ool007ooOol300000goo001oo`0700000goo0000000800000goo0000000200000goo00000005
00000goo000000040002Ool01000Ool007oo1@000goo00D007oo000007oo00@00003Ool0000000`0
0003Ool0000000800003Ool007oo00D00003Ool0000000800003Ool007oo00<00003Ool007oo00<0
0003Ool0000000P00003Ool007oo00P00003Ool007oo00D00003Ool0000000H00003Ool0000000<0
0003Ool00000009oo`d0009oo`H0005oo`40000000<007ooOol017oo0P0000=oo`0000001Goo0P00
00=oo`00Ool017oo0P0017oo0P0000Aoo`00001oo`H00004Ool007oo0003Ool01@00Ool007oo0000
17oo00@007ooOomoo`D000=oo`<0009oo`03001oogoo00D0009oo`800003Ool0000000=oo`03001o
o`0000<00003Ool007oo00800004Ool007oo0003Ool01000Ool000000Woo00<007oo00000Woo1000
0Woo00<007ooOol02Woo00<007oo00000goo0`001Goo00@007oo000000Aoo`04001oogooOol30003
Ool01@00Oomoogoo00001Goo0`0017oo0P000Woo00@007ooOol0009oo`04001oo`000003Ool00`00
Oomoo`02Ool01000Oomoo`001Goo00D007ooOomoo`00009oo`03001oo`0000=oo`8000=oo`800003
Ool0000000Ioo`800003Ool0000000800004Ool00000Ool20002Ool20002Ool20003Ool40007Ool1
00000005001oo`00001oo`0300000goo00000003Ool60002Ool01000Ool000000Woo0P0000Aoo`00
001oo`<0009oo`03001oogoo00<00003Ool0000000800004Ool000000002Ool2000017oo001oo`00
0Woo0P0000Uoo`00Ool007oo001oo`00Ool00P0000=oo`00000027oo0P0017oo00@007oo001oo`<0
0003Ool007oo00T00006Ool007oo001oo`000Woo1P0000=oo`0000000`000goo0P000Woo0`000goo
00@007oo000000=oo`03001oogoo00D00003Ool0000000P00005Ool00000001oo`080004Ool30007
Ool600001Goo00000000Ool00P0000=oo`0000000P0000Uoo`00Oomoo`00Ool007oo00000goo0`00
00Eoo`00Ool007oo00<00004Ool00000Ool200000goo001oo`03000017oo0000000017oo0P000goo
0P000Woo1@000Woo0`0000=oo`00000010000Goo0@0000001@00Ool00000Ool00`0000Aoo`00Oomo
o`800003Ool0000000=oo`04001oo`00Ool20002Ool400000goo0000000700000goo00000002Ool8
000017oo001oogoo1P0000=oo`0000000goo1@0000=oo`000000100000Aoo`000000009oo`03001o
o`0000<00003Ool007oo00=oo`06001oogooOol007oo0P000Woo00@007ooOomoo`800004Ool00000
Ool20003Ool01000Ool007oo0`0000Aoo`00Ool0009oo`800003Ool0000000T00004Ool007oo0003
Ool00`00Ool00002Ool01000Oomoogoo0P000goo00@007ooOol000=oo`8000=oo`<00003Ool00000
00<00004Ool000000007Ool200000goo0000000200000goo0000000300001Woo00000000Ool0009o
o`8000Aoo`03001oo`0000<00003Ool000000080009oo`05001oo`00001oo`0300000goo00000003
00000goo00000002Ool200001Goo001oogoo00000Woo10000Woo0P0000=oo`00Ool00Woo0@000000
1000Oomoogoo0P001Goo0`0000Moo`00001oo`00Ool00004Ool01000Oomoogoo0`000Woo00<007oo
Ool00goo00<007oo00000P001Goo00D007ooOomoo`0000Qoo`<00004Ool000000004Ool2000:Ool0
1P00Oomoogoo001oo`@00003Ool007oo00Aoo`04001oogoo0002Ool20005Ool01000Ool000000goo
00<007ooOol00`000Woo00@007ooOol0009oo`03001oogoo00Aoo`04001oo`000002Ool01000Oomo
ogoo0P0000Ioo`00000007oo0002Ool00`00Ool00005Ool00`00Oomoo`06Ool01P00Ool00000Ool0
009oo`8000Aoo`<00003Ool007oo009oo`80009oo`04001oogoo0002Ool01000Oomoogoo0`0000Ao
o`00Ool0009oo`03001oo`00009oo`03001oogoo00Qoo`8000Ioo`04001oogoo0005Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool00`00Oomoo`03Ool20003Ool20002Ool100000007001oogoo001oo`00
Ool00P0000Aoo`00001oo`@00004Ool007ooOol30002Ool3000017oo001oogoo0P0000Aoo`000000
00=oo`800003Ool0000000D000Aoo`<00004Ool000000002Ool40002Ool40002Ool70003Ool00`00
Oomoo`03Ool01`00Ool00000Ool007oo00@00005Ool00000Ool00002Ool01000Ool007oo1`0000=o
o`0000000P000Woo1P0000=oo`0000001P0000Uoo`00Ool007oo001oo`00Ool010000Woo00@007oo
Oomoo`@00005Ool00000001oo`0300000goo001oo`030003Ool01000Oomoo`001Woo0P000Woo00D0
07oo000007oo00<00003Ool007oo00<00004Ool007ooOol200000goo00000005Ool200000goo001o
o`03Ool300000goo001oo`03Ool20002Ool00`00Ool00003Ool00`00Ool00003000017oo000007oo
0`000Woo100000Aoo`00Oomoo`80009oo`<00004Ool00000Ool100000008001oo`00001oo`00Ool0
00=oo`03001oogoo00=oo`04001oogoo0002Ool00`00Oomoo`02000017oo001oo`000Woo00D007oo
Ool007oo00<000Eoo`<0009oo`<000=oo`800003Ool0000000=oo`04001oo`000003Ool01@00Ool0
07oo00000goo0`000Woo00@007oo0000009oo`<0009oo`<000Moo`04001oogooOol20002Ool00`00
Ool0000200001Goo001oo`00Ool00P0000=oo`00Ool00P0000Qoo`00000007oo001oo`0017oo0P00
00=oo`00Ool01@0000=oo`0000000P0000Eoo`00001oo`0000Aoo`03001oogoo00Ioo`03001oo`00
00=oo`08001oogooOol007oo001oo`<000=oo`05001oogoo001oo`0400001Goo001oogoo00000Woo
00@007ooOol000Ioo`8000Aoo`P000=oo`80009oo`8000=oo`800003Ool00000008000Aoo`03001o
ogoo009oo`80009oo`@00003Ool0000000Aoo`@000=oo`40000000<007ooOol00goo00D007ooOomo
o`0000Uoo`03001oogoo00=oo`8000Moo`03001oogoo00<000Eoo`8000=oo`03001oogoo00Aoo`03
001oogoo009oo`8000Aoo`04001oo`000008Ool00`00Oomoo`05Ool20006Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Ool00002Ool00`00Oomoo`04Ool20009Ool00`00Ool00002Ool20003Ool0
1000Oomoo`000goo00<007ooOol01goo0`0017oo00D007ooOomoo`0000=oo`@000Moo`03001oo`00
00Ioo`03001oogoo009oo`@000Aoo`03001oogoo00=oo`03001oogoo009oo`8000=oo`8000Eoo`05
001oogoo001oo`0200001Goo001oogoo000017oo00D007oo001oo`00009oo`04001oo`00Ool20002
Ool00`00Oomoo`09Ool01P00Ool00000Ool000Aoo`03001oogoo0040000000D007oo000007oo0080
009oo`03001oogoo00@000=oo`07001oogoo001oo`00Ool00P0017oo0`0000=oo`00Ool00goo00<0
07ooOol00P001Goo100000Aoo`00000000Aoo`06001oogooOol007oo0`0000=oo`00Ool00Woo00<0
07oo00000goo00@007oo001oo`800008Ool007oo001oo`00Ool000=oo`05001oo`00Ool00002Ool5
0002Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`@00003Ool007oo00800003Ool007oo0080
00Moo`800003Ool00000008000=oo`05001oo`00Ool00002Ool01000Ool000000Woo00H007oo0000
07oo0007Ool01000Ool007oo0P0000Eoo`00Oomoo`00009oo`@0009oo`04001oogoo0002Ool20000
17oo001oo`001Woo0P000Woo00<007oo00000Woo00<007oo000017oo0`000Woo00D007ooOol007oo
0080009oo`04001oo`00Ool30003Ool01P00Oomoogoo001oo`8000=oo`03001oogoo00=oo`H00003
Ool007oo0040000000@007ooOomoo`800004Ool007oo0002Ool00`00Oomoo`0400000goo001oo`02
Ool20002Ool20002Ool200000goo000000030002Ool01000Ool000001Goo00<007ooOol00goo0P00
1Woo00<007ooOol00goo00<007ooOol00`0000=oo`00Ool00goo00<007oo00000Woo0P000Woo00<0
07ooOol017oo0P0027oo0P0027oo0`0017oo00@007ooOol000Ioo`04001oo`00Ool50004Ool40000
17oo001oo`0017oo00<007oo00000P0000Eoo`00000007oo0080009oo`03001oogoo00D0009oo`<0
009oo`05001oogoo001oo`020004Ool01000Ool007oo10000goo00@007oo001oo`H00003Ool007oo
009oo`04001oo`000002Ool01000Ool007oo0`0000Aoo`00Ool0009oo`04001oo`000002Ool20004
Ool20003Ool300000goo00000003000017oo001oogoo0P000goo10000Woo0@0000000`00Oomoo`03
00000goo001oo`03Ool00`00Oomoo`07Ool01000Oomoo`0027oo0P0017oo00<007ooOol01Woo00D0
07ooOomoo`00009oo`04001oo`000004Ool20006Ool01000Oomoogoo0P001Goo00@007ooOomoo`<0
009oo`06001oo`00001oo`000goo0P0017oo00<007ooOol017oo00<007ooOol02Woo00<007ooOol0
1Goo00<007oo00000goo0P000goo00<007ooOol00goo00<007oo00000`001Woo00<007ooOol00`00
0goo0P001Woo0`000Woo00<007ooOol00Woo00D007ooOol007oo0080009oo`03001oogoo00Uoo`03
001oogoo00Qoo`03001oogoo00=oo`03001oo`0000=oo`03001oogoo009oo`04001oogoo0002Ool0
1@00Oomoogoo00001Woo0P0000=oo`00000027oo00<007ooOol03Woo0@0000001000Ool000000goo
0P000Woo00@007oo001oo`800004Ool007oo0003Ool20002Ool50006Ool50002Ool200001Goo001o
ogoo00001goo0P001Woo00D007ooOomoo`0000Ioo`<0009oo`<000=oo`03001oogoo00Moo`03001o
ogoo0080009oo`04001oo`00Ool30002Ool01P00Ool00000Ool000=oo`800005Ool007oo001oo`03
0002Ool60003Ool2000027oo001oo`00Ool007oo0002Ool20002Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000Woo00H007ooOol007oo0002Ool00`00Ool00003Ool20002Ool50007Ool50007Ool20005
Ool00`00Ool0000:Ool20004Ool20003Ool00`00Ool00003Ool01000Ool000000goo0P000goo0P00
0Woo00D007oo000007oo00<000=oo`03001oogoo0080009oo`40000000<007oo000017oo00<007oo
Ool00P000Woo0P000Woo00@007ooOol0009oo`80009oo`04001oo`000004Ool20005Ool30007Ool5
0002Ool00`00Ool0000200000goo001oo`030003Ool01000Ool007oo0P0000=oo`00Ool00`000goo
00@007oo000000Yoo`<00003Ool007oo00Aoo`<000Moo`8000Aoo`03001oogoo008000=oo`<00003
Ool00000009oo`800003Ool007oo00=oo`04001oogoo0002Ool20009Ool00`00Oomoo`02000017oo
000000000Woo00<007oo000017oo0P000Woo00<007oo00000Woo0P0017oo0P000Woo0P0000Aoo`00
Oomoo`<00003Ool00000009oo`06001oogooOol007oo0P000Woo00<007oo000017oo00<007ooOol0
0Woo0P001Goo00D007oo001oo`0000]oo`03001oo`0000Eoo`03001oogoo00H0009oo`40005oo`40
000000<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007oo0000
1Goo0P000Woo10000Woo00D007ooOomoo`0000=oo`03001oogoo00]oo`03001oogoo009oo`03001o
ogoo00Aoo`04001oogoo0002Ool01@00Oomoogoo00001goo00<007ooOol01Goo00D007ooOomoo`00
00Uoo`<000=oo`03001oo`00009oo`05001oogooOol00005Ool01000Oomoo`003Woo00<007ooOol0
0goo0`0017oo10000Woo00D007ooOomoo`0000Yoo`03001oogoo00<000Uoo`8000aoo`03001oogoo
00=oo`04001oogoo0003Ool00`00Oomoo`04Ool01000Oomoo`001Woo00D007ooOomoo`0000=oo`03
001oogoo009oo`800003Ool00000009oo`03001oogoo00Aoo`03001oogoo00aoo`40000000D007oo
Ool007oo008000=oo`03001oogoo00Aoo`03001oogoo00@0009oo`<0009oo`04001oogoo0002Ool4
00001Woo001oo`00Ool000Aoo`80009oo`<00004Ool007ooOol200000goo001oo`02Ool01000Ool0
000017oo0P0000Aoo`000000009oo`H0009oo`80009oo`03001oogoo009oo`03001oogoo00@00003
Ool007oo00Eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Eoo`@0009oo`04001oo`00
Ool20008Ool00`00Oomoo`0400001Goo001oogoo00000Woo00H007ooOomoo`00Ool20003Ool00`00
Ool00002Ool01@00Oomoo`00Ool0100000Eoo`00Oomoo`00009oo`03001oogoo009oo`07001oo`00
001oo`00Ool0100000Eoo`00Ool007oo0080009oo`03001oo`0000Eoo`03001oo`0000=oo`80009o
o`8000Aoo`80009oo`D000Ioo`05001oo`00001oo`02000017oo001oogoo0P000goo10000Woo0@00
00000`00Ool00006Ool00`00Oomoo`0;Ool02000Oomoo`00Ool007oo000:Ool00`00Oomoo`03Ool2
0004Ool30003Ool2000017oo001oo`000goo00H007oo001oo`00Ool20004Ool01@00Ool00000Ool0
0`000Woo0P0000=oo`00Ool00Woo0`001Woo0P0017oo00<007ooOol010001Goo00<007ooOol017oo
0P000Woo00D007oo001oo`00009oo`04001oogoo0002Ool400000goo001oo`09Ool01P00Ool007oo
001oo`800004Ool000000003Ool20002Ool00`00Oomoo`04Ool00`00Ool000020002Ool2000017oo
001oo`000Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00P0017oo0P0000Aoo`00001o
o`@000Aoo`03001oo`00009oo`04001oo`000002Ool00`00Ool00005Ool01000Oomoogoo0`000goo
0P002Goo00<007ooOol017oo0@0000000`00Oomoo`06Ool01000Oomoogoo0P0017oo0P000Woo00D0
07ooOomoo`0000=oo`03001oogoo009oo`80009oo`8000Uoo`05001oogooOol00006Ool00`00Oomo
o`05Ool00`00Oomoo`0AOol00`00Oomoo`06Ool01@00Oomoo`00Ool00P000Woo00<007ooOol017oo
00D007ooOomoo`0000=oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00]oo`04001oo`00
Ool20006Ool2000>Ool2000017oo001oo`000goo0P003goo0P0000=oo`00Ool01Woo00<007oo0000
0`001Woo00<007oo00000Woo00<007oo00000Woo00H007oo000007oo000:Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool20005Ool300000goo00000007Ool20002Ool100000003001oogoo00<00003Ool0
07oo00=oo`03001oogoo00D0009oo`05001oogooOol00002Ool01000Ool007oo0P0000Aoo`00Ool0
00=oo`<0009oo`<0009oo`04001oogoo0003Ool00`00Ool00007Ool30004Ool00`00Oomoo`02Ool0
2000Oomoogoo001oo`00Ool2000:Ool00`00Ool00006Ool00`00Ool00003Ool00`00Ool00002Ool0
1P00Oomoogoo001oo`8000=oo`05001oo`00Ool00003Ool00`00Ool00002Ool00`00Ool00002Ool3
0002Ool01000Oomoogoo10000Woo00<007ooOol00goo00@007oo001oo`80009oo`8000Aoo`03001o
o`0000=oo`07001oogooOol007oo000017oo00<007ooOol00goo00<007oo00000P0000Aoo`00001o
o`8000]oo`<000=oo`08001oo`00001oo`00Ool0009oo`04001oo`000002Ool00`00Oomoo`02Ool2
00000goo00000003Ool20002Ool00`00Ool00002Ool00`00Ool000030002Ool01@00Oomoo`00Ool0
0@0000000`00Ool00002Ool01000Ool000000Woo0P000Woo00<007ooOol01Woo00@007oo000000]o
o`04001oogooOol20002Ool01000Ool007oo0`0027oo0P0017oo00@007oo000000Aoo`04001oo`00
0005Ool30005Ool200000goo001oo`04Ool00`00Ool00002Ool3000017oo000000000goo00@007oo
Ool0009oo`03001oogoo008000Moo`04001oogooOol40004Ool00`00Ool00002Ool20002Ool20007
Ool01@00Ool007oo000017oo00<007ooOol00P000Woo0P0017oo00D007oo001oo`00009oo`06001o
o`00001oo`0017oo00<007oo00000Woo00D007oo001oo`00009oo`04001oogoo0003Ool3000;Ool0
1@00Ool007oo000017oo00<007ooOol00P000Woo00@007oo000000=oo`03001oogoo00=oo`03001o
ogoo00Uoo`04001oo`000002Ool00`00Oomoo`0100000004001oogoo0009Ool00`00Oomoo`04Ool0
1000Oomoogoo0P002Goo00<007oo000017oo00<007ooOol01Goo00<007ooOol00goo00<007ooOol0
3Goo00<007ooOol04goo10005Woo00<007ooOol00Woo0P0000=oo`0000001goo0P001Woo00@007oo
Ool000Eoo`8000Aoo`03001oogoo00ioo`03001oogoo00Eoo`800003Ool007oo00Aoo`03001oo`00
00Eoo`80009oo`8000Eoo`03001oogoo00Qoo`04001oogoo0002Ool00`00Oomoo`02Ool01000Oomo
o`0017oo00D007ooOomoo`0000Moo`03001oogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`02
Ool20003Ool100000003001oo`0000Eoo`03001oo`00009oo`04001oo`000005Ool00`00Oomoo`04
Ool01000Oomoo`001Goo10000goo0P000goo0P0000=oo`00Ool00Woo00<007ooOol00P0000Aoo`00
001oo`800005Ool007ooOol00004Ool01@00Oomoo`00Ool00P001goo00@007ooOol000Eoo`800006
Ool007ooOol007oo0P0017oo00H007ooOol007oo0005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool2
00000goo001oo`03Ool00`00Oomoo`02Ool2000017oo0000000017oo00@007ooOol000=oo`800003
Ool007oo00=oo`03001oogoo00Aoo`05001oogoo001oo`02000017oo000007oo0`0000=oo`00Ool0
0Woo00<007oo00002Goo00<007ooOol00Woo00<007ooOol00goo00<007oo00001Goo00@007ooOol0
00Ioo`04001oo`000008Ool00`00Ool00003Ool2000017oo000007oo0P0000Ioo`00Oomoo`00Ool2
0002Ool00`00Oomoo`02Ool00`00Oomoo`03Ool100000005001oogoo001oo`030003Ool02P00Oomo
o`00Ool007oo001oo`000goo0P000Woo0P000Woo0`0000=oo`00Ool00Woo00<007ooOol017oo0`00
0Woo0P000goo00<007oo00000goo00@007oo000000Moo`8000Uoo`07001oogooOol007oo00001Goo
0P001Woo0P0000=oo`00Ool017oo00<007ooOol00P000Woo0`0000Aoo`000000009oo`03001oo`00
00=oo`03001oo`0000Eoo`8000Eoo`03001oo`0000Aoo`03001oo`00009oo`@0009oo`04001oo`00
000:Ool300000goo0000000:Ool00`00Ool00005Ool00`00Ool0000200000goo001oo`04Ool40004
Ool01@00Ool007oo00000goo0`001Goo0P0017oo0P000Woo0P0000Aoo`00000000Qoo`8000]oo`03
001oogoo0080009oo`40000000<007ooOol027oo00D007ooOomoo`00009oo`03001oogoo00Aoo`03
001oogoo00Aoo`8000ioo`03001oo`0000=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo
00Eoo`05001oogooOol00002Ool00`00Ool00005Ool00`00Oomoo`06Ool01000Oomoo`001Goo00@0
07ooOol000Qoo`03001oogoo011oo`@001Yoo`05001oogooOol00006Ool3000017oo001oogoo0P00
0goo00<007ooOol027oo00<007ooOol06Woo00<007ooOol04goo00@007ooOomoo`8000Moo`03001o
ogoo009oo`800003Ool007oo008000Uoo`40005oo`40000000<007oo00000Woo0P0000Aoo`00Ool0
00Eoo`03001oogoo009oo`03001oogoo0080009oo`03001oogoo00=oo`D0009oo`04001oogoo0002
Ool00`00Oomoo`020002Ool00`00Ool00007Ool20004Ool20002Ool2000<Ool00`00Oomoo`02Ool2
0008Ool01000Ool000000goo00P007ooOol007oo001oo`000goo00@007oo0000009oo`05001oogoo
Ool0000:Ool01P00Ool007oo001oo`800004Ool007ooOol20006Ool01P00Oomoo`00Ool0009oo`05
001oo`00Ool00009Ool20004Ool20002Ool00`00Ool00003Ool01@00Oomoogoo000027oo0P001Woo
00<007oo00002Goo00<007ooOol00Woo00@007ooOol000=oo`03001oogoo009oo`800003Ool007oo
00Aoo`04001oogooOol200000goo001oo`03Ool01@00Oomoo`00Ool01@0000=oo`00Ool00goo0@00
00000`00Oomoo`06Ool00`00Oomoo`05Ool01`00Oomoogoo001oo`0000Aoo`D0009oo`03001oogoo
008000Eoo`80009oo`03001oogoo00Moo`03001oo`0000Eoo`8000=oo`03001oogoo0080009oo`80
01=oo`04001oogoo0009Ool00`00Ool0000;Ool01`00Oomoogoo001oo`0000Eoo`80009oo`05001o
o`00Ool00007Ool01@00Oomoogoo000017oo00H007oo001oo`00Ool20002Ool00`00Oomoo`07Ool2
0002Ool00`00Oomoo`02Ool00`00Oomoo`07Ool300001Goo001oogoo00000goo00<007oo00000Woo
0P000Woo00<007oo00000Woo00<007ooOol017oo0P000goo00D007ooOomoo`00009oo`05001oogoo
Ool00006Ool01000Ool000000goo0P000Woo00<007ooOol01Woo00@007ooOol0009oo`03001oogoo
0040000000<007ooOol00P0017oo00<007ooOol027oo00@007oo000001Eoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oo`0000aoo`03001oo`00009oo`03001oogoo009oo`8000Ioo`03001oo`00
00=oo`03001oogoo00Aoo`03001oogoo009oo`05001oo`00Ool00006Ool01000Oomoogoo0P001Woo
00<007ooOol02goo0P0047oo00@007ooOomoo`<0009oo`03001oogoo01]oo`03001oo`00009oo`80
00Ioo`03001oo`0000=oo`03001oogoo00Qoo`05001oogoo001oo`020003Ool20003Ool01@00Oomo
ogoo000017oo00<007ooOol03Goo0P000goo0@0000000`00Oomoo`02Ool01@00Ool007oo00000Woo
0`001goo0P001Goo0`001goo0P0000=oo`00Ool00P001Woo00<007ooOol00Woo00<007ooOol00P00
0goo0P0000=oo`0000001Goo00@007ooOomoo`<00009Ool007ooOol007oo001oo`0000=oo`06001o
ogoo001oo`000goo00H007ooOol007oo0002Ool01000Oomoogoo1@0000=oo`0000001goo00@007oo
Oomoo`8000=oo`<000=oo`800003Ool0000000<00003Ool0000000Aoo`@000Aoo`8000Qoo`03001o
o`0000Aoo`05001oogooOol00003Ool01@00Oomoogoo00001Goo00<007oo00000Woo0P001Goo00<0
07ooOol02Woo00<007ooOol00goo00<007oo00000goo00<007ooOol01Goo0P001Woo00D007ooOomo
o`0000Moo`05001oogooOol00004Ool01@00Oomoogoo00001Goo0@0000001000Ool000000goo00<0
07ooOol00Woo00<007ooOol00P000Woo0P001Goo0`000Woo00@007oo001oo`8000Aoo`80009oo`03
001oogoo00=oo`04001oo`000002Ool00`00Oomoo`03Ool200000goo000000020005Ool01@00Oomo
ogoo00002Woo00<007oo00001Woo00<007ooOol01Goo00<007ooOol00P0017oo00D007ooOomoo`00
009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007oo0000009oo`800003
Ool00000009oo`03001oogoo0080009oo`03001oo`0000Ioo`800003Ool007oo00800003Ool00000
00<000Uoo`03001oogoo00=oo`800005Ool007ooOol00004Ool200000goo001oo`02Ool20006Ool0
1@00Oomoogoo000017oo0`0000=oo`00Ool00P0000=oo`00Ool00Woo00D007oo001oo`0000=oo`80
00Ioo`03001oo`00009oo`05001oogoo001oo`020002Ool01@00Oomoogoo00000Woo0P000Woo0@00
00000`00Oomoo`04Ool2000:Ool01@00Oomoogoo000017oo00<007ooOol00goo00@007oo000001Ao
o`07001oogooOol007oo00001Woo00<007oo00000Woo00<007oo00000goo00<007ooOol01Goo0P00
1goo00<007ooOol01Goo0P001Goo00@007ooOomoo`8000Eoo`04001oogoo0005Ool00`00Oomoo`04
Ool00`00Ool0000:Ool01000Oomoo`002Goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol0
2Woo0P000Woo00<007ooOol02Goo00<007ooOol00goo00@007ooOol000Aoo`03001oogoo00=oo`80
009oo`03001oo`0000Aoo`03001oogoo00moo`80009oo`04001oo`00000@Ool10001Ool100000003
001oo`0000Eoo`03001oogoo0080009oo`03001oo`000080009oo`03001oogoo009oo`04001oogoo
0003Ool01P00Oomoo`00Ool000=oo`04001oogoo0002Ool00`00Ool000020006Ool00`00Oomoo`02
Ool02000Ool00000Ool007oo0005Ool01P00Oomoogoo001oo`D000Aoo`8000Moo`06001oogoo001o
o`000Woo00D007oo001oo`0000=oo`<00005Ool007ooOol00002Ool00`00Ool000030006Ool00`00
Oomoo`02Ool01@00Oomoogoo00002goo00<007ooOol01goo0P0000Aoo`00Ool0009oo`03001oogoo
00=oo`03001oo`00008000Ioo`8000Aoo`80009oo`03001oogoo00=oo`03001oogoo009oo`04001o
ogooOol20003Ool200001goo000007oo001oo`0000Aoo`03001oo`0000Aoo`800007Ool007ooOol0
07oo00000goo0P002Goo0P0000=oo`00Ool00P0000Aoo`00Ool0009oo`03001oogoo009oo`400000
00<007ooOol00Woo00<007oo00000Woo00H007ooOol007oo0004Ool00`00Oomoo`03Ool01P00Oomo
o`00Ool000Ioo`03001oogoo00Aoo`03001oo`0000=oo`04001oogoo0003Ool30002Ool00`00Oomo
o`05Ool01000Oomoo`001Woo00@007ooOol000=oo`@00004Ool007oo0004Ool00`00Oomoo`06Ool0
0`00Ool00002Ool01000Oomoo`002Goo00<007oo00000P000goo00<007ooOol00Woo00<007oo0000
1Woo0`000goo0P0000Eoo`00001oo`0000Eoo`8000=oo`04001oogooOol20003Ool00`00Oomoo`04
Ool00`00Ool000050002Ool01000Ool007oo0P0000=oo`0000000P0017oo0`0017oo00@007oo0000
00=oo`03001oogoo008000Eoo`03001oo`00009oo`8000Uoo`03001oogoo00<000Eoo`03001oo`00
00=oo`80009oo`04001oo`00Ool40002Ool00`00Oomoo`0100000004001oogoo0002Ool00`00Oomo
o`02Ool00`00Ool00002Ool00`00Oomoo`08Ool00`00Oomoo`09Ool20003Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`020003Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0C
Ool00`00Oomoo`02Ool2000017oo001oo`0027oo0P000goo00D007ooOomoo`0000=oo`03001oogoo
00Ioo`03001oogoo00=oo`03001oogoo00Qoo`05001oogooOol00009Ool00`00Oomoo`08Ool00`00
Ool00004Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool20005
Ool00`00Ool00009Ool01`00Oomoogoo001oo`0000Ioo`8000Aoo`03001oogoo00Yoo`03001oogoo
009oo`40000000<007oo00000Woo0P0017oo00H007ooOol007oo0007Ool40003Ool00`00Ool00002
Ool00`00Oomoo`02Ool3000<Ool00`00Ool00005Ool01000Ool000000goo00D007ooOomoo`00009o
o`03001oogoo00Eoo`03001oo`0000Aoo`06001oogoo001oo`000Woo00<007oo00000Woo00<007oo
Ool017oo00<007ooOol00P000goo00<007ooOol00Woo0`0017oo00<007oo00000goo00@007ooOol0
00Eoo`03001oogoo00<0009oo`03001oo`0000=oo`03001oogoo00=oo`8000=oo`03001oo`0000Yo
o`04001oogooOol20003Ool00`00Oomoo`02Ool200000goo001oo`03Ool00`00Oomoo`04Ool20003
Ool2000=Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Ool00003Ool01@00Oomoogoo00001Goo
0P002Woo00L007ooOomoo`00Ool00003Ool100000003001oogoo00Eoo`03001oo`0000Aoo`04001o
ogoo0003Ool00`00Oomoo`09Ool00`00Ool000020005Ool01000Oomoo`001Goo00@007ooOomoo`80
009oo`05001oogooOol00003Ool00`00Oomoo`0:Ool30003Ool01000Ool0000017oo00<007oo0000
1Goo00<007oo00000goo0P000goo00@007ooOol000=oo`04001oogoo0003Ool20008Ool00`00Oomo
o`05Ool01P00Ool00000Ool000Eoo`03001oogoo00=oo`03001oo`0000Qoo`03001oo`00009oo`05
001oogooOol00004Ool20003Ool01P00Oomoo`00Ool000Ioo`<00004Ool007ooOol200000goo0000
00030009Ool00`00Oomoo`0:Ool30004Ool01000Oomoo`0017oo00@007oo000000Aoo`03001oogoo
00=oo`03001oogoo00Uoo`03001oogoo0040000000<007ooOol01Woo00<007ooOol017oo00D007oo
001oo`0000Aoo`03001oogoo00aoo`8000Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00]oo`03001oogoo00Uoo`03001oo`0000Moo`04001oo`00000;Ool00`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool01000Ool0000027oo00<007oo00002Goo00@007oo
Ool000Yoo`04001oo`000003Ool00`00Oomoo`04Ool00`00Oomoo`0KOol200001Goo001oogoo0000
0Woo00D007oo001oo`0000Moo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol00006Ool0
1000Oomoogoo0P000Woo00D007ooOomoo`00009oo`04001oogooOol100000003001oogoo008000Ao
o`03001oogoo00aoo`04001oogooOol20002Ool01000Oomoo`004Goo00H007ooOol007oo0008Ool0
0`00Oomoo`02Ool00`00Ool00005Ool01000Oomoo`001Goo00<007ooOol01Goo100000Eoo`00Oomo
o`0000=oo`03001oo`0000=oo`800003Ool007oo008000Eoo`03001oo`00009oo`<000Aoo`03001o
ogoo00Eoo`03001oogoo008000=oo`07001oogooOol007oo00000Woo00<007oo000027oo0P0017oo
100000=oo`00Ool00Woo00<007ooOol01Goo0P0000Aoo`00Oomoo`800003Ool007oo009oo`06001o
ogooOol007oo0`000goo0`002Woo00<007oo00000Woo00@007ooOol0009oo`04001oogooOol30006
Ool00`00Oomoo`04Ool01000Oomoo`003Woo0@000Goo0@0000000`00Ool00002Ool01@00Ool007oo
00001goo00D007ooOomoo`00009oo`8000Ioo`03001oogoo009oo`03001oogoo009oo`8000=oo`80
00ioo`03001oogoo008000=oo`03001oo`00015oo`03001oogoo00Moo`D000]oo`<000Eoo`03001o
ogoo00Moo`06001oogoo001oo`000Woo00@007oo000000Ioo`<000Ioo`03001oogoo01=oo`03001o
ogoo00Yoo`8000Eoo`04001oogooOol20005Ool00`00Oomoo`06Ool02000Oomoo`00Ool007oo0006
Ool00`00Ool00003Ool00`00Oomoo`030005Ool20005Ool01@00Ool00000Ool00P001Goo0P0000Ao
o`00Ool0009oo`03001oogoo009oo`40000000<007ooOol017oo00<007ooOol01goo00D007ooOomo
o`0000=oo`03001oogoo00Aoo`<000Aoo`05001oogooOol00008Ool00`00Ool00003Ool00`00Oomo
o`06Ool20007Ool02000Oomoo`00Ool007oo0009Ool00`00Oomoo`09Ool20007Ool00`00Oomoo`03
Ool200000goo001oo`0:Ool01000Oomoo`0017oo00<007ooOol01goo0P002goo00D007ooOomoo`00
00=oo`03001oogoo011oo`03001oo`0000Aoo`03001oogoo00]oo`03001oo`00011oo`03001oogoo
00Ioo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool20007Ool00`00Ool00003Ool0
1000Ool007oo0P000Woo00<007ooOol00@0000001000Oomoo`000goo00<007ooOol00Woo0`001Goo
10000goo00<007ooOol00goo00T007ooOol007oo001oo`00Ool00`001Woo00@007ooOomoo`80009o
o`04001oogooOol200000goo001oo`0200001Goo001oogoo00000Woo00<007ooOol00goo00<007oo
Ool00goo00<007oo00001Goo00<007ooOol00Woo00<007ooOol00goo00<007oo000017oo0P0000=o
o`00Ool00Woo00D007ooOomoo`00009oo`03001oogoo00=oo`03001oo`0000=oo`800003Ool007oo
00eoo`05001oo`00Ool00003Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool40003Ool00`00Ool00006
Ool200000goo001oo`02Ool30009Ool00`00Oomoo`04Ool00`00Oomoo`03Ool20003Ool00`00Oomo
o`03Ool01@00Ool007oo000017oo00D007ooOomoo`0000Uoo`03001oo`00009oo`05001oogooOol0
0003Ool20003Ool100000003001oo`0000Eoo`03001oogoo00Aoo`03001oogoo00Aoo`8000Aoo`80
0003Ool0000000Ioo`03001oo`0000Eoo`<000Moo`03001oogoo00]oo`03001oogoo009oo`04001o
ogoo0002Ool01000Ool007oo0P000goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01goo
0`0000=oo`00000017oo0P0000=oo`00Ool00Woo0P000Woo1@0017oo00<007oo00000Woo00<007oo
Ool01goo00D007ooOol007oo00800003Ool007oo00Ioo`8000=oo`04001oo`00Ool20003Ool00`00
Oomoo`020005Ool00`00Oomoo`05Ool00`00Ool00003Ool01000Oomoogoo0P0057oo00D007ooOomo
o`00009oo`06001oogoo001oo`000goo00<007ooOol00goo00<007oo00000Woo00<007ooOol01Goo
00D007ooOomoo`0000Eoo`40000000<007ooOol01Goo00<007ooOol00P000goo00<007ooOol00P00
0Woo00<007ooOol017oo00D007oo001oo`0000Eoo`03001oogoo00Qoo`05001oogooOol00004Ool2
000AOol00`00Ool00005Ool01000Ool000000goo00D007oo001oo`00009oo`07001oogooOol007oo
000017oo00@007ooOol0009oo`04001oogooOol2000?Ool00`00Oomoo`04Ool01`00Ool007oo001o
o`0000Yoo`03001oo`0001Uoo`03001oogoo00=oo`03001oogoo00Yoo`800003Ool007oo00Aoo`05
001oogooOol00007Ool01P00Oomoo`00Ool0009oo`8000Eoo`03001oogoo00Moo`03001oogoo00Ao
o`800003Ool007oo01=oo`40000000P007ooOol007oo001oo`001goo00<007oo00000P002Woo00<0
07ooOol00Woo10001Woo00D007oo001oo`0000=oo`03001oo`00008000=oo`03001oogoo00Qoo`80
00Ioo`04001oogoo000<Ool00`00Oomoo`04Ool30003Ool00`00Oomoo`07Ool3000017oo001oo`00
0goo00<007ooOol00goo00<007oo00001Woo00D007ooOomoo`0000=oo`03001oo`0000<000Qoo`04
001oogoo0003Ool40004Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000=o
o`03001oo`0000Moo`06001oo`00Ool007oo0P001Goo0P0000=oo`00Ool00Woo00<007oo00000goo
00<007ooOol00goo0P0000Eoo`00001oo`0000Eoo`03001oogoo00Aoo`05001oogooOol00003Ool0
0`00Oomoo`030001Ool100000003001oo`0000=oo`05001oogooOol00002Ool00`00Oomoo`03Ool0
1@00Oomoogoo00000Woo1P000goo00<007ooOol027oo00<007ooOol00goo00@007oo000000Aoo`03
001oogoo00Eoo`8000=oo`03001oogoo009oo`8000Qoo`03001oogoo00Ioo`8000=oo`03001oogoo
008000Aoo`03001oogoo00Ioo`80009oo`<000Qoo`8000=oo`07001oo`00Ool007oo00000Woo00D0
07ooOomoo`0000Aoo`03001oo`0000=oo`80009oo`04001oogooOol200000goo001oo`02Ool01000
Ool000001Woo00<007ooOol017oo0`000Woo00D007ooOomoo`00009oo`8000=oo`03001oogoo00Ao
o`06001oogoo001oo`000Woo00<007ooOol00Woo0P0000=oo`00Ool00P0000Aoo`00Ool000Ioo`80
00=oo`03001oogoo009oo`8000Aoo`03001oo`0000=oo`8000eoo`40000000<007ooOol00Woo0P00
17oo00D007oo001oo`0001Ioo`04001oogoo000AOol00`00Oomoo`02Ool20003Ool01@00Oomoogoo
00002Woo00<007oo00001goo00<007ooOol01goo00<007ooOol00P000Woo00<007ooOol00Woo0P00
2Goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0
0goo00<007ooOol00Woo0P001goo00<007ooOol017oo0P0000=oo`0000001Goo0P001goo00D007oo
001oo`0000Aoo`03001oogoo00Eoo`80009oo`03001oogoo00Ioo`8000Uoo`03001oogoo00=oo`03
001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo009oo`40000000<007ooOol0
27oo00H007ooOol007oo0003Ool00`00Ool00005Ool01000Oomoo`001goo00<007ooOol01Woo00<0
07oo00000P0000=oo`0000001Goo0P0017oo00<007oo000017oo00<007ooOol01Goo00<007ooOol0
0goo00D007oo001oo`0000Aoo`05001oo`00Ool00002Ool00`00Oomoo`06Ool00`00Oomoo`04Ool3
000017oo001oo`000goo0P000Woo0P0000=oo`00Ool00goo00@007ooOol000Qoo`04001oogooOol3
0006Ool01@00Ool007oo00001Woo00<007oo00001Goo00<007ooOol01Woo00H007ooOol007oo0006
Ool00`00Oomoo`09Ool00`00Oomoo`06Ool01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03
001oogoo00Ioo`03001oo`0000=oo`80009oo`03001oogoo00=oo`03001oogoo00Aoo`800003Ool0
000000<0009oo`03001oogoo0040000000<007ooOol00P000goo00<007oo00001Woo00<007ooOol0
1Woo0P000Woo00<007ooOol00P0000Eoo`00Oomoo`0000Aoo`03001oogoo00@000aoo`03001oo`00
00Eoo`<00004Ool000000002Ool00`00Oomoo`020004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool2
0002Ool00`00Ool00002Ool00`00Oomoo`02Ool00`00Oomoo`08Ool20002Ool00`00Ool00002Ool0
1@00Oomoogoo00001Goo0P0000=oo`0000000P0000=oo`00Ool017oo0P001Goo00D007ooOol007oo
008000Eoo`04001oo`00000:Ool01000Oomoo`001Goo00<007ooOol00goo00@007ooOomoo`800007
Ool00000Ool007oo00001Goo00<007oo00000Woo0P0000=oo`00Ool00goo0P0000Ioo`00Ool007oo
0005Ool01000Ool000001Woo00@007ooOomoo`800003Ool0000000=oo`07001oogooOol007oo0000
0goo0P000goo0@0000000`00Oomoo`06Ool00`00Oomoo`03Ool01000Oomoo`0047oo00<007ooOol0
0Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo
00ioo`04001oogooOol20006Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`03Ool01000
Oomoo`0017oo00@007ooOol0015oo`03001oogoo00Aoo`<001Aoo`03001oo`0000=oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Moo`05001oogoo
Ool0000;Ool00`00Ool00005Ool00`00Oomoo`08Ool00`00Oomoo`04Ool30002Ool00`00Oomoo`0:
Ool100000003001oo`00009oo`05001oo`00Ool00006Ool00`00Oomoo`03Ool00`00Ool000030000
0goo001oo`05Ool20002Ool00`00Ool00003Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00D0
07oo001oo`0000Aoo`04001oogooOol200000goo001oo`02Ool200000goo001oo`03Ool00`00Oomo
o`02Ool20007Ool20006Ool200001Goo001oo`00Ool00P0000=oo`00Ool00goo00<007oo00000P00
0Woo00D007ooOomoo`0000Yoo`03001oo`0000Qoo`04001oogoo0002Ool01`00Ool00000Ool007oo
00800003Ool00000009oo`03001oo`0000800003Ool007oo009oo`03001oo`0000800005Ool00000
Ool00004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool20005Ool00`00Oomoo`02Ool01000Oomoogoo
0`000Woo00<007ooOol01goo00<007oo000017oo00<007ooOol00P0017oo0P0027oo00<007ooOol0
0goo00D007ooOomoo`00009oo`03001oogoo0040000000@007ooOol000=oo`03001oo`0000Qoo`03
001oo`0000Ioo`05001oogooOol00002Ool00`00Oomoo`04Ool2000017oo000000000goo00@007oo
Ool0009oo`04001oogoo0002Ool20002Ool01000Oomoogoo0P0000Aoo`00Ool000Ioo`03001oogoo
00Aoo`800005Ool007ooOol00002Ool00`00Oomoo`02Ool30003Ool2000017oo000007oo10003Goo
00<007oo00000P000Woo00D007ooOomoo`0000Qoo`03001oogoo00Aoo`8000Aoo`03001oo`00009o
o`03001oogoo00Aoo`8000=oo`03001oogoo00Ioo`8000Eoo`04001oogooOol20008Ool00`00Ool0
0003Ool00`00Oomoo`020004Ool00`00Oomoo`0>Ool00`00Oomoo`030004Ool20003Ool00`00Oomo
o`02Ool00`00Ool00002Ool00`00Oomoo`0;Ool01000Ool007oo0@0000000`00Ool0000LOol00`00
Oomoo`03Ool00`00Ool0000LOol01@00Oomoogoo00001Goo00<007ooOol01Goo00<007ooOol02Goo
00L007ooOomoo`00Ool0000=Ool01`00Oomoogoo001oo`0000=oo`03001oo`0000Yoo`8000Eoo`80
00=oo`03001oogoo01Ioo`03001oogoo00=oo`05001oogooOol00003Ool00`00Oomoo`0?Ool00`00
Oomoo`03Ool20004Ool2000;Ool40002Ool00`00Oomoo`04Ool00`00Oomoo`0EOol00`00Oomoo`05
Ool00`00Oomoo`04Ool100000003001oogoo00=oo`03001oogoo00=oo`8000=oo`05001oogooOol0
0002Ool20007Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool20002Ool00`00Oomo
o`08Ool20004Ool00`00Ool000020003Ool00`00Oomoo`0:Ool20004Ool00`00Oomoo`05Ool01@00
Oomoogoo00000goo0P001Goo0P001goo0`001Goo00<007ooOol00goo00@007oo001oo`80009oo`03
001oogoo00Aoo`800004Ool007oo0002Ool00`00Oomoo`02Ool00`00Ool00004Ool00`00Oomoo`02
0002Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Ool007oo00003goo00<007ooOol02Woo00@0
07ooOol000Aoo`03001oo`0000Aoo`06001oogoo001oo`001goo00<007ooOol00Woo0P0000=oo`00
Ool01Goo00@007ooOol000Yoo`40000000<007ooOol01Goo00L007ooOomoo`00Ool00002Ool00`00
Oomoo`0>Ool20007Ool00`00Oomoo`08Ool200000goo001oo`02Ool2000017oo001oogoo0P000Woo
00@007ooOol0009oo`03001oogoo00=oo`800003Ool007oo00Aoo`03001oogoo009oo`05001oogoo
Ool00002Ool01@00Oomoogoo00000goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol00Woo
00<007oo000017oo0`0017oo00<007ooOol01Woo00<007oo00001goo00<007oo00000goo0`000goo
00<007ooOol00goo00<007ooOol00goo0P0037oo00<007ooOol00Woo00<007ooOol01Goo00<007oo
Ool01goo00<007ooOol02Goo00D007ooOomoo`00009oo`07001oogoo001oo`00Ool00P001goo0P00
00=oo`00Ool00Woo00<007ooOol017oo00H007ooOol007oo0002Ool100000006001oogoo001oo`00
3goo00<007ooOol00P000Woo00<007ooOol00goo00<007ooOol00Woo0P0047oo00<007ooOol09Woo
00<007ooOol00goo00<007ooOol02goo00<007oo000017oo00@007oo000000Aoo`80009oo`03001o
o`0002Ioo`03001oo`0000Qoo`03001oo`00008000Moo`03001oogoo00Eoo`03001oogoo00Ioo`04
001oo`000005Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool01000Oomoo`000Woo00<007ooOol027oo
00<007ooOol01Woo0`001Goo0@0000000`00Ool00003Ool20003Ool20002Ool00`00Oomoo`02Ool4
00000goo001oo`02Ool01000Oomoo`000goo0P0027oo00<007ooOol02goo00<007oo00002Woo00<0
07ooOol00Woo00<007ooOol00P0000=oo`00Ool01Goo00<007ooOol00Woo0P001Woo00P007ooOol0
07oo001oo`000Woo00<007ooOol017oo00<007ooOol00goo0P000goo00@007oo0000009oo`<000Ao
o`8000Moo`03001oogoo00Ioo`04001oogoo0007Ool30002Ool00`00Oomoo`04Ool00`00Ool00002
Ool02@00Oomoogoo001oo`00Ool00004Ool20002Ool01@00Ool007oo00000Woo00<007ooOol01Woo
0P000goo00H007oo001oo`00Ool20005Ool01@00Oomoogoo00001goo0P0017oo0P001Goo00<007oo
Ool017oo1@000goo0P000goo0@0000000`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool2
0002Ool00`00Oomoo`020003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01000Oomoo`000Woo0P00
1Goo0P000goo00<007ooOol00`001goo00<007ooOol00goo00@007ooOomoo`8000Ioo`03001oogoo
009oo`05001oo`00Ool00005Ool200000goo001oo`02Ool01P00Ool00000Ool0009oo`03001oogoo
009oo`03001oogoo009oo`8000=oo`800004Ool007oo000:Ool200000goo001oo`09Ool01000Oomo
o`000goo1@003goo0P0000=oo`00Ool00Woo00<007ooOol017oo0`000goo00<007ooOol00Woo00<0
07ooOol00Woo0P000Woo0P000Woo00<007ooOol02Woo00@007ooOol000=oo`03001oogoo008000Io
o`03001oo`0000=oo`03001oogoo0080009oo`800003Ool007oo00Eoo`03001oogoo00=oo`400000
00<007ooOol00goo00<007ooOol017oo00H007ooOomoo`00Ool2000;Ool01000Oomoo`001Woo0P00
2Goo00<007ooOol01goo00<007ooOol017oo00<007ooOol03Goo0P002Goo00@007oo000000Eoo`03
001oogoo00Ioo`04001oo`000005Ool00`00Oomoo`02Ool00`00Ool0000?Ool01@00Oomoogoo0000
0Woo00<007ooOol037oo00<007ooOol01Goo00<007ooOol03goo00@007ooOomoo`8000aoo`03001o
o`0000<000Yoo`03001oogoo00Aoo`04001oogoo000=Ool01@00Oomoogoo00001goo00@007ooOomo
o`8000eoo`03001oogoo0040000000@007ooOol000Moo`03001oo`0000Aoo`8000=oo`03001oogoo
009oo`03001oogoo009oo`8000Eoo`03001oogoo00Aoo`04001oo`00Ool20003Ool01000Oomoo`00
0goo00<007ooOol00goo00@007ooOol000Aoo`04001oogooOol20004Ool01@00Oomoogoo00001Goo
0P000Woo00<007ooOol017oo00<007ooOol01goo0P0000Moo`00Oomoo`00Ool00002Ool20002Ool0
2`00Ool007oo001oo`00Ool007oo00001Goo0P000Woo00@007ooOol000aoo`03001oogoo00Aoo`07
001oogoo001oo`00Ool00P0000=oo`00Ool00`0037oo00<007ooOol02Woo00<007ooOol01Goo00<0
07ooOol01goo00X007ooOol007oo001oo`00Ool000Eoo`03001oo`0000Qoo`03001oo`0000Ioo`03
001oo`0000Eoo`03001oogoo00=oo`04001oo`00Ool100000005001oogooOol00003Ool01000Oomo
o`000goo0P000Woo00<007ooOol01goo00<007ooOol00P000goo00D007ooOomoo`00009oo`03001o
ogoo009oo`06001oo`00001oo`002Goo00D007ooOomoo`0000Eoo`04001oogooOol20004Ool00`00
Ool00002Ool200000goo001oo`05Ool20008Ool200001Goo001oogoo000017oo00<007ooOol00goo
00<007ooOol017oo00<007oo00000P0027oo00<007ooOol00goo0P000Woo0P000goo0P000Woo00H0
07ooOol007oo0004Ool200000goo001oo`05Ool01000Oomoogoo0P000goo0P0027oo00<007oo0000
1goo00<007ooOol00`002goo00<007ooOol00`0000=oo`00Ool00Woo00<007ooOol01Goo00@007oo
000000Moo`8000Ioo`03001oogoo00Qoo`03001oogoo00Aoo`40000000<007oo00001goo00D007oo
Oomoo`0000Qoo`03001oogoo00Aoo`8000Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oo`00
015oo`03001oogoo00=oo`03001oogoo009oo`80021oo`03001oogoo00Ioo`03001oogoo009oo`80
00=oo`8000Moo`8001aoo`05001oogooOol00005Ool00`00Oomoo`0?Ool20003Ool00`00Oomoo`02
Ool01@00Oomoogoo000047oo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol01Goo00<007oo
00001Woo00@007ooOol000Eoo`03001oogoo009oo`40000000<007ooOol00Woo00D007oo001oo`00
00Moo`06001oogoo001oo`000goo0P0000Moo`00001oo`00Ool00003Ool20002Ool01000Oomoogoo
0P001Goo00<007ooOol03Woo00<007ooOol017oo00<007ooOol017oo00<007ooOol00goo00<007oo
Ool027oo00H007ooOomoo`00Ool2000>Ool01P00Ool00000Ool000Aoo`04001oogooOol200000goo
001oo`020009Ool2000017oo001oo`002Woo00<007ooOol04goo00<007ooOol00Woo00<007ooOol0
1goo0P000Woo00<007ooOol00Woo0P001Goo00<007ooOol00goo00<007ooOol00Woo00D007ooOomo
o`00009oo`04001oo`00Ool20006Ool01000Oomoo`000goo00<007ooOol017oo00<007ooOol017oo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol00@0000001000Ool000001Goo00<007ooOol0
0goo00<007ooOol02Woo00@007oo000000=oo`03001oogoo009oo`04001oogoo0002Ool00`00Oomo
o`05Ool01000Oomoo`000goo00D007oo001oo`0000=oo`<000Ioo`05001oogooOol00003Ool01@00
Oomoo`00Ool00P0000=oo`00Ool00Woo00<007ooOol00goo00D007ooOomoo`0000Moo`07001oo`00
Ool007oo000027oo0`002goo00D007ooOomoo`0000Qoo`03001oogoo00=oo`04001oogoo0004Ool0
0`00Ool0000AOol01@00Oomoogoo000017oo00D007oo001oo`00009oo`03001oogoo00Aoo`8000=o
o`800003Ool007oo009oo`8000=oo`03001oo`00009oo`8000Aoo`04001oo`00Ool30004Ool20007
Ool30006Ool00`00Oomoo`03Ool400000goo001oo`02Ool100000003001oogoo00Aoo`03001oogoo
00Qoo`03001oogoo011oo`03001oo`00019oo`03001oogoo00=oo`03001oo`0000=oo`03001oogoo
00Moo`03001oogoo00Aoo`07001oogooOol007oo000017oo00<007oo000017oo00<007ooOol00Woo
00<007ooOol02Goo00<007ooOol02Goo00D007ooOomoo`0003Ioo`03001oogoo00Ioo`03001oogoo
00=oo`04001oogoo000=Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool01@00Ool007oo000017oo0`0017oo00<007ooOol00Woo0@0000000`00Oomoo`03Ool00`00
Oomoo`07Ool00`00Ool00007Ool30006Ool20003Ool00`00Ool000020009Ool01`00Oomoogoo001o
o`0000=oo`08001oo`00Ool007oo001oo`800004Ool000000009Ool01@00Oomoogoo00005goo00<0
07ooOol00goo00<007ooOol00Woo00D007ooOol007oo008000Aoo`05001oogooOol0000COol01@00
Oomoogoo000027oo00@007ooOol000Aoo`<00003Ool007oo00=oo`03001oogoo00Ioo`04001oo`00
0003Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Ool0000200001Goo001oogoo00000goo00<0
07ooOol02Goo00L007ooOomoo`00Ool00003Ool01000Ool0000047oo00D007ooOomoo`00009oo`03
001oogoo00=oo`40000000@007ooOol000Aoo`05001oogooOol00007Ool01@00Ool007oo00001Goo
0P001Woo00@007ooOol000Eoo`8000=oo`8000Aoo`04001oogoo0005Ool02@00Oomoo`00Ool007oo
001oo`02000017oo000000000Woo00D007oo001oo`0000=oo`04001oogoo0002Ool30002Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool01000Oomoogoo0`0000=oo`0000000Woo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol00goo0P0000=oo`0000001Woo00@007ooOol000Io
o`<0009oo`03001oogoo00Aoo`03001oo`0000=oo`8000Aoo`04001oogooOol20002Ool01@00Oomo
ogoo00000Woo00<007ooOol01Goo00<007ooOol00goo00<007ooOol017oo0`000Woo00<007ooOol0
1goo00@007ooOol000=oo`05001oogooOol00002Ool30005Ool00`00Oomoo`02Ool00`00Ool00009
Ool20001Ool100000003001oogoo009oo`04001oogoo0003Ool20003Ool00`00Oomoo`05Ool2000Q
Ool00`00Oomoo`02Ool00`00Oomoo`0HOol01@00Oomoogoo00001Goo00<007ooOol00goo00<007oo
Ool03goo00<007oo00003Woo00<007ooOol02Woo00L007oo001oo`00Ool00008Ool00`00Oomoo`03
Ool00`00Ool0000;Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`0AOol00`00Oomoo`09
Ool00`00Oomoo`09Ool2000=Ool01000Ool000001Goo00<007ooOol00goo00@007ooOomoo`400000
00<007oo000027oo00@007ooOol0009oo`03001oogoo00Moo`03001oo`0000=oo`03001oogoo009o
o`03001oogoo00moo`04001oogoo000:Ool2000:Ool20008Ool01000Oomoogoo0P000Woo00D007oo
001oo`0000Qoo`03001oogoo00Yoo`06001oogoo001oo`001Woo00@007ooOol000Ioo`800003Ool0
07oo00=oo`8000Qoo`07001oo`00Ool007oo00001Goo00<007ooOol00`0000Aoo`00Ool000Eoo`05
001oogooOol00002Ool200001Goo001oo`00Ool00P0000=oo`0000000P001Woo00H007ooOomoo`00
Ool20002Ool20003Ool4000017oo001oo`000goo00@007ooOol000Eoo`06001oogoo001oo`000goo
0P0000Ioo`00Ool007oo0008Ool00`00Oomoo`04Ool100000003001oogoo009oo`<000Aoo`03001o
ogoo00Ioo`03001oogoo00Yoo`<0009oo`03001oogoo00=oo`04001oo`000004Ool01000Oomoogoo
0P000goo0`001Woo00<007ooOol017oo00@007ooOol0009oo`05001oo`00Ool0000;Ool00`00Ool0
0004Ool20009Ool00`00Oomoo`04Ool00`00Ool00005Ool20004Ool200001Goo001oo`00Ool00P00
00=oo`00Ool00goo00<007ooOol00goo00<007ooOol00`001Goo00D007oo001oo`0000=oo`03001o
ogoo00Eoo`8000Qoo`03001oogoo008000Qoo`04001oogoo0005Ool00`00Oomoo`02Ool00`00Ool0
000<Ool20009Ool00`00Oomoo`04Ool2000017oo001oo`003Goo00<007ooOol00goo00<007oo0000
0Woo0@0000000`00Oomoo`03Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P001Goo00<007oo
Ool01goo00<007ooOol00goo00@007ooOomoo`8000ioo`04001oogoo0003Ool01000Oomoo`005Woo
0P002Woo00<007oo00001Goo00<007ooOol04goo00<007ooOol03Woo00@007ooOol0019oo`03001o
ogoo00Aoo`8000Ioo`03001oo`00009oo`04001oogoo0005Ool20007Ool00`00Oomoo`0;Ool00`00
Oomoo`06Ool01000Oomoogoo0P000goo00<007ooOol03goo00D007ooOomoo`0000eoo`40000000@0
07ooOol000aoo`04001oogooOol20009Ool02000Oomoo`00Ool007oo0007Ool01000Oomoo`001Woo
00@007oo001oo`800004Ool007oo000:Ool01P00Oomoo`00Ool000Eoo`07001oogooOol007oo0000
0Woo00@007ooOomoo`<000Moo`800003Ool007oo0080009oo`03001oogoo009oo`03001oo`0000=o
o`800007Ool007ooOol007oo00002Woo00<007ooOol01Woo00@007ooOol000Aoo`03001oogoo00Ao
o`03001oo`0000Ioo`06001oogoo001oo`000goo00<007oo00001Woo00L007ooOomoo`00Ool00004
Ool00`00Ool00008Ool00`00Oomoo`02Ool01000Oomoo`0037oo00<007ooOol01Goo00<007oo0000
1goo0P0000Aoo`00Ool000Ioo`03001oogoo00=oo`<00003Ool007oo009oo`40000000D007ooOomo
o`0000Ioo`05001oo`00Ool00002Ool01P00Oomoogoo001oo`8000Moo`05001oogooOol00002Ool0
0`00Oomoo`03Ool01P00Oomoo`00Ool0009oo`800003Ool007oo00=oo`03001oo`00009oo`8000Eo
o`05001oogooOol00003Ool00`00Oomoo`03Ool30003Ool01@00Oomoogoo00002goo0`0017oo00<0
07ooOol01goo00<007ooOol00P000Woo00<007ooOol037oo00<007ooOol00goo0P000Woo00<007oo
Ool04Woo00<007ooOol01Goo00<007oo00001Goo00H007ooOol007oo0002Ool00`00Oomoo`07Ool0
0`00Ool000020003Ool20006Ool00`00Oomoo`0@Ool00`00Oomoo`020002Ool00`00Oomoo`07Ool0
0`00Oomoo`03Ool01@00Oomoo`00Ool00`000Woo00<007ooOol00Woo0@0000000`00Ool00005Ool0
1000Oomoo`001Goo00@007ooOol0009oo`03001oo`00019oo`03001oogoo00]oo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Aoo`07001oogooOol007oo00001Goo00<007ooOol00Woo00<0
07ooOol00Woo00@007ooOol000Qoo`04001oogoo000<Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool0
0`00Oomoo`0COol00`00Oomoo`03Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo00<007ooOol0
17oo00<007ooOol08Goo0P000Woo0P000Woo00<007ooOol017oo00<007ooOol00Woo00D007ooOomo
o`0000=oo`8000Yoo`800003Ool007oo00Moo`40000000H007ooOol007oo0003Ool20002Ool00`00
Ool00002Ool20002Ool20004Ool20007Ool01000Ool007oo0P003goo00<007ooOol00`0000=oo`00
00000goo00<007oo000027oo00<007ooOol02Woo00<007oo000067oo0P000Woo00@007ooOol000Ao
o`<000]oo`04001oogoo0005Ool00`00Oomoo`02Ool40003Ool01@00Oomoogoo000017oo00L007oo
001oo`00Ool00002Ool00`00Oomoo`06Ool00`00Ool00009Ool300000goo00000008Ool20004Ool0
1`00Oomoogoo001oo`0000Moo`03001oo`0000Moo`8000Ioo`06001oogooOol007oo0P0000Aoo`00
Ool000=oo`03001oogoo00Aoo`03001oogoo0080005oo`40000000<007oo000017oo00<007oo0000
17oo00<007oo00000Woo00D007ooOomoo`0000=oo`03001oogoo00Aoo`80009oo`04001oogoo0003
Ool01`00Ool00000Ool007oo0080009oo`03001oogoo00Qoo`8000eoo`03001oogoo00Ioo`03001o
ogoo00Aoo`05001oogooOol00005Ool01000Ool0000027oo00@007ooOol0009oo`03001oogoo00Yo
o`03001oogoo00Ioo`@000Uoo`04001oogoo0002Ool00`00Oomoo`0<Ool01P00Oomoo`00Ool000Eo
o`<000=oo`04001oogoo0002Ool00`00Oomoo`02Ool20002Ool01@00Oomoogoo00001Woo00D007oo
Oomoo`0000Ioo`@0009oo`03001oo`0000Uoo`800003Ool007oo00eoo`03001oo`00009oo`03001o
ogoo00=oo`04001oogooOol100000003001oogoo00Aoo`03001oogoo021oo`04001oo`00Ool2000:
Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Yoo`03001oogoo00Uoo`03001oogoo00Aoo`03
001oo`0000Uoo`05001oogooOol00006Ool00`00Oomoo`0?Ool01000Oomoogoo0P000Woo00<007oo
Ool017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Woo00<007oo00002Goo00H007oo
Ool007oo000>Ool00`00Ool00007Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
0`00Oomoo`0AOol01@00Oomoogoo000027oo00<007ooOol017oo0@0000000`00Oomoo`03Ool01000
Oomoo`001goo00<007ooOol027oo00D007ooOomoo`0000=oo`03001oogoo00Ioo`03001oogoo00D0
0007Ool00000Ool007oo00000Woo00<007oo00000Woo0`000Woo00<007ooOol00goo00@007ooOomo
o`80009oo`04001oogooOol200000goo001oo`08Ool01@00Oomoo`00Ool00P001goo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Eoo`04001oogoo0007Ool4000:Ool0
1000Oomoogoo0P001Goo00@007ooOol000Aoo`04001oogoo0004Ool00`00Oomoo`06Ool00`00Oomo
o`030006Ool01000Ool000000Woo0P000Woo00H007ooOol007oo0004Ool30002Ool01`00Oomoogoo
001oo`00009oo`8000Aoo`08001oo`00001oo`00Ool000Eoo`D000Yoo`03001oo`00009oo`400000
00<007ooOol037oo00<007ooOol00Woo00@007ooOol000Qoo`03001oogoo009oo`03001oo`0000Io
o`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00=oo`03001oo`0000Ao
o`03001oogoo009oo`03001oogoo02Aoo`8002aoo`05001oogooOol0000:Ool00`00Oomoo`0AOol0
0`00Oomoo`07Ool00`00Oomoo`09Ool01000Oomoo`000Woo00@007ooOol000Ioo`04001oogoo0009
Ool01@00Oomoogoo00005Woo0@0000001P00Ool00000Ool0009oo`03001oogoo00Eoo`03001oo`00
00=oo`05001oogooOol00002Ool01`00Oomoogoo001oo`0000Aoo`06001oogoo001oo`0027oo0`00
27oo0P0000=oo`00000027oo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol00goo00<007oo
Ool00Woo00L007oo001oo`00Ool00002Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`04
Ool01@00Oomoogoo00001Woo0P000goo00L007ooOomoo`00Ool00002Ool00`00Oomoo`03Ool20000
0goo001oo`0200001Goo000007oo00003Woo00@007ooOol000=oo`06001oogoo001oo`001Goo00<0
07ooOol00goo00<007oo00000Woo0P0027oo00@007ooOomoo`8000Eoo`05001oogooOol00003Ool0
2@00Oomoogoo001oo`00Ool00004Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007oo00001Goo
0@0000000`00Oomoo`05Ool01@00Oomoogoo00001Goo00<007ooOol01Goo0P000Woo1@000goo00<0
07ooOol00Woo00<007oo000017oo00<007ooOol00Woo00<007oo00001Goo00<007oo000027oo00@0
07oo001oo`<000=oo`05001oogooOol00002Ool01@00Oomoogoo00001Goo00<007ooOol00goo00<0
07ooOol00Woo00D007oo001oo`0000Ioo`04001oo`000003Ool01`00Oomoogoo001oo`0000Eoo`08
001oogoo001oo`00Ool000Qoo`05001oogooOol00004Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool0
1`00Oomoogoo001oo`00009oo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol0000FOol2
0009Ool20002Ool00`00Oomoo`02Ool30002Ool01@00Ool007oo00001Woo00D007ooOomoo`0000Ao
o`<00003Ool0000000=oo`40000000<007ooOol00goo00<007ooOol00goo0P003goo00<007ooOol0
5Goo00<007oo000017oo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000moo`03001o
ogoo00Qoo`04001oo`00000?Ool00`00Oomoo`0BOol00`00Oomoo`0AOol01000Oomoo`002Goo00<0
07ooOol00Woo00<007ooOol037oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol02Goo00<0
07ooOol02Woo0P003goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol04Woo0@0000000`00
Oomoo`02Ool00`00Ool00003Ool01000Oomoo`000Woo00H007ooOol007oo0003Ool01`00Ool007oo
001oo`0000Aoo`05001oogooOol00004Ool01`00Oomoogoo001oo`0000Qoo`03001oogoo00=oo`03
001oogoo00]oo`03001oogoo00Qoo`<000Aoo`04001oo`000004Ool01000Ool007oo0`000goo1@00
00=oo`00Ool017oo0P000Woo00<007oo00001Goo00<007ooOol00Woo0P001Goo00<007ooOol00goo
00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00goo100017oo00<007oo
Ool00Woo0P003goo00D007ooOol007oo008000Uoo`05001oogooOol00008Ool00`00Oomoo`02Ool0
0`00Oomoo`0<Ool2000017oo001oo`001Goo00<007ooOol010000Woo00<007ooOol00P000Goo0@00
00001000Oomoo`000Woo00T007ooOomoo`00Ool007oo00002Goo00<007ooOol00P000Woo00<007oo
00000Woo00H007ooOomoo`00Ool30006Ool00`00Ool00005Ool300000goo001oo`05Ool20002Ool2
0005Ool00`00Oomoo`09Ool01P00Oomoogoo001oo`800004Ool007ooOol20008Ool3000?Ool00`00
Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`07Ool20003Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`030005Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Ool0000200000goo00000002Ool00`00Oomoo`02Ool20003Ool01000Oomoo`000Woo
00D007oo001oo`0000Moo`800003Ool007oo00Uoo`03001oogoo00=oo`05001oogooOol00008Ool0
1000Oomoogoo0@0000001@00Oomoogoo000037oo00<007ooOol05Goo00D007ooOomoo`0000ioo`03
001oogoo019oo`03001oogoo00=oo`03001oo`0000Uoo`8000=oo`03001oogoo00=oo`03001oogoo
00=oo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Eoo`04001oogoo0003Ool00`00Oomo
o`05Ool01@00Oomoogoo00002Goo00@007ooOol000Qoo`8000Ioo`04001oogoo000:Ool00`00Oomo
o`04Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`06Ool20003Ool00`00Oomoo`02Ool0
1000Oomoo`000goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol02Woo0@0000001@00Ool0
07oo00002Woo00<007ooOol00goo00@007ooOomoo`8000Aoo`05001oogooOol00002Ool2000@Ool0
0`00Oomoo`05Ool00`00Ool00008Ool01@00Oomoo`00Ool00P000goo00<007ooOol01Woo00<007oo
Ool00goo00<007ooOol01Goo00<007oo00000Woo1@0017oo00D007oo001oo`0000Yoo`05001oogoo
Ool00002Ool01000Oomoo`001Goo00H007ooOol007oo0005Ool00`00Oomoo`07Ool01@00Oomoo`00
Ool00`0027oo00<007ooOol00P0000Qoo`00000007oo001oo`0017oo00@007ooOol0009oo`04001o
ogooOol20004Ool00`00Ool00004Ool30002Ool20002Ool200000goo001oo`05Ool00`00Oomoo`02
00000goo001oo`02Ool01P00Oomoogoo001oo`8000Eoo`03001oogoo009oo`04001oogoo0006Ool1
00000006001oo`00001oo`000Woo00L007ooOol007oo001oo`02000:Ool01000Oomoo`001Goo0P00
17oo00<007oo00000Woo00<007ooOol017oo00<007oo00000Woo00<007ooOol01Goo00@007oo001o
o`<00003Ool0000000Ioo`03001oogoo00=oo`80009oo`03001oogoo00Moo`03001oogoo00=oo`05
001oogoo001oo`020003Ool20009Ool02`00Ool007oo001oo`00Ool007oo00001Goo00<007ooOol0
0P000Woo00<007oo000017oo00<007ooOol017oo00<007oo00002Woo00@007ooOomoo`8000=oo`03
001oogoo00Aoo`06001oogooOol007oo0P0017oo0P0017oo00<007ooOol00goo0P0000Aoo`00Ool0
00=oo`<000]oo`03001oogoo00Aoo`<0009oo`03001oogoo00Uoo`800003Ool0000000Yoo`03001o
o`00009oo`40000000<007ooOol027oo00<007ooOol01Woo0P000Woo00<007ooOol027oo00<007oo
Ool067oo00D007ooOomoo`0001eoo`03001oogoo00eoo`03001oogoo00Qoo`8000Aoo`03001oogoo
00Ioo`03001oogoo00Ioo`800003Ool007oo03moo`03001oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo01Qoo`03001oogoo00Moo`05001oo`00Ool00004Ool00`00Oomoo`08Ool100000003001oogoo
00Aoo`04001oo`000002Ool01000Ool007oo0P000Woo00D007ooOomoo`0000=oo`05001oogooOol0
0004Ool30002Ool00`00Oomoo`03Ool00`00Ool00002Ool20005Ool00`00Oomoo`07Ool00`00Oomo
o`03Ool01@00Oomoogoo000017oo00<007oo000027oo00<007ooOol01Woo00<007ooOol00Woo00<0
07oo000027oo00@007ooOomoo`8000=oo`06001oogoo001oo`0037oo0P0000=oo`00Ool00goo0P00
1Goo00D007oo001oo`00009oo`09001oo`00Ool007oo001oo`0000Eoo`03001oogoo009oo`03001o
o`0001Aoo`04001oogoo0002Ool01@00Ool007oo00000Woo0P001Goo00<007ooOol01goo0P002Goo
00<007oo00000Woo00<007oo00000Woo0P000goo00<007ooOol01goo1@000goo0@0000000`00Oomo
o`04Ool00`00Oomoo`04Ool01000Oomoogoo0`0000Aoo`00Ool000Uoo`03001oogoo00=oo`04001o
ogoo0002Ool01000Oomoo`000goo00H007ooOomoo`00Ool20007Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Aoo`8000=oo`03001o
ogoo009oo`05001oogooOol00003Ool00`00Ool00006Ool2000017oo000007oo10001Goo10000goo
00<007oo00001Goo00<007ooOol027oo0P000Woo0`000Woo00<007ooOol02goo00@007oo0000009o
o`03001oogoo008000Uoo`03001oogoo00Ioo`03001oogoo00Qoo`80009oo`<000aoo`04001oogoo
0002Ool00`00Oomoo`06Ool01@00Oomoogoo000017oo0P0017oo00<007ooOol00@0000000`00Oomo
o`03Ool01000Oomoo`001Woo00<007ooOol00goo0P0000=oo`00Ool017oo00<007ooOol01goo0P00
0goo0P0000=oo`00Ool037oo0P002Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol000Mo
o`03001oo`00029oo`03001oogoo00Eoo`8000Moo`03001oogoo00=oo`03001oogoo00Moo`8000Mo
o`03001oogoo00]oo`03001oogoo00Moo`03001oogoo015oo`03001oo`0000=oo`03001oogoo00Uo
o`03001oo`00009oo`<000Ioo`03001oogoo019oo`05001oogooOol00003Ool10001Ool100000006
001oo`00001oo`003Goo00<007ooOol00goo00<007ooOol00goo00@007ooOomoo`800003Ool007oo
00=oo`8000Aoo`03001oo`00008000=oo`03001oogoo009oo`04001oogoo0009Ool01@00Oomoogoo
00000Woo0P0017oo0P000goo00@007ooOol0009oo`03001oo`00009oo`03001oo`00009oo`03001o
ogoo00Aoo`03001oogoo00=oo`03001oogoo00=oo`800005Ool007oo001oo`020004Ool01000Oomo
o`001Goo0P001Woo0P000Woo0P000goo00@007ooOol000Aoo`03001oogoo00Aoo`04001oogooOol2
0002Ool200000goo001oo`03Ool200001Woo001oo`00Ool0009oo`<000=oo`04001oogoo0002Ool0
0`00Oomoo`03Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Ool0
0002Ool00`00Ool00005Ool01@00Oomoogoo00000goo00<007ooOol00goo00<007ooOol00P0000=o
o`00Ool00goo00@007ooOomoo`40000000<007ooOol01Goo00<007ooOol017oo00<007oo00001Goo
00<007ooOol00Woo0P0017oo00<007ooOol00Woo00<007ooOol02Woo00D007ooOomoo`0000Eoo`03
001oogoo00Aoo`06001oogoo001oo`001goo0P0017oo00<007ooOol00Woo00<007oo00004Goo00@0
07ooOol0009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0003Ool00`00Ool00004Ool0
0`00Oomoo`03Ool00`00Ool00003Ool01000Oomoo`001goo00<007ooOol00goo00<007oo00000goo
00<007oo00000Woo00<007oo00000goo00<007ooOol04goo00<007ooOol01Goo00<007ooOol02Goo
00<007ooOol00goo0`000goo00<007ooOol00Woo00<007ooOol00Woo0`0000]oo`00Oomoo`00Ool0
07oo001oo`0000Moo`03001oogoo00Yoo`40000000<007ooOol01Goo00<007ooOol04Woo00D007oo
Oomoo`00009oo`03001oogoo00moo`03001oogoo00Ioo`03001oo`0002Aoo`03001oogoo01Aoo`80
009oo`05001oogooOol00005Ool00`00Oomoo`0AOol20003Ool01000Oomoo`000Woo00<007ooOol0
0goo00<007ooOol03Woo00<007oo00001goo0P0000Aoo`00Ool001moo`03001oogoo00Eoo`03001o
ogoo00Yoo`03001oogoo00Ioo`05001oogooOol00002Ool01000Oomoo`001Woo0@0000000`00Oomo
o`02Ool30004Ool01@00Oomoogoo00000goo00<007ooOol017oo00<007ooOol01goo0P000Woo00<0
07ooOol017oo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Aoo`04001oogoo0002Ool0
0`00Ool00002Ool00`00Ool00005000EOol00`00Ool000020003Ool01@00Oomoogoo00000goo00L0
07ooOomoo`00Ool00006Ool01000Ool000001Goo0P000goo00@007ooOol000Qoo`<000Ioo`80009o
o`03001oogoo00=oo`07001oogooOol007oo00001Goo00H007ooOol007oo0003Ool00`00Oomoo`03
000:Ool00`00Oomoo`020003Ool00`00Ool00004Ool40006Ool00`00Oomoo`02Ool00`00Oomoo`0;
Ool400000goo001oo`02Ool00`00Oomoo`07Ool00`00Ool00002Ool100000003001oogoo00800003
Ool007oo00=oo`04001oo`000003Ool01000Oomoogoo0P005Goo00<007ooOol02goo0P0000Aoo`00
Ool000Aoo`03001oo`0000=oo`8000=oo`03001oo`00009oo`03001oogoo00Moo`03001oo`000080
009oo`03001oo`00009oo`06001oo`00001oo`000goo0P0057oo00<007ooOol00`000goo0P0047oo
00<007ooOol017oo00H007ooOol007oo0008Ool00`00Ool00004Ool20005Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000Woo0P0027oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00P001Woo
0P000goo0P0000=oo`00Ool017oo00D007ooOomoo`0000Moo`03001oogoo00Moo`03001oo`0000=o
o`40000000D007oo001oo`0000eoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo015oo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00Uoo`80
00Ioo`03001oogoo00ioo`03001oogoo00ioo`03001oo`0000Yoo`03001oogoo00Ioo`03001oogoo
00]oo`03001oogoo009oo`03001oogoo00Eoo`03001oo`0000Yoo`03001oogoo00Aoo`03001oogoo
00Qoo`04001oogoo0003Ool00`00Oomoo`03Ool00`00Ool0000FOol01000Oomoo`001goo0P0000=o
o`00000017oo00<007ooOol00P001Woo0@0000001@00Oomoogoo00001Goo00D007oo001oo`00009o
o`03001oogoo00Ioo`04001oogoo0002Ool02000Ool00000Ool007oo0007Ool00`00Oomoo`04Ool0
1P00Oomoo`00Ool0009oo`03001oogoo00Aoo`05001oogooOol00009Ool40007Ool00`00Oomoo`02
Ool01000Oomoo`0017oo00<007ooOol017oo00<007ooOol02goo0P000goo00D007ooOomoo`0000Io
o`04001oo`000002Ool01@00Oomoogoo00001Goo00<007oo00001Goo0P0017oo0P0017oo0P0000=o
o`0000001Woo0P0017oo00<007oo00000goo00<007ooOol00goo0`0000Aoo`00Oomoo`8000Moo`03
001oo`0000Eoo`8000Ioo`03001oogoo00=oo`09001oogooOol007oo001oo`0000]oo`03001oo`00
00Qoo`80009oo`03001oo`00009oo`40000000H007oo000007oo000;Ool01P00Oomoo`00Ool000Ao
o`03001oogoo009oo`80009oo`03001oo`00009oo`03001oogoo009oo`<000=oo`03001oo`0000Io
o`03001oogoo00<000Moo`04001oogoo0007Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomo
o`02000:Ool01@00Oomoogoo00001Goo00<007oo000017oo00<007oo00001Goo00<007ooOol00Woo
00<007ooOol00goo0`0000=oo`0000002Woo0`000Woo0`0000Eoo`00Oomoo`0000=oo`04001oogoo
0003Ool200000goo001oo`07Ool00`00Oomoo`0300000goo00000002Ool01@00Oomoogoo00001Goo
00<007ooOol01Goo0P001Woo0P0017oo00@007ooOol0009oo`06001oogoo001oo`000goo00<007oo
Ool00P001goo00D007ooOomoo`0000=oo`06001oo`00Ool007oo0@0000000`00Oomoo`05Ool01000
Oomoo`000goo00<007ooOol037oo00<007ooOol027oo0P0000=oo`00Ool01goo00D007ooOomoo`00
00Moo`8000eoo`03001oogoo015oo`8001Yoo`03001oogoo00eoo`03001oogoo00Qoo`800003Ool0
07oo00=oo`05001oogooOol00009Ool2000FOol3000ROol00`00Oomoo`09Ool300000goo001oo`03
Ool00`00Oomoo`07Ool00`00Oomoo`03Ool200000goo001oo`07Ool100000003001oogoo00Aoo`08
001oo`00Ool007oo001oo`8000Moo`04001oo`00Ool200000goo0000000300000goo001oo`03Ool0
1@00Oomoogoo00000Woo00<007oo00001goo00<007ooOol02Woo00<007oo00000goo0`0017oo00D0
07ooOomoo`00011oo`8000Qoo`06001oogooOol007oo0`002Goo0P0027oo00<007ooOol01goo0P00
17oo0P001goo00D007ooOomoo`00009oo`07001oogoo001oo`00Ool00P001goo0P0000=oo`000000
1Goo00<007ooOol037oo00<007ooOol00P0000=oo`0000001goo00L007ooOol007oo001oo`020000
0goo001oo`0<Ool20002Ool00`00Oomoo`09Ool01000Ool000002goo0@0000000`00Oomoo`04Ool0
1000Ool000000Woo00<007ooOol01Goo00H007ooOomoo`00Ool2000017oo001oo`001Woo0P0017oo
00D007ooOomoo`00009oo`8000Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Aoo`05
001oo`00001oo`020002Ool01000Oomoogoo0`0017oo0P002Goo00<007oo00000P000goo00@007oo
Ool000Aoo`03001oo`00009oo`03001oogoo00Aoo`8000=oo`8000=oo`8000=oo`03001oogoo009o
o`03001oogoo009oo`05001oogooOol00003Ool200002Woo00000000Ool007oo001oo`001Goo00@0
07oo001oo`<000Yoo`04001oogoo0005Ool200000goo0000000200000goo001oo`07Ool01@00Oomo
ogoo00000goo00<007ooOol017oo00<007ooOol027oo00D007oo001oo`0000=oo`05001oogooOol0
0007Ool01000Oomoo`000Woo00D007oo001oo`00009oo`40000000@007ooOol0009oo`03001oogoo
01Ioo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Uoo`03001oo`0000Uoo`03001oogoo
00Uoo`03001oogoo00Uoo`03001oogoo008000Eoo`06001oogoo001oo`001Goo0P002Goo0P001Goo
00<007ooOol02Goo00<007ooOol00Woo00@007ooOol000=oo`03001oogoo00<000Eoo`8000ioo`80
00=oo`03001oogoo009oo`04001oogoo0004Ool01000Oomoo`003Woo00<007oo00001goo00<007oo
Ool00P000Woo00<007ooOol05Woo00L007ooOomoo`00Ool00003Ool00`00Oomoo`0>Ool100000003
001oo`00009oo`05001oogooOol00004Ool2000017oo000007oo0P0017oo00<007ooOol017oo00<0
07ooOol02Woo0`000Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0
0Woo00<007ooOol017oo00@007oo000000Eoo`800003Ool0000000@000Aoo`05001oo`00Ool00006
Ool00`00Oomoo`02Ool200001Goo001oogoo00000Woo00<007ooOol01Goo00<007ooOol017oo00D0
07ooOomoo`0000Aoo`04001oogooOol30006Ool20002Ool00`00Oomoo`02Ool00`00Oomoo`07Ool0
1000Oomoo`000goo00<007ooOol027oo00H007ooOol007oo0002Ool00`00Oomoo`0:Ool200000goo
001oo`0<Ool00`00Oomoo`0400000goo001oo`020002Ool00`00Oomoo`020005Ool01@00Oomoogoo
000027oo00<007oo00000goo0@0000000`00Oomoo`05Ool00`00Oomoo`05Ool00`00Ool000020003
Ool2000017oo001oogoo0P0017oo0P001Goo00<007oo00002goo00<007ooOol00P000Woo00D007oo
Oomoo`0000=oo`8000Ioo`05001oogoo001oo`030004Ool01000Oomoo`000goo0P001Woo0P000Woo
00<007ooOol00Woo00<007ooOol01Goo0P000Woo00<007ooOol00Woo00<007ooOol01goo00<007oo
Ool00Woo00<007ooOol01Woo100000Aoo`00Oomoo`800005Ool00000Ool00005Ool00`00Oomoo`02
Ool20002Ool20003Ool20002Ool20002Ool00`00Ool00002Ool01`00Oomoogoo001oo`0000Qoo`04
001oogoo0002Ool01000Oomoogoo0`0000=oo`00Ool017oo100000Aoo`00001oo`8000Aoo`05001o
ogooOol00005Ool40004Ool00`00Oomoo`02Ool00`00Oomoo`02000017oo001oo`000Woo0@000000
0`00Oomoo`03Ool00`00Ool0000=Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool00`00Ool00005Ool0
0`00Oomoo`0=Ool00`00Ool0000BOol01@00Oomoogoo00001Woo0P0000=oo`00Ool02Goo00<007oo
Ool01Woo0P0027oo0P000goo00<007ooOol01goo00L007ooOomoo`00Ool00003Ool00`00Oomoo`06
Ool01@00Ool007oo000037oo00<007ooOol00goo00<007oo00001Goo0P0017oo00<007ooOol00goo
00<007ooOol00goo00@007ooOomoo`800003Ool007oo00=oo`03001oogoo00aoo`03001oogoo00mo
o`03001oogoo00Aoo`8000Moo`03001oogoo00=oo`40005oo`40000000P007ooOol007oo001oo`00
1goo00D007oo001oo`00009oo`<000Eoo`03001oogoo009oo`06001oogoo001oo`0017oo00@007oo
Oomoo`8000Aoo`L00003Ool007oo00Ioo`03001oogoo009oo`03001oo`0000Ioo`03001oogoo0080
0005Ool007oo001oo`020002Ool300000goo001oo`0:Ool00`00Ool00002Ool00`00Oomoo`07Ool0
1000Oomoo`002Goo00<007ooOol01Goo00D007ooOomoo`0000Eoo`03001oo`00009oo`03001oogoo
00Eoo`04001oogooOol40006Ool00`00Oomoo`07Ool01000Ool000000Woo00<007ooOol027oo00D0
07oo001oo`0000Eoo`03001oogoo00Moo`80009oo`03001oogoo008000Aoo`03001oogoo00Qoo`03
001oogoo00Eoo`<000=oo`03001oogoo009oo`06001oogoo001oo`000goo0@0000001`00Ool007oo
001oo`0000Eoo`80009oo`03001oogoo00Aoo`03001oo`0000Uoo`<00003Ool007oo00<000Ioo`@0
00=oo`03001oogoo00Aoo`8000Eoo`04001oo`000006Ool01000Oomoogoo0P0000Eoo`00Oomoo`00
00=oo`03001oogoo00Eoo`05001oogooOol00005Ool00`00Ool00004Ool20002Ool20003Ool20007
Ool00`00Ool0000200000goo00000002Ool00`00Oomoo`05Ool00`00Ool00002Ool01000Oomoo`00
0Woo00<007ooOol00goo00<007ooOol017oo00<007ooOol01Woo0P002Goo00<007ooOol00Woo00D0
07oo001oo`0000Ioo`03001oo`00009oo`03001oo`00009oo`8000Qoo`@000Aoo`03001oogoo009o
o`<00005Ool007ooOol00002Ool00`00Oomoo`0;Ool60008Ool100000005001oogooOol00006Ool0
0`00Ool0000COol00`00Oomoo`07Ool2000=Ool00`00Oomoo`03Ool00`00Oomoo`05Ool2000JOol0
1000Ool000001Woo00D007ooOomoo`0001]oo`03001oogoo01aoo`03001oogoo00Qoo`03001oogoo
00Yoo`03001oogoo00Ioo`03001oogoo00Moo`07001oo`00Ool007oo00001goo00@007ooOol000Io
o`03001oogoo009oo`<000Moo`03001oogoo00Ioo`8000=oo`03001oogoo00=oo`03001oogoo00Uo
o`40000000<007oo00001goo00D007ooOomoo`0000=oo`03001oo`0000Yoo`03001oogoo00]oo`80
00Eoo`07001oo`00Ool007oo00002Goo0P0000Aoo`00Ool000=oo`03001oogoo009oo`03001oogoo
0080009oo`03001oogoo00=oo`80009oo`03001oogoo00Aoo`03001oogoo00800003Ool007oo00ao
o`03001oogoo009oo`03001oogoo009oo`8000=oo`03001oo`0000Aoo`06001oo`00001oo`0027oo
00P007ooOol007oo001oo`0017oo00<007ooOol01Woo00<007ooOol010001goo0P000Woo0P000Woo
00<007ooOol00Woo00@007oo001oo`800003Ool007oo009oo`06001oo`00001oo`002Goo00<007oo
00001goo00<007ooOol00Woo0`000goo00D007ooOomoo`0000Yoo`03001oo`00009oo`08001oogoo
001oo`00Ool0009oo`40000000H007ooOol007oo0006Ool00`00Ool00003Ool01000Oomoogoo0P00
17oo0P0000Aoo`00Oomoo`80009oo`<00003Ool007oo00Ioo`03001oogoo009oo`08001oogoo001o
o`00Ool000=oo`04001oogoo0003Ool00`00Oomoo`06Ool01000Oomoo`000Woo0`0017oo00<007oo
00000Woo00<007ooOol027oo10001Goo00<007ooOol00goo00<007ooOol017oo00<007ooOol00Woo
0P001Goo00L007ooOomoo`00Ool0000:Ool200000goo001oo`0AOol00`00Oomoo`03Ool50004Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Ool00004Ool0
0`00Oomoo`0200000goo00000008Ool00`00Ool00002Ool00`00Oomoo`020002Ool20005Ool00`00
Oomoo`05Ool00`00Oomoo`06Ool01000Oomoogoo0@0000000`00Oomoo`05Ool00`00Oomoo`06Ool0
0`00Oomoo`07Ool00`00Ool0000DOol01000Oomoogoo0P001Goo00<007oo00002Woo0P001Goo00<0
07ooOol02goo00<007ooOol00Woo0P001Goo00<007ooOol00Woo00D007ooOomoo`0000Ioo`03001o
ogoo01=oo`03001oogoo00Eoo`03001oogoo00aoo`04001oogoo0004Ool00`00Oomoo`03Ool00`00
Oomoo`04Ool00`00Oomoo`07Ool01`00Oomoo`00Ool007oo008000Eoo`8001=oo`03001oogoo00Ao
o`03001oogoo009oo`04001oogooOol20002Ool01000Oomoo`0017oo00D007ooOomoo`0000=oo`03
001oo`0000Qoo`03001oogoo00=oo`40000000<007ooOol017oo00L007oo001oo`00Ool0000COol2
00001Woo001oo`00Ool000=oo`03001oogoo00Aoo`03001oo`0000=oo`03001oogoo00Eoo`03001o
ogoo009oo`03001oogoo008000Aoo`03001oogoo00Uoo`04001oo`000008Ool00`00Oomoo`08Ool0
1P00Ool00000Ool0009oo`<000Eoo`03001oo`0000Qoo`8000=oo`03001oogoo00Eoo`03001oogoo
00Moo`<000Uoo`03001oogoo00Eoo`05001oogooOol00004Ool01000Oomoo`000Woo0P0027oo0P00
17oo0P000goo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol03Woo00L0
07ooOomoo`00Ool00003Ool01000Oomoo`0017oo00<007ooOol00P0000=oo`00Ool00P000Goo0@00
00001000Ool000000goo00<007oo00000P000goo00<007oo00000Woo00<007oo00000goo00<007oo
00001goo00<007ooOol00goo0P000goo00<007ooOol00Woo00<007ooOol00P000Woo00<007oo0000
0`002Woo0P0000Aoo`000000009oo`05001oogooOol00007Ool00`00Ool00009Ool200000goo001o
o`02Ool01@00Oomoo`00Ool00`001Goo0P000goo00<007ooOol01Goo00<007oo00000goo00<007oo
Ool01@000Woo00@007ooOol000=oo`03001oogoo00Eoo`@00003Ool0000000=oo`03001oogoo009o
o`06001oogoo001oo`0017oo0P003goo00<007ooOol017oo00<007ooOol017oo00H007oo001oo`00
Ool20005Ool00`00Ool0000;Ool01P00Ool007oo001oo`<00004Ool000000003Ool00`00Oomoo`05
Ool2000017oo001oo`000goo0@0000000`00Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`005Woo
00D007ooOomoo`0000Uoo`03001oogoo00]oo`04001oo`000002Ool01000Oomoo`001Goo00<007oo
00002Woo00<007ooOol027oo0P000Woo00<007oo00001Goo00<007oo00000Woo0P000goo00<007oo
Ool027oo00H007ooOol007oo0002Ool00`00Oomoo`04Ool00`00Oomoo`06Ool20009Ool00`00Ool0
0005Ool01@00Oomoogoo00002goo00@007ooOol000Eoo`03001oogoo00Eoo`03001oo`0000Aoo`03
001oogoo00eoo`03001oo`00009oo`03001oogoo00Uoo`03001oo`0000Eoo`03001oogoo009oo`04
001oogoo000?Ool100000003001oogoo009oo`05001oogooOol0000>Ool01P00Oomoo`00Ool0009o
o`8000=oo`8000Eoo`03001oo`00009oo`03001oogoo00Eoo`03001oo`00009oo`04001oo`000002
Ool02@00Ool007oo001oo`00Ool00007Ool30002Ool00`00Ool00004Ool20002Ool200000goo001o
o`04Ool01000Oomoo`000Woo00<007ooOol01Woo00@007ooOomoo`<000Uoo`04001oogoo0002Ool0
0`00Oomoo`04Ool00`00Ool00004Ool01`00Oomoogoo001oo`0000=oo`04001oogooOol20003Ool0
1000Oomoo`0027oo00<007ooOol017oo00<007ooOol00P0000Aoo`00Oomoo`<000Aoo`03001oogoo
009oo`03001oogoo00800004Ool007oo0004Ool20003Ool00`00Ool00003Ool01000Oomoogoo1000
00Aoo`00000000Qoo`04001oogooOol30003Ool60008Ool100000004001oogoo0002Ool00`00Ool0
0005Ool200000goo001oo`02Ool01`00Oomoo`00Ool007oo0080009oo`04001oo`000008Ool01P00
Ool00000Ool000aoo`8000Ioo`03001oo`00009oo`05001oo`00Ool00002Ool01`00Oomoo`00Ool0
07oo00<000=oo`03001oo`0000=oo`04001oogooOol50003Ool2000;Ool200000goo001oo`03Ool0
0`00Ool00006Ool20002Ool01000Oomoogoo0P000Woo00@007ooOol0009oo`05001oo`00Ool00003
Ool30005Ool00`00Oomoo`02Ool20002Ool01000Oomoo`000goo00<007oo00005goo00@007oo0000
009oo`03001oogoo00Aoo`03001oogoo008000Moo`800003Ool0000000Yoo`03001oogoo00Moo`03
001oogoo00=oo`03001oogoo009oo`05001oo`00Ool00002Ool100000003001oogoo00=oo`03001o
ogoo00Uoo`04001oo`000008Ool01000Oomoo`000goo00D007ooOomoo`0001Aoo`03001oogoo009o
o`04001oogoo000FOol00`00Ool00008Ool00`00Oomoo`03Ool01000Oomoo`000Woo00D007ooOomo
o`0000Moo`03001oogoo01=oo`03001oo`0000=oo`@0009oo`8000Ioo`03001oogoo00Eoo`03001o
ogoo00ioo`03001oogoo01Yoo`03001oogoo00Qoo`03001oogoo00=oo`04001oogoo000>Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool00`00Ool00002Ool00`00Oomoo`07Ool100000006001oo`00Ool0
07oo0P0027oo00@007oo001oo`8000=oo`05001oo`00001oo`030003Ool01@00Oomoogoo000027oo
00<007oo00000Woo00<007oo00000goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Woo
00<007ooOol017oo00@007ooOol0009oo`800003Ool0000000=oo`<000Aoo`04001oogoo0003Ool0
1@00Ool007oo00000goo0P000Woo0`0000=oo`0000000Woo00D007ooOomoo`0000Aoo`03001oo`00
008000=oo`05001oogooOol0000;Ool01@00Oomoogoo00001goo0P002Goo0P000Woo00<007oo0000
17oo0P001Woo0P001Woo00<007ooOol01goo00<007ooOol00P001Woo10000Woo00@007ooOol000Ao
o`04001oogoo0004Ool01000Oomoo`002Goo00<007ooOol017oo00@007oo0000009oo`40000000D0
07oo001oo`0000Moo`08001oogoo001oo`00Ool000Aoo`03001oo`0000Aoo`D0009oo`8000]oo`05
001oo`00Ool00003Ool20003Ool01000Ool000001Woo0P001Goo00@007ooOol000=oo`04001oogoo
Ool40002Ool20004Ool01000Oomoogoo0P0000=oo`00Ool017oo00<007ooOol00P000Woo00<007oo
Ool02Goo00<007ooOol00P0000=oo`00Ool00goo00@007ooOol000Aoo`03001oo`0000Eoo`8000Eo
o`04001oogoo0005Ool200001Goo001oogoo00000Woo00<007ooOol00goo00<007ooOol01Goo00<0
07ooOol00goo0P000goo00D007ooOomoo`0000Eoo`8000=oo`03001oo`0000Qoo`03001oogoo0080
00Eoo`<00007Ool007oo001oo`00Ool00P001Goo00L007ooOomoo`00Ool00006Ool200001Woo001o
ogoo001oo`40000000@007ooOol000Moo`03001oo`0000Eoo`04001oogoo0002Ool30009Ool00`00
Oomoo`05Ool01000Oomoo`000Woo0`000Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0
1Woo00<007ooOol01goo00<007ooOol03goo00<007ooOol00goo0P0037oo00<007ooOol017oo00@0
07ooOol000Aoo`80011oo`03001oo`0001Aoo`04001oogoo0008Ool20005Ool00`00Oomoo`02Ool0
0`00Oomoo`08Ool01000Oomoogoo0P002goo00@007ooOol000Moo`04001oogoo0003Ool01@00Oomo
ogoo000017oo00<007ooOol017oo00<007ooOol01Woo00P007ooOol007oo001oo`000goo0@000000
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0200000goo001oo`04Ool30006Ool00`00Oomo
o`07Ool20005Ool00`00Oomoo`09Ool200000goo00000005Ool40004Ool00`00Ool00002Ool01P00
Oomoogoo001oo`800004Ool007ooOol30003Ool01@00Oomoogoo000047oo00<007ooOol00Woo00<0
07ooOol01Goo00@007ooOol0009oo`8000=oo`03001oogoo00Eoo`8000Ioo`80009oo`03001oogoo
00Eoo`<00006Ool00000001oo`001Goo0P001Woo0`0000=oo`00Ool00Woo0P000Woo00@007ooOomo
o`8000Aoo`03001oogoo00Ioo`D000=oo`03001oo`0000<000Aoo`8000Eoo`04001oo`00Ool20004
Ool00`00Ool00003Ool01000Oomoo`001Woo00<007ooOol01Woo0@0000000`00Oomoo`05Ool01`00
Oomoogoo001oo`0000=oo`03001oo`00009oo`03001oo`0000Aoo`04001oogoo0004Ool300001Goo
001oo`00Ool00P0017oo00<007ooOol017oo00T007ooOomoo`00Ool007oo00000goo00<007ooOol0
0goo0P000Woo00<007ooOol02Woo0P003Goo00H007ooOol007oo0004Ool00`00Oomoo`07Ool30002
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool2000?Ool01000Ool000001Woo00@007ooOol000Eoo`05
001oo`00001oo`020002Ool00`00Oomoo`0400001Goo001oogoo000017oo100000Eoo`00Oomoo`00
009oo`04001oo`000005Ool01000Oomoo`001Woo00<007ooOol027oo00<007oo00000P0017oo00@0
07oo001oo`@00004Ool00000Ool4000017oo001oogoo0`001Goo00<007ooOol00@0000001000Ool0
000017oo00<007ooOol06Goo00<007ooOol03goo00@007ooOol000Yoo`03001oogoo00Uoo`03001o
o`0001Aoo`03001oogoo00=oo`03001oogoo00eoo`04001oogoo000:Ool01@00Oomoogoo00004Goo
00<007ooOol01Goo00<007ooOol047oo0P001Woo0P001Goo00@007ooOol000Aoo`03001oogoo00=o
o`8000Ioo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Eoo`05001o
ogooOol00004Ool01000Oomoogoo0P0017oo0`001Woo00<007ooOol00Woo0@0000000`00Oomoo`03
Ool200001Woo00000000Ool000=oo`8000=oo`03001oogoo00Yoo`03001oo`0000Qoo`<000Aoo`03
001oogoo00800003Ool007oo00Aoo`<00003Ool007oo00Ioo`04001oogoo0002Ool00`00Ool00003
Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`05001oo`00Ool00002Ool200000goo0000000:
Ool00`00Ool00006Ool00`00Oomoo`04Ool01000Oomoo`002Woo00<007oo00000Woo00@007ooOol0
00Aoo`80009oo`03001oo`0000Eoo`03001oogoo009oo`04001oogoo0008Ool00`00Oomoo`02Ool0
0`00Ool0000200000goo001oo`030003Ool20002Ool00`00Oomoo`02000017oo000000000Woo00@0
07ooOomoo`<00005Ool007ooOol0000=Ool00`00Ool00005Ool01@00Oomoogoo00001Woo00@007oo
Ool0009oo`04001oogoo0003Ool100000003001oogoo009oo`03001oogoo00Ioo`800003Ool007oo
00Aoo`03001oogoo009oo`04001oogoo000<Ool2000:Ool01000Oomoogoo0`0000Eoo`00Ool007oo
00<000=oo`03001oogoo00<000Aoo`03001oo`00009oo`800004Ool007oo0003Ool00`00Oomoo`04
Ool200001goo001oogoo001oo`0000=oo`80009oo`03001oogoo00Eoo`05001oogooOol00002Ool0
0`00Ool0000<Ool20007Ool00`00Oomoo`02000017oo000000000Woo0P001goo00@007ooOomoo`80
0003Ool007oo00Eoo`05001oo`00Ool00004Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000=o
o`03001oogoo009oo`04001oogoo0004Ool01000Oomoo`000Woo00<007ooOol00P001goo00<007oo
Ool00`0017oo00<007ooOol00goo00D007ooOomoo`00009oo`03001oo`0000Aoo`@00004Ool00000
Ool100000004001oogoo0005Ool01@00Oomoogoo00001Woo00<007ooOol017oo00<007oo00000goo
00<007oo00000Woo00H007ooOol007oo0002Ool01000Oomoo`000Woo00<007ooOol057oo00<007oo
000027oo0P0017oo00H007ooOol007oo0005Ool00`00Oomoo`03Ool00`00Oomoo`07Ool2000;Ool0
0`00Oomoo`020006Ool00`00Oomoo`0EOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
00001goo00<007ooOol017oo0P001Woo0P001Woo00<007ooOol00Woo00<007ooOol057oo00<007oo
Ool01Goo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol057oo0@0000000`00Ool00003Ool0
0`00Ool00007Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Ool00002Ool01000Ool000000Woo
00H007ooOol007oo0003Ool00`00Ool00002Ool00`00Oomoo`09Ool40007Ool00`00Ool00002Ool2
0006Ool01P00Ool00000Ool0009oo`05001oogooOol00002Ool20002Ool00`00Ool00009Ool20000
0goo001oo`03Ool20004Ool00`00Ool00004Ool00`00Oomoo`06Ool40005Ool01000Oomoogoo0P00
00=oo`00Ool00`0000=oo`00Ool00Woo0`000Woo00D007ooOol007oo00<000Qoo`8000=oo`03001o
ogoo00Eoo`03001oogoo00=oo`800003Ool0000000<00005Ool007ooOol00004Ool01`00Oomoogoo
001oo`00009oo`80009oo`8000Moo`03001oogoo009oo`03001oogoo00Ioo`03001oo`0000=oo`08
001oo`00001oo`00Ool000=oo`40000000H007oo001oo`00Ool20006Ool2000:Ool00`00Ool00006
Ool00`00Oomoo`0200001Goo00000000Ool010000goo0`000Woo00<007oo00000Woo0P000Woo00<0
07ooOol00goo00L007oo001oo`00Ool00002Ool00`00Oomoo`03Ool01000Oomoogoo0`0000=oo`00
000017oo00<007ooOol01Goo00L007ooOol007oo001oo`040002Ool00`00Ool00002Ool00`00Oomo
o`06Ool20008Ool01`00Oomoogoo001oo`0000Eoo`@000Aoo`80009oo`04001oo`00Ool30006Ool0
1000Oomoo`000Woo0`0000Aoo`00Ool000=oo`05001oogooOol00008Ool01000Oomoo`000Woo00@0
07ooOol0009oo`03001oogoo00Aoo`03001oo`0000=oo`03001oo`0000Aoo`800003Ool007oo00=o
o`07001oogoo001oo`00Ool00P001Goo0`000Woo00<007ooOol017oo00<007ooOol00goo00<007oo
Ool00@0000000`00Oomoo`0>Ool01@00Oomoogoo00000Woo00<007ooOol01Woo0P0017oo00<007oo
Ool01Woo00<007ooOol02goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool017oo00<007ooOol00goo00H007ooOol007oo0002Ool00`00Oomoo`0:Ool2000DOol01000Ool0
000017oo00<007ooOol00goo0P001Goo00<007ooOol017oo00D007ooOomoo`00009oo`03001oogoo
00Ioo`06001oogoo001oo`001goo00<007ooOol01goo00H007ooOol007oo0003Ool20005Ool00`00
Oomoo`08Ool00`00Ool00006Ool00`00Oomoo`06Ool00`00Oomoo`0400000goo001oo`05Ool01@00
Ool007oo00001Goo0P001Goo00<007ooOol00Woo00<007ooOol00Woo0@0000001P00Oomoo`00Ool0
00Eoo`8000=oo`04001oo`00Ool20002Ool01P00Ool00000Ool000Ioo`09001oogooOol007oo001o
o`0000=oo`800004Ool007oo0006Ool20002Ool01000Ool000000goo00@007oo0000009oo`03001o
o`00009oo`06001oogooOol007oo0P0000Aoo`00001oo`<00006Ool00000001oo`001Goo0P001goo
00@007ooOomoo`80009oo`03001oogoo00800005Ool00000Ool00002Ool00`00Ool00006Ool00`00
Oomoo`0:Ool00`00Oomoo`020003Ool00`00Oomoo`03000017oo001oogoo0P001Woo00<007ooOol0
0Woo00D007ooOomoo`00009oo`03001oo`00009oo`05001oogooOol00008Ool01@00Ool007oo0000
37oo0P0000=oo`00Ool00goo0`001goo00<007oo00000Woo0`0017oo00<007ooOol00P0000=oo`00
00000goo10000goo00<007ooOol017oo0@0000000`00Oomoo`07Ool200002Woo001oo`00Ool007oo
001oo`000goo00<007oo00000P000Woo0P000Woo00D007oo001oo`0000Aoo`8000=oo`03001oogoo
00Aoo`03001oo`0000=oo`03001oo`0000Qoo`07001oo`00Ool007oo00000Woo0P001Woo0`0017oo
0P000goo00<007ooOol01@003Woo00<007oo00002Goo0`0000Aoo`00Ool000Aoo`800003Ool007oo
00Aoo`80009oo`04001oo`000002Ool00`00Ool00009Ool01000Ool000000Woo00<007ooOol017oo
0P0000=oo`00Ool00Woo00@007oo000000=oo`04001oo`000002Ool00`00Ool00005Ool00`00Oomo
o`02Ool00`00Ool00007Ool01@00Oomoogoo00000goo1@0017oo00<007oo00000goo00H007oo0000
07oo0003Ool20003Ool00`00Ool00002Ool01000Oomoogoo1@000Goo0@0000001000Ool0000017oo
00<007ooOol01Goo00@007ooOol000Aoo`03001oogoo00=oo`03001oo`0000Aoo`03001oogoo00Yo
o`03001oogoo00=oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`0JOol20005Ool30005
Ool01000Oomoogoo0P0000=oo`00Ool02goo00<007ooOol017oo00<007ooOol00Woo00D007oo001o
o`0000Eoo`03001oogoo009oo`04001oo`000002Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`0@Ool30007Ool01@00Oomoogoo00001Goo0P0000=oo`00Ool01Goo00<007ooOol03Woo00<0
07oo00000Woo00<007oo000037oo00<007ooOol00Woo00<007ooOol00Woo0P001Woo0@0000000`00
Oomoo`04Ool30002Ool00`00Ool00007Ool00`00Oomoo`0200000goo001oo`02000017oo00000000
0Woo0P000Woo0`001Goo0`0000=oo`00Ool00Woo00<007ooOol00P0000=oo`0000000Woo0P0000=o
o`0000000goo00<007ooOol00Woo0P000goo00D007ooOomoo`0000Uoo`03001oo`0000800003Ool0
07oo00Aoo`04001oo`000003Ool200001Goo001oogoo00000Woo00@007oo000000Aoo`03001oogoo
00Eoo`@000=oo`03001oo`00009oo`04001oogoo000@Ool30002Ool30003Ool500000goo00000002
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007oo000010000Woo00@007ooOol000Qoo`04001o
ogooOol2000017oo0000000017oo00<007oo00000Woo00<007ooOol00Woo00D007oo001oo`0000Eo
o`03001oogoo00]oo`05001oo`00Ool00003Ool100000003001oogoo009oo`80009oo`<000Ioo`04
001oo`00Ool300000goo00000003Ool30003Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00L0
07oo000007oo001oo`020009Ool00`00Oomoo`06Ool20002Ool01000Oomoo`000goo00H007ooOomo
o`00Ool20008Ool01@00Oomoogoo00000Woo00X007oo000007oo001oo`00Ool0009oo`800005Ool0
0000001oo`0200000goo001oo`05Ool30002Ool20003Ool20005Ool200000goo001oo`06Ool00`00
Ool00005Ool00`00Ool00002Ool01@00Oomoogoo00001goo0P001Goo00<007ooOol00Woo0P001Woo
00T007oo001oo`00Ool007oo00000Woo00H007ooOomoo`00Ool2000017oo001oogoo0P003Woo0`00
17oo00<007ooOol00Woo00<007ooOol00goo00<007oo00000goo00<007oo00001Goo00<007ooOol0
0@0000001000Oomoo`002Goo00D007ooOomoo`0000Eoo`03001oo`0000Qoo`03001oo`0000eoo`03
001oogoo00=oo`03001oogoo00aoo`04001oogoo0005Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool2
0005Ool02000Oomoogoo001oo`00Ool20002Ool20008Ool00`00Oomoo`04Ool20005Ool00`00Oomo
o`08Ool01@00Oomoo`00Ool00P001goo00@007ooOol000Ioo`03001oo`0000Aoo`07001oogooOol0
07oo00000goo0P002goo00<007ooOol027oo00@007ooOomoo`8000Qoo`04001oogoo0007Ool00`00
Oomoo`09Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`03Ool20003Ool00`00Oomoo`02Ool10000
0008001oo`00Ool007oo001oo`8000=oo`<00003Ool007oo00=oo`04001oogoo0004Ool20003Ool0
0`00Oomoo`040002Ool00`00Ool00004Ool01000Oomoo`000Woo0P0000Aoo`00Oomoo`<000=oo`04
001oo`000007Ool01000Oomoo`000Woo00<007oo00001Goo00D007oo001oo`0000=oo`04001oogoo
Ool20002Ool00`00Ool000020007Ool00`00Oomoo`02Ool01P00Ool00000Ool000=oo`03001oo`00
008000=oo`03001oo`0000=oo`03001oo`0000Eoo`8000=oo`04001oo`00Ool30003Ool200001Woo
001oogoo001oo`80009oo`05001oogooOol00002Ool01000Oomoo`000goo0`000goo0`0000=oo`00
00000goo00D007ooOomoo`0000Aoo`07001oogooOol007oo00000goo00<007oo00000`000Woo00<0
07ooOol00goo0P0000=oo`00Ool017oo0P0000Moo`00001oo`00Ool00003Ool01@00Ool00000Ool0
10000goo00L007ooOol007oo001oo`0100000006001oogooOol007oo0P001Woo00<007oo00000goo
00@007ooOol000Ioo`04001oogoo0003Ool00`00Oomoo`06Ool2000017oo001oogoo2P0000=oo`00
Ool0100017oo0P000goo0P000Woo00@007oo001oo`<00004Ool007oo0002Ool01000Oomoo`000goo
0P0017oo0P000Woo00L007oo001oo`00Ool00002Ool01000Ool0000017oo00@007ooOol0009oo`03
001oogoo00Moo`05001oogoo001oo`0200001Goo001oogoo00000Woo00X007oo000007oo001oo`00
Ool000=oo`03001oogoo0080009oo`8000=oo`03001oogoo00Uoo`04001oogooOol300000goo001o
o`03Ool00`00Oomoo`05Ool00`00Oomoo`020004Ool01@00Oomoogoo00000goo0P0017oo00<007oo
00000P000Woo0P000Woo0`0000=oo`00Ool01Goo00<007ooOol01@000goo0P000Woo00<007oo0000
0`000Woo0@000Goo0@0000001000Oomoo`002goo00<007ooOol09Goo00@007ooOol000Moo`04001o
ogoo0009Ool00`00Oomoo`05Ool01000Ool000002Goo00<007ooOol057oo0P004Woo00<007ooOol0
0Woo00<007ooOol01goo00<007oo00003Goo00@007ooOol000Moo`03001oo`0000Eoo`06001oo`00
001oo`000goo00<007ooOol00Woo00<007ooOol01Woo00<007oo00001Woo00<007oo00000goo00@0
07ooOol000=oo`03001oogoo00=oo`80009oo`<000Aoo`<0009oo`800003Ool007oo009oo`03001o
ogoo009oo`04001oogoo0005Ool00`00Ool00003Ool100000003001oogoo009oo`03001oogoo00=o
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`<00003Ool007oo009oo`P0009oo`03
001oogoo008000=oo`03001oo`0000<0009oo`03001oogoo00Eoo`04001oogoo0002Ool30003Ool0
0`00Oomoo`04Ool00`00Ool00003Ool01000Ool007oo0P0000=oo`0000000goo00<007ooOol00P00
1Woo10000Woo00<007oo00000P001Goo00@007oo000000=oo`03001oo`000080009oo`800004Ool0
07oo0006Ool01000Ool000002goo00<007ooOol00P0000=oo`00Ool00P0000Aoo`00001oo`800003
Ool00000009oo`05001oogooOol00007Ool20002Ool00`00Ool00005Ool2000017oo000007oo0P00
1goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00D007oo001oo`0000=oo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo00Aoo`04001oo`000004Ool00`00Oomoo`0100000004
001oo`000004Ool00`00Ool0000300001Woo000007oo001oo`80009oo`04001oo`00Ool200001Woo
001oo`00Ool000Ioo`03001oogoo00=oo`800003Ool007oo00=oo`05001oogooOol00002Ool20004
Ool40002Ool01`00Oomoo`00Ool007oo00<000Aoo`05001oo`00Ool00009Ool300000goo001oo`08
Ool00`00Ool00003Ool20002Ool01000Oomoogoo0P0000=oo`00Ool00Woo00<007oo00000Woo00<0
07ooOol00P000Woo00@007ooOol000=oo`03001oogoo00Ioo`04001oogoo0005Ool01P00Oomoogoo
001oo`800006Ool007oo001oo`000Woo0P0000Aoo`00Oomoo`<000Aoo`03001oogoo00=oo`03001o
o`000080009oo`8000=oo`05001oo`00Ool00002Ool01@00Ool007oo00000goo00<007ooOol01@00
00Ioo`00001oo`00Ool200000goo001oo`0200000goo001oo`03Ool20004Ool00`00Ool00004Ool2
0003Ool00`00Oomoo`02Ool100000003001oogoo00Aoo`8000Qoo`05001oo`00Ool0000<Ool01@00
Ool007oo00001Goo00D007ooOomoo`0000Yoo`03001oogoo00ioo`03001oogoo009oo`03001oogoo
00Ioo`03001oogoo00Moo`03001oo`0000Aoo`03001oogoo00ioo`05001oogooOol00008Ool00`00
Ool0000<Ool200000goo00000002Ool00`00Oomoo`02Ool02@00Oomoogoo001oo`00Ool00004Ool2
000<Ool20007Ool20006Ool20006Ool01000Oomoo`000Woo00<007oo000027oo00<007oo00000goo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol027oo0P000goo00<007oo
Ool00Woo00D007ooOomoo`00009oo`04001oo`00Ool100000005001oogoo001oo`020002Ool02000
Ool00000Ool007oo0002Ool00`00Ool00002Ool400000goo001oo`04Ool00`00Ool00003Ool00`00
Oomoo`02Ool20003Ool40002Ool01000Oomoogoo0P0000Aoo`00001oo`8000Eoo`04001oogooOol2
00000goo00000003Ool01@00Ool007oo000017oo00H007oo000007oo0002Ool00`00Ool00003Ool0
0`00Oomoo`02Ool02@00Ool007oo001oo`00Ool0000DOol01@00Oomoogoo00001Woo0P000Woo00@0
07oo001oo`800004Ool007ooOol2000:Ool00`00Oomoo`02Ool01000Ool007oo10001Woo00@007oo
000000Eoo`04001oogoo0003Ool00`00Oomoo`0400000goo00000002Ool00`00Ool00002Ool01000
Oomoo`000goo00<007ooOol00goo00<007oo000017oo0`0017oo00<007oo00001Woo00D007oo0000
07oo00<00004Ool007ooOol400000goo001oo`0100000008001oo`00Ool007oo001oo`@00003Ool0
07oo00=oo`08001oogooOol007oo001oo`@000=oo`8000=oo`800003Ool007oo00H000=oo`800003
Ool00000009oo`03001oo`00008000Aoo`8000=oo`<0009oo`800005Ool00000Ool00003Ool20006
Ool01000Oomoogoo0P000Woo00<007oo000017oo00<007oo00002Goo00<007oo00000`0000Aoo`00
Ool0009oo`D000=oo`03001oo`0000Aoo`03001oo`0000800003Ool007oo00=oo`05001oogoo001o
o`030002Ool00`00Ool00003Ool300000goo001oo`03Ool20008Ool30003Ool200000goo001oo`06
000017oo001oogoo0P000Woo00<007ooOol00goo00<007ooOol00Woo00H007ooOomoo`00Ool30008
Ool20004Ool3000017oo000007oo20000Woo00@007oo000000=oo`03001oo`0000Eoo`40000000H0
07ooOomoo`00Ool30008Ool200000goo001oo`040002Ool01000Ool007oo0P000goo00D007oo001o
o`0000=oo`03001oogoo01aoo`03001oogoo00Eoo`03001oogoo00=oo`05001oogooOol00002Ool3
0006Ool00`00Oomoo`04Ool01@00Ool007oo00001Goo00D007ooOomoo`00011oo`80009oo`05001o
ogooOol00003Ool01P00Oomoogoo001oo`800003Ool007oo00Aoo`800003Ool007oo00Aoo`03001o
ogoo00Yoo`800003Ool007oo00Ioo`03001oo`00009oo`03001oogoo00Ioo`8000Eoo`03001oogoo
00=oo`03001oogoo00=oo`05001oogooOol00006Ool01@00Oomoogoo00002Goo0P001Goo00<007oo
Ool017oo00<007oo00001Goo00<007ooOol00@0000001P00Oomoo`00Ool000Moo`800003Ool00000
00Eoo`03001oo`000080009oo`800003Ool0000000800005Ool007oo001oo`0200001Woo001oo`00
Ool000=oo`800004Ool007ooOol200000goo0000000300001Woo001oo`00Ool0009oo`<0009oo`04
001oo`000002Ool01000Oomoogoo10000Woo10000goo00D007oo001oo`00009oo`05001oogooOol0
0004Ool200000goo001oo`02000017oo000000000goo00H007oo000007oo0002Ool00`00Oomoo`02
0003Ool00`00Oomoo`02Ool01000Oomoo`000goo0P000goo0P001Woo0P0000Eoo`00Ool007oo00<0
00=oo`800003Ool00000008000Yoo`D0009oo`80009oo`<0009oo`06001oo`00001oo`000Woo00H0
07oo000007oo0002Ool01000Ool007oo10000goo0P0000Qoo`00001oo`00Ool007oo0P0000Moo`00
001oo`00Ool00004Ool00`00Ool00004Ool200000goo001oo`0200000goo001oo`0100000004001o
o`00000:Ool20004Ool01P00Ool00000Ool000Eoo`<00003Ool007oo00<000Aoo`04001oo`00Ool2
00000goo00000004Ool00`00Ool000060005Ool2000017oo001oo`000goo00H007oo001oo`00Ool2
000017oo001oogoo0`0017oo00D007ooOol007oo008000Ioo`800003Ool007oo009oo`80009oo`03
001oogoo00=oo`04001oo`00Ool20003Ool01@00Oomoogoo00000Woo0P0000=oo`00Ool00Woo0P00
00=oo`00Ool00P000goo0P0000Moo`00Ool007oo001oo`020002Ool02P00Ool00000Ool007oo001o
o`000Woo100017oo00<007oo00000Woo0P0000Aoo`00Oomoo`80009oo`03001oogoo009oo`03001o
ogoo009oo`05001oo`00Ool00002Ool30003Ool01@00Ool007oo00000Woo00<007ooOol00`000Woo
0`0000Eoo`00Ool007oo00800003Ool007oo00=oo`03001oo`0000800004Ool00000Ool50002Ool4
00000goo001oo`0100000003001oogoo00Eoo`03001oo`0000<000=oo`03001oogoo009oo`03001o
ogoo00Eoo`04001oogooOol40007Ool200000goo001oo`06Ool20002Ool00`00Oomoo`06Ool00`00
Ool000020007Ool01000Oomoo`000goo00@007ooOol000Aoo`04001oogoo0003Ool00`00Oomoo`06
Ool200000goo001oo`07Ool30008Ool01000Oomoogoo0P000Woo0`000Woo00<007ooOol0100000Eo
o`00Oomoo`0000=oo`03001oogoo009oo`@000Moo`80009oo`800004Ool007oo0004Ool00`00Ool0
0002Ool01P00Oomoo`00Ool000Eoo`03001oogoo009oo`<0009oo`04001oo`00Ool20009Ool01000
Oomoogoo0P001goo00D007oo001oo`00009oo`03001oogoo009oo`03001oogoo00Moo`04001oogoo
Ool20004Ool00`00Ool00005Ool100000005001oo`00001oo`050002Ool70002Ool00`00Oomoo`03
Ool20004Ool00`00Oomoo`02Ool01000Oomoogoo0`0017oo1P0000Moo`00Oomoo`00Ool00002Ool2
00000goo000000050007Ool30002Ool00`00Oomoo`0300000goo000000070002Ool01@00Ool007oo
000017oo00<007oo00000`0000=oo`00Ool00P0000Aoo`00000000Aoo`04001oo`00Ool20002Ool0
1@00Oomoogoo000017oo0`000Woo00<007oo00001goo0`000goo00<007oo00000goo00<007ooOol0
0P000Woo00<007ooOol00P0000Aoo`000000009oo`03001oo`00008000Aoo`05001oo`00001oo`02
0002Ool4000017oo001oo`001Woo0P000Woo0P000Woo00@007ooOol0009oo`P0009oo`03001oo`00
00800004Ool007ooOol;0002Ool00`00Oomoo`0200000goo00000002Ool00`00Ool00002Ool10000
000:001oogooOol007oo001oo`00Ool200001Goo000007oo00000Woo0`000Woo00@007oo001oo`80
0003Ool007oo00=oo`800004Ool000000002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
ogoo00D00006Ool00000001oo`000Woo0P0000Aoo`00001oo`<0009oo`08001oo`00001oo`00Ool0
009oo`04001oo`00Ool3000017oo000007oo0P000Woo0`0000Aoo`00001oo`@00003Ool00000009o
o`03001oo`0000@000Eoo`800004Ool007oo0002Ool20005Ool01000Oomoo`001Woo00D007ooOol0
07oo00@00003Ool00000009oo`<00003Ool000000080009oo`05001oo`00001oo`0600000goo0000
0003Ool00`00Oomoo`020002Ool00`00Ool000020002Ool200001Woo000007oo001oo`80009oo`07
001oo`00Ool007oo00000goo00<007ooOol00goo00@007ooOomoo`800006Ool007ooOol007oo0P00
00=oo`0000000P001Woo00<007oo00000Woo100000=oo`0000000P0000=oo`00Ool00@0000001P00
Oomoogoo001oo`8000Yoo`05001oogooOol00002Ool30003Ool01P00Ool007oo001oo`<00003Ool0
07oo009oo`8000=oo`<000Ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Eoo`03001o
ogoo00=oo`04001oogoo0002Ool20005Ool3000:Ool20002Ool2000017oo000007oo0P000goo0P00
17oo00<007oo00002Woo00@007ooOol000Ioo`04001oogoo0006Ool01`00Ool007oo001oo`00009o
o`<0009oo`04001oogoo0002Ool00`00Oomoo`06Ool01@00Oomoo`00Ool00`0000Aoo`00Ool000eo
o`<00006Ool007oo001oo`001Goo00<007ooOol00goo0`001Woo0P000Woo00D007oo001oo`00009o
o`03001oogoo00=oo`8000Eoo`03001oo`0000800003Ool007oo00<0009oo`03001oogoo00400000
00H007oo000007oo0007Ool6000017oo001oogoo1`000goo1`000Woo00<007ooOol00`0000=oo`00
Ool01`0000=oo`0000000goo00<007oo00000P0000=oo`00Ool00`0000Moo`00Ool007oo001oo`04
00000goo000000020002Ool20002Ool200000goo001oo`030003Ool400000goo001oo`02Ool00`00
Oomoo`060002Ool00`00Ool000040003Ool01000Ool007oo0P0000=oo`00Ool01Goo0P0000=oo`00
000010000Woo0P0000=oo`0000000P0000Aoo`00Oomoo`<0009oo`800006Ool00000001oo`001goo
00<007ooOol00Woo00<007oo00001P0000=oo`0000001Goo10000Woo0`000Woo00@007oo001oo`80
00=oo`<00003Ool0000000@00003Ool0000000800005Ool007oo001oo`02000017oo001oo`000Woo
00<007oo00002P0000=oo`0000000Woo00D007oo000007oo0040000000D007oo000007oo00T00004
Ool000000002Ool01000Ool007oo1@0000=oo`0000000`000Woo0`0000Eoo`00Oomoo`0000=oo`80
009oo`<00003Ool0000000800003Ool0000000800003Ool0000000D00004Ool00000Ool70002Ool4
0003Ool01000Oomoogoo0P000Woo00<007oo0000100017oo100000Aoo`00Ool0009oo`L0009oo`<0
0003Ool00000009oo`<00003Ool007oo00@0009oo`@0009oo`D00004Ool00000Ool200000goo001o
o`0300000goo001oo`050002Ool00`00Ool0000500001goo00000000Ool007oo00<000=oo``00003
Ool00000008000=oo`03001oo`0000@00003Ool007oo00d00003Ool0000000@00004Ool00000Ool5
00001Goo001oo`00Ool010000goo2P000Goo0@0000001`00Oomoogoo001oo`00009oo`@00003Ool0
07oo00<0009oo`8000Moo`L00006Ool00000Ool007oo1P000Woo00H007ooOomoo`00Ool20002Ool2
0002Ool2000017oo000007oo0P000goo00<007ooOol00goo0P000goo0`0000Aoo`00001oo`800004
Ool000000006Ool30003Ool30006Ool20002Ool20002Ool01000Ool007oo100000=oo`0000000Woo
0P0000Aoo`00Oomoo`<00003Ool007oo00800004Ool007ooOol20005Ool01000Ool000000goo1@00
00Aoo`00Ool000Aoo`80009oo`03001oogoo00=oo`03001oogoo00<00003Ool007oo00=oo`03001o
o`00009oo`03001oogoo00@00004Ool000000003Ool20004Ool01000Oomoo`000Woo0P000Woo0P00
0goo0P0017oo00H007oo000007oo0002Ool3000017oo001oogoo0P0000Aoo`000000009oo`07001o
ogooOol007oo00000Woo0@0000001@00Ool00000Ool0100000Aoo`00Oomoo`800003Ool0000000D0
0003Ool0000000H00003Ool0000000H00003Ool0000000H00003Ool0000000d00003Ool000000080
009ooa000003Ool007oo00<00004Ool007ooOol400000goo0000000300000goo0000000300000goo
001oo`0600000goo001oo`0300000goo0000000@00000goo0000000300000goo0000000600000goo
001oo`02000017oo000007oo1`0000=oo`0000003P0000=oo`0000000`0000Aoo`00001oo`H00003
Ool0000000800003Ool0000000L00003Ool0000000/00005Ool007oo001oo`0200000goo00000003
00000goo0000000?00000goo0000000:0001Ool100000003001oo`0003L00003Ool0000000h00003
Ool0000001400003Ool0000000P00003Ool0000000D00003Ool0000000<00003Ool0000000<00003
Ool0000000D00003Ool0000000<00003Ool0000000T00003Ool0000000<00003Ool0000003800003
Ool0000004P0005oo`40000000<007ooOol0ogoo7Goo0@00003o000Q00000001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0263022, -0.0250052, \
0.00366761, 0.00593432}},
  ImageSoundCache->{{{0, 287}, {176.938, 0}} -> GraphicsData["MacintoshSound",
   "\<\
00400@050000X001P540000001@0000000100200000000000000000lhM?4/Z2=
NVMD@c8T5`d60@011@`E8BloDF=gRYf``M7OjoCkooomn?7VfLZjZ9F1KU]9>2PK
40P200032Q<N;3a>H7>7VjfocmkZm?[nooghlNKIb[VWU81/FDLf9QT?1`800@D<
5B8`@E=VNHfQ]<GEhnkgo?ooo?G/h=;2/9f9MF5>?B`N4`T300032A8N;3a>HGF9
W;32d^3/mOcooocfkN7C`k6NRWEQCS`/7Q890`000`XC82hoDFAiSJ6da]KTkoSm
ooojlnWLcKbYUH5]FDHd9AP=1@400@L?6RPhBUeaQYZ^`=7Pk?GlooolmN_Od;n/
VHA`FdPf9QT>1P400@L?6RPhBUibQib_`]?QkOOmoooklnWLc;^WTgiZED8a8AD;
10000`XC82m0DfQlTJJibm_Xlo[oooggkN7B`JjJQG1KAcDU5`d50@02214N;CiA
IGZ@Y;S:f^Scn_oooOK]h=6o[9R2KEQ5<b<E2`@000<:524a@eM/PIJ[_m3Pk?Km
ooojl^OIbKJRSGMRCSXY6`l60@021a0M;3eAIG^@Y[[<g>[do?oonoCYfl^hY8mi
I4lk:Q/?1P400PPA7BdoDVMmTjRlcmo/m_gooo[bi]O6/ij8LUe8=B@F2`@000@;
5R@eB5abR9jcamSVl_[ooocejmg<^ZF?NF=>>RTJ3PD100<9524bAEY_QYbaaMOV
l_[ooocejmg<^JB>Mf5<>2LH30@000@;5RDfBUmeS::gbmcZmOcooo[biMK4/9Z4
KEM2;alB20800@LA7Rm2EVf3V[34e^Kbn_ooo?CYf/RdWhQaFdDb8A<90P011a0N
;T5FK8>J/<GGi_;koooklnOHa[6KQ6eF@BhM40L10089528dB5ieS:>hc=k/m_go
o_S^h<nkYXmhH4Xf91D:0`011Q0M;T5GKXFL/lOJjOClookil>;B_ZVBNV=<=bDF
2P<00@H@7Bi2F6n7W[G9fn[foOonn>kPc[ZTS7EMAc8Q4PP1008952<eBV5hT:Rn
d^?`nOoono?WelB^UgmWCcXW5`/3004641h`A5YbRZ:ic]o^n?koo?GYfLJ`VH5Y
DC/X60/300464Al`AEadS:Bkd>7_nOoono?VeL:[Tg]RBcHS50P200895BDhCVEn
UZk4f>Sdo?onn>gNbkJNQVeE?RXI30@00@HA7c97GWN@Z;oDiO;koooikn3>^J69
KeM0:aX=10011Q4O<TMON96Z`MGVlocoo_S]gL^eWH=ZDS/W5PX200895BDiCfR1
Vk?9g>cgo_ollnKE`:V@MUe5<1d?1@001Q0O<DMONI:[`mOXmOgooOKYfLF]U7]Q
BC8O40H000D?7S16GWRBZl?Gj?Gmoogej=O2Zi5gGTD_7@h400474R8eC6EoVK;9
gNgho_oklN;?^J26K5<k9QD90P0331X/@EYdSZS0e^OeoOommNOF`:R>LeU1:aT;
0`022QLX?UI`RjFne>Kdo?ommNSF`JR>LeU0:QP;0P022aT[@EYdSjW2enWfoOol
l^CA^Z66Je4i91<70@0541lcBfF0VkG<h?3jookgjm[5[99fFd8/6@/200<;6Re3
GGRC[/OLkOSoooW^g/V`UWYOABhK30<00P/I;4=LN9>^amc]nOoonNgLaZjCMe]1
:aP:0P033AdaBF=oVkG=h_7koogeimBmXhQ/D3LR4@H00@LD9SaFLXjZ`mW[n?oo
nNgLaZfAMETo:1H80@05424gD6b8Y;oFjOKnoo[_g/V_U7MK@2TF2@401A4R>55]
RZK1f>[go_oikM_5ZhmbEC/U4`H00@PE9cmIMY>_bMo`noommNKB^Yn2IDT`6``2
00<>7SA=JHJS_mKYmokonNcJ`jR;KE4g8@l4008;6Rm8I86N^]?Wm_kon^kLaJZ=
Ke8h8A04008;6Rm9IH>Q_=GYmokon>_H`JF7JDdc7@d300@>83IAKXbZaMc^n_om
m>G?]YUkGD4X5@L00@PF:dAPOYfidnOfo_oijmRoXhEVBBlJ2P401A8U?EUhU[C>
i?Cmoo[]fl:VR6U<<A/;0P054RDmFWRG]LoUmOkonNcH_j>4IDP]60T100LE:T=Q
P9nle^[hookfi]6fV7UJ?B@A1@0231heDFn?[LWQl_gonnkK`ZF6ITP]60T100PG
;DMUQJG2fnkkoocbh<R[S6a=<Q/:0@075BY5Hh>R`=W]n_oml^37Zh][C30J2@40
21L]B6N7YlCMl?connkK`J>3Hd@Z50H00P`M=E9bTk;>iOKnooOWd;BEM5@g7P`2
00HD:TETQJG3gO3loo_]fKjPOei09A4400@@93iLOIjmf>gjooc`g<:TPf939a85
00<?8ceKOIjmf>gkooc_fl2QP5m09A0400@B9d9QPjC3gO7mooW[e;RHMUDg7P/1
00PH<4e^T;7?i_Ooo_CQb:V8IDDY4`D00a0U@622Y<CNl_gon>SA]99`CS4H2002
31ljFG^N_][_o?ojjmBhUWAB<aX9004;7SUHNYfnf^olooWZdkFDLDl`60L00PhR
?Ej1XlCOl_gomnG<[H]WARTB10054b]8JXj`cnOhoog`fknNNULg7@X10@/O>UYn
XL;Nl_gom^C:ZXMS@BD?0`07635AM9Rjf>klooWXd;2=JDLY4P@01QH_CW6E^=K]
nooijM2`SFQ6:14300LG<E5eVKcIl?gomnG;ZXIQ?b8=0@0:7CUJOjC5hOGoo_;M
`9ihE3<I1`034BQ7Ji2ddnckooWXcjj:I44S3P802QhjGH:WbNCgooc_ekRDKdX[
4P@01aTdEG^P`n3dookafkfILdh]50@01QPbE7VO`n3eoogaf[^GLD/[4P<021Xf
FGnUb>Cgooc]e;B?J4<T3P413250I8^`d^_kooSUbJJ0FCHJ1`0452i@MYg1goGo
oNoG]i5ZABD>0@4<8d9WSkGFk_gomN31WGE?;A<300TM>en7[M3[noogi<JRNU<`
5@@01a/hGHF/cn[kooOTaZ5iDRlD10087C]QRK3CkOcomMo0VW9::A020@`TA6^C
^]_co_g_e[B=I3hO2@04531CO:C9ioWonNG7XWU@;A8300/R@VVC^]_coog^dk28
GSPJ1P066SQNQk3Ck_golmZiTFM07`T011HcF86[cn_looCM^iAY@R4:00@E<UR2
Zm3/o?ocfkV@IShN200563MNR;7El?knl=FaQe`f5`D02B11JYFmgoKon^S9XWM=
:@l10Q4]DWbWcN_loo?J]heR>QX600PO@FZE_^3gooWUaIaaAb<;00@F=Ef9/mSb
ooc[cJIjCbX?0@8B;eJ2[M?_o_g^dJYnDb`@0@8A;UF1[M?_o_g]cjQlD2X>0@8D
<UZ6/]SboocYbJ5dB2@:00DI>fBB_N3gooSQ_Y=V>aX500/TBGFSc>_lo_3C[7mB
:`h10aDeGhfigOKon>:nTfDj60@032Q>O:WBkokmjl^QLTHQ20087dA`WlWZo?k_
dZUkCBH;00DK?f^JaNOkoo7D[7e?9``01A/oJi[6j?cnl=:YNT`U2P077dAaXL_/
oOg/bj1a@ah600/VCWf/eO;on^BoTV8f50814c=OSkgRnOoceZemCRH:00LPAgJV
dO3onnG1Tf<f508253ISU<;Vnok_cjAcA1h600d[EHJfg_Oom=R^OTdT2@0994en
[mSeooOL]8=B:0/0229;NjgGm?oggKB3DRL:00PTCGj`f_KomMV_OD`S200;:EF7
^>3ioo7AY7916P@14SARULGYoOgY`iAP<Q001Ae5MZWEm?ogfZmmBb4700h_G931
iocmj/FDH38@00HOBG^_f_Oolm>VLT0I0`8E>fbPco7on=fbOT/Q1P0@<V:Gb>cn
nn:iQU4U200=;UfBa>[nnnBkQe<V200=;ejDaN_nnn:hQ4lS1`0@<fBJbnoon=b`
NdHL104F?G2VeOGolm:RK3TC0@DPC86fh__nj/:?F2T900d`HIS:koohfZae@1L2
0aa8OK?Pn_kZ`XeF9`P043AWWm7cooCBX6Te40089eN?a>_onMf^MT4G0@@OC8Bj
iOglhkIoB1`30Q]6OKGRo?gU^X=;7@<26TEm]N;loNFiPDTL0`<LBH6iiOgkhK=j
@QL11B9ARl;[ooSIYfhg400:;5nJc_?ol/bFG2T801<lLjgNn_gV^H166@858U:=
aNkom]>OHbh:010iL:_Mn_gU]ge45`469UVEc?;olLZBEb@50AU7P[cYo_SGXVH_
2`0A>gF`hOckgjea>0l03CA/ZMcjoN>cMcdB00/aJ:GJn_gT]7Pm4P0;<FZWfo[m
h[5d>@l03SI`[^3lnmfXJS4;01=0O;WXooOCVe`V1@8LChg8lOo_`hQ:6@47:f>S
fO[mhJi_=0`04d5n_>_om<bADQh21BMOWmOioN:^KS<;01E5Q<7^oo34QdPG00Xb
KJkRoOWEVeXS0`@TG9gFnOgPZVT^204KD97=mOoW]7<e2`0FB8W7l_oZ^GPi3@0D
AHK5lOo[^WTj3@0EAhS7looY]W@f2`0HC8o=m_kT[V/^1`8OEi[Fn_cKXEdS0`DZ
Ij[Ro_K=ST/G00dkO;k_onbiMSH:01]BU]Cjo=ZOFR02235`]NWol<1m>`d06E2E
do[lfIaG7@4:=WRlk_o[]W4`1`8SH:KPo_G9Qd8@01I=Tm?jnmNHDQT03Sn3aoGn
hJEN8@49=GVnl?oV[FHV0`L`LkW^onVaJBT41Rma^NkojK1X9`<7<GFll?oVZf8S
0PTgOL?do]nQF1`03T::c_WkeI=:4`0GDI_KoOG6OcP90REV/>[oj[1V9@8:>H78
mocHUDXB01UFXN3olKac;@@6<WW2m?kKV4dC01UFX^;okkQ]:089>X?;nO_ARSl;
0BEX]Nkohj9E600FDj3QonjeJB@134:>eOcfa7P`10LfPL_in/f4>0P4;WO3m_cC
Rch:0RYb`?CmeHe02`8ZL/3eoMB<?PX3;7K3m__@QCP71C=nbo[hb7/_10TmS=Gm
lk][904@C9gRonZYF1L0766bkokKTT4:0bmkb_[haGDZ0Pe8V^7ojJMD500QJ[cd
o=21<`@9@9;Lonb[F1D08FZmmO_=OBh234RKhooUWd/>0Relc?_d^fLN01UP]O;m
d80`0`e:WnKoh9I12@DiS=[ojjIA404/OLkll[=M5P0TL/Kjm[]U6`0OJl3hn<1Z
7P0MJ;kgn<1Z7P0MJ/3hmkeV6`0QKlKjm;MN5P0XNLkmkjaC3`8bR=Woiia320M2
V^KofXLa0Q5F/?;kafhO021ab?ca[E8>0cN@h?oNS3@245Ncm?[1IQT0:GoEonNJ
?`D;CZ[`o<I[6`0WOMCoiYLl10iD/OCi_F0D0C:=h?oJQ2/06V[7o>jTAPL:CJcb
n[iP4`8fT^CodgPR02Ale_oRSC4166W7oNbN?P@@Fk_ilZY920]@/OKf/U4;24Z[
loRgE@`6AjWbnKQF30M8Z_?h]E<;24f_m_F_C0P;EKSilJA2115Qa?gZUS@16g;B
omj39@0YQn7ocF`F0SbPl?VfD@T;Ekckk9Te0AageooFMQ/1>9c_n[I?20eM`ogV
S2X0:8[Uo/AM3@QB^__[U2l09HOTo/AL30UF__gWS2P0;I?[nkI=1Q9YcooHM1P3
A:khkiTa02N<j?biCPHCK=?odVXA1U6loNB48@4kY_KaVc40:Y;]nJe00Aj2i?fk
C@DFM=_oaEP846_Dol]O2`eUd?o?H``<Hlood6<<36CAoleP2PmYeOo8F0LCL]cn
_dh46WoTnk910BB?k_JP<@0cXoO/Rb02B;[ng74A2V;BolID1AV1ioVX=P0bY?SY
PaX5E<SocE/75gkWnJHb03R]nn9f4PYVf?ji@`0ZWOKZPaP6GM7o_dP19i[fjh8G
1f7Eo[Q0032Vn^9c3`mchoZT;@15__o=E@<QUOG[Oa@:JmokYbh0Al;oadd1:Z;j
h6`:5H?^lHXI26SNnj@Z0E3<okTl03fjolY=0BjZoMML12>LnN1X1abBm^Ia2aN;
lnUg3AF7l^]i3QB6l^]h3AF9lnQc2aV@m^A[1anIn]aP12NVoM9A0CBfol=004G8
ok0^0U_KnYLL2WK/kWX<6ICifeX2<KGo_cT0D]GkVQ`;N^oZK`LTY_k:@`1;dObL
70]mlNIW12bcok/c0V3Rlh0<79kmbd80DMSiSA4FU__@A`1>eoV<41RJoL]005SO
m7h:8j_o^Rh4KnkWH`4iaofJ5a>Do</m0F7WkF/3=LCnVQDEV_k3<`A`l>9G04[H
mW`7;;_oWaLEWOjl;0MommA30FC[iUX0CMgbL0<jc_V322booI<?8K;oX1DJZ?nZ
6aFPok0O4Y_o]24@VOnd8A6Jok8O4Yoo[A/FY_nT5Ab`oiT?9KgmRPPbboQg0T?K
kf40F>[QBP5am/db2Hon/Q/I[onA2C;?mF/0E>[OA0=nnkdQ5J_oT0PgeO1N06Od
cBh=W_nJ2c;BlEh0J_K79a>[oXT4A>;SA@B9ojP@;<oaG01cn[XJ8<;gJ@1Xml4O
7;khJP1Zn;hK8LGeH01go:lB;]G[B`B@oi@5B>[E;A>dnV`0LOb^3cCMhS/<Z?ee
06ck[`lgh=dc4KGiH`22oiH4DO;36BWFiCX>/_UQ0HWoR@5SnZh<@N_<7RKFhcDC
_O=>1jClI`6<ogl0MOnD0V;kY@IBm[@<AO2o4Sc[aaLei/dJ<>?@7BkRdAd^h]0L
<>C=6CCXaa@kkKl?AO>d2E;iY@ARoI<0M_mn08gnI@BVmd/>`NXa7m[D6SW_]`QJ
o980P_mX1:cc?aOCf1/jlZh4J_mj0J3gA1KCeQQ2mZ01O_mP2;kV9S7_[`=dofH7
_>HT=O:V0H7nE@o?eA=?oHD1Yo0`;>j[0HClC1OLa0Q[of4<c]<?G?m]2<KH4UOo
KPS7eQ1MofH<dL`9KOmC5n6g0XSi>2ccUP2]iQY@ofP=el43QOPd<_R60l?C2W?m
@2WdS@;0e0UgncPbnGd7dL42To0PD?mF7>jE0/?=1H[c8U7oD2?dQ@OE]`2Yg`ai
n2Q=oddXn7H?i9h2b<40Z=d9Q_4II_`^B_m5<oeM8?Ie4nf:2N6L1=F/0LVi0;o3
0;K;0Jo@0J[D0ZOE0ZOE0ZSC0Jg?0K?90;_00<Je0M6W1=fF2^Z24oA[8_aB=Olj
CodRKO8?S]l3//80did:kW<QoDM5oR5dk0NWa`3EUA3fFcOo9fo/1Zjm0^Al8?hi
G?@;Y/81i7PVobi^j@>oY@cgCd_h3JFm1>iP?O`CWL83kUi1nPjY]@WgBES_0lNB
7?lUQll1kEY<l`C7Sb;o6Ybj2_/gM]L1kE9Ij@3OJ4Gc0]Af>oL4cW/hn0C@Mcge
0]Q[BNh0iEIOgP7d>X343?lLZI`Vo0GEIeCR0OL_U:dMo@KFHUkH1_dK/hPmk@3e
;IjL;o@0lS6KW37a0?HWZhU3i0Cn4/]RJl<Ho07_;ZR6C=T<o`CX=Z:8C]D@o@7c
8kaXLK@[k0Co1NX/]F]b[SCS2od0nA;J?JQdKj/kfAGf0_l2mAGK=[INRhUR/CcB
7n/;nP7o0?d7la?T9=8g_TbYH9EcPhEbU6BREje=]TFm?l8kaSS7=lLhaS_2?ke5
]Tf]F:5TTg>3QG6HGJa8`C?F8>P?mPCn0?h4mA?Q;<9@VgY_Yd;A7O05o`7h4mXl
ZGA]/C?T2_h0mQ[;E8NN?]l;o`;_:k5gGLXFn`3b:Jj0D=P:o`WJD7bg7_/1jSj<
[2?j0NM6O[`Eo`[?Je?R0OP^Tk0Ho`k1Q3Of0]]VC^/0iUUHi`3VFe;/0=a^?_P6
`i8PoafE``GcCeCa1<2M5?diI^/2`j0?nDY>n0nLb`3KRAOkBdKm7GcW1Jc50=6Q
1nV05_IU9_eB<om5??m0@?m0?_m6=_iC:O]X6O642]jW0;o=0i;^6UcoB2OeR0C7
c@ImnST]mI01/^@JCOig1KkP6DWlR02TlcHSiKl9G_j409CkE@ZkkCLJdMlX9=[I
9BGHgR`Lbn]03JojI@21oi/7ANSH<PnXoXD3B^KP@`B2o;/Q4j?oYAHKZonW6QBK
o[l`1G7_iV@2<[[o]S42F]WkWR<5H=WlZS40@KWnefH;3fgIolAG20mUcOoMOR40
;H_QomEm9`0JIkohn<=`9@4@BYWMo_?1NSH:0AeCUM3fonZoQThP1@4B=66B_n;h
ooSUb:F0GCdS40@00PTE93E7FVamSI^X/kc4bm3Ce]OHemKCcl[3^k:VVHYjJ5E2
<1h@1@012AXbDGFK`>3gooSP^XUE:0T04CYd/^Gnm/^9@Ph07f:ak_kHRSH33U>a
mONdD0P<G<GogGDE1e[=ol=90Bn[o]5@03[2ojPQ2hKid3d3M?K@=@R@ojH?;]C[
BPJIog/0M_n?07;oP`2>oEP<aMlKAO^60[GQ5EcoDQo`S@GC]@2kb02cb`2l_@3D
VPcbHS?o8H7J0=ie<o`=]Y/Po`jnQSSc0>dkSjL[lP3k5/eCRYI<bb7/2_/1o`3o
0Oh1oP3o0?h4mACL=jm_K[DYl07l6<1dDN02nBbA^0on9X_90nmL@?`FS=X1_[L1
djL2d[40^]86PoLa=?NB09kf@1SCg2@VfMlb4kGkLP1Fj^5>05[RlW`<68gckHLM
0dF_moB^D@h2:gBml?o]`H]F:`h10@/K;T5BHFadMgMcJUi??2TF1`045cY/YM[k
nm>;?0H9BZceli`^04;0okL_17CddcP8Uon90FOmU022oU<Dg[H0Xn8;R>T:V]<0
dh/OoabPZa_n1]e:RYa4dac]3OD:la3V:<9LOJdWm`3VDekV0=J86O]A=?m@9oJ5
0k[U92kVcR0Pa?Qe0cO2okPn02J6g_oUYEhV1`097354DEUIDTDc7PX01RIOZNWo
dg4D26ORlgL3@^;L;AkIcPeWoShjocaDmPVkTRcg0?DMccnhA/4^i0So3<Ul<odH
Q^H:QOD]<Njj3cKIl6`499K`n/9d<`d00P/B51490@4EA8gKom9O12o4n6L1V_Lf
=_i@?OdA]8a0gQ7d2^lP`79;k`>k^`2`iB8/fnUI03>SlOgL[HE[HFIkX<ognKU7
04SQgRT^mH4AmdMZcAGf1_DHa7TgoRIFof/2QOc@F`d27T1EF4PX1`A3^OnM1Uoo
C3cm2]E6/4?I1_Q?<_ZB0TcEom>EJ5IMO[Oclh@5E?eV9_l>fRcP1o]4>OVT3aUi
an[dk]2:9PJ?oD55mP3l0O`]HoiS04JXgNgV`F/:;nJT2Od>m03USP1kl?_Sg?7n
^1dkobFfAN80Y_V6:0X99X;hX`;a8N`0^naU5PD<@<?^5ZQ[^`C1n[NAZ^oN68jF
RQcSk[2WgOQ9Bm5D=^Siio[R:7>SVP9c_:m82_8Gof0500nIhP[;dei>Y_X;nb8=
905Ti3<i[j`aA/FZ7aEhm`JHmN]IDG3lolX0nJN3kVCF?TW^9OOnf`3HonD3l_Oc
1=kkPVd00m`01Tf?k7B94WZ;lgbPC?L;3?]^i0@</b;<02Fe[44Pno`VGfY8_jVH
lRog_d88]@TDICMR0O[1g<937UXQ9Ol0f;XC6Hodh3dUo`3MkNOT2EThL00lK2[n
d^IM:;ieg2H4B/O/0OG_iU1m=0l0SkXOoio1OlXffo_nVE4Ejc49j0bENECM1ol2
G:5I^jH?n39MI=e4F`bR_1PRk`K_53S02MI?ZPgeoVf60Ki@eKo1@L;o2aOmJC@j
0k0G_F2>mCa=4PFFWoeocN5>Z=7`eYP0gaI7obaN3lWoUB9^0n7ekocA_B<_jd=f
o`5E>LSJ=H811h3e2n00C0n53KP23@1D[@AOVOUcoaB<<P0Vg0GM;`d0oh4]0=n`
d07iC3C23B[m7FT3o`OmCg>BI_l0igEFG]IGfoH7YgL9o2USm`Gj6`<:o5Rc<SC9
g05>0_U^U?H7T?Ool9L@<]oREPP00C_c=_AF?<EnjkWo06XVZ0]@^?]KnOl049LD
eAk21X`0I`6=5_gW70G/D]l10LlUTUbd2ocoFOO_U<j]lCL3Jj7onAOmmm`<HW@0
og1VnPkDkgTmG<bH0?m/<iCT;2YO56BNi8J[o@[oR4Z@oPOmTDAan4jo04]X7Rcm
2Holo_Qf6?@m7hfTFP38FMH7<G1K2T_l0?620`lE04gn;LP=i]UeDgWNhPc1@^`>
A<;_kl533>EKUD3mAP=9OWTn05go;Z1Pc`2/o:=C>4^Bl]0@Q/HPe68dnZHL0ATT
4`0`aN/JP/<Te5M?oU05M=[mooojcf41Hom8D^@:m1jV_`2GoY@O018U9A807Hcl
[0>@g`3^9m<MnPJbc@MMmMQP400=6AL901agj>Q73mFc0^]<PIURRYlWob9SoUT6
T_gAIAP01Q@I4`D06fWCoYX;@_BI0]>G6Ol;gc3=9n`1mT1JnB9=oH`1E^K`RB@0
5D=_SYfLS6`o4P0VRNk/J01Uo940[mP3];0>oaK7F9=dTE_16od7`iX?lWX<elP?
ANcE>P9Of?o:L2L30aD^@dmBBSPQ2P0@AISXo;Dj05WXh3`>^n/Z>?]`5_ET<_hD
[9T^lP7n1_<?lPSm0?PQ[i4ZoA:Mb`35_02Xiahnm:l:A>KPB01Jg?ZV=@0NL<?e
o^FjS6=4;R0I5aTP;45OQ[?Nno_DRSH25FoIo[0`0fW^gT85U?mm08_mE1?L^02U
g@JLe`35X17m<H772olCaf=b/CCN5O4;mP_a5]de/79TaQGn2=1a@_D5`i`AnE@h
oc]3od/XmXP2^N@P=o2g2dS`aalL^ob31bnnojd[0U?:olmU4@A0VnKoiJMO90@2
6Cm/UkcHk?Snooomo?_loOkooo_bhl^[Q5P_3P0:<Ffbj_oTWTL924Z_mnnE:056
`Ono>`1Ggo9a0T7KkEH1O?jS24[b^`e:mj81OOiE4]Zo0h[d9DgoBC3mF2_nCC_o
;FK`2:ne1oE;F^/0gFM<j`3^?h>f7?`1k3:VPUO87_84o`3k2^hGhR;K9]XRhAW]
3?T1o`;f5m99Ti95g0Wo2MUFL<L>oa>hSBkk1lJ9:?lEWkd5lE/ooAZ6g`:i^P7E
X0GOV@KKY@79`@6QiQARoddNjZT0T_Ll8NBo2EknRP26og40S_mh07SnWPM4imXf
2icoW0dZa?^31bo1oYTE59?ke500>K_oa4H0<:Oji7XF1UC1o^618P0^S^?oe7`X
01IM/_3nfI953`0KEY_Hn_cNZfhg400794j0[mOboog]e;BAKThb70d3004741/X
=D=@G6MaNX67S8n@T8n=RH=lM6]PE4Pj;B0E2`@000HB8cYFMYNienklooCL^HeO
=18111]5Nk?Qo?cP[6``2@4MEikMo_C3N2l423f>fOo[YTh=13VDi?oCMal0;XoW
oL1G2@iSc_oAH`/?K]cm]3d0=:kmeeh48igkfU`2;[;o_cL1GN7cNPPX]OnW6a:I
o[TU3ICn]1hEZ?nG2c3@lV40JoS07Qg1mV40O?jQ24K/cB0TdnDg4l3`A0filTD?
_^di6=3O92gX`@aEo8l0T?]=4m?B4E?nOP:bj250nXH2]^8GE?mU3m^j0I;b94So
HAGXX02ld@F;l1]PoSPnoe@VnF`GlGh?jhT;ihd:ih/=k84Blg0MnUX`oci;oB9`
k`ZNd03<X0_bI37o:G7Y0k^/2O=J@?`CV/H2jVDko16T^0SgAUk[0MAn;_d@[ZLE
ob:C_@[l;HS42O`/SKd=oanRYQgo3<An?_40jTMfa`go4kmmA^P1n2RTUSCa0?DZ
YI4ljP;l6L1^Gl`BoP;[=:::B]T<o`;];;1fH/4Pm07n2n4hZ7QU^BcX2?h0n1?J
>ja]N:17c27/2?d0oPGb5]```4nPKh2?HZ]7`c7G8>HCl@Wi1?d1o`3o0?l1oP;l
0o/4n`Gj1?/4o0?m0_h0o`3o0?l1o0Gg3>lEhb?C=Km;YfJ;PffRC/0`g1Sa1_h0
oPGa6MLj/6F2UU759^X9oP3k3mlf[fecZcSO3Od0nAGCBIB?CM8DnP3i6<aGPJLd
j0Go2Mm2U9Pmi0Ko2]Y<QJX[lP3i7[YfE]H;o`[FEg;05_h4hD]l^QWm1=iBL/D@
o`c=JeKM1?`RYiP]n07SDV_A1odOYYdUo0KBKDcZ0>e8L=85nRj<_0ko7in/5_lH
ZJ@JoaJZYAWo6J>^4_lSTkh9ncAje07_D5S[0=Mh<o`>/:TAoC1if@3UJCck3Jf_
3?Y1HN/2bY8Jobidh@3CRAko;W;T0LbE5OdnGO47/[@6kf8goQn2gP39WPkfESon
7H7Q0L2[1ne]:OlfG?H@U=H0aZT6jWPNoDY3oRE/l@fEf@6j^P7GV@[]N1[iFboo
@DGo;E_j7G7b4XCY2YCO1J;F0Zg>0;G70;_30;o00<2o0;o00;c40;O90;3@0ZKI
1I[R2H_[4GWd6fKk:U3o?C[oEBGiLA?/S`KG[`2kcP>Hj15anR]9odlVmg/;gZX0
^=@7Q_<QD_m>9?B51]6n0IcZ65goBBKdR@C9b@B8mBU3oVX?g[@0W>dNComR4^2c
09W`94GnL@[BaPEnnc`ZliH0[^HJCom^2/k=2FkoDASR]`:4nd0SjjX0T?Li9njW
093h>bG[[@67ndHKh[d5LomK3/oC4EGnO0:`k2TalJL1PoeC4=3E54ckS@2Hn4<H
fLd@DOb<09GjBQ?AeaQ1mZ81NomW1K?_=23Oba5:n9h1NOm_0jKfA1?<gb<^j<8=
C_VP0VooP02?oV85Z_I93l7Z=1cDg2@ZhLhH=n_144Cb]PY>mj`7EoVU1EgkX@AP
o9l3H?^P15kkY0EHnJX7DOJc2dOa_Q4kj/XJ;]oH9R3AiSLC_o9;2:SkI06=oh40
K_fQ1Tkb`1H`gMd`5[ocD`BHogd0K?bY2d3XdbLKa?9B19CoQ`5Mm[`G:mGX@`RP
oWh0HONl5bSAk4/5Ton@14g]dBXE]_Y]06_i^APVbo5H0GknZPl`eNa>0hKoY@hb
e^a@0X7n[18ZcO9M077i_QhK^_]g0EG]eSD:VOnK2c;Cl5`0JoK8:16Uoi<9=]G`
G@1Vm<la2iOoYA8U`_Yi0TSRj540K_K=<@ZBojlI6k7nT@X`boMd0TONk5`0G>cO
B05`mM4h1H7ka2`:Sojj90nIok4N4j3o[1XFY?nY6ANUojTJ5Z?o[A`CW_nc8@nF
o[/X2h[laS86O?OC@09Zkn1A05KSkFL1@M;hP0P[_?jM5ANPokXZ27ogeTL0FnC^
J`<hb?bD4QVQokd_1GCahEP0A]?iR@hNY_nl;`A`k^IQ0C[7oI`H4HojddP0D=Wg
Q`hKWok7?05Kh?B02anSo/Hl05SNmXH>6I[lcdL0B];lV1T>Q?GQG`8b^Onf<09Q
hOF641JAnM]H0CFkokLb0U_Ln94G3X3aj6d78Z;mdDh0>[ko^CD1DmClXB86J^Ce
RaD>O^o/N0`GSoKSJ@LPW?[KGP<WYOgEE`8/ZokADP4_[_k@D@4_[OkAE08/ZOgE
F@<WX__LHPHPUoOTK`XGRO7/Oa8>MnSeTQd6H][lZ2h1BlOo`4@0<jkmeel67I3c
k80D2fgPnZ@/0DW3olM>0RNMn>Ih4@e`hOZV;`13_?oAF`DLRnobSal4EL_oa4d2
99KdkHLK1EW>ol=<0R>Cl_2=7`=@a_o=F@HIP^WhXBl0>k3lhGDB2V?Dol5=0an;
kOJN;@0j[O_UOAL6ElWocel94W;Mo[U70R2:k?NT=00_W_G_TRL0?Jkjih@M0dVi
oN1i5`EA`OkKLQ<7ElGof6hA25S6omQ_4PMFa?oJLa@6DKonggXI0dVfo>J68@4m
Z_S^UB`0<9W`mZLk0B65iOfkD0HCK=CodFTA1e:moNF68`0fWo;fYcd17GcNolQP
3@UF_ogUR2D0<IO^nK=:1A=YcooJN1/1>j?cmZ]30aI^d_oIN1`1>Io`n;5:1Q1S
b?kRQbH0:hcVo/EP3`I:/OObY3l35F_=on659`0XR>;oc6XE0SfQl?ZhE0X9D;Ch
lZI3115Q`ogZUcH16Fk>on><;@0OMmGogXDX029lf?oLPRH097gHomb29`0RNmKo
ghL[01iddOoTT38166W8oN^L?@@@Fk_ilja<2@Q:Z_;j_V0C0SNDiOoBN2808gWC
onFD>0<AFkWhmK=E3P@lVNOodWTT021ccOg/XD@72TZWkoc8KQd09G[Ao^VM@PL:
BZK^oLac8@0OL<Wll:Y?30@kU>?ofhTb0Q5H/_?ja6`M029bb_ca[U@?0S>9fooU
VT4724>Li_oJRC@33U2Yk_kAOBX155Zbl_c:MBD05f2gmO[7LB<06F:imO[7LR<0
65nflo_:MbL055V`l?gAObh23dnUj_oJS3T52D6Fh?oUWDP<0c:3d_g`/UdG025[
_oKjb7HX0A5AYNWogYA12@DeQ]CmlKAP6P0KH[GaoM>6=PD8?HoJo^j_G1P076>e
lOkFRSX71SN6dogc^VTQ01=CYNOoi9m=404TKKgdo=:7>0L6=H??noK2LbT234FD
fok_]6@O01=AXNCojJYJ6@0HFJWXonFSE1D06ef/j_oTXE8E01]M[>[oiJAE5`0I
FJOWonRZG1/0552Nh?o^]FLS0@e4T=OmmL9g;`@7=Gk8mo_BRd0<0BAX]>gohj=G
6@0DCi_Mo_:nLbd41cAkaOGmf9E:4@0KFJCSonnhKRX323EmaOGmfYQ=500GDIcM
o_C3Nc@70bU/]NgoijaR8P4;>h;8m_gJVE0F01=:TmGknLj:@Pl06eNPg_keaH0j
2`4PGZOSoo;0NSD90R=RZ^GolKmi=@T28f6Yhoob`W`h2P4OFj?Oo_G8QD0>01UA
V=Okn]:BBaD04DB9boKmgZ=L8089<gFjkOo[]g8a208RGJ?NoOO=SDPD0153Q/Sd
o^>[IRT412QUZ^;nmLZ:AQ<04D:4a_?oik5];PL28EZNf_cjeYYF7P48<Fnbiooc
ahM54`0@?h31l?o/^WTi3@0FBH_:m?oV/W0b2@4KD9;?mokS[V/_204LDYC@mokS
[V``204KCi7=m_oV/g8d2`0FB8W7l_o/_7`m400@?Wbkjoocb8];6@49<6^[h?gj
eimN9PD385FEd?KoikIg>Pl043ej^>WomLnDEB0312AKV]?go^JeMcX?00ljM[CU
o_SEWEhX1P8LCXc7lOo`aHY<6`469ejLe?Onj;Ql@1<02c5YYmckoN:`LcP?00hg
L:gPo?cN[6le3@0?>7:^h?clgja`=`h03SI^ZmkkoN:bMS`B00X_IZ;Gn?kX^h56
60469UVEc?;ol<VAEB<50QY8P[cYo_SHYFXc3@0>=6^VfOWnjKf4BQ/211m@R/;/
ooOFXVPb3@0=<fRSe_Ook<><DR850AQ4OKKSoOcR/gY25`458U:<`^con=VWKSPA
00TZG9G:l?oedj1W<`h02bePVLgbooCAWVHb3@0;;F2Hc?7omMBRJCD@00TYFY;7
kOohfZYb?A@11B5?QkcWoOcR]X1:7@@25d5f[M_iong7Te`[2P0=;f6HbnoommV[
M3lG0P@LB7fcgo[njlFAFb/;00`]GIC7k?ojgk=mB1d40ADlKjGDm?ode:E_?1D1
11a6N[3Ln?o_c9]V=A401R5=PKGPn_o]bIQR<Pl01b9>P[KPn_o^bYUT=1401R1:
OK7Mn?oacj1[>QD10aY1M:SEm?off:ahAQd50A8eIIW8k?kki;b:EbX;00TVDHBf
goWol<nQKSdG0P8E>VZMc>konn>kRUL[30078Tan/=[fooCGZgU87`H03ReJS;gT
noo_cJ1^?QT30A8eHiG4j?gnjlRJJ3XF0P8E>6JHa^WmoN_8VVPj5P8253ISUL?X
o?k]c9m]?aX4010`G8flh_[ol]BYN4TQ200:9Tmo[mSdooSO^8UI;Pl011XnK9c9
jogmk<^OKT4L1@0=:UB3/m[eooSO^8YJ<1010aLiIIG2i__olMBZNddU2P077dAa
XLc/oOg/c:5bAAl700TSBWRVd>ono>[9WVm27PL02RA:N:K@k_kmjlZPLTDP2008
8DIcXL_[oOk_dJQjCBH;00DJ?6RF`NCjooGJ]HQJ<A<20A4_EhFbf??onnO6W6i2
7`P021m3KYc6io_olmVcQeXb4`813baCP:cCkokmk<jVNDdX3@035SENRkKKm?ok
ilNNLDHR2P056CYST;[Nm_ojiLBKKdDQ2@056CYSSkWMmOojilNOLdPU2`045SEL
R;?Gl_kmk<nXOE8/404142]ANjK=jocolmZfS64i6@H021m0JIBmgoKon^O8XGI=
:0h10Q4]DGbVc>[kooCM^i9W?ah800DH=ej8/]K`o_k`eK:8GSLI1@087CeTS[OJ
l_kmk]:^QE/e5`D021hnIHngfO;noNkD/8QN>1X600LJ>En9/MC_oOkbf[R@Id0P
2P03531DOJK;j?[on>?5WgI>:a4200`SA6^D^mccoog_eK>;HS`M2@045C1DO:C9
i_WonNO:YGeE<QH400PK>Ej6[]7/o?ofhL>NMTl/4P<02QlmHh^adnglooGP`Yee
CR`B0`097SaQR:oAk?_omn?6XGYC<AH500LI=UV0Yl[VnOojjLj/QEhj7@T00a8[
C7:I_]cco_kbfkbGL4XZ4@<02AdjGHBZc>Sioo[Zcjj8HCdP2`023RE5JI2eeNgl
ooOTb:EoFCLK20034RY:KiFif?3mooKRaJ=mEcDJ20034RY9KYBhenolooOTbJN1
G3XM2P023RE3IXbadN[joo[ZdK2<Id<U3`802A`hFGjSaN7eookbgKnMN5<c60L0
0a4XAfZ?/m;[n_ojjm:cSfY7:A4300HG<E5dVKcIkocon>K<[8QT@B@?0P086SAD
N9bnfo7mooOUbj^8Hd4U3`8021TbDWFI^mW_o?oij=2aSVY7:Q<400DD:dY/T;;A
jOWoo>oI_9YfE3@J2@023B4lG82S`mobo_ofiLb/RVI5:18400DD:TQYSJo=i_Oo
oO;N`j>0GCdR3P801aP`CW2C]=;YnOoll=c0X7eK>b4=0P07631>Ki:cdNShooga
g/>TPElo90l300DD:dMXRZc:hoGno_GTbjf<JTT/5PH00PhQ?5]lW[kIk__onngH
_IekFS/Q3P801QD[B6R:ZlWRm?komnO@/i=aDC<K2P402ATaCVj@/<gUm_knm^G=
/91_CS8J2@412AXaCVj?[lcTmOkomnO@]9AcDcDM2`401aH/AfN8Z<KOlOgon^cG
_IinGClU4@@00`lR>eUiV[WDj_Soo_CSbjn?Kdlc70/100LF:dIUQJG2g>okooc`
gLBWQfM8;AL800496Bm;JHVYa]kao?okkmc3YXIVB2dG20012AP^BFN7Y/?Lko_o
o?7Oaj^<KDhc70/200HC9d5NOIbje>Whookfim6gVGYK?RDB1@0231dcCVf<Z/KN
l?coo?7Ob:b>Ke0e7Pd300@@8SYFM9>ac>;coOojk]c4Z8Y[CC8L30801A4S>eMe
U;7<h_?moo__gLJZSFi@=Al>0`033QlfDFj=ZlKMko_ooO?Sc[BGN5Xo9Q<60049
5ba5HGnM^M;Wm_konNgJ`ZN:K4ld7Ph300<=7S==JXRV`MW[n?onmnWE_J64ITXa
6``200@?7cI@K8ZW`]W/nOonmnWF_Z>6J4`c7@d300<=7C9;IhBQ_MGXm_kon^kL
aJ^?LUDk918600485RU0FgRE/L[Pl?_ooOGVd[ZOPVE:<A`=0`0331``BFB1WKSA
iOCmoocbh/feVGePABdJ2`800`hM<T]VPYnidNGdoOoll^?>]Y]oHTP`70`3008<
6Ri6H7bI]<cQlO_oo_KXeKjTR6aA>28A1P001a<U>eA_RjO0enWfo_okl>3<]9Um
HDL`70d3008:62]2FgNB[LKKk?SoooW^gLR`UGYNABdJ30<00P/I:d9KMi:]aM_/
n?kon^oObk>IOV99<Ah>100121DV?5A_RZFne>OdoOolm>KC_JB9KU@k9QD80@04
3Qd`Af1kU[37g>gho_ojl>3=]Ib1ITde8A460006420dBfAoVK?:g^kiooojkmo<
]I^1ITdf8Q8700053ahaB65kUZo7fn_go_okl^?A^j:8KU@m:1H:0P022aPY?eI`
RZBld^CbnoonmncKak2GOF=;=24A1P001@hM<4ENMi6[`]OXmOgooOKYf<B]U7YP
B38O40H000D?7C15GGNAZ/7FioClookgjm_7/IQoIDdf8a<80@0331TZ?eI_R:6i
c^7_nOoon_7Rd;^TRg5I@BdK3@@00@HA7c97GgRAZ/3Ei_?lookhkMk<]Yj6KE@m
:AT<0`011a8Q<dUPNI:Z`MGVlo_oo_W^h<fhXHQ_Ed0/6`h400053ad_@eYbRj>j
cn7_nOoono?VeL6[TgYRBcDS50P200895B@gCFAlUJg3e^KcnoonnNoQd;^USGAL
AS4O4@L100<;5bHiCfInUjk4enOcnoonnO3RdKfVSgMOB3@R4`P2008952<eBV1h
T:RndN;`nOooo?CWf<F`VH5YDSdZ6@d400053AX[?U=ZPYZ`aMSWlocooo[`hm?0
ZY=kI4di9QL;0`011PlL;41EK8>K/LKHj??kooojlNCD`JbEOVM@>bTI3@@000@<
62PjCfEmU:Zodn?`nOkoo?GZflZfX8UbFdDb8A<80P011a4N;d9GKXFL//KHio?k
oooklnOHa[6KQFiG@RlO4@P100884Ql`@eQ^QI^aaMOVl_[ooo_djM[8]In9LUa7
<b8D2P<00@H>6bXlD6IlTjVmd>3^mogoo_S_h]:oZiEoJ5<n;1`@1`400PPB7bm2
EVb2V:k2e>?`nOkooOO]h=2mZI=mIe8n;1`@1`400PPA7Ri0E6Z0UZ^odN7^mogo
o_W`hmC3[iZ4KUQ4<R4D2P<000D=62HgBUmeRj2eb=WWl_[ooocfk=k>_:RCOFMC
?bdN4@P200463QXY>TeRMhfR]/WJj??jooolm^cOckfYUGmZED4_81<90`001@`G
9CI8G767W;33e>?_n?koo_W`iMK5/ij9M5m;>2PI3PH1008741`[?4mSN8fR]/SI
io;jo_ommnkRe<>`W8MbGDTg9aT>1P400PL@72XkCF5fRj2ca]KUl?SnookilNKH
akFRSGQTD3d/7Q480P0010`F8c=4Efb0UJVlcMgZm?_ooogfkN7C`ZnLQg=NBcTY
6`l70P011@dH9CE6FFf2UZZmc]gZm?_oooggk^;Da;:NRWIRCS`/7A890`0010/D
8Bm0DfIjSj:famOUl?SmookjlnWLcKbYUX9]FTLf9QT>1P400@D=5b@cA5MZOY:V
^L[Ii_7io_onn_;XflbkZIJ2KUY8=bLJ3`L2004531DR<45CIWZ=XKC5eN?^moco
oocek>7C`k6ORgMTDCl_8AD;10000PL?6RLfAeU/P9>V^LWIi_3hoOoonoC[gm71
[if9MV=@?RhP50/400021`hI9CA5EfYmT:>ea]KSk_Klooolm^kSe/JfXi5mJUM6
=BHI3`L200042Q<N;3]<GW64UjZkc=[WlOSmoookmNcPdl>bX8ikJ5E4=2DI3PL2
00042Q<N:cY;GG22UJRib]SUkoOmooolm^kTelRhYYB1KUa:>BXM4PX400021`hH
9392DfEhRYf_`<oMjO;io_oonoC/h=?4]::@OF]IAcLY71490`000PL>62@b@U9T
MhVK[Kk=fnOan?gooocfk^?Gb;VWUX=aGddm;R4E30D100442Q<N:cU9FVaoTJ>d
a=?PjoCjo_onn_C[h=C5]JBBP6iLBc//7a@;1@400@@;4ah[>DUJJgf?XK;2dMkY
loWnoookm^kSelVjZIR6M69A@34T60l70P000PL?62@a@51QLhFGZ;W8e^;]mO_n
ookjm>_Qe<JgYYF3LF1??c0S60h70P000PL>62<`?dmPLH>DY[K6e>3[lo[noool
m^kTf<^l[9^:N6MFACHY7A8:10400@@:4Q`X=TEEIWN9VZ^kb]OSkOGko_onnoG]
hmO9^ZZIR7MVEDDf:1dB2P@100442Q4K9cA3DV=dQIJW]lKDh>_cnOkooocgl>OL
cl6aXI1oKUe=?RlS60l80`000PH<51l[>4MGIgR:VZ^jbMKRk?Cjo_ooo?O_i]_>
`;6QT81_GTho<B@I40P300011@XB72Pe@e9SLhBEYKG4d]kXlOSmooomnO?[hMG8
^ZZJRWUXF4Pj;20F3@L200021P`D7RXgAEEUMHJFYkK5d]kXlOSlooonn_C/h]O:
_:fMS7a[Fd`m;b<I40T3000110TA6RDa?diMKWj>WjjmbmSSk?Cjo_oooOSajMoC
a[RYVHUhJ5Q9>bdR5`l80`000@@:4AXU<Cm=GFemSIf]^lWFhN_cnOgooogilncR
elZm[Yj?OViNCd4c9a`B2`D100021PdE7RXfA5=RLX:BX[6ocMWTkOCjo_oooOWb
jn7FbKb]WXinKUm?@C@W7A<<1P8000862a<L9c=0Cei]OHfM[;[8e>3YlOSlooon
noK_i]c@`kJWV8QhJ5U:?C0T6Q4:1@4000873A@N:CE2D5m_OXjM[;_8e>3YlOSl
ooonnoO`j=kBa[RZVhalKEe?@C@X7A@<1P8000442Q4I8blkBEMVMHFDXk;0cMSS
k??ioOooo_[ek^KLd<BfZ9V:Nf]LCT0c9adD30H2000110T@628]>DIDHg:1TJ2^
_<WEh>Wamocooooln?;ZhMK:_K2QTX=dIEI8>blS6Q4:1@4000852Q4J92lkB5IU
M8>BXJnmb]GPjO7go?kooochl^_Rf<c0/ZBFQgQYFT`o<RLM50d70`000@<83QHO
:CE1Cee[NXVHY[C2c]WSk??ioOooo_cglNWPe/Zn/J>DQGMXFT`n<RLM50d70`00
00<73A@M9c8oC5YXMXFDX[2mb]GPjO3fnokooogim>gUg=75^:^MSX1aHeE7>blT
6Q8;1P80004420hE7RPd@4eJJ7N5U::`_LWEgnS`m__nooonn_G_imkDb;b_XI>5
MVQJC3lc:1hF3PP40@000PD:4ATR;CQ4DEm]NhZHY[?0c=OQjO7gnokooogjmNoW
g]?8_:nRU8EgJE]>@CDZ81L?2@D1000110T?5QlY=41<FVMePi:O[K[6dMcUkOCi
oOoooochlncTfm35^JbNTH=eIeU<?c@Y7aH?2@@1000110T>5QhX<ci;F6EcPHnM
Z[O3c]WRjo;gnokooogjmNoXgmG;_k>VV8YlKf5DAc/`9A`D3@P30@000PD:41LP
:CA0C5UVM8:?WJZg`lkIh^[amo_nooonnoKaj^7HcL:fZIb?PG=VFDa0=2XP5a0:
1@8000431``B6R<]>4A@GFYhQI>P[KW5d=[Sjo;gnokoookkm_7ZhMS>`kNZWY23
MFQKCT8f;28I4P`60`0000852Q0G7bTc?TYGHg5nS9VV/[k:e=kVk_Cio?oooogj
mNoXh=O<`KFYW8n2M6MJCT8g;28J4P`70`4000852@lE7BH`>dMCH6ejQiBQ[[[5
d=[Sj_7gnokoookln??]iMgCbKjbYIV<OW5TF4]0=BXQ6A4;1P<100021@T>5AdV
<3Y6DEi[N8FBWZ^g`/gGh>S_mOWmoooooO[el>WQf<k3^:bPThIiK61CAc`a9alG
40X50P0000852P\>"]},
  ImageCacheContents->"Sound"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
WindowSize->{584, 698},
WindowMargins->{{14, Automatic}, {Automatic, 7}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"], 
    "*c"->SubscriptBox[ "*", "\[ScriptC]"], 
    "<c"->SubscriptBox[ "\[Precedes]", "\[ScriptC]"], 
    "<=c"->SubscriptBox[ "\[PrecedesSlantEqual]", "\[ScriptC]"], 
    ">=c"->SubscriptBox[ "\[SucceedsSlantEqual]", "\[ScriptC]"], 
    ">c"->SubscriptBox[ "\[Succeeds]", "\[ScriptC]"], 
    "function"->RowBox[ {"\[Placeholder]", 
        TagBox[ 
          SubscriptBox[ "&", "\[Placeholder]"], functionTag]}], 
    "<>?"->SubscriptBox[ "\[LeftArrowRightArrow]", "?"], "tensh"->TagBox[ 
        RowBox[ {
          TagBox[ "\[Placeholder]", "TensorName", TagStyle -> "TensorName"], 
          StyleBox[ 
            AdjustmentBox[ 
              TagBox[ 
                GridBox[ {{"\[Placeholder]"}, {"\[VeryThinSpace]"}}], 
                "TensorIndices", TagStyle -> "TensorIndices"], 
              BoxBaselineShift -> -0.44999998807907104], "TensorIndices"]}], 
        "Tensor", TagStyle -> "TensorWrapper", SyntaxForm -> "symbol"], 
    "tensl"->TagBox[ 
        RowBox[ {
          TagBox[ "\[Placeholder]", "TensorName", TagStyle -> "TensorName"], 
          StyleBox[ 
            AdjustmentBox[ 
              TagBox[ 
                GridBox[ {{"\[VeryThinSpace]"}, {"\[Placeholder]"}}], 
                "TensorIndices", TagStyle -> "TensorIndices"], 
              BoxBaselineShift -> -0.44999998807907104], "TensorIndices"]}], 
        "Tensor", TagStyle -> "TensorWrapper", SyntaxForm -> "symbol"], 
    "tenshh"->TagBox[ 
        RowBox[ {
          TagBox[ "\[Placeholder]", "TensorName", TagStyle -> "TensorName"], 
          StyleBox[ 
            AdjustmentBox[ 
              TagBox[ 
                
                GridBox[ {{"\[Placeholder]", "\[Placeholder]"}, {
                  "\[VeryThinSpace]", "\[VeryThinSpace]"}}], "TensorIndices", 
                TagStyle -> "TensorIndices"], 
              BoxBaselineShift -> -0.44999998807907104], "TensorIndices"]}], 
        "Tensor", TagStyle -> "TensorWrapper", SyntaxForm -> "symbol"], 
    "tenshl"->TagBox[ 
        RowBox[ {
          TagBox[ "\[Placeholder]", "TensorName", TagStyle -> "TensorName"], 
          StyleBox[ 
            AdjustmentBox[ 
              TagBox[ 
                GridBox[ {{"\[Placeholder]", "\[VeryThinSpace]"}, {
                  "\[VeryThinSpace]", "\[Placeholder]"}}], "TensorIndices", 
                TagStyle -> "TensorIndices"], 
              BoxBaselineShift -> -0.44999998807907104], "TensorIndices"]}], 
        "Tensor", TagStyle -> "TensorWrapper", SyntaxForm -> "symbol"], 
    "tensll"->TagBox[ 
        RowBox[ {
          TagBox[ "\[Placeholder]", "TensorName", TagStyle -> "TensorName"], 
          StyleBox[ 
            AdjustmentBox[ 
              TagBox[ 
                
                GridBox[ {{"\[VeryThinSpace]", "\[VeryThinSpace]"}, {
                  "\[Placeholder]", "\[Placeholder]"}}], "TensorIndices", 
                TagStyle -> "TensorIndices"], 
              BoxBaselineShift -> -0.44999998807907104], "TensorIndices"]}], 
        "Tensor", TagStyle -> "TensorWrapper", SyntaxForm -> "symbol"], 
    "tenshhh"->TagBox[ 
        RowBox[ {
          TagBox[ "\[Placeholder]", "TensorName", TagStyle -> "TensorName"], 
          StyleBox[ 
            AdjustmentBox[ 
              TagBox[ 
                
                GridBox[ {{"\[Placeholder]", "\[Placeholder]", 
                  "\[Placeholder]"}, {"\[VeryThinSpace]", "\[VeryThinSpace]", 
                  "\[VeryThinSpace]"}}], "TensorIndices", TagStyle -> 
                "TensorIndices"], BoxBaselineShift -> -0.44999998807907104], 
            "TensorIndices"]}], "Tensor", TagStyle -> "TensorWrapper", 
        SyntaxForm -> "symbol"], "tenshll"->TagBox[ 
        RowBox[ {
          TagBox[ "\[Placeholder]", "TensorName", TagStyle -> "TensorName"], 
          StyleBox[ 
            AdjustmentBox[ 
              TagBox[ 
                
                GridBox[ {{"\[Placeholder]", "\[VeryThinSpace]", 
                  "\[VeryThinSpace]"}, {"\[VeryThinSpace]", "\[Placeholder]", 
                  "\[Placeholder]"}}], "TensorIndices", TagStyle -> 
                "TensorIndices"], BoxBaselineShift -> -0.44999998807907104], 
            "TensorIndices"]}], "Tensor", TagStyle -> "TensorWrapper", 
        SyntaxForm -> "symbol"], "tenshhl"->TagBox[ 
        RowBox[ {
          TagBox[ "\[Placeholder]", "TensorName", TagStyle -> "TensorName"], 
          StyleBox[ 
            AdjustmentBox[ 
              TagBox[ 
                
                GridBox[ {{"\[Placeholder]", "\[Placeholder]", 
                  "\[VeryThinSpace]"}, {"\[VeryThinSpace]", 
                  "\[VeryThinSpace]", "\[Placeholder]"}}], "TensorIndices", 
                TagStyle -> "TensorIndices"], 
              BoxBaselineShift -> -0.44999998807907104], "TensorIndices"]}], 
        "Tensor", TagStyle -> "TensorWrapper", SyntaxForm -> "symbol"], 
    "tenslll"->TagBox[ 
        RowBox[ {
          TagBox[ "\[Placeholder]", "TensorName", TagStyle -> "TensorName"], 
          StyleBox[ 
            AdjustmentBox[ 
              TagBox[ 
                
                GridBox[ {{"\[VeryThinSpace]", "\[VeryThinSpace]", 
                  "\[VeryThinSpace]"}, {"\[Placeholder]", "\[Placeholder]", 
                  "\[Placeholder]"}}], "TensorIndices", TagStyle -> 
                "TensorIndices"], BoxBaselineShift -> -0.44999998807907104], 
            "TensorIndices"]}], "Tensor", TagStyle -> "TensorWrapper", 
        SyntaxForm -> "symbol"], "tenshhhh"->TagBox[ 
        RowBox[ {
          TagBox[ "\[Placeholder]", "TensorName", TagStyle -> "TensorName"], 
          StyleBox[ 
            AdjustmentBox[ 
              TagBox[ 
                
                GridBox[ {{"\[Placeholder]", "\[Placeholder]", 
                  "\[Placeholder]", "\[Placeholder]"}, {"\[VeryThinSpace]", 
                  "\[VeryThinSpace]", "\[VeryThinSpace]", 
                  "\[VeryThinSpace]"}}], "TensorIndices", TagStyle -> 
                "TensorIndices"], BoxBaselineShift -> -0.44999998807907104], 
            "TensorIndices"]}], "Tensor", TagStyle -> "TensorWrapper", 
        SyntaxForm -> "symbol"], "tenshhhl"->TagBox[ 
        RowBox[ {
          TagBox[ "\[Placeholder]", "TensorName", TagStyle -> "TensorName"], 
          StyleBox[ 
            AdjustmentBox[ 
              TagBox[ 
                
                GridBox[ {{"\[Placeholder]", "\[Placeholder]", 
                  "\[Placeholder]", "\[VeryThinSpace]"}, {"\[VeryThinSpace]", 
                  "\[VeryThinSpace]", "\[VeryThinSpace]", "\[Placeholder]"}}],
                 "TensorIndices", TagStyle -> "TensorIndices"], 
              BoxBaselineShift -> -0.44999998807907104], "TensorIndices"]}], 
        "Tensor", TagStyle -> "TensorWrapper", SyntaxForm -> "symbol"], 
    "tenshhll"->TagBox[ 
        RowBox[ {
          TagBox[ "\[Placeholder]", "TensorName", TagStyle -> "TensorName"], 
          StyleBox[ 
            AdjustmentBox[ 
              TagBox[ 
                
                GridBox[ {{"\[Placeholder]", "\[Placeholder]", 
                  "\[VeryThinSpace]", "\[VeryThinSpace]"}, {
                  "\[VeryThinSpace]", "\[VeryThinSpace]", "\[Placeholder]", 
                  "\[Placeholder]"}}], "TensorIndices", TagStyle -> 
                "TensorIndices"], BoxBaselineShift -> -0.44999998807907104], 
            "TensorIndices"]}], "Tensor", TagStyle -> "TensorWrapper", 
        SyntaxForm -> "symbol"], "tenshlll"->TagBox[ 
        RowBox[ {
          TagBox[ "\[Placeholder]", "TensorName", TagStyle -> "TensorName"], 
          StyleBox[ 
            AdjustmentBox[ 
              TagBox[ 
                
                GridBox[ {{"\[Placeholder]", "\[VeryThinSpace]", 
                  "\[VeryThinSpace]", "\[VeryThinSpace]"}, {
                  "\[VeryThinSpace]", "\[Placeholder]", "\[Placeholder]", 
                  "\[Placeholder]"}}], "TensorIndices", TagStyle -> 
                "TensorIndices"], BoxBaselineShift -> -0.44999998807907104], 
            "TensorIndices"]}], "Tensor", TagStyle -> "TensorWrapper", 
        SyntaxForm -> "symbol"], "tensllll"->TagBox[ 
        RowBox[ {
          TagBox[ "\[Placeholder]", "TensorName", TagStyle -> "TensorName"], 
          StyleBox[ 
            AdjustmentBox[ 
              TagBox[ 
                
                GridBox[ {{"\[VeryThinSpace]", "\[VeryThinSpace]", 
                  "\[VeryThinSpace]", "\[VeryThinSpace]"}, {"\[Placeholder]", 
                  "\[Placeholder]", "\[Placeholder]", "\[Placeholder]"}}], 
                "TensorIndices", TagStyle -> "TensorIndices"], 
              BoxBaselineShift -> -0.44999998807907104], "TensorIndices"]}], 
        "Tensor", TagStyle -> "TensorWrapper", SyntaxForm -> "symbol"]},
StyleDefinitions -> "ThesisStyles.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000_X2@?oaonh32@9B10<5:0?l007m001804P0000036L9H000
0P800000003l000000000BL?00400@00000000000000000000000000003olOo^
0`T2DP00000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "3.0 Code"->{
    Cell[1717, 49, 70, 1, 36, "Subsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[2341, 66, 113, 1, 54, "Subsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[2457, 69, 149, 4, 50, "Subsubsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[2609, 75, 222, 5, 37, "CommentText",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[2834, 82, 336, 7, 57, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[3173, 91, 232, 5, 37, "CommentText",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[3408, 98, 416, 8, 72, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[3827, 108, 237, 5, 37, "CommentText",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[4067, 115, 298, 8, 42, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[4368, 125, 363, 9, 27, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[4734, 136, 76, 1, 34, "Subsubsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[4813, 139, 167, 4, 23, "CommentText",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[4983, 145, 709, 15, 72, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[5695, 162, 139, 4, 23, "CommentText",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[5837, 168, 608, 12, 42, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[6448, 182, 74, 1, 34, "Subsubsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[6525, 185, 174, 4, 23, "CommentText",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[6702, 191, 1112, 17, 72, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[7817, 210, 230, 5, 27, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[8050, 217, 77, 1, 34, "Subsubsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[8130, 220, 177, 4, 23, "CommentText",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[8310, 226, 267, 5, 27, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[8580, 233, 80, 1, 34, "Subsubsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[8663, 236, 478, 12, 66, "CommentText",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[9144, 250, 2664, 48, 207, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[11811, 300, 143, 4, 23, "CommentText",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[11957, 306, 603, 12, 57, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[12563, 320, 87, 1, 36, "Subsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[12653, 323, 90, 1, 34, "Subsubsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[15064, 375, 74, 1, 34, "Subsubsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[17205, 421, 91, 1, 34, "Subsubsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[19723, 477, 93, 1, 34, "Subsubsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[21968, 523, 93, 1, 34, "Subsubsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[26440, 612, 67, 1, 36, "Subsection",
      CellTags->{"3.0 Code", "4.0 Code"}]},
  "4.0 Code"->{
    Cell[1717, 49, 70, 1, 36, "Subsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[2341, 66, 113, 1, 54, "Subsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[2457, 69, 149, 4, 50, "Subsubsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[2609, 75, 222, 5, 37, "CommentText",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[2834, 82, 336, 7, 57, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[3173, 91, 232, 5, 37, "CommentText",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[3408, 98, 416, 8, 72, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[3827, 108, 237, 5, 37, "CommentText",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[4067, 115, 298, 8, 42, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[4368, 125, 363, 9, 27, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[4734, 136, 76, 1, 34, "Subsubsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[4813, 139, 167, 4, 23, "CommentText",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[4983, 145, 709, 15, 72, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[5695, 162, 139, 4, 23, "CommentText",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[5837, 168, 608, 12, 42, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[6448, 182, 74, 1, 34, "Subsubsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[6525, 185, 174, 4, 23, "CommentText",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[6702, 191, 1112, 17, 72, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[7817, 210, 230, 5, 27, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[8050, 217, 77, 1, 34, "Subsubsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[8130, 220, 177, 4, 23, "CommentText",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[8310, 226, 267, 5, 27, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[8580, 233, 80, 1, 34, "Subsubsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[8663, 236, 478, 12, 66, "CommentText",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[9144, 250, 2664, 48, 207, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[11811, 300, 143, 4, 23, "CommentText",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[11957, 306, 603, 12, 57, "Input",
      InitializationCell->True,
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[12563, 320, 87, 1, 36, "Subsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[12653, 323, 90, 1, 34, "Subsubsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[15064, 375, 74, 1, 34, "Subsubsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[17205, 421, 91, 1, 34, "Subsubsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[19723, 477, 93, 1, 34, "Subsubsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[21968, 523, 93, 1, 34, "Subsubsection",
      CellTags->{"3.0 Code", "4.0 Code"}],
    Cell[26440, 612, 67, 1, 36, "Subsection",
      CellTags->{"3.0 Code", "4.0 Code"}]},
  "Play"->{
    Cell[26728, 625, 149, 3, 42, "Input",
      CellTags->"Play"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"3.0 Code", 180926, 2768},
  {"4.0 Code", 184304, 2848},
  {"Play", 187678, 2928}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 70, 1, 36, "Subsection",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[1790, 52, 227, 5, 42, "Input",
  InitializationCell->True],
Cell[2020, 59, 318, 5, 42, "Input",
  InitializationCell->True],
Cell[2341, 66, 113, 1, 54, "Subsection",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[2457, 69, 149, 4, 50, "Subsubsection",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[2609, 75, 222, 5, 37, "CommentText",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[2834, 82, 336, 7, 57, "Input",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[3173, 91, 232, 5, 37, "CommentText",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[3408, 98, 416, 8, 72, "Input",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[3827, 108, 237, 5, 37, "CommentText",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[4067, 115, 298, 8, 42, "Input",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[4368, 125, 363, 9, 27, "Input",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[4734, 136, 76, 1, 34, "Subsubsection",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[4813, 139, 167, 4, 23, "CommentText",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[4983, 145, 709, 15, 72, "Input",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[5695, 162, 139, 4, 23, "CommentText",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[5837, 168, 608, 12, 42, "Input",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[6448, 182, 74, 1, 34, "Subsubsection",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[6525, 185, 174, 4, 23, "CommentText",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[6702, 191, 1112, 17, 72, "Input",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[7817, 210, 230, 5, 27, "Input",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[8050, 217, 77, 1, 34, "Subsubsection",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[8130, 220, 177, 4, 23, "CommentText",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[8310, 226, 267, 5, 27, "Input",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[8580, 233, 80, 1, 34, "Subsubsection",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[8663, 236, 478, 12, 66, "CommentText",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[9144, 250, 2664, 48, 207, "Input",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[11811, 300, 143, 4, 23, "CommentText",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[11957, 306, 603, 12, 57, "Input",
  InitializationCell->True,
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[12563, 320, 87, 1, 36, "Subsection",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[12653, 323, 90, 1, 34, "Subsubsection",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[12746, 326, 48, 0, 22, "CommentText"],
Cell[12797, 328, 797, 14, 87, "Input",
  InitializationCell->True],
Cell[13597, 344, 284, 5, 57, "Input",
  InitializationCell->True],
Cell[13884, 351, 589, 10, 42, "Input",
  InitializationCell->True],
Cell[14476, 363, 585, 10, 42, "Input",
  InitializationCell->True],
Cell[15064, 375, 74, 1, 34, "Subsubsection",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[15141, 378, 60, 0, 22, "CommentText"],
Cell[15204, 380, 488, 10, 42, "Input",
  InitializationCell->True],
Cell[15695, 392, 1507, 27, 177, "Input",
  InitializationCell->True],
Cell[17205, 421, 91, 1, 34, "Subsubsection",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[17299, 424, 392, 8, 66, "CommentText"],
Cell[17694, 434, 845, 15, 117, "Input",
  InitializationCell->True],
Cell[18542, 451, 786, 15, 87, "Input",
  InitializationCell->True],
Cell[19331, 468, 389, 7, 42, "Input",
  InitializationCell->True],
Cell[19723, 477, 93, 1, 34, "Subsubsection",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[19819, 480, 392, 8, 52, "CommentText"],
Cell[20214, 490, 1395, 23, 162, "Input",
  InitializationCell->True],
Cell[21612, 515, 353, 6, 42, "Input",
  InitializationCell->True],
Cell[21968, 523, 93, 1, 34, "Subsubsection",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[22064, 526, 392, 8, 52, "CommentText"],
Cell[22459, 536, 1388, 24, 162, "Input",
  InitializationCell->True],
Cell[23850, 562, 111, 3, 34, "Subsubsection"],
Cell[23964, 567, 2310, 38, 162, "Input",
  InitializationCell->True],
Cell[26277, 607, 160, 3, 27, "Input",
  InitializationCell->True],
Cell[26440, 612, 67, 1, 36, "Subsection",
  CellTags->{"3.0 Code", "4.0 Code"}],
Cell[26510, 615, 36, 0, 34, "Subsubsection"],
Cell[26549, 617, 154, 4, 42, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[26728, 625, 149, 3, 42, "Input",
  CellTags->"Play"],
Cell[26880, 630, 142529, 1890, 184, 33936, 475, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

