(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     23214,        755]*)
(*NotebookOutlinePosition[     51929,       1677]*)
(*  CellTagsIndexPosition[     51857,       1671]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Multilocus algebra", "Subsection"],

Cell[CellGroupData[{

Cell["Old notation", "Subsubsection"],

Cell[TextData[{
  "Convert from the old ",
  Cell[BoxData[
      \({i, \(j\^*\)}\)]],
  "notation - used still in DataManipulation"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Subsubsection"],

Cell["\<\
Add some notes on the references in \
ReferencesDocumentation.nb\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Links", "Subsubsection"],

Cell["\<\
Equations in the help files need to correspond to equations in the \
Kp et al. MS.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["PhenotypesDocumentation: Fit[]", "Subsubsection"],

Cell["Explain how to use Fit[] to find selection coefficients", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["QLE", "Subsubsection"],

Cell[TextData[{
  "Implement automatic calculation of QLE results.  This is ",
  StyleBox["almost ",
    FontSlant->"Italic"],
  "possible at present using the weak selection approximation under \
SlowChange[].  At least, include an example; ideally, allow a way to \
automatically keep only leading-order terms throughout."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Mutation", "Subsubsection"],

Cell[TextData[{
  "Mutation is not implemented, though it is described in \
Mutation~Documentation..  The most general framework would be to treat ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\[DoubleStruckI]\)]],
  " as a vector ({1,0,\[Ellipsis]} etc), so that mutation would appear as a \
set of matrix operators on the moments.  (This is more-or-less trivial for \
two alleles).  The difficulty is that this is the one point where the \
internal structure ofthe disequilibria is involved. With two alleles per \
locus, we just have a factor ",
  Cell[BoxData[
      \(TraditionalForm\`\((1 - u\_i - v\_i)\), \ 
      which\ could\ be\ specified\)]],
  "using a list of the ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{
            FormBox[\({\[Ellipsis] {u\_i, v\_i\),
              "TraditionalForm"], ")"}], "\[Ellipsis]"}], "}"}]]],
  ".  For the more general vector structure, we would have a matrix operator \
for each locus, so that associations would look like: ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Product]\+\(i \[Element] U\)M\_i)\) \
\[GothicCapitalD]\_\[DoubleStruckCapitalU]\)]],
  ".  these could be left unevaluated until the end of the calculation; if \
specific tensor forms for the \[GothicCapitalD] were given, they would be \
linear operations on those \[GothicCapitalD]'s.."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Multiple alleles", "Subsubsection"],

Cell[TextData[{
  "Most of the package is independent of the nature of the ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\[DoubleStruckI]\)]],
  ".  With multiple alleles, these are most naturally written as indicator \
vectors {0,0,1,\[Ellipsis]}, so that the \[GothicCapitalD] become tensors.  \
The reduction formula analogous to Biallelic[] is then trivially ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(X\_\[DoubleStruckI]\%2 = X\_\[DoubleStruckI]\),
            "TraditionalForm"], 
          ",", \(\(X\_\[DoubleStruckI]\) Y\_\[DoubleStruckI] = 
            0\ if\ X\_\[DoubleStruckI] \[NotEqual] Y\_\[DoubleStruckI]\)}], 
        TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[GothicCapitalD]\_\({\(\(\[DoubleStruckI]\)\(.\)\), \
\[DoubleStruckI]}\[Vee]\[DoubleStruckCapitalU]\)\), "=", 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                RowBox[{"(", 
                  RowBox[{\(2  \[GothicM]\_\[DoubleStruckI]\), "-", 
                    StyleBox["1",
                      FontWeight->"Bold"]}], 
                  ")"}]}], \(\[GothicCapitalD]\_\({\[DoubleStruckI]}\[Vee]\
\[DoubleStruckCapitalU]\)\)}], "+", 
            RowBox[{
              RowBox[{\(\[GothicM]\_\[DoubleStruckI]\), "(", 
                RowBox[{
                  StyleBox["1",
                    FontWeight->"Bold"], "-", 
                  FormBox[\(\[GothicM]\_\[DoubleStruckI]\),
                    "TraditionalForm"]}], ")"}], 
              FormBox[\(\[GothicCapitalD]\_\[DoubleStruckCapitalU]\),
                "TraditionalForm"]}]}]}], TraditionalForm]]],
  ", where ",
  StyleBox["1",
    FontWeight->"Bold"],
  " is a vector of 1's.  Selecion coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicA]\_\[DoubleStruckCapitalU]\)]],
  " are tensors with the same structure as the \[GothicCapitalD], and just \
combine as a dot product.  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Servedio example", "Subsubsection"],

Cell["\<\
Include this at a higher level in the browser and give a better \
title.
Include definition of HaploidFitnessSet (omitted at present)\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Random drift", "Subsubsection",
  CellTags->"To do"],

Cell[TextData[{
  "Rules for changing reference points, Recombination[] and Selection[] need \
to act on the \[GothicCapitalC] appropriately. This should be \
straightforward: ChangeContext[] already acts correctly.  Selection[] will \
need to be restricted: the \[GothicA] in general are not polynomial \
functions.  The best course might be to introduce associations between the \
\[GothicCapitalD] and the selection coefficients, which are generated in a \
general way by Selection[], and add rules which relate selection coefficients \
to the \[GothicCapitalD] at appropriate stages.  A rule could be given which \
transforms ",
  Cell[BoxData[
      \(TraditionalForm\`\[GothicCapitalC]\_\({{\[DoubleStruckCapitalA]}, \
\[Ellipsis]}, {{\[DoubleStruckI]}, \[Ellipsis]}, \[Ellipsis]\)\)]],
  " when functions ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " are specified in terms of other functions."
}], "Text"],

Cell["\<\
The WrightFisherSampling[] rule needs to be given as a sum over \
partitions, weighted by NumberOfSamplePartitions[].  For each partition, the \
association involves \[GothicCapitalD] with the corresponding structure (see \
above).  An option for SlowChange can be given, that keeps only terms O(1/N). \
 Idealy, there would be the possibility of different population sizes in \
different demes/genetic backgrounds.., in the same way theat recombination \
and selection can depend on context. \
\>", "Text"],

Cell["\<\
An example needs to be worked through:
- the change in associations across one generation of migration and drift
- approximations for slow change
- cumulative change across many generations; solve for the equilibrium.\
\>", \
"Text"],

Cell["\<\
Explanation of the simplification that comes from the diffusion \
limit, where only the variance generated by drift need be considered.\
\>", \
"Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Cytoplasmic inheritance", "Subsubsection"],

Cell["\<\
In CytoplasmicDoc.nb, compare the results with Asmussen et al's, \
and link to a revised verison of the paper with MO\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Composition", "Subsubsection"],

Cell["\<\
Include derivation of the composition scheme, with examples with \
and without reduction rules for repeated elements.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["ShortContext", "Subsubsection"],

Cell["\<\
ShortContext[] would allow more efficient evaluation of some \
functions, but is not used much at present.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Arbitrary sums", "Subsubsection"],

Cell["\<\
With a good deal of work, it might be possible to allow the \
machinery to work with arbitrary sums and hence derive general expressions.\
\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Biallelic", "Subsubsection"],

Cell[TextData[{
  "I extended Biallelic to simplify ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\(\(\[DoubleStruckI]\)\(\ \)\)\ and\ \[Zeta]\_\
\[DoubleStruckI]\)]],
  ", which is necessary when defining selection coefficients.  However, I \
have not extended the application of Biallelic to population disequilibria, \
which seems a bit more complicated."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Summing over large sets", "Subsubsection"],

Cell[TextData[{
  "Selection[] uses ",
  StyleBox[" ",
    FontWeight->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(\[DoubleStruckCapitalU] \[SubsetEqual] \
\[DoubleStruckCapitalW]\)\[GothicA]\_\[DoubleStruckCapitalU]\)]],
  "to sum over all distinct subsets.  This can be inefficient when there are \
many elements in \[DoubleStruckCapitalW] ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(~\)\(2\^n\))\) . \ \ A\ more\ efficient\ \
solution\ would\ be\ to\ specify\ \((perha\)\)]],
  "ps optionally) the set of coefficients that are actually needed."
}], "Text"],

Cell["\<\
Subsets[\[DoubleStruckCapitalW]] is quite slow, and so it would be \
much more efficient to either store this, or use a smaller # of coefficients. \
 One possibility might be to use MakeFitness Set as a list of relevant \
subsets...\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Selfing & paternal inheritance", "Subsubsection"],

Cell["\<\
This is needed to complete the comparison with Asmussen & Orive. I \
have implemented it, but not made it context- or genotype-dependent.   Also, \
treating the chloroplasts as Y-linked is not really adequate - a bodge.  \
Paternal inheritance needs to be included formally in  NonMendelian[].\
\>", \
"Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Sex", "Subsubsection"],

Cell["\<\
Sex need not be specified for diploid stages, though SexOfOrigin \
must be.  Sexless diploid stages may not work with all the functions, as they \
were not written with that possibility in mind.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["UnlinkedRecombination", "Subsubsection"],

Cell["\<\
Need to add options for sex linkage etc, and a new routine to allow \
for a linear map.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Applying rules", "Subsubsection"],

Cell["\<\
There are still some problems with rules blocking later rules.  \
This shows up in the Servedio example, where //.rules does not always \
completely reduce expressions.  It mjay be better practice to keep control by \
using /. successively.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Reference points", "Subsubsection"],

Cell["\<\
Selection[] does not allow change of reference points, which can \
cause much complication.  The drawback with allowing a change in reference \
point is that it requires a lot of unnecessary calculation of disequilibria, \
which may be inefficient.  Should be included as an option, though.\
\>", \
"Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Possible bug (MK)", "Subsubsection"],

Cell["See notebook from Mark K Assortment problem.nb", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Packages within packages", "Subsubsection"],

Cell["\<\
There was an obscure problem in Multilocus.nb: since I changed \
Subsets to use the Combinatorica routine, the option Subsets->True was not \
recognised within packages such as this.  Therefore, \
AddUp[\[Ellipsis],Subsets->True] is interpreted mistakenly as AddUp[\
\[Ellipsis],Multilocus`Multilocus`Private`Subsets->True] leading to errors.  \
There is no difficulty outside packages.  The problem seemed to be that \
within the package, the set manipulation extensions were not available (a \
problem that has come up elsewhere).  I have fixed this by using <<package; \
within the private parts - but this should not be necessary.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["PC implementation", "Subsubsection"],

Cell["\<\
On PCs, <<Multilocus`Multilocus` (at least) hangs up. This can be \
fixed by evaluating initialisation from within Multilocus.nb, but the problem \
remains.\
\>", "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Structured Models", "Subsection"],

Cell["\<\
There is an obscure bug relating to use of \\; saving using \
PackageSaver gives a syntax error in Module[] yet evaluation of cells \
directly does not.
This bug seems to have gone away, but there may be an obscure syntax problem \
lurking....\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Estimating D", "Subsection"],

Cell[CellGroupData[{

Cell["Lost documentation", "Subsubsection"],

Cell["\<\
Some of the example output mysteriously vanished; I have retreived \
it from the stuffed folder in Archives (5.4.01)\
\>", "Text"],

Cell["\<\
On the G4 in my office, some documentation files lost styling - yet \
they seem OK on the Powerbook.  The default style sheet just needs to be set \
to \"Help Browser\"\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Many loci", "Subsubsection"],

Cell["\<\
The routines at present only work with up to (say) 6 loci because \
they enumerate all genotype frequnecies.  It should be possible to work with \
the frequencies of only observed genotypes.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Multiple alleles", "Subsubsection"],

Cell["\<\
See notebook & emails to Mir 9/02.  Need to extend the package to \
the case where there are arbitrary (but known) allele frequencies in the two \
source populations\
\>", "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Numerical models", "Subsection"],

Cell["\<\
** Simulation of individuals does not work at present.  There was a \
fatal bug in MigrateExact, such that m=Nm/n was not defined properly.  I have \
put in a rough fix, but the recursion still fails; and I have not checked the \
compiled version (March 03)\
\>", "Text"],

Cell["\<\
Allow for frequency dependence in IterateExact etc, using \
W[p][i][X,Y] etc.  In principle, this could be used to implement truncation \
selection, but in practice would be clumsy.\
\>", "Text"],

Cell["\<\
Write compiled versions of individual iterations. It is impossible \
to store offspring distributions for all possible genotypes, so one must \
write compiled versions of NewGametes and RandomFamily, which will allow for \
linkage.\
\>", "Text"],

Cell["\<\
Include truncation selection in FrequencyRepresentations \
(nontrivial), and in SelectionExact, where fitness is supplied as a \
list.\
\>", "Text"],

Cell["\<\
Include TruncationSelection as an option in IterateExact, and \
compile\
\>", "Text"],

Cell["\<\
Allow an option for IterateExact which makes an allele frequency \
table; works out if any loci are fixed; runs IterateExact without those loci \
(but with a modified fitness table/function and Linkage option); and then \
reconstructs the population.  This would give a large saving if a fair \
fraction of loci were fixed; could invoke if (say) more than 10% of loci were \
fixed. Must ensure it is not used if there is mutation.   IgnoreFixedLoci->k \
would invoke the rule if more than k loci were fixed.\
\>", "Text"],

Cell["\<\
Mutation is not at present implemented in SymmetricNeutralModels or \
in the compiled versions of IterateExact.\
\>", "Text"],

Cell[TextData[{
  "Allow for migration of (say) constant numbers of individuals in a more \
natural way (see ",
  ButtonBox["notes)",
    ButtonData:>{"Allele frequencies: migration", "Constant numbers"},
    ButtonStyle->"AddOnsLink"]
}], "Text"],

Cell["\<\
Add to MakePopulation[] the option used in Paternity Analysis March \
2002: one can construct a population with specified F, D using the negative \
hypergeometric model. Could extend to allow allele frequencies to differ \
across loci, but not easily.  \
\>", "Text"],

Cell["\<\
Possible problem with symmetric model: different answers with and \
without a neutrallocus added.  See Introgression.nb\
\>", "Text"],

Cell["\<\
Extend MakePopulation to allow linkage disequilibrium and \
heterozygote deficit.  See makePop in documentation for checking family \
moment estmation for how to do this with the symmetric model.  Note that it \
is not easy to construct heterozygote deficit using the symmetric model: a \
fraction of gametes ibd would violate the assumption that classes of genotype \
are equivalent.\
\>", "Text"],

Cell["\<\
Further work in March '03: a compiled version of individual \
iterations is half-written, but really NewGametes[] must be compiled for this \
to work.  The present code will fail for large numbers of loci because the \
gamete table cannot be stored: there are too many possible genotypes.  So, an \
option is needed that avoids storing GameteTable - which will need a major \
reorganisation of the code.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Genealogies", "Subsection"],

Cell["Include a way of plotting the ancestral graph.", "Text"],

Cell["GenealogiesToAncestralGraph should be possible", "Text"],

Cell["Change NodeFunction to InformationFunction", "Text"],

Cell["Allow for mutation at specified sites", "Text"],

Cell[CellGroupData[{

Cell["Recombination", "Subsubsection"],

Cell["\<\
Complete coalescent with recombination, trying to keep functions as \
far as possible similar.  Include the  generating function, and if possible, \
inference of ancestral graphs from mutations.\
\>", "Text"],

Cell[TextData[{
  "** The algorithms might be improved by using Interval[].  I have written a \
simple forwards simulation in this way in ",
  ButtonBox["Fixation of the genome.nb",
    ButtonData:>{
      FrontEnd`FileName[ {
        ParentDirectory[ 
          ParentDirectory[ 
            ParentDirectory[ 
              ParentDirectory[ 
                ParentDirectory[ ]]]]], "Manuscripts", "Ancestry"}, 
        "Fixation of the genome.nb", CharacterEncoding -> "MacintoshRoman"], 
      None},
    ButtonStyle->"Hyperlink"],
  " which generates distributions of blocks sizes."
}], "Text"],

Cell[TextData[{
  "** There may be a bug in ExtractGenealogies - see ",
  ButtonBox["SimulatingCwR.nb",
    ButtonData:>{
      FrontEnd`FileName[ {
        ParentDirectory[ 
          ParentDirectory[ 
            ParentDirectory[ 
              ParentDirectory[ 
                ParentDirectory[ 
                  ParentDirectory[ ]]]]]], "Manuscripts", 
        "Hitchiking of the genome"}, "SimulatingCwR.nb", CharacterEncoding -> 
        "MacintoshRoman"], "ExtractGenealogy bug"},
    ButtonStyle->"Hyperlink"],
  ".  When the graph has not yet fixed, it seems to fail to produce multiple \
roots"
}], "Text"],

Cell["\<\
Descendants is extremely slow for ancestral graphs. This may be \
inevitable, because the number of descendants grows exponentially.  But maybe \
interval arihmetic would make it more effecient.\
\>", "Text"],

Cell[TextData[{
  "Implement mutation-related functions as for genealogies - see ",
  ButtonBox["SimulatingCwR.nb",
    ButtonData:>{
      FrontEnd`FileName[ {
        ParentDirectory[ 
          ParentDirectory[ 
            ParentDirectory[ 
              ParentDirectory[ 
                ParentDirectory[ 
                  ParentDirectory[ ]]]]]], "Manuscripts", 
        "Hitchiking of the genome"}, "SimulatingCwR.nb", CharacterEncoding -> 
        "MacintoshRoman"], "ExtractGenealogy bug"},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["To do on GriffithsTavare", "Subsubsection"],

Cell["\<\
CheckGenealogy[] should verify that a certain set of mutations is \
consistent with the infinite-sites model: FindNode[] does not do a full \
check.\
\>", "Text"],

Cell["\<\
ExactProbability[] could be greatly speeded up by just calculating \
the mgf for relevant variables as one goes back - at present the full mgf is \
used, which is highly inefficient.\
\>", "Text"],

Cell["\<\
MonteCarloGriffithsTavare[] might be speeded up by compiling it.  \
\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MSc class", "Subsubsection"],

Cell["\<\
Index new functions in Genealogies (include DeleteNullLineages \
extension)\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cross-package & general issues", "Subsection"],

Cell[CellGroupData[{

Cell["Combinatorica", "Subsubsection"],

Cell["\<\
Genealogies` needs to be extended to include ConfigurationSet, \
which involves Compositions, loaded from Combinatorica.  There is an \
unavoivable clash between Ordering (used in Combinatorica and in Statistics) \
but clashes with Subsets and IncidenceMatrix could be avoided.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Notation package", "Subsubsection"],

Cell["There is a way of not loading the Palette - see web page", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conflicts between packages", "Subsubsection"],

Cell["\<\
PossibleGenotypes[] and PossibleDiploidGenotypes[]: ideally, these \
would be combined in a single function\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Error messages", "Subsubsection"],

Cell["\<\
The best way to handle erors is to define tags f::err=\"\", and \
then call them using Message[].  In some of the older packages, Print[] is \
used instead: should be changed.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HTML help", "Subsubsection"],

Cell[TextData[{
  "Ideally, the help files would all be converted to HTML and set up on the \
web, so that non-",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " people could view it.  ",
  StyleBox["MathReader",
    FontSlant->"Italic"],
  " wouldn't allow Rebuild Help Index.. to be used to set up the help files \
properly."
}], "Text"]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1276}, {0, 832}},
WindowSize->{562, 713},
WindowMargins->{{Automatic, 66}, {0, Automatic}},
Visible->True,
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.
Make modifications to any definition using commands in the Format menu.\
\>", 
    "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellLabel->False,
    ImageSize->{200, 200},
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellFrame->{{0, 0}, {0, 0.25}},
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->9,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LineSpacing->{0.95, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->36],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{18, 30}, {4, 0}},
    CellFrameMargins->4,
    FontSize->30]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{18, 30}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{18, 30}, {0, 10}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->3,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{18, 30}, {4, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{18, 30}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{18, 30}, {4, 12}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 2},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{55, 50}, {5, 5}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontSize->10],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{55, 55}, {5, 2}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{55, 10}, {5, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    ShowCellLabel->False,
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{55, 10}, {8, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelPositioning->Left,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{55, 55}, {10, 10}},
    ShowCellLabel->False,
    FontSize->9.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[LongDash]",
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{55, 55}, {0, 3}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{26, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 72}, {2, 10}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{55, 55}, {0, 15}},
    ImageSize->{0.0625, 0.0625},
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Oblique"],
  
  Cell[StyleData["CellLabel", "Printout"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{45, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{36, Inherited}, {2, 30}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{45, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{36, Inherited}, {2, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{18, 40}, {2, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Reference", "Printout"],
    CellMargins->{{18, 40}, {Inherited, 0}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{55, 10}, {0, 10}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{55, 145}, {2, 10}},
    CellHorizontalScrolling->True,
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{55, 145}, {2, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{55, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{18, 10}, {Inherited, 6}},
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{18, 30}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "To do"->{
    Cell[6662, 209, 58, 1, 24, "Subsubsection",
      CellTags->"To do"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"To do", 51757, 1664}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 40, 0, 42, "Subsection"],

Cell[CellGroupData[{
Cell[1841, 57, 37, 0, 32, "Subsubsection"],
Cell[1881, 59, 143, 5, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2061, 69, 35, 0, 24, "Subsubsection"],
Cell[2099, 71, 88, 3, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2224, 79, 30, 0, 24, "Subsubsection"],
Cell[2257, 81, 106, 3, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2400, 89, 55, 0, 24, "Subsubsection"],
Cell[2458, 91, 71, 0, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2566, 96, 28, 0, 24, "Subsubsection"],
Cell[2597, 98, 336, 7, 54, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2970, 110, 33, 0, 24, "Subsubsection"],
Cell[3006, 112, 1348, 28, 144, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4391, 145, 41, 0, 24, "Subsubsection"],
Cell[4435, 147, 1952, 46, 84, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6424, 198, 41, 0, 24, "Subsubsection"],
Cell[6468, 200, 157, 4, 38, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6662, 209, 58, 1, 24, "Subsubsection",
  CellTags->"To do"],
Cell[6723, 212, 922, 17, 108, "Text"],
Cell[7648, 231, 517, 8, 80, "Text"],
Cell[8168, 241, 243, 6, 66, "Text"],
Cell[8414, 249, 161, 4, 38, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8612, 258, 48, 0, 24, "Subsubsection"],
Cell[8663, 260, 141, 3, 38, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8841, 268, 36, 0, 24, "Subsubsection"],
Cell[8880, 270, 141, 3, 38, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9058, 278, 37, 0, 24, "Subsubsection"],
Cell[9098, 280, 130, 3, 38, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9265, 288, 39, 0, 24, "Subsubsection"],
Cell[9307, 290, 163, 4, 38, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9507, 299, 34, 0, 24, "Subsubsection"],
Cell[9544, 301, 371, 8, 52, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9952, 314, 48, 0, 24, "Subsubsection"],
Cell[10003, 316, 581, 13, 53, "Text"],
Cell[10587, 331, 256, 5, 38, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[10880, 341, 55, 0, 24, "Subsubsection"],
Cell[10938, 343, 319, 6, 52, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[11294, 354, 28, 0, 24, "Subsubsection"],
Cell[11325, 356, 218, 4, 38, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[11580, 365, 46, 0, 24, "Subsubsection"],
Cell[11629, 367, 111, 3, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[11777, 375, 39, 0, 24, "Subsubsection"],
Cell[11819, 377, 264, 5, 52, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[12120, 387, 41, 0, 24, "Subsubsection"],
Cell[12164, 389, 316, 6, 52, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[12517, 400, 42, 0, 24, "Subsubsection"],
Cell[12562, 402, 62, 0, 24, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[12661, 407, 49, 0, 24, "Subsubsection"],
Cell[12713, 409, 658, 10, 108, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[13408, 424, 42, 0, 24, "Subsubsection"],
Cell[13453, 426, 180, 4, 38, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[13682, 436, 39, 0, 26, "Subsection"],
Cell[13724, 438, 267, 6, 52, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[14028, 449, 34, 0, 26, "Subsection"],

Cell[CellGroupData[{
Cell[14087, 453, 43, 0, 32, "Subsubsection"],
Cell[14133, 455, 140, 3, 38, "Text"],
Cell[14276, 460, 192, 4, 38, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[14505, 469, 34, 0, 24, "Subsubsection"],
Cell[14542, 471, 214, 4, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14793, 480, 41, 0, 32, "Subsubsection"],
Cell[14837, 482, 189, 4, 42, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[15075, 492, 38, 0, 26, "Subsection"],
Cell[15116, 494, 281, 5, 58, "Text"],
Cell[15400, 501, 205, 4, 42, "Text"],
Cell[15608, 507, 255, 5, 58, "Text"],
Cell[15866, 514, 158, 4, 42, "Text"],
Cell[16027, 520, 95, 3, 26, "Text"],
Cell[16125, 525, 531, 8, 90, "Text"],
Cell[16659, 535, 135, 3, 42, "Text"],
Cell[16797, 540, 247, 6, 26, "Text"],
Cell[17047, 548, 277, 5, 58, "Text"],
Cell[17327, 555, 143, 3, 42, "Text"],
Cell[17473, 560, 408, 7, 74, "Text"],
Cell[17884, 569, 427, 7, 74, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[18348, 581, 33, 0, 26, "Subsection"],
Cell[18384, 583, 62, 0, 26, "Text"],
Cell[18449, 585, 62, 0, 26, "Text"],
Cell[18514, 587, 58, 0, 26, "Text"],
Cell[18575, 589, 53, 0, 26, "Text"],

Cell[CellGroupData[{
Cell[18653, 593, 38, 0, 32, "Subsubsection"],
Cell[18694, 595, 218, 4, 42, "Text"],
Cell[18915, 601, 597, 15, 42, "Text"],
Cell[19515, 618, 617, 16, 42, "Text"],
Cell[20135, 636, 218, 4, 42, "Text"],
Cell[20356, 642, 550, 15, 26, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20943, 662, 49, 0, 32, "Subsubsection"],
Cell[20995, 664, 172, 4, 42, "Text"],
Cell[21170, 670, 206, 4, 42, "Text"],
Cell[21379, 676, 92, 3, 26, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21508, 684, 34, 0, 32, "Subsubsection"],
Cell[21545, 686, 99, 3, 26, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21693, 695, 52, 0, 42, "Subsection"],

Cell[CellGroupData[{
Cell[21770, 699, 38, 0, 32, "Subsubsection"],
Cell[21811, 701, 301, 5, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22149, 711, 41, 0, 32, "Subsubsection"],
Cell[22193, 713, 72, 0, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22302, 718, 51, 0, 32, "Subsubsection"],
Cell[22356, 720, 131, 3, 38, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22524, 728, 39, 0, 32, "Subsubsection"],
Cell[22566, 730, 199, 4, 38, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22802, 739, 34, 0, 32, "Subsubsection"],
Cell[22839, 741, 347, 10, 56, "Text"]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

